/* Generated by Cython 3.0.5 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "cPyparsing",
        "sources": [
            "cPyparsing.pyx"
        ]
    },
    "module_name": "cPyparsing"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_5" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x030005F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PY_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info; // borrowed
        #endif
        PyObject *py_minor_version = NULL;
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11; // we don't yet need to distinguish between versions > 11
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        Py_XDECREF(py_minor_version);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);  // we don't have access to __pyx_empty_bytes here
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE(obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__cPyparsing
#define __PYX_HAVE_API__cPyparsing
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const wchar_t *u)
{
    const wchar_t *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#endif
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else  // Py < 3.12
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "cPyparsing.pyx",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException;
struct __pyx_defaults;
typedef struct __pyx_defaults __pyx_defaults;
struct __pyx_defaults1;
typedef struct __pyx_defaults1 __pyx_defaults1;
struct __pyx_defaults2;
typedef struct __pyx_defaults2 __pyx_defaults2;
struct __pyx_defaults3;
typedef struct __pyx_defaults3 __pyx_defaults3;
struct __pyx_defaults4;
typedef struct __pyx_defaults4 __pyx_defaults4;
struct __pyx_defaults5;
typedef struct __pyx_defaults5 __pyx_defaults5;
struct __pyx_defaults6;
typedef struct __pyx_defaults6 __pyx_defaults6;
struct __pyx_defaults7;
typedef struct __pyx_defaults7 __pyx_defaults7;
struct __pyx_defaults8;
typedef struct __pyx_defaults8 __pyx_defaults8;
struct __pyx_defaults9;
typedef struct __pyx_defaults9 __pyx_defaults9;
struct __pyx_defaults10;
typedef struct __pyx_defaults10 __pyx_defaults10;
struct __pyx_defaults11;
typedef struct __pyx_defaults11 __pyx_defaults11;
struct __pyx_defaults {
  PyObject *__pyx_arg_isinstance;
};
struct __pyx_defaults1 {
  PyObject *__pyx_arg_isinstance;
};
struct __pyx_defaults2 {
  PyObject *__pyx_arg_maxMatches;
};
struct __pyx_defaults3 {
  PyObject *__pyx_arg_maxMatches;
};
struct __pyx_defaults4 {
  PyObject *__pyx_arg_maxsplit;
};
struct __pyx_defaults5 {
  PyObject *__pyx_arg_wordChars;
};
struct __pyx_defaults6 {
  PyObject *__pyx_arg_wordChars;
};
struct __pyx_defaults7 {
  PyObject *__pyx_arg_default;
};
struct __pyx_defaults8 {
  PyObject *__pyx_arg_suppress_LT;
  PyObject *__pyx_arg_suppress_GT;
};
struct __pyx_defaults9 {
  PyObject *__pyx_arg_lpar;
  PyObject *__pyx_arg_rpar;
};
struct __pyx_defaults10 {
  PyObject *__pyx_arg_ignoreExpr;
};
struct __pyx_defaults11 {
  PyObject *__pyx_arg_exc_type;
};

/* "cPyparsing.pyx":230
 * # [CPYPARSING] custom list_str
 * def list_str(l):
 *     return "[" + ", ".join(repr(x) for x in l) + "]"             # <<<<<<<<<<<<<<
 * 
 * _generatorType = type((y for y in range(1)))
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_x;
};


/* "cPyparsing.pyx":232
 *     return "[" + ", ".join(repr(x) for x in l) + "]"
 * 
 * _generatorType = type((y for y in range(1)))             # <<<<<<<<<<<<<<
 * 
 * def _xml_escape(data):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_y;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":239
 *     # ampersand must be replaced first
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())             # <<<<<<<<<<<<<<
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr {
  PyObject_HEAD
  PyObject *__pyx_v_s;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
};


/* "cPyparsing.pyx":249
 * alphanums = alphas + nums
 * _bslash = chr(92)
 * printables = "".join(c for c in string.printable if c not in string.whitespace)             # <<<<<<<<<<<<<<
 * 
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":252
 * 
 * 
 * def conditionAsParseAction(fn, message=None, fatal=False):             # <<<<<<<<<<<<<<
 *     msg = message if message is not None else "failed user-defined condition"
 *     exc_type = ParseFatalException if fatal else ParseException
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction {
  PyObject_HEAD
  PyObject *__pyx_v_exc_type;
  PyObject *__pyx_v_fn;
  PyObject *__pyx_v_msg;
};


/* "cPyparsing.pyx":669
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":670
 * 
 *     def _itervalues(self):
 *         return (self[k] for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     def _iteritems(self):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_k;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":672
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":673
 * 
 *     def _iteritems(self):
 *         return ((k, self[k]) for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     if PY_3:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_k;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":863
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__ {
  PyObject_HEAD
  Py_ssize_t __pyx_v_offset;
};


/* "cPyparsing.pyx":891
 * 
 *     def __str__(self):
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'             # <<<<<<<<<<<<<<
 * 
 *     def _asStringList(self, sep=''):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_i;
};


/* "cPyparsing.pyx":921
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict {
  PyObject_HEAD
  PyObject *__pyx_v_toItem;
};


/* "cPyparsing.pyx":955
 *                 return obj
 * 
 *         return dict((k, toItem(v)) for k, v in item_fn())             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_k;
  PyObject *__pyx_v_v;
};


/* "cPyparsing.pyx":975
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_k;
  PyObject *__pyx_v_v;
  PyObject *__pyx_v_vlist;
};


/* "cPyparsing.pyx":1107
 *         if full:
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())             # <<<<<<<<<<<<<<
 *                 for k, v in items:
 *                     if out:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_k;
  PyObject *__pyx_v_v;
};


/* "cPyparsing.pyx":1119
 *                     else:
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):             # <<<<<<<<<<<<<<
 *                 v = self
 *                 for i, vv in enumerate(v):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_vv;
};


/* "cPyparsing.pyx":1296
 * # this version is Python 2.x-3.x cross-compatible
 * 'decorator to trim function calls to match the arity of the target'
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity {
  PyObject_HEAD
  PyObject *__pyx_v_extract_tb;
  PyObject *__pyx_v_foundArity;
  PyObject *__pyx_v_func;
  PyObject *__pyx_v_limit;
  PyObject *__pyx_v_maxargs;
  PyObject *__pyx_v_pa_call_line_synth;
};


/* "cPyparsing.pyx":1635
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set ``breakFlag`` to True to enable, False to
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak {
  PyObject_HEAD
  PyObject *__pyx_v__parseMethod;
};


/* "cPyparsing.pyx":1697
 *             self.parseAction = []
 *         else:
 *             if not all(callable(fn) for fn in fns):             # <<<<<<<<<<<<<<
 *                 raise TypeError("parse actions must be callable")
 *             self.parseAction = list(map(_trim_arity, list(fns)))
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_fn;
};


/* "cPyparsing.pyx":2532
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString {
  PyObject_HEAD
  PyObject *__pyx_v_e;
  PyObject *__pyx_v_exc;
  PyObject *__pyx_v_instring;
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_v_loc;
  long __pyx_v_matches;
  PyObject *__pyx_v_maxMatches;
  PyObject *__pyx_v_nextLoc;
  PyObject *__pyx_v_nextloc;
  PyObject *__pyx_v_overlap;
  PyObject *__pyx_v_parseFn;
  PyObject *__pyx_v_preloc;
  PyObject *__pyx_v_preparseFn;
  PyObject *__pyx_v_self;
  PyObject *__pyx_v_tokens;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
  PyObject *__pyx_t_3;
  PyObject *__pyx_t_4;
  PyObject *__pyx_t_5;
};


/* "cPyparsing.pyx":2686
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split {
  PyObject_HEAD
  PyObject *__pyx_v_e;
  PyObject *__pyx_v_includeSeparators;
  PyObject *__pyx_v_instring;
  PyObject *__pyx_v_last;
  PyObject *__pyx_v_maxsplit;
  PyObject *__pyx_v_s;
  PyObject *__pyx_v_self;
  long __pyx_v_splits;
  PyObject *__pyx_v_t;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":2788
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of ``expr * 3`` in place of
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ {
  PyObject_HEAD
  PyObject *__pyx_v_makeOptionalList;
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":2816
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):
 *             other = tuple(o if o is not Ellipsis else None for o in other)             # <<<<<<<<<<<<<<
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_o;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":3374
 *         self.must_skip = must_skip
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3763
 *         csv_value = Word(printables, excludeChars=",")
 *     """
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_excludeChars;
};


/* "cPyparsing.pyx":3767
 *         if excludeChars:
 *             excludeChars = set(excludeChars)
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":3769
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":4108
 *         return self.strRepr
 * 
 *     def sub(self, repl):             # <<<<<<<<<<<<<<
 *         r"""
 *         Return Regex with an attached parse action to transform the parsed
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub {
  PyObject_HEAD
  PyObject *__pyx_v_repl;
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":4176
 *         [['This is the quote with "embedded" quotes']]
 *     """
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False,             # <<<<<<<<<<<<<<
 *                  unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):
 *         super(QuotedString, self).__init__()
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":4216
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_i;
};


/* "cPyparsing.pyx":4458
 *         u'\u3000': '<IDEOGRAPHIC_SPACE>',
 *         }
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":4461
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))             # <<<<<<<<<<<<<<
 *         # ~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":4463
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 *         # ~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Expected " + self.name
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":4693
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":4705
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 *             if any(isinstance(expr, basestring) for expr in exprs):             # <<<<<<<<<<<<<<
 *                 # [CPYPARSING] use map not iterator
 *                 exprs = map(lambda e: self._literalStringClass(e) if isinstance(e, basestring) else e, exprs)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_expr;
};


/* "cPyparsing.pyx":4888
 *             exprs[:] = tmp
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":4896
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)             # <<<<<<<<<<<<<<
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":4908
 * 
 *         super(And, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":4986
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5011
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5018
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5092
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5104
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5134
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5141
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5235
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5247
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5318
 *     def __init__(self, exprs, savelist=True):
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.initExprGroups = True
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5325
 *     def streamline(self):
 *         super(Each, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5330
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))             # <<<<<<<<<<<<<<
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, (Optional, Regex))]
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5363
 * 
 *         if tmpReqd:
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":5382
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":6340
 *         self.called = False
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """Decorator for debugging parse actions.
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction {
  PyObject_HEAD
  PyObject *__pyx_v_f;
};


/* "cPyparsing.pyx":6409
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """Helper to define a counted list of expressions.
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray {
  PyObject_HEAD
  PyObject *__pyx_v_arrayExpr;
  PyObject *__pyx_v_expr;
};


/* "cPyparsing.pyx":6454
 *     return ret
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral {
  PyObject_HEAD
  PyObject *__pyx_v_rep;
};


/* "cPyparsing.pyx":6477
 *                 # flatten t tokens
 *                 tflat = _flatten(t.asList())
 *                 rep << And(Literal(tt) for tt in tflat)             # <<<<<<<<<<<<<<
 *         else:
 *             rep << Empty()
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_tt;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":6484
 *     return rep
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr {
  PyObject_HEAD
  PyObject *__pyx_v_rep;
};


/* "cPyparsing.pyx":6502
 *     e2 = expr.copy()
 *     rep <<= e2
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *__pyx_outer_scope;
  PyObject *__pyx_v_matchTokens;
};


/* "cPyparsing.pyx":6521
 *     return _ustr(s)
 * 
 * def oneOf(strs, caseless=False, useRegex=True, asKeyword=False):             # <<<<<<<<<<<<<<
 *     """Helper to quickly define a set of alternative Literals, and makes
 *     sure to do longest-first testing when there is a conflict,
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf {
  PyObject_HEAD
  PyObject *__pyx_v_parseElementClass;
};


/* "cPyparsing.pyx":6598
 *         try:
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_sym;
};


/* "cPyparsing.pyx":6600
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_sym;
};


/* "cPyparsing.pyx":6606
 * 
 *     # last resort, just use MatchFirst
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 * 
 * def dictOf(key, value):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_sym;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":6738
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""Helper to easily define string ranges for use in Word
 *     construction. Borrows syntax from regexp '[]' string range
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange {
  PyObject_HEAD
  PyObject *__pyx_v__expanded;
};


/* "cPyparsing.pyx":6764
 *        ``'a-zA-Z0-9_$'``, etc.)
 *     """
 *     _expanded = lambda p: p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":6766
 *     _expanded = lambda p: p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         return ""
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_part;
};


/* "cPyparsing.pyx":6770
 *         return ""
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """Helper method for defining parse actions that require matching at
 *     a specific column in the input text.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol {
  PyObject_HEAD
  PyObject *__pyx_v_n;
};


/* "cPyparsing.pyx":6779
 *     return verifyCol
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """Helper method for common parse actions that simply return
 *     a literal value.  Especially useful when used with
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith {
  PyObject_HEAD
  PyObject *__pyx_v_replStr;
};


/* "cPyparsing.pyx":6809
 *     return t[0][1:-1]
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """Helper to define a parse action by mapping a function to all
 *     elements of a ParseResults list. If any additional args are passed,
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap {
  PyObject_HEAD
  PyObject *__pyx_v_args;
  PyObject *__pyx_v_func;
};


/* "cPyparsing.pyx":6865
 * Deprecated in favor of :class:`pyparsing_common.downcaseTokens`"""
 * 
 * def _makeTags(tagStr, xml,             # <<<<<<<<<<<<<<
 *               suppress_LT=Suppress("<"),
 *               suppress_GT=Suppress(">")):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags {
  PyObject_HEAD
  PyObject *__pyx_v_resname;
};


/* "cPyparsing.pyx":6938
 *     ANY_VALUE = object()
 * 
 *     def __call__(self, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         """Helper to create a validating parse action to be used with start
 *         tags created with :class:`makeXMLTags` or
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ {
  PyObject_HEAD
  PyObject *__pyx_v_attrs;
};


/* "cPyparsing.pyx":7296
 *     return ret
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """Helper method for defining space-delimited indentation blocks,
 *     such as those used to define block statements in Python source code.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock {
  PyObject_HEAD
  PyObject *__pyx_v_backup_stack;
  PyObject *__pyx_v_indentStack;
  PyObject *__pyx_v_reset_stack;
};


/* "cPyparsing.pyx":7661
 *                            + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 *                            ).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)             # <<<<<<<<<<<<<<
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_tt;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":7669
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDate(fmt="%Y-%m-%d"):
 *         """
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate {
  PyObject_HEAD
  PyObject *__pyx_v_fmt;
};


/* "cPyparsing.pyx":7694
 *         return cvt_fn
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):
 *         """Helper to create a parse action for converting parsed
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime {
  PyObject_HEAD
  PyObject *__pyx_v_fmt;
};


/* "cPyparsing.pyx":7769
 *         self.__name__ = fn.__name__
 * 
 *     def __get__(self, obj, cls):             # <<<<<<<<<<<<<<
 *         if cls is None:
 *             cls = type(obj)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ {
  PyObject_HEAD
  PyObject *__pyx_v_cls;
};


/* "cPyparsing.pyx":7772
 *         if cls is None:
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])             # <<<<<<<<<<<<<<
 *                                               for superclass in cls.__mro__[1:]):
 *             cls._intern = {}
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_superclass;
};


/* "cPyparsing.pyx":8058
 *                     # an empty tuple will skip any result validation
 *                     fail_msg = next(
 *                         (exp for exp in expected if isinstance(exp, str)), None             # <<<<<<<<<<<<<<
 *                     )
 *                     expected_exception = next(
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_exp;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":8062
 *                     expected_exception = next(
 *                         (
 *                             exp             # <<<<<<<<<<<<<<
 *                             for exp in expected
 *                             if isinstance(exp, type) and issubclass(exp, Exception)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_exp;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":8076
 *                     else:
 *                         expected_list = next(
 *                             (exp for exp in expected if isinstance(exp, list)), None             # <<<<<<<<<<<<<<
 *                         )
 *                         expected_dict = next(
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_exp;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":8079
 *                         )
 *                         expected_dict = next(
 *                             (exp for exp in expected if isinstance(exp, dict)), None             # <<<<<<<<<<<<<<
 *                         )
 *                         if (expected_list, expected_dict) != (None, None):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_exp;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":8097
 *             )
 * 
 *         @contextmanager             # <<<<<<<<<<<<<<
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException {
  PyObject_HEAD
  PyObject *__pyx_v_exc_type;
  PyObject *__pyx_v_msg;
  PyObject *__pyx_v_self;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
  PyObject *__pyx_t_3;
};

/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg // no-op
    #define __Pyx_Arg_XDECREF_VARARGS(arg) // no-op - arg is borrowed
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    static CYTHON_UNUSED PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg // no-op, __Pyx_Arg_FASTCALL is direct and this needs
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)  // no-op - arg was returned from array
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right)
    #endif
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_ConcatInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_ConcatInPlaceSafe(left, right) ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_ConcatInPlace(left, right))

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseClosureNameError.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchInspect.proto */
static PyObject* __Pyx_patch_inspect(PyObject* module);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* pyfrozenset_new.proto */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* PySetContains.proto */
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* HasAttr.proto */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* PyObjectCall2Args.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* SliceObject.proto */
#define __Pyx_PyObject_DelSlice(obj, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)\
    __Pyx_PyObject_SetSlice(obj, (PyObject*)NULL, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)
static CYTHON_INLINE int __Pyx_PyObject_SetSlice(
        PyObject* obj, PyObject* value, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* IterNext.proto */
#define __Pyx_PyIter_Next(obj) __Pyx_PyIter_Next2(obj, NULL)
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject *, PyObject *);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* CallableCheck.proto */
#if CYTHON_USE_TYPE_SLOTS && PY_MAJOR_VERSION >= 3
#define __Pyx_PyCallable_Check(obj)   (Py_TYPE(obj)->tp_call != NULL)
#else
#define __Pyx_PyCallable_Check(obj)   PyCallable_Check(obj)
#endif

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* CallUnboundCMethod2.proto */
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_LshiftObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_LshiftObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceLshift(op1, op2) : PyNumber_Lshift(op1, op2))
#endif

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* DelItemInt.proto */
#define __Pyx_DelItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_DelItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_DelItem_Generic(o, to_py_func(i))))
static int __Pyx_DelItem_Generic(PyObject *o, PyObject *j);
static CYTHON_INLINE int __Pyx_DelItemInt_Fast(PyObject *o, Py_ssize_t i,
                                               int is_list, int wraparound);

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* UnicodeAsUCS4.proto */
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject*);

/* object_ord.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyObject_Ord(c)\
    (likely(PyUnicode_Check(c)) ? (long)__Pyx_PyUnicode_AsPy_UCS4(c) : __Pyx__PyObject_Ord(c))
#else
#define __Pyx_PyObject_Ord(c) __Pyx__PyObject_Ord(c)
#endif
static long __Pyx__PyObject_Ord(PyObject* c);

/* py_dict_items.proto */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* pop.proto */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L);
#define __Pyx_PyObject_Pop(L) (likely(PyList_CheckExact(L)) ?\
    __Pyx_PyList_Pop(L) : __Pyx__PyObject_Pop(L))
#else
#define __Pyx_PyList_Pop(L)  __Pyx__PyObject_Pop(L)
#define __Pyx_PyObject_Pop(L)  __Pyx__PyObject_Pop(L)
#endif

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* ClassMethod.proto */
#include "descrobject.h"
CYTHON_UNUSED static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* SetNewInClass.proto */
static int __Pyx_SetNewInClass(PyObject *ns, PyObject *name, PyObject *value);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_MultiplyObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceMultiply(op1, op2) : PyNumber_Multiply(op1, op2))
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* Common.proto */
static int __Pyx_check_twos_complement(void) {
    if ((-1) != (~0)) {
        PyErr_SetString(PyExc_RuntimeError, "Two's complement required for overflow checks.");
        return 1;
    } else if ((sizeof(short) == sizeof(int))) {
        PyErr_SetString(PyExc_RuntimeError, "sizeof(short) < sizeof(int) required for overflow checks.");
        return 1;
    } else {
        return 0;
    }
}
#define __PYX_SIGN_BIT(type)    ((((unsigned type) 1) << (sizeof(type) * 8 - 1)))
#define __PYX_HALF_MAX(type)    ((((type) 1) << (sizeof(type) * 8 - 2)))
#define __PYX_MIN(type)         ((__PYX_IS_UNSIGNED(type) ? (type) 0 : 0 - __PYX_HALF_MAX(type) - __PYX_HALF_MAX(type)))
#define __PYX_MAX(type)         ((~__PYX_MIN(type)))
#define __Pyx_add_no_overflow(a, b, overflow) ((a) + (b))
#define __Pyx_add_const_no_overflow(a, b, overflow) ((a) + (b))
#define __Pyx_sub_no_overflow(a, b, overflow) ((a) - (b))
#define __Pyx_sub_const_no_overflow(a, b, overflow) ((a) - (b))
#define __Pyx_mul_no_overflow(a, b, overflow) ((a) * (b))
#define __Pyx_mul_const_no_overflow(a, b, overflow) ((a) * (b))
#define __Pyx_div_no_overflow(a, b, overflow) ((a) / (b))
#define __Pyx_div_const_no_overflow(a, b, overflow) ((a) / (b))
#if defined(__has_builtin)
#  if __has_builtin(__builtin_add_overflow) && !defined(__ibmxl__)
#    define __PYX_HAVE_BUILTIN_OVERFLOW
#  endif
#elif defined(__GNUC__) && (__GNUC__ >= 5) && (!defined(__INTEL_COMPILER) || (__INTEL_COMPILER >= 1800))
#  define __PYX_HAVE_BUILTIN_OVERFLOW
#endif
#if defined(__GNUC__)
#  define __Pyx_is_constant(x) (__builtin_constant_p(x))
#elif defined(__has_builtin)
#  if __has_builtin(__builtin_constant_p)
#    define __Pyx_is_constant(x) (__builtin_constant_p(x))
#  endif
#else
#  define __Pyx_is_constant(x) (0)
#endif

/* BaseCaseSigned.proto */
static CYTHON_INLINE int __Pyx_add_int_checking_overflow(int a, int b, int *overflow);
static CYTHON_INLINE int __Pyx_sub_int_checking_overflow(int a, int b, int *overflow);
static CYTHON_INLINE int __Pyx_mul_int_checking_overflow(int a, int b, int *overflow);
static CYTHON_INLINE int __Pyx_div_int_checking_overflow(int a, int b, int *overflow);
#define __Pyx_add_const_int_checking_overflow __Pyx_add_int_checking_overflow
#define __Pyx_sub_const_int_checking_overflow __Pyx_sub_int_checking_overflow
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
#define __Pyx_mul_const_int_checking_overflow __Pyx_mul_int_checking_overflow
#else
static CYTHON_INLINE int __Pyx_mul_const_int_checking_overflow(int a, int constant, int *overflow);
#endif
#define __Pyx_div_const_int_checking_overflow __Pyx_div_int_checking_overflow

/* BaseCaseSigned.proto */
static CYTHON_INLINE long __Pyx_add_long_checking_overflow(long a, long b, int *overflow);
static CYTHON_INLINE long __Pyx_sub_long_checking_overflow(long a, long b, int *overflow);
static CYTHON_INLINE long __Pyx_mul_long_checking_overflow(long a, long b, int *overflow);
static CYTHON_INLINE long __Pyx_div_long_checking_overflow(long a, long b, int *overflow);
#define __Pyx_add_const_long_checking_overflow __Pyx_add_long_checking_overflow
#define __Pyx_sub_const_long_checking_overflow __Pyx_sub_long_checking_overflow
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
#define __Pyx_mul_const_long_checking_overflow __Pyx_mul_long_checking_overflow
#else
static CYTHON_INLINE long __Pyx_mul_const_long_checking_overflow(long a, long constant, int *overflow);
#endif
#define __Pyx_div_const_long_checking_overflow __Pyx_div_long_checking_overflow

/* BaseCaseSigned.proto */
#ifdef HAVE_LONG_LONG
static CYTHON_INLINE long long __Pyx_add_long_long_checking_overflow(long long a, long long b, int *overflow);
static CYTHON_INLINE long long __Pyx_sub_long_long_checking_overflow(long long a, long long b, int *overflow);
static CYTHON_INLINE long long __Pyx_mul_long_long_checking_overflow(long long a, long long b, int *overflow);
static CYTHON_INLINE long long __Pyx_div_long_long_checking_overflow(long long a, long long b, int *overflow);
#define __Pyx_add_const_long_long_checking_overflow __Pyx_add_long_long_checking_overflow
#define __Pyx_sub_const_long_long_checking_overflow __Pyx_sub_long_long_checking_overflow
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
#define __Pyx_mul_const_long_long_checking_overflow __Pyx_mul_long_long_checking_overflow
#else
static CYTHON_INLINE long long __Pyx_mul_const_long_long_checking_overflow(long long a, long long constant, int *overflow);
#endif
#define __Pyx_div_const_long_long_checking_overflow __Pyx_div_long_long_checking_overflow
#endif

/* BaseCaseUnsigned.proto */
static CYTHON_INLINE unsigned int __Pyx_add_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow);
static CYTHON_INLINE unsigned int __Pyx_sub_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow);
static CYTHON_INLINE unsigned int __Pyx_mul_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow);
static CYTHON_INLINE unsigned int __Pyx_div_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow);
#define __Pyx_add_const_unsigned_int_checking_overflow __Pyx_add_unsigned_int_checking_overflow
#define __Pyx_sub_const_unsigned_int_checking_overflow __Pyx_sub_unsigned_int_checking_overflow
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
#define __Pyx_mul_const_unsigned_int_checking_overflow __Pyx_mul_unsigned_int_checking_overflow
#else
static CYTHON_INLINE unsigned int __Pyx_mul_const_unsigned_int_checking_overflow(unsigned int a, unsigned int constant, int *overflow);
#endif
#define __Pyx_div_const_unsigned_int_checking_overflow __Pyx_div_unsigned_int_checking_overflow

/* BaseCaseUnsigned.proto */
static CYTHON_INLINE unsigned long __Pyx_add_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow);
static CYTHON_INLINE unsigned long __Pyx_sub_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow);
static CYTHON_INLINE unsigned long __Pyx_mul_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow);
static CYTHON_INLINE unsigned long __Pyx_div_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow);
#define __Pyx_add_const_unsigned_long_checking_overflow __Pyx_add_unsigned_long_checking_overflow
#define __Pyx_sub_const_unsigned_long_checking_overflow __Pyx_sub_unsigned_long_checking_overflow
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
#define __Pyx_mul_const_unsigned_long_checking_overflow __Pyx_mul_unsigned_long_checking_overflow
#else
static CYTHON_INLINE unsigned long __Pyx_mul_const_unsigned_long_checking_overflow(unsigned long a, unsigned long constant, int *overflow);
#endif
#define __Pyx_div_const_unsigned_long_checking_overflow __Pyx_div_unsigned_long_checking_overflow

/* BaseCaseUnsigned.proto */
static CYTHON_INLINE unsigned long long __Pyx_add_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow);
static CYTHON_INLINE unsigned long long __Pyx_sub_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow);
static CYTHON_INLINE unsigned long long __Pyx_mul_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow);
static CYTHON_INLINE unsigned long long __Pyx_div_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow);
#define __Pyx_add_const_unsigned_long_long_checking_overflow __Pyx_add_unsigned_long_long_checking_overflow
#define __Pyx_sub_const_unsigned_long_long_checking_overflow __Pyx_sub_unsigned_long_long_checking_overflow
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
#define __Pyx_mul_const_unsigned_long_long_checking_overflow __Pyx_mul_unsigned_long_long_checking_overflow
#else
static CYTHON_INLINE unsigned long long __Pyx_mul_const_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long constant, int *overflow);
#endif
#define __Pyx_div_const_unsigned_long_long_checking_overflow __Pyx_div_unsigned_long_long_checking_overflow

/* SizeCheck.proto */
static int __Pyx_check_sane_Py_ssize_t(void) {
    if (((sizeof(Py_ssize_t) <= sizeof(int)) ||
#ifdef HAVE_LONG_LONG
            (sizeof(Py_ssize_t) == sizeof(PY_LONG_LONG)) ||
#endif
            (sizeof(Py_ssize_t) == sizeof(long)))) {
        return 0;
    } else {
        PyErr_Format(PyExc_RuntimeError,\
            "Bad size for int type %.60s: %d", "Py_ssize_t", (int) sizeof(Py_ssize_t));
        return 1;
    }
}

/* Binop.proto */
static CYTHON_INLINE Py_ssize_t __Pyx_sub_const_Py_ssize_t_checking_overflow(Py_ssize_t a, Py_ssize_t b, int *overflow);

/* Binop.proto */
static CYTHON_INLINE Py_ssize_t __Pyx_sub_Py_ssize_t_checking_overflow(Py_ssize_t a, Py_ssize_t b, int *overflow);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CoroutineBase.proto */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */

/* Module declarations from "cPyparsing" */
static PyObject *__pyx_7genexpr__pyx_v_10cPyparsing_nm;
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "cPyparsing"
extern int __pyx_module_is_main_cPyparsing;
int __pyx_module_is_main_cPyparsing = 0;

/* Implementation of "cPyparsing" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_ImportError;
static PyObject *__pyx_builtin_chr;
static PyObject *__pyx_builtin_sum;
static PyObject *__pyx_builtin_sorted;
static PyObject *__pyx_builtin_reversed;
static PyObject *__pyx_builtin_any;
static PyObject *__pyx_builtin_all;
static PyObject *__pyx_builtin_min;
static PyObject *__pyx_builtin_max;
static PyObject *__pyx_builtin_xrange;
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_staticmethod;
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_zip;
static PyObject *__pyx_builtin_vars;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_NameError;
static PyObject *__pyx_builtin_map;
static PyObject *__pyx_builtin_SyntaxWarning;
static PyObject *__pyx_builtin_Ellipsis;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_super;
static PyObject *__pyx_builtin_SyntaxError;
static PyObject *__pyx_builtin_filter;
/* #### Code section: string_decls ### */
static const char __pyx_k_0[] = "{0}";
static const char __pyx_k_L[] = "L";
static const char __pyx_k_W[] = "W:(";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_b[] = "\\b";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_f[] = "\\f";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_j[] = "j";
static const char __pyx_k_k[] = "k";
static const char __pyx_k_l[] = "l";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_o[] = "o";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_s[] = "s";
static const char __pyx_k_t[] = "t";
static const char __pyx_k_u[] = "u";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_z[] = "z";
static const char __pyx_k_0x[] = "\\0x";
static const char __pyx_k_CR[] = "<CR>";
static const char __pyx_k_FB[] = "_FB";
static const char __pyx_k_FF[] = "<FF>";
static const char __pyx_k_LF[] = "<LF>";
static const char __pyx_k_NL[] = "NL";
static const char __pyx_k_Or[] = "Or";
static const char __pyx_k_SP[] = "<SP>";
static const char __pyx_k__2[] = "[";
static const char __pyx_k__3[] = ", ";
static const char __pyx_k__4[] = "]";
static const char __pyx_k__5[] = "&";
static const char __pyx_k__6[] = ";";
static const char __pyx_k__7[] = "&><\"'";
static const char __pyx_k_cc[] = "cc";
static const char __pyx_k_e2[] = "e2";
static const char __pyx_k_eq[] = "__eq__";
static const char __pyx_k_ff[] = "ff";
static const char __pyx_k_fn[] = "fn";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_ne[] = "__ne__";
static const char __pyx_k_nl[] = "nl";
static const char __pyx_k_on[] = "on";
static const char __pyx_k_or[] = "__or__";
static const char __pyx_k_p1[] = "p1";
static const char __pyx_k_p2[] = "p2";
static const char __pyx_k_pa[] = "pa";
static const char __pyx_k_pe[] = "pe";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_rr[] = "rr";
static const char __pyx_k_se[] = "se";
static const char __pyx_k_tb[] = "tb";
static const char __pyx_k_to[] = "to_";
static const char __pyx_k_ve[] = "ve";
static const char __pyx_k_vv[] = "vv";
static const char __pyx_k_ws[] = "ws";
static const char __pyx_k_wt[] = "wt";
static const char __pyx_k_0_1[] = "{0}: {1}";
static const char __pyx_k_0_2[] = "... [{0}]";
static const char __pyx_k_And[] = "And";
static const char __pyx_k_BOM[] = "BOM";
static const char __pyx_k_CJK[] = "CJK";
static const char __pyx_k_HIT[] = "HIT";
static const char __pyx_k_L_2[] = "_L";
static const char __pyx_k_TAB[] = "<TAB>";
static const char __pyx_k_TRY[] = "TRY";
static const char __pyx_k_W_s[] = "W:(%s)";
static const char __pyx_k__10[] = "";
static const char __pyx_k__11[] = "\\\\";
static const char __pyx_k__12[] = "\\";
static const char __pyx_k__13[] = ")";
static const char __pyx_k__14[] = ">!<";
static const char __pyx_k__15[] = "*";
static const char __pyx_k__16[] = " ";
static const char __pyx_k__17[] = "^";
static const char __pyx_k__19[] = "\n";
static const char __pyx_k__22[] = "(";
static const char __pyx_k__25[] = "  ";
static const char __pyx_k__26[] = "<";
static const char __pyx_k__27[] = ">";
static const char __pyx_k__28[] = "</";
static const char __pyx_k__29[] = "- ";
static const char __pyx_k__30[] = ": ";
static const char __pyx_k__31[] = "]:\n";
static const char __pyx_k__34[] = ",";
static const char __pyx_k__35[] = " -> ";
static const char __pyx_k__65[] = "#";
static const char __pyx_k__66[] = "\357\273\277";
static const char __pyx_k__67[] = "...";
static const char __pyx_k__79[] = "]*";
static const char __pyx_k__80[] = "][";
static const char __pyx_k__91[] = "[^";
static const char __pyx_k__94[] = "(?:[^";
static const char __pyx_k__95[] = "|(?:";
static const char __pyx_k__96[] = ")|(?:";
static const char __pyx_k__97[] = "(.)";
static const char __pyx_k__98[] = "\t";
static const char __pyx_k__99[] = "\014";
static const char __pyx_k_add[] = "__add__";
static const char __pyx_k_all[] = "all";
static const char __pyx_k_and[] = "__and__";
static const char __pyx_k_any[] = "any";
static const char __pyx_k_b_2[] = "b";
static const char __pyx_k_chr[] = "chr";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_col[] = "col";
static const char __pyx_k_cpy[] = "cpy";
static const char __pyx_k_cur[] = "cur";
static const char __pyx_k_d_2[] = "[+-]?\\d+";
static const char __pyx_k_dir[] = "__dir__";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_err[] = "err";
static const char __pyx_k_exc[] = "exc";
static const char __pyx_k_f_2[] = "f";
static const char __pyx_k_fmt[] = "fmt";
static const char __pyx_k_fns[] = "fns";
static const char __pyx_k_frm[] = "frm";
static const char __pyx_k_g_1[] = "\\g<1>";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_hit[] = "hit";
static const char __pyx_k_ind[] = "ind";
static const char __pyx_k_ior[] = "__ior__";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_len[] = "(len) ";
static const char __pyx_k_loc[] = "loc";
static const char __pyx_k_map[] = "map";
static const char __pyx_k_mat[] = "mat";
static const char __pyx_k_max[] = "max";
static const char __pyx_k_min[] = "min";
static const char __pyx_k_mro[] = "__mro__";
static const char __pyx_k_msg[] = "msg";
static const char __pyx_k_mul[] = "__mul__";
static const char __pyx_k_n_2[] = "\\n";
static const char __pyx_k_n_n[] = "//(?:\\\\\\n|[^\\n])*";
static const char __pyx_k_n_r[] = "\\n\\r";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_out[] = "out";
static const char __pyx_k_par[] = "par";
static const char __pyx_k_pbe[] = "pbe";
static const char __pyx_k_pdb[] = "pdb";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_r_2[] = "\\r";
static const char __pyx_k_ref[] = "ref";
static const char __pyx_k_rep[] = "rep";
static const char __pyx_k_req[] = "__req__";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_ret[] = "ret";
static const char __pyx_k_rne[] = "__rne__";
static const char __pyx_k_ror[] = "__ror__";
static const char __pyx_k_rpt[] = "rpt";
static const char __pyx_k_s_2[] = "\"%s\"";
static const char __pyx_k_s_3[] = "'%s'";
static const char __pyx_k_s_4[] = "[%s]+";
static const char __pyx_k_s_5[] = "[%s]";
static const char __pyx_k_s_6[] = "|(?:%s)";
static const char __pyx_k_s_7[] = "|(?:%s.)";
static const char __pyx_k_s_8[] = ")*%s";
static const char __pyx_k_s_9[] = "<%s>";
static const char __pyx_k_s_S[] = "<!--[\\s\\S]*?-->";
static const char __pyx_k_s_m[] = "s_m";
static const char __pyx_k_sep[] = "sep";
static const char __pyx_k_set[] = "set";
static const char __pyx_k_src[] = "src";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sub[] = "sub";
static const char __pyx_k_sum[] = "sum";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_t_2[] = "\\t";
static const char __pyx_k_tag[] = "tag";
static const char __pyx_k_tmp[] = "tmp";
static const char __pyx_k_tok[] = "tok";
static const char __pyx_k_tup[] = "tup";
static const char __pyx_k_xml[] = "xml";
static const char __pyx_k_xor[] = "__xor__";
static const char __pyx_k_zip[] = "zip";
static const char __pyx_k_Char[] = "Char";
static const char __pyx_k_Dict[] = "Dict";
static const char __pyx_k_Each[] = "Each";
static const char __pyx_k_FAIL[] = "FAIL";
static const char __pyx_k_ITEM[] = "ITEM";
static const char __pyx_k_LEFT[] = "LEFT";
static const char __pyx_k_MISS[] = "MISS";
static const char __pyx_k_MMSP[] = "<MMSP>";
static const char __pyx_k_NBSP[] = "<NBSP>";
static const char __pyx_k_PEER[] = "PEER";
static const char __pyx_k_PY_3[] = "PY_3";
static const char __pyx_k_Re_s[] = "Re:(%s)";
static const char __pyx_k_Thai[] = "Thai";
static const char __pyx_k_UUID[] = "UUID";
static const char __pyx_k_Word[] = "Word";
static const char __pyx_k__100[] = "\r";
static const char __pyx_k__102[] = " \t\r\n";
static const char __pyx_k__104[] = ":(";
static const char __pyx_k__105[] = "-";
static const char __pyx_k__107[] = "{";
static const char __pyx_k__108[] = "}";
static const char __pyx_k__110[] = " ^ ";
static const char __pyx_k__111[] = " | ";
static const char __pyx_k__112[] = " & ";
static const char __pyx_k__113[] = "~{";
static const char __pyx_k__114[] = "}...";
static const char __pyx_k__115[] = "]...";
static const char __pyx_k__116[] = ": ...";
static const char __pyx_k__117[] = ".";
static const char __pyx_k__118[] = "', ";
static const char __pyx_k__119[] = ")\n";
static const char __pyx_k__122[] = " [";
static const char __pyx_k__136[] = "|";
static const char __pyx_k__144[] = "/";
static const char __pyx_k__145[] = ":";
static const char __pyx_k__147[] = "_-:";
static const char __pyx_k__148[] = "=";
static const char __pyx_k__150[] = "'";
static const char __pyx_k__166[] = "\t ";
static const char __pyx_k__339[] = " \n\t\r";
static const char __pyx_k__461[] = "_$";
static const char __pyx_k__511[] = "\302\240";
static const char __pyx_k__512[] = "\341\232\200";
static const char __pyx_k__513[] = "\341\240\216";
static const char __pyx_k__514[] = "\342\200\200";
static const char __pyx_k__515[] = "\342\200\201";
static const char __pyx_k__516[] = "\342\200\202";
static const char __pyx_k__517[] = "\342\200\203";
static const char __pyx_k__518[] = "\342\200\204";
static const char __pyx_k__519[] = "\342\200\205";
static const char __pyx_k__520[] = "\342\200\206";
static const char __pyx_k__521[] = "\342\200\207";
static const char __pyx_k__522[] = "\342\200\210";
static const char __pyx_k__523[] = "\342\200\211";
static const char __pyx_k__524[] = "\342\200\212";
static const char __pyx_k__525[] = "\342\200\213";
static const char __pyx_k__526[] = "\342\200\257";
static const char __pyx_k__527[] = "\342\201\237";
static const char __pyx_k__528[] = "\343\200\200";
static const char __pyx_k__621[] = "_";
static const char __pyx_k__718[] = "\\[]-*.$+^?()~ ";
static const char __pyx_k__721[] = "\\]";
static const char __pyx_k__755[] = "\"";
static const char __pyx_k__768[] = "_:";
static const char __pyx_k__770[] = "><& \"'";
static const char __pyx_k__771[] = ");";
static const char __pyx_k__774[] = "/\\*(?:[^*]|\\*(?!/))*";
static const char __pyx_k__776[] = "*/";
static const char __pyx_k__780[] = ".*";
static const char __pyx_k__786[] = "#.*";
static const char __pyx_k__789[] = " \t";
static const char __pyx_k__795[] = "::";
static const char __pyx_k__856[] = "\330\247\331\204\330\271\330\261\330\250\331\212\330\251";
static const char __pyx_k__857[] = "\344\270\255\346\226\207";
static const char __pyx_k__858[] = "\320\272\320\270\321\200\320\270\320\273\320\273\320\270\321\206\320\260";
static const char __pyx_k__859[] = "\316\225\316\273\316\273\316\267\316\275\316\271\316\272\316\254";
static const char __pyx_k__860[] = "\327\242\326\264\327\221\327\250\326\264\327\231\327\252";
static const char __pyx_k__861[] = "\346\227\245\346\234\254\350\252\236";
static const char __pyx_k__862[] = "\346\274\242\345\255\227";
static const char __pyx_k__863[] = "\343\202\253\343\202\277\343\202\253\343\203\212";
static const char __pyx_k__864[] = "\343\201\262\343\202\211\343\201\214\343\201\252";
static const char __pyx_k__865[] = "\355\225\234\352\265\255\354\226\264";
static const char __pyx_k__866[] = "\340\271\204\340\270\227\340\270\242";
static const char __pyx_k__867[] = "\340\244\246\340\245\207\340\244\265\340\244\250\340\244\276\340\244\227\340\244\260\340\245\200";
static const char __pyx_k__893[] = "?";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_body[] = "body";
static const char __pyx_k_bool[] = "__bool__";
static const char __pyx_k_call[] = "__call__";
static const char __pyx_k_code[] = "code";
static const char __pyx_k_copy[] = "copy";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_date[] = "date";
static const char __pyx_k_diag[] = "__diag__";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_dump[] = "dump";
static const char __pyx_k_elem[] = "elem";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_expr[] = "expr";
static const char __pyx_k_ffff[] = "::ffff:";
static const char __pyx_k_file[] = "file";
static const char __pyx_k_find[] = "find";
static const char __pyx_k_flag[] = "flag";
static const char __pyx_k_from[] = "from_";
static const char __pyx_k_full[] = "full";
static const char __pyx_k_func[] = "func";
static const char __pyx_k_hash[] = "__hash__";
static const char __pyx_k_iadd[] = "__iadd__";
static const char __pyx_k_ikey[] = "ikey";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_item[] = "item";
static const char __pyx_k_iter[] = "__iter__";
static const char __pyx_k_ixor[] = "__ixor__";
static const char __pyx_k_keys[] = "keys";
static const char __pyx_k_last[] = "last";
static const char __pyx_k_line[] = "line";
static const char __pyx_k_loc1[] = "loc1";
static const char __pyx_k_loc2[] = "loc2";
static const char __pyx_k_locn[] = "locn";
static const char __pyx_k_lpar[] = "lpar";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_nums[] = "nums";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_opt1[] = "opt1";
static const char __pyx_k_opt2[] = "opt2";
static const char __pyx_k_prev[] = "(prev) ";
static const char __pyx_k_pstr[] = "pstr";
static const char __pyx_k_radd[] = "__radd__";
static const char __pyx_k_rand[] = "__rand__";
static const char __pyx_k_read[] = "read";
static const char __pyx_k_real[] = "real";
static const char __pyx_k_repl[] = "repl";
static const char __pyx_k_repr[] = "repr";
static const char __pyx_k_rmul[] = "__rmul__";
static const char __pyx_k_rpar[] = "rpar";
static const char __pyx_k_rsub[] = "__rsub__";
static const char __pyx_k_rxor[] = "__rxor__";
static const char __pyx_k_s_10[] = "</%s>";
static const char __pyx_k_save[] = "save";
static const char __pyx_k_seen[] = "seen";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_sort[] = "sort";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_strg[] = "strg";
static const char __pyx_k_strs[] = "strs";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_tokn[] = "tokn";
static const char __pyx_k_toks[] = "toks";
static const char __pyx_k_ustr[] = "_ustr";
static const char __pyx_k_utf8[] = "utf8";
static const char __pyx_k_uuid[] = "uuid";
static const char __pyx_k_vars[] = "vars";
static const char __pyx_k_warn[] = "warn";
static const char __pyx_k_0_0_7[] = "\\\\0[0-7]+";
static const char __pyx_k_0_1_2[] = "{0}.{1} - {2}";
static const char __pyx_k_0_1_3[] = "{0}.{1}";
static const char __pyx_k_Empty[] = "Empty";
static const char __pyx_k_FATAL[] = "(FATAL)";
static const char __pyx_k_Greek[] = "Greek";
static const char __pyx_k_Group[] = "Group";
static const char __pyx_k_Kanji[] = "Kanji";
static const char __pyx_k_MATCH[] = "MATCH";
static const char __pyx_k_Match[] = "Match ";
static const char __pyx_k_NNBSP[] = "<NNBSP>";
static const char __pyx_k_RIGHT[] = "RIGHT";
static const char __pyx_k_RLock[] = "RLock";
static const char __pyx_k_Regex[] = "Regex";
static const char __pyx_k_Token[] = "Token";
static const char __pyx_k_W_s_2[] = "!W:(%s...)";
static const char __pyx_k_W_s_3[] = "!W:(%s)";
static const char __pyx_k_White[] = "White";
static const char __pyx_k_Y_m_d[] = "%Y-%m-%d";
static const char __pyx_k_all_2[] = "__all__";
static const char __pyx_k_aname[] = "aname";
static const char __pyx_k_arity[] = "arity";
static const char __pyx_k_asXML[] = "asXML";
static const char __pyx_k_attrs[] = "attrs";
static const char __pyx_k_b_s_b[] = "\\b%s\\b";
static const char __pyx_k_cache[] = "cache";
static const char __pyx_k_cause[] = "__cause__";
static const char __pyx_k_chars[] = "chars";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_clear[] = "clear";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_col_2[] = ", col:";
static const char __pyx_k_colno[] = "colno";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_d_d_d[] = "[+-]?(?:\\d+\\.\\d*|\\.\\d+)";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_delim[] = "delim";
static const char __pyx_k_depth[] = "depth";
static const char __pyx_k_deque[] = "deque";
static const char __pyx_k_dummy[] = "dummy";
static const char __pyx_k_empty[] = "empty";
static const char __pyx_k_ender[] = "ender";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_exact[] = "exact";
static const char __pyx_k_expr1[] = "expr1";
static const char __pyx_k_exprs[] = "exprs";
static const char __pyx_k_fatal[] = "fatal";
static const char __pyx_k_flags[] = "flags";
static const char __pyx_k_fname[] = "fname";
static const char __pyx_k_get_2[] = "__get__";
static const char __pyx_k_group[] = "group";
static const char __pyx_k_ident[] = "ident";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_lastE[] = "lastE";
static const char __pyx_k_len_2[] = "len";
static const char __pyx_k_len_3[] = "__len__";
static const char __pyx_k_limit[] = "limit";
static const char __pyx_k_lower[] = "lower";
static const char __pyx_k_masks[] = "masks";
static const char __pyx_k_match[] = "match";
static const char __pyx_k_modal[] = "modal";
static const char __pyx_k_mylen[] = "mylen";
static const char __pyx_k_oneOf[] = "oneOf";
static const char __pyx_k_other[] = "other";
static const char __pyx_k_parse[] = "_parse";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_reset[] = "reset";
static const char __pyx_k_ret_2[] = " (ret: ";
static const char __pyx_k_rfind[] = "rfind";
static const char __pyx_k_slots[] = "__slots__";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_start[] = "start";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_str_2[] = "__str__";
static const char __pyx_k_strip[] = "strip";
static const char __pyx_k_sub_2[] = "__sub__";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_tests[] = "tests";
static const char __pyx_k_tflat[] = "tflat";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_title[] = "title";
static const char __pyx_k_types[] = "types";
static const char __pyx_k_upper[] = "upper";
static const char __pyx_k_usage[] = "usage";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_vlist[] = "vlist";
static const char __pyx_k_wkref[] = "wkref";
static const char __pyx_k_wraps[] = "wraps";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_wslit[] = "wslit";
static const char __pyx_k_100_FF[] = "\n        100\n        FF\n        ";
static const char __pyx_k_Arabic[] = "Arabic";
static const char __pyx_k_DOTALL[] = "DOTALL";
static const char __pyx_k_FAIL_2[] = "FAIL: ";
static const char __pyx_k_Hebrew[] = "Hebrew";
static const char __pyx_k_INDENT[] = "INDENT";
static const char __pyx_k_Korean[] = "Korean";
static const char __pyx_k_Latin1[] = "Latin1";
static const char __pyx_k_LatinA[] = "LatinA";
static const char __pyx_k_LatinB[] = "LatinB";
static const char __pyx_k_NotAny[] = "NotAny";
static const char __pyx_k_SkipTo[] = "SkipTo";
static const char __pyx_k_UNDENT[] = "UNDENT";
static const char __pyx_k_alphas[] = "alphas";
static const char __pyx_k_anchor[] = "anchor";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_asDict[] = "asDict";
static const char __pyx_k_asList[] = "asList";
static const char __pyx_k_at_loc[] = " at loc ";
static const char __pyx_k_author[] = "__author__";
static const char __pyx_k_bslash[] = "_bslash";
static const char __pyx_k_called[] = "called";
static const char __pyx_k_closer[] = "closer";
static const char __pyx_k_column[] = "column";
static const char __pyx_k_compat[] = "__compat__";
static const char __pyx_k_curCol[] = "curCol";
static const char __pyx_k_cvt_fn[] = "cvt_fn";
static const char __pyx_k_decode[] = "decode";
static const char __pyx_k_dictOf[] = "dictOf";
static const char __pyx_k_dlName[] = "dlName";
static const char __pyx_k_doctag[] = "doctag";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_endloc[] = "endloc";
static const char __pyx_k_entity[] = "entity";
static const char __pyx_k_errmsg[] = "errmsg";
static const char __pyx_k_escape[] = "escape";
static const char __pyx_k_expand[] = "expand";
static const char __pyx_k_extend[] = "extend";
static const char __pyx_k_f_code[] = "f_code";
static const char __pyx_k_f_self[] = "f_self";
static const char __pyx_k_failOn[] = "failOn";
static const char __pyx_k_failed[] = "failed";
static const char __pyx_k_filter[] = "filter";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_frames[] = "frames";
static const char __pyx_k_from_2[] = "from";
static const char __pyx_k_groups[] = "groups";
static const char __pyx_k_ignore[] = "ignore";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_indent[] = "indent";
static const char __pyx_k_insStr[] = "insStr";
static const char __pyx_k_insert[] = "insert";
static const char __pyx_k_intern[] = "_intern";
static const char __pyx_k_invert[] = "__invert__";
static const char __pyx_k_kwargs[] = "kwargs";
static const char __pyx_k_lambda[] = "<lambda>";
static const char __pyx_k_lastCR[] = "lastCR";
static const char __pyx_k_line_2[] = "), (line:";
static const char __pyx_k_line_3[] = "(line: '";
static const char __pyx_k_lineno[] = "lineno";
static const char __pyx_k_lookup[] = "__lookup";
static const char __pyx_k_lshift[] = "__lshift__";
static const char __pyx_k_lstrip[] = "lstrip";
static const char __pyx_k_maxLen[] = "maxLen";
static const char __pyx_k_maxint[] = "maxint";
static const char __pyx_k_maxlen[] = "maxlen";
static const char __pyx_k_maxloc[] = "maxloc";
static const char __pyx_k_merged[] = "merged";
static const char __pyx_k_minLen[] = "minLen";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "name";
static const char __pyx_k_negate[] = "negate";
static const char __pyx_k_nested[] = "nested ";
static const char __pyx_k_newloc[] = "newloc";
static const char __pyx_k_nextCR[] = "nextCR";
static const char __pyx_k_number[] = "number";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_offset[] = "offset";
static const char __pyx_k_opExpr[] = "opExpr";
static const char __pyx_k_opList[] = "opList";
static const char __pyx_k_opener[] = "opener";
static const char __pyx_k_paArgs[] = "paArgs";
static const char __pyx_k_pprint[] = "pprint";
static const char __pyx_k_preloc[] = "preloc";
static const char __pyx_k_py_str[] = "py_str";
static const char __pyx_k_ranges[] = "_ranges";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_remove[] = "remove";
static const char __pyx_k_repr_2[] = "__repr__";
static const char __pyx_k_resTag[] = "resTag";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_retobj[] = "retobj";
static const char __pyx_k_rstrip[] = "rstrip";
static const char __pyx_k_s_term[] = "%s term";
static const char __pyx_k_select[] = "select";
static const char __pyx_k_smExpr[] = "smExpr";
static const char __pyx_k_sorted[] = "sorted";
static const char __pyx_k_splits[] = "splits";
static const char __pyx_k_srange[] = "srange";
static const char __pyx_k_stderr[] = "stderr";
static const char __pyx_k_stdout[] = "stdout";
static const char __pyx_k_stopOn[] = "stopOn";
static const char __pyx_k_string[] = "string";
static const char __pyx_k_tables[] = "tables";
static const char __pyx_k_tagStr[] = "tagStr";
static const char __pyx_k_thread[] = "_thread";
static const char __pyx_k_tmpLoc[] = "tmpLoc";
static const char __pyx_k_tmpOpt[] = "tmpOpt";
static const char __pyx_k_tmploc[] = "tmploc";
static const char __pyx_k_toItem[] = "toItem";
static const char __pyx_k_tokens[] = "tokens";
static const char __pyx_k_unichr[] = "unichr";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_warn_2[] = "warn_";
static const char __pyx_k_ws_map[] = "ws_map";
static const char __pyx_k_wschar[] = "wschar";
static const char __pyx_k_xrange[] = "xrange";
static const char __pyx_k_Chinese[] = "Chinese";
static const char __pyx_k_Combine[] = "Combine";
static const char __pyx_k_EM_QUAD[] = "<EM_QUAD>";
static const char __pyx_k_EN_QUAD[] = "<EN_QUAD>";
static const char __pyx_k_Forward[] = "Forward";
static const char __pyx_k_Keyword[] = "Keyword";
static const char __pyx_k_LineEnd[] = "LineEnd";
static const char __pyx_k_Literal[] = "Literal";
static const char __pyx_k_MAX_INT[] = "_MAX_INT";
static const char __pyx_k_Mapping[] = "Mapping";
static const char __pyx_k_Matched[] = "Matched ";
static const char __pyx_k_NoMatch[] = "NoMatch";
static const char __pyx_k_WordEnd[] = "WordEnd";
static const char __pyx_k_any_tag[] = "any tag";
static const char __pyx_k_asMatch[] = "asMatch";
static const char __pyx_k_at_char[] = "  (at char ";
static const char __pyx_k_breaker[] = "breaker";
static const char __pyx_k_builtin[] = "__builtin__";
static const char __pyx_k_callers[] = "callers";
static const char __pyx_k_charset[] = "charset";
static const char __pyx_k_class_2[] = "class";
static const char __pyx_k_co_name[] = "co_name";
static const char __pyx_k_columns[] = "columns";
static const char __pyx_k_combine[] = "combine";
static const char __pyx_k_command[] = "command";
static const char __pyx_k_comment[] = "comment";
static const char __pyx_k_compile[] = "compile";
static const char __pyx_k_content[] = "content";
static const char __pyx_k_context[] = "context";
static const char __pyx_k_default[] = "default";
static const char __pyx_k_delitem[] = "__delitem__";
static const char __pyx_k_depth_2[] = "_depth";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_escChar[] = "escChar";
static const char __pyx_k_explain[] = "explain";
static const char __pyx_k_flatten[] = "_flatten";
static const char __pyx_k_fnumber[] = "fnumber";
static const char __pyx_k_found_r[] = ", found %r";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_getName[] = "getName";
static const char __pyx_k_getattr[] = "__getattr__";
static const char __pyx_k_getitem[] = "__getitem__";
static const char __pyx_k_haskeys[] = "haskeys";
static const char __pyx_k_hexnums[] = "hexnums";
static const char __pyx_k_ilshift[] = "__ilshift__";
static const char __pyx_k_include[] = "include";
static const char __pyx_k_indices[] = "indices";
static const char __pyx_k_inspect[] = "inspect";
static const char __pyx_k_intExpr[] = "intExpr";
static const char __pyx_k_integer[] = "integer";
static const char __pyx_k_isalpha[] = "isalpha";
static const char __pyx_k_isdigit[] = "isdigit";
static const char __pyx_k_isequal[] = "isequal";
static const char __pyx_k_isspace[] = "isspace";
static const char __pyx_k_item_fn[] = "item_fn";
static const char __pyx_k_itemseq[] = "itemseq";
static const char __pyx_k_leaving[] = "<<leaving ";
static const char __pyx_k_lineEnd[] = "lineEnd";
static const char __pyx_k_locator[] = "locator";
static const char __pyx_k_longest[] = "longest";
static const char __pyx_k_matches[] = "matches";
static const char __pyx_k_maxargs[] = "maxargs";
static const char __pyx_k_maxsize[] = "maxsize";
static const char __pyx_k_message[] = "message";
static const char __pyx_k_missing[] = "missing <";
static const char __pyx_k_must_be[] = "', must be '";
static const char __pyx_k_new_loc[] = "new_loc";
static const char __pyx_k_newself[] = "newself";
static const char __pyx_k_nextLoc[] = "nextLoc";
static const char __pyx_k_nextloc[] = "nextloc";
static const char __pyx_k_nonzero[] = "__nonzero__";
static const char __pyx_k_opAssoc[] = "opAssoc";
static const char __pyx_k_opExpr1[] = "opExpr1";
static const char __pyx_k_opExpr2[] = "opExpr2";
static const char __pyx_k_openTag[] = "openTag";
static const char __pyx_k_operDef[] = "operDef";
static const char __pyx_k_opt1map[] = "opt1map";
static const char __pyx_k_os_path[] = "os.path";
static const char __pyx_k_overlap[] = "overlap";
static const char __pyx_k_parseFn[] = "parseFn";
static const char __pyx_k_pattern[] = "pattern";
static const char __pyx_k_popitem[] = "popitem";
static const char __pyx_k_popleft[] = "popleft";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_print_2[] = "print_";
static const char __pyx_k_py_repr[] = "py_repr";
static const char __pyx_k_removed[] = "removed";
static const char __pyx_k_replStr[] = "replStr";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_resname[] = "resname";
static const char __pyx_k_restore[] = "restore";
static const char __pyx_k_results[] = "results";
static const char __pyx_k_retToks[] = "retToks";
static const char __pyx_k_retreat[] = "retreat";
static const char __pyx_k_reverse[] = "reverse";
static const char __pyx_k_s_class[] = "%s:class";
static const char __pyx_k_s_pl_sl[] = "s_pl_sl";
static const char __pyx_k_selfTag[] = "selfTag";
static const char __pyx_k_setName[] = "setName";
static const char __pyx_k_setitem[] = "__setitem__";
static const char __pyx_k_skipped[] = "_skipped*";
static const char __pyx_k_skipper[] = "skipper";
static const char __pyx_k_strRepr[] = "strRepr";
static const char __pyx_k_success[] = "success";
static const char __pyx_k_symbols[] = "symbols";
static const char __pyx_k_tb_next[] = "tb_next";
static const char __pyx_k_thiscol[] = "thiscol";
static const char __pyx_k_tmpReqd[] = "tmpReqd";
static const char __pyx_k_toklist[] = "toklist";
static const char __pyx_k_ungroup[] = "ungroup";
static const char __pyx_k_unicode[] = "unicode";
static const char __pyx_k_verbose[] = "verbose";
static const char __pyx_k_version[] = "__version__";
static const char __pyx_k_weakref[] = "weakref";
static const char __pyx_k_wrapper[] = "wrapper";
static const char __pyx_k_Cyrillic[] = "Cyrillic";
static const char __pyx_k_EM_SPACE[] = "<EM_SPACE>";
static const char __pyx_k_EN_SPACE[] = "<EN_SPACE>";
static const char __pyx_k_Ellipsis[] = "Ellipsis";
static const char __pyx_k_Expected[] = "Expected ";
static const char __pyx_k_Hiragana[] = "Hiragana";
static const char __pyx_k_Iterable[] = "Iterable";
static const char __pyx_k_Japanese[] = "Japanese";
static const char __pyx_k_Katakana[] = "Katakana";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_OnlyOnce[] = "OnlyOnce";
static const char __pyx_k_Optional[] = "Optional";
static const char __pyx_k_Or___str[] = "Or.__str__";
static const char __pyx_k_P_entity[] = "&(?P<entity>";
static const char __pyx_k_Suppress[] = "Suppress";
static const char __pyx_k_UNINDENT[] = "UNINDENT";
static const char __pyx_k_adjacent[] = "adjacent";
static const char __pyx_k_arrayLen[] = "arrayLen";
static const char __pyx_k_asString[] = "asString";
static const char __pyx_k_attrDict[] = "attrDict";
static const char __pyx_k_attrName[] = "attrName";
static const char __pyx_k_attrname[] = "attrname";
static const char __pyx_k_baseExpr[] = "baseExpr";
static const char __pyx_k_callable[] = "callable";
static const char __pyx_k_caseless[] = "caseless";
static const char __pyx_k_closeTag[] = "closeTag";
static const char __pyx_k_comments[] = "comments";
static const char __pyx_k_contains[] = "__contains__";
static const char __pyx_k_d_d_eE_d[] = "[+-]?\\d+\\.?\\d*([eE][+-]?\\d+)?";
static const char __pyx_k_datetime[] = "datetime";
static const char __pyx_k_enable_2[] = "enable_";
static const char __pyx_k_endswith[] = "endswith";
static const char __pyx_k_entering[] = ">>entering ";
static const char __pyx_k_escQuote[] = "escQuote";
static const char __pyx_k_exc_info[] = "exc_info";
static const char __pyx_k_exc_type[] = "exc_type";
static const char __pyx_k_expanded[] = "_expanded";
static const char __pyx_k_expected[] = "expected";
static const char __pyx_k_f_locals[] = "f_locals";
static const char __pyx_k_fail_msg[] = "fail_msg";
static const char __pyx_k_foundstr[] = "foundstr";
static const char __pyx_k_fraction[] = "fraction";
static const char __pyx_k_fullDump[] = "fullDump";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_ind_or_e[] = "ind_or_e";
static const char __pyx_k_instring[] = "instring";
static const char __pyx_k_instrlen[] = "instrlen";
static const char __pyx_k_iterkeys[] = "iterkeys";
static const char __pyx_k_keepTabs[] = "keepTabs";
static const char __pyx_k_key_fifo[] = "key_fifo";
static const char __pyx_k_lastExpr[] = "lastExpr";
static const char __pyx_k_line_str[] = "line_str";
static const char __pyx_k_list_str[] = "list_str";
static const char __pyx_k_locn_end[] = "locn_end";
static const char __pyx_k_lookup_2[] = "lookup";
static const char __pyx_k_makeTags[] = "_makeTags";
static const char __pyx_k_matchLen[] = "matchLen";
static const char __pyx_k_maxsplit[] = "maxsplit";
static const char __pyx_k_module_2[] = "<module>";
static const char __pyx_k_notChars[] = "notChars";
static const char __pyx_k_notchars[] = "notchars";
static const char __pyx_k_operator[] = "operator";
static const char __pyx_k_original[] = "original";
static const char __pyx_k_parseAll[] = "parseAll";
static const char __pyx_k_position[] = "position";
static const char __pyx_k_pp_value[] = "pp_value";
static const char __pyx_k_preParse[] = "preParse";
static const char __pyx_k_punc8bit[] = "punc8bit";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_reString[] = "reString";
static const char __pyx_k_re_match[] = "re_match";
static const char __pyx_k_register[] = "register";
static const char __pyx_k_required[] = "required";
static const char __pyx_k_ret_toks[] = "ret_toks";
static const char __pyx_k_reversed[] = "reversed";
static const char __pyx_k_runTests[] = "runTests";
static const char __pyx_k_s_s_term[] = "%s%s term";
static const char __pyx_k_savelist[] = "savelist";
static const char __pyx_k_sci_real[] = "sci_real";
static const char __pyx_k_setBreak[] = "setBreak";
static const char __pyx_k_setDebug[] = "setDebug";
static const char __pyx_k_set_name[] = "__set_name__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_skiptext[] = "skiptext";
static const char __pyx_k_startloc[] = "startloc";
static const char __pyx_k_strptime[] = "strptime";
static const char __pyx_k_suppress[] = "suppress";
static const char __pyx_k_tag_body[] = "tag_body";
static const char __pyx_k_termName[] = "termName";
static const char __pyx_k_thisExpr[] = "thisExpr";
static const char __pyx_k_thisFunc[] = "thisFunc";
static const char __pyx_k_tmpExprs[] = "tmpExprs";
static const char __pyx_k_tokenMap[] = "tokenMap";
static const char __pyx_k_tryParse[] = "tryParse";
static const char __pyx_k_useRegex[] = "useRegex";
static const char __pyx_k_validate[] = "validate";
static const char __pyx_k_warnings[] = "warnings";
static const char __pyx_k_ANY_VALUE[] = "ANY_VALUE";
static const char __pyx_k_And___str[] = "And.__str__";
static const char __pyx_k_ErrorStop[] = "_ErrorStop";
static const char __pyx_k_FILE_NAME[] = "_FILE_NAME";
static const char __pyx_k_FifoCache[] = "_FifoCache";
static const char __pyx_k_LineStart[] = "LineStart";
static const char __pyx_k_MULTILINE[] = "MULTILINE";
static const char __pyx_k_NameError[] = "NameError";
static const char __pyx_k_NullToken[] = "_NullToken";
static const char __pyx_k_OneOrMore[] = "OneOrMore";
static const char __pyx_k_Or___init[] = "Or.__init__";
static const char __pyx_k_Or___ixor[] = "Or.__ixor__";
static const char __pyx_k_Regex_sub[] = "Regex.sub";
static const char __pyx_k_StringEnd[] = "StringEnd";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_WordRegex[] = "_WordRegex";
static const char __pyx_k_WordStart[] = "WordStart";
static const char __pyx_k_addoffset[] = "addoffset";
static const char __pyx_k_all_names[] = "_all_names";
static const char __pyx_k_alphanums[] = "alphanums";
static const char __pyx_k_arrayExpr[] = "arrayExpr";
static const char __pyx_k_asKeyword[] = "asKeyword";
static const char __pyx_k_attrValue[] = "attrValue";
static const char __pyx_k_attribute[] = "attribute '";
static const char __pyx_k_best_expr[] = "best_expr";
static const char __pyx_k_bodyChars[] = "bodyChars";
static const char __pyx_k_bodychars[] = "bodychars";
static const char __pyx_k_breakFlag[] = "breakFlag";
static const char __pyx_k_charRange[] = "_charRange";
static const char __pyx_k_classattr[] = "classattr";
static const char __pyx_k_classname[] = "classname";
static const char __pyx_k_commaItem[] = "commaItem";
static const char __pyx_k_comment_2[] = "// comment";
static const char __pyx_k_debugging[] = "debugging";
static const char __pyx_k_dictvalue[] = "dictvalue";
static const char __pyx_k_doActions[] = "doActions";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_errorStop[] = "errorStop";
static const char __pyx_k_exception[] = " (exception: ";
static const char __pyx_k_formatted[] = "formatted";
static const char __pyx_k_fromToken[] = "fromToken";
static const char __pyx_k_from_dict[] = "from_dict";
static const char __pyx_k_func_name[] = "func_name";
static const char __pyx_k_functools[] = "functools";
static const char __pyx_k_groupdict[] = "groupdict";
static const char __pyx_k_has_value[] = "' has value '";
static const char __pyx_k_include_2[] = "include_";
static const char __pyx_k_initChars[] = "initChars";
static const char __pyx_k_ipv6_part[] = "_ipv6_part";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_iteritems[] = "iteritems";
static const char __pyx_k_itertools[] = "itertools";
static const char __pyx_k_last_expr[] = "last_expr";
static const char __pyx_k_lineStart[] = "lineStart";
static const char __pyx_k_locMarker[] = "locMarker";
static const char __pyx_k_matchExpr[] = "matchExpr";
static const char __pyx_k_maxExcLoc[] = "maxExcLoc";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_missing_2[] = "missing";
static const char __pyx_k_multiline[] = "multiline";
static const char __pyx_k_must_skip[] = "must_skip";
static const char __pyx_k_namespace[] = "namespace";
static const char __pyx_k_not_ender[] = "not_ender";
static const char __pyx_k_optionals[] = "optionals";
static const char __pyx_k_parseFile[] = "parseFile";
static const char __pyx_k_parseImpl[] = "parseImpl";
static const char __pyx_k_postParse[] = "postParse";
static const char __pyx_k_printable[] = "printable";
static const char __pyx_k_quoteChar[] = "quoteChar";
static const char __pyx_k_retTokens[] = "retTokens";
static const char __pyx_k_self_type[] = "self_type";
static const char __pyx_k_setOffset[] = "setOffset";
static const char __pyx_k_set_trace[] = "set_trace";
static const char __pyx_k_show_skip[] = "show_skip";
static const char __pyx_k_simpleSQL[] = "simpleSQL";
static const char __pyx_k_skipped_2[] = "_skipped";
static const char __pyx_k_skipped_3[] = "skipped";
static const char __pyx_k_stringEnd[] = "stringEnd";
static const char __pyx_k_tableName[] = "tableName";
static const char __pyx_k_test_expr[] = "test_expr";
static const char __pyx_k_threading[] = "threading";
static const char __pyx_k_tmptokens[] = "tmptokens";
static const char __pyx_k_tokenlist[] = "tokenlist";
static const char __pyx_k_traceback[] = "__traceback__";
static const char __pyx_k_verifyCol[] = "verifyCol";
static const char __pyx_k_whiteStrs[] = "whiteStrs";
static const char __pyx_k_withClass[] = "withClass";
static const char __pyx_k_wordChars[] = "wordChars";
static const char __pyx_k_0123456789[] = "0123456789";
static const char __pyx_k_And___iadd[] = "And.__iadd__";
static const char __pyx_k_And___init[] = "And.__init__";
static const char __pyx_k_CharsNotIn[] = "CharsNotIn";
static const char __pyx_k_CloseMatch[] = "CloseMatch";
static const char __pyx_k_Devanagari[] = "Devanagari";
static const char __pyx_k_Each___str[] = "Each.__str__";
static const char __pyx_k_FollowedBy[] = "FollowedBy";
static const char __pyx_k_GoToColumn[] = "GoToColumn";
static const char __pyx_k_HAIR_SPACE[] = "<HAIR_SPACE>";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_MatchFirst[] = "MatchFirst";
static const char __pyx_k_PrecededBy[] = "PrecededBy";
static const char __pyx_k_THIN_SPACE[] = "<THIN_SPACE>";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_Word___str[] = "Word.__str__";
static const char __pyx_k_ZeroOrMore[] = "ZeroOrMore";
static const char __pyx_k_allResults[] = "allResults";
static const char __pyx_k_alphas8bit[] = "alphas8bit";
static const char __pyx_k_anyOpenTag[] = "anyOpenTag";
static const char __pyx_k_assertTrue[] = "assertTrue";
static const char __pyx_k_basestring[] = "basestring";
static const char __pyx_k_cPyparsing[] = "cPyparsing";
static const char __pyx_k_cache_item[] = "cache_item";
static const char __pyx_k_charsAsStr[] = "charsAsStr";
static const char __pyx_k_columnName[] = "columnName";
static const char __pyx_k_columnSpec[] = "columnSpec";
static const char __pyx_k_contextlib[] = "contextlib";
static const char __pyx_k_expandtabs[] = "expandtabs";
static const char __pyx_k_expr_order[] = "expr_order";
static const char __pyx_k_expr_parse[] = "expr_parse";
static const char __pyx_k_expression[] = " expression";
static const char __pyx_k_exprsFound[] = "exprsFound";
static const char __pyx_k_exprtokens[] = "exprtokens";
static const char __pyx_k_extract_tb[] = "extract_tb";
static const char __pyx_k_failAction[] = "failAction";
static const char __pyx_k_foundArity[] = "foundArity";
static const char __pyx_k_getnewargs[] = "__getnewargs__";
static const char __pyx_k_identChars[] = "identChars";
static const char __pyx_k_identifier[] = "identifier";
static const char __pyx_k_ignoreExpr[] = "ignoreExpr";
static const char __pyx_k_isinstance[] = "isinstance";
static const char __pyx_k_itemgetter[] = "itemgetter";
static const char __pyx_k_iterkeys_2[] = "_iterkeys";
static const char __pyx_k_itervalues[] = "itervalues";
static const char __pyx_k_joinString[] = "joinString";
static const char __pyx_k_locn_start[] = "locn_start";
static const char __pyx_k_matchOrder[] = "matchOrder";
static const char __pyx_k_matchWhite[] = "matchWhite";
static const char __pyx_k_maxMatches[] = "maxMatches";
static const char __pyx_k_maxunicode[] = "maxunicode";
static const char __pyx_k_methodCall[] = "methodCall";
static const char __pyx_k_mismatches[] = " mismatches)";
static const char __pyx_k_namedItems[] = "namedItems";
static const char __pyx_k_nestedExpr[] = "nestedExpr";
static const char __pyx_k_otheritems[] = "otheritems";
static const char __pyx_k_parseCache[] = "_parseCache";
static const char __pyx_k_prefix_len[] = "prefix_len";
static const char __pyx_k_preparseFn[] = "preparseFn";
static const char __pyx_k_printables[] = "printables";
static const char __pyx_k_resetCache[] = "resetCache";
static const char __pyx_k_restOfLine[] = "restOfLine";
static const char __pyx_k_resultlist[] = "resultlist";
static const char __pyx_k_reversed_2[] = "__reversed__";
static const char __pyx_k_saveAsList[] = "saveAsList";
static const char __pyx_k_scanString[] = "scanString";
static const char __pyx_k_singleChar[] = "_singleChar";
static const char __pyx_k_skipresult[] = "skipresult";
static const char __pyx_k_skipto_arg[] = "skipto_arg";
static const char __pyx_k_splitlines[] = "splitlines";
static const char __pyx_k_stacklevel[] = "stacklevel";
static const char __pyx_k_startswith[] = "startswith";
static const char __pyx_k_streamline[] = "streamline";
static const char __pyx_k_suffix_len[] = "suffix_len";
static const char __pyx_k_testString[] = "testString";
static const char __pyx_k_to_symbols[] = "to_symbols";
static const char __pyx_k_trim_arity[] = "_trim_arity";
static const char __pyx_k_whiteChars[] = "whiteChars";
static const char __pyx_k_whitespace[] = "whitespace";
static const char __pyx_k_with_up_to[] = " (with up to ";
static const char __pyx_k_xml_escape[] = "_xml_escape";
static const char __pyx_k_2_4_7_2_3_0[] = "2.4.7.2.3.0";
static const char __pyx_k_Char___init[] = "Char.__init__";
static const char __pyx_k_Dict___init[] = "Dict.__init__";
static const char __pyx_k_Each___init[] = "Each.__init__";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_MAC_address[] = "MAC address";
static const char __pyx_k_OrderedDict[] = "_OrderedDict";
static const char __pyx_k_PendingSkip[] = "_PendingSkip";
static const char __pyx_k_Regex___str[] = "Regex.__str__";
static const char __pyx_k_StringStart[] = "StringStart";
static const char __pyx_k_SyntaxError[] = "SyntaxError";
static const char __pyx_k_Word___init[] = "Word.__init__";
static const char __pyx_k_anyCloseTag[] = "anyCloseTag";
static const char __pyx_k_asGroupList[] = "asGroupList";
static const char __pyx_k_assertEqual[] = "assertEqual";
static const char __pyx_k_check_ender[] = "check_ender";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_defaultdict[] = "defaultdict";
static const char __pyx_k_ending_with[] = " ending with ";
static const char __pyx_k_escapedPunc[] = "_escapedPunc";
static const char __pyx_k_extractText[] = "extractText";
static const char __pyx_k_filterfalse[] = "filterfalse";
static const char __pyx_k_hex_integer[] = "hex integer";
static const char __pyx_k_htmlComment[] = "htmlComment";
static const char __pyx_k_ignoreExprs[] = "ignoreExprs";
static const char __pyx_k_indentStack[] = "indentStack";
static const char __pyx_k_is_instring[] = "is_instring";
static const char __pyx_k_is_iterable[] = "is_iterable";
static const char __pyx_k_iteritems_2[] = "_iteritems";
static const char __pyx_k_line_column[] = "line_column";
static const char __pyx_k_locatedExpr[] = "locatedExpr";
static const char __pyx_k_mac_address[] = "mac_address";
static const char __pyx_k_makeXMLTags[] = "makeXMLTags";
static const char __pyx_k_matchString[] = "matchString";
static const char __pyx_k_matchTokens[] = "matchTokens";
static const char __pyx_k_minElements[] = "minElements";
static const char __pyx_k_mro_entries[] = "__mro_entries__";
static const char __pyx_k_occurrences[] = "occurrences";
static const char __pyx_k_optElements[] = "optElements";
static const char __pyx_k_ordereddict[] = "ordereddict";
static const char __pyx_k_parseAction[] = "parseAction";
static const char __pyx_k_parseMethod[] = "_parseMethod";
static const char __pyx_k_parseString[] = "parseString";
static const char __pyx_k_real_number[] = "real number";
static const char __pyx_k_replaceWith[] = "replaceWith";
static const char __pyx_k_reset_stack[] = "reset_stack";
static const char __pyx_k_resultsName[] = "resultsName";
static const char __pyx_k_selectToken[] = "selectToken";
static const char __pyx_k_startAction[] = "startAction";
static const char __pyx_k_streamlined[] = "streamlined";
static const char __pyx_k_stringStart[] = "stringStart";
static const char __pyx_k_suppress_GT[] = "suppress_GT";
static const char __pyx_k_suppress_LT[] = "suppress_LT";
static const char __pyx_k_tagAttrName[] = "tagAttrName";
static const char __pyx_k_test_string[] = "test_string";
static const char __pyx_k_theseTokens[] = "theseTokens";
static const char __pyx_k_tokensStart[] = "tokensStart";
static const char __pyx_k_traceback_2[] = "traceback";
static const char __pyx_k_unicode_set[] = "unicode_set";
static const char __pyx_k_update_dict[] = "update_dict";
static const char __pyx_k_versionTime[] = "__versionTime__";
static const char __pyx_k_xmlBodyText[] = "xmlBodyText";
static const char __pyx_k_0_failed_1_2[] = "{0} failed: {1}: {2}";
static const char __pyx_k_ABCDEFabcdef[] = "ABCDEFabcdef";
static const char __pyx_k_Empty___init[] = "Empty.__init__";
static const char __pyx_k_FIGURE_SPACE[] = "<FIGURE_SPACE>";
static const char __pyx_k_Forward_copy[] = "Forward.copy";
static const char __pyx_k_Group___init[] = "Group.__init__";
static const char __pyx_k_HTML_comment[] = "HTML comment";
static const char __pyx_k_IPv4_address[] = "IPv4 address";
static const char __pyx_k_IPv6_address[] = "IPv6 address";
static const char __pyx_k_ISO8601_date[] = "ISO8601 date";
static const char __pyx_k_Keyword_copy[] = "Keyword.copy";
static const char __pyx_k_NotAny___str[] = "NotAny.__str__";
static const char __pyx_k_Or_parseImpl[] = "Or.parseImpl";
static const char __pyx_k_ParseResults[] = "ParseResults";
static const char __pyx_k_QuotedString[] = "QuotedString";
static const char __pyx_k_Regex___init[] = "Regex.__init__";
static const char __pyx_k_Token___init[] = "Token.__init__";
static const char __pyx_k_White___init[] = "White.__init__";
static const char __pyx_k_addCondition[] = "addCondition";
static const char __pyx_k_asStringList[] = "_asStringList";
static const char __pyx_k_assertRaises[] = "assertRaises";
static const char __pyx_k_backup_stack[] = "backup_stack";
static const char __pyx_k_cache_result[] = "cache_result";
static const char __pyx_k_callPreParse[] = "callPreParse";
static const char __pyx_k_callPreparse[] = "callPreparse";
static const char __pyx_k_canParseNext[] = "canParseNext";
static const char __pyx_k_commasepitem[] = "_commasepitem";
static const char __pyx_k_commonprefix[] = "commonprefix";
static const char __pyx_k_countedArray[] = "countedArray";
static const char __pyx_k_debugActions[] = "debugActions";
static const char __pyx_k_defaultValue[] = "defaultValue";
static const char __pyx_k_defaultvalue[] = "defaultvalue";
static const char __pyx_k_endQuoteChar[] = "endQuoteChar";
static const char __pyx_k_endlocMarker[] = "endlocMarker";
static const char __pyx_k_excludeChars[] = "excludeChars";
static const char __pyx_k_failureTests[] = "failureTests";
static const char __pyx_k_finalResults[] = "finalResults";
static const char __pyx_k_from_symbols[] = "from_symbols";
static const char __pyx_k_ifilterfalse[] = "ifilterfalse";
static const char __pyx_k_inAccumNames[] = "inAccumNames";
static const char __pyx_k_includeMatch[] = "includeMatch";
static const char __pyx_k_include_list[] = "include_list";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_ipv4_address[] = "ipv4_address";
static const char __pyx_k_ipv6_address[] = "ipv6_address";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_iso8601_date[] = "iso8601_date";
static const char __pyx_k_itervalues_2[] = "_itervalues";
static const char __pyx_k_keepMatching[] = "keepMatching";
static const char __pyx_k_lookup_bools[] = "lookup_bools";
static const char __pyx_k_makeHTMLTags[] = "makeHTMLTags";
static const char __pyx_k_markerString[] = "markerString";
static const char __pyx_k_match_string[] = "match_string";
static const char __pyx_k_maxException[] = "maxException";
static const char __pyx_k_maxSpecified[] = "maxSpecified";
static const char __pyx_k_mismatches_2[] = "mismatches";
static const char __pyx_k_modalResults[] = "modalResults";
static const char __pyx_k_not_in_cache[] = "not_in_cache";
static const char __pyx_k_original_end[] = "_original_end";
static const char __pyx_k_parseNoCache[] = "_parseNoCache";
static const char __pyx_k_parse_action[] = "<parse action>";
static const char __pyx_k_printResults[] = "printResults";
static const char __pyx_k_quoteCharLen[] = "quoteCharLen";
static const char __pyx_k_quotedString[] = "quotedString";
static const char __pyx_k_removeQuotes[] = "removeQuotes";
static const char __pyx_k_rest_of_line[] = "rest of line";
static const char __pyx_k_returnString[] = "returnString";
static const char __pyx_k_save_context[] = "_save_context";
static const char __pyx_k_searchString[] = "searchString";
static const char __pyx_k_staticmethod[] = "staticmethod";
static const char __pyx_k_tagAttrValue[] = "tagAttrValue";
static const char __pyx_k_upcaseTokens[] = "upcaseTokens";
static const char __pyx_k_usage_weight[] = "usage_weight";
static const char __pyx_k_version_info[] = "version_info";
static const char __pyx_k_0_9a_fA_F_1_4[] = "[0-9a-fA-F]{1,4}";
static const char __pyx_k_And_parseImpl[] = "And.parseImpl";
static const char __pyx_k_FifoCache_get[] = "_FifoCache.get";
static const char __pyx_k_FifoCache_set[] = "_FifoCache.set";
static const char __pyx_k_Forward___str[] = "Forward.__str__";
static const char __pyx_k_MultipleMatch[] = "_MultipleMatch";
static const char __pyx_k_NotAny___init[] = "NotAny.__init__";
static const char __pyx_k_Or_streamline[] = "Or.streamline";
static const char __pyx_k_OrderedDict_2[] = "OrderedDict";
static const char __pyx_k_ParserElement[] = "ParserElement";
static const char __pyx_k_PositionToken[] = "_PositionToken";
static const char __pyx_k_SkipTo___init[] = "SkipTo.__init__";
static const char __pyx_k_SyntaxWarning[] = "SyntaxWarning";
static const char __pyx_k_adaptive_mode[] = "adaptive_mode";
static const char __pyx_k_bodyCharsOrig[] = "bodyCharsOrig";
static const char __pyx_k_cStyleComment[] = "cStyleComment";
static const char __pyx_k_callDuringTry[] = "callDuringTry";
static const char __pyx_k_caselessmatch[] = "caselessmatch";
static const char __pyx_k_checkUnindent[] = "checkUnindent";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_convertToDate[] = "convertToDate";
static const char __pyx_k_delimitedList[] = "delimitedList";
static const char __pyx_k_enablePackrat[] = "enablePackrat";
static const char __pyx_k_expected_dict[] = "expected_dict";
static const char __pyx_k_expected_list[] = "expected_list";
static const char __pyx_k_extract_stack[] = "extract_stack";
static const char __pyx_k_file_contents[] = "file_contents";
static const char __pyx_k_frame_summary[] = "frame_summary";
static const char __pyx_k_furthest_locs[] = "_furthest_locs";
static const char __pyx_k_generatorType[] = "_generatorType";
static const char __pyx_k_hex_integer_2[] = "hex_integer";
static const char __pyx_k_htmlEntityMap[] = "_htmlEntityMap";
static const char __pyx_k_html_stripper[] = "_html_stripper";
static const char __pyx_k_indentedBlock[] = "indentedBlock";
static const char __pyx_k_infixNotation[] = "infixNotation";
static const char __pyx_k_initCharsOrig[] = "initCharsOrig";
static const char __pyx_k_init_subclass[] = "__init_subclass__";
static const char __pyx_k_loc_in_suffix[] = "loc_in_suffix";
static const char __pyx_k_markInputline[] = "markInputline";
static const char __pyx_k_maxMismatches[] = "maxMismatches";
static const char __pyx_k_mayIndexError[] = "mayIndexError";
static const char __pyx_k_mixed_integer[] = "mixed_integer";
static const char __pyx_k_multirequired[] = "multirequired";
static const char __pyx_k_packrat_cache[] = "packrat_cache";
static const char __pyx_k_packrat_parse[] = "packrat_parse";
static const char __pyx_k_parseWithTabs[] = "parseWithTabs";
static const char __pyx_k_parserElement[] = "parserElement";
static const char __pyx_k_prefix_lookup[] = "prefix_lookup";
static const char __pyx_k_reBracketExpr[] = "_reBracketExpr";
static const char __pyx_k_setFailAction[] = "setFailAction";
static const char __pyx_k_sre_constants[] = "sre_constants";
static const char __pyx_k_stripHTMLTags[] = "stripHTMLTags";
static const char __pyx_k_successAction[] = "successAction";
static const char __pyx_k_suffix_lookup[] = "suffix_lookup";
static const char __pyx_k_tableNameList[] = "tableNameList";
static const char __pyx_k_try_not_ender[] = "try_not_ender";
static const char __pyx_k_unicodeString[] = "unicodeString";
static const char __pyx_k_validateTrace[] = "validateTrace";
static const char __pyx_k_withAttribute[] = "withAttribute";
static const char __pyx_k_0_xX_0_9a_fA_F[] = "\\\\0?[xX][0-9a-fA-F]+";
static const char __pyx_k_And__ErrorStop[] = "And._ErrorStop";
static const char __pyx_k_And_streamline[] = "And.streamline";
static const char __pyx_k_AttributeError[] = "AttributeError";
static const char __pyx_k_Combine___init[] = "Combine.__init__";
static const char __pyx_k_Combine_ignore[] = "Combine.ignore";
static const char __pyx_k_Dict_postParse[] = "Dict.postParse";
static const char __pyx_k_Each_parseImpl[] = "Each.parseImpl";
static const char __pyx_k_FAIL_EXCEPTION[] = "FAIL-EXCEPTION: ";
static const char __pyx_k_Forward___init[] = "Forward.__init__";
static const char __pyx_k_Keyword___init[] = "Keyword.__init__";
static const char __pyx_k_LineEnd___init[] = "LineEnd.__init__";
static const char __pyx_k_Literal___init[] = "Literal.__init__";
static const char __pyx_k_MutableMapping[] = "MutableMapping";
static const char __pyx_k_NoMatch___init[] = "NoMatch.__init__";
static const char __pyx_k_OnlyOnce_reset[] = "OnlyOnce.reset";
static const char __pyx_k_Optional___str[] = "Optional.__str__";
static const char __pyx_k_ParseException[] = "ParseException";
static const char __pyx_k_TokenConverter[] = "TokenConverter";
static const char __pyx_k_UnboundedCache[] = "_UnboundedCache";
static const char __pyx_k_WordEnd___init[] = "WordEnd.__init__";
static const char __pyx_k_Word_parseImpl[] = "Word.parseImpl";
static const char __pyx_k_Y_m_dT_H_M_S_f[] = "%Y-%m-%dT%H:%M:%S.%f";
static const char __pyx_k_adaptive_usage[] = "adaptive_usage";
static const char __pyx_k_addParseAction[] = "addParseAction";
static const char __pyx_k_cPyparsing_pyx[] = "cPyparsing.pyx";
static const char __pyx_k_checkRecursion[] = "checkRecursion";
static const char __pyx_k_checkSubIndent[] = "checkSubIndent";
static const char __pyx_k_columnNameList[] = "columnNameList";
static const char __pyx_k_contextmanager[] = "contextmanager";
static const char __pyx_k_convertToFloat[] = "convertToFloat";
static const char __pyx_k_downcaseTokens[] = "downcaseTokens";
static const char __pyx_k_escapedHexChar[] = "_escapedHexChar";
static const char __pyx_k_escapedOctChar[] = "_escapedOctChar";
static const char __pyx_k_firstMatchChar[] = "firstMatchChar";
static const char __pyx_k_firstQuoteChar[] = "firstQuoteChar";
static const char __pyx_k_from_exception[] = "_from_exception";
static const char __pyx_k_getinnerframes[] = "getinnerframes";
static const char __pyx_k_hasIgnoreExprs[] = "hasIgnoreExprs";
static const char __pyx_k_indented_block[] = "indented block";
static const char __pyx_k_initExprGroups[] = "initExprGroups";
static const char __pyx_k_instring_slice[] = "instring_slice";
static const char __pyx_k_listAllMatches[] = "listAllMatches";
static const char __pyx_k_matchOnlyAtCol[] = "matchOnlyAtCol";
static const char __pyx_k_mayReturnEmpty[] = "mayReturnEmpty";
static const char __pyx_k_multioptionals[] = "multioptionals";
static const char __pyx_k_namedItemsOnly[] = "namedItemsOnly";
static const char __pyx_k_not_a_subentry[] = "not a subentry";
static const char __pyx_k_original_start[] = "_original_start";
static const char __pyx_k_other_instring[] = "other_instring";
static const char __pyx_k_otherdictitems[] = "otherdictitems";
static const char __pyx_k_packratEnabled[] = "_packratEnabled";
static const char __pyx_k_pyparsing_test[] = "pyparsing_test";
static const char __pyx_k_rightLeftAssoc[] = "rightLeftAssoc";
static const char __pyx_k_setParseAction[] = "setParseAction";
static const char __pyx_k_setResultsName[] = "_setResultsName";
static const char __pyx_k_signed_integer[] = "signed integer";
static const char __pyx_k_skipIgnorables[] = "_skipIgnorables";
static const char __pyx_k_skipWhitespace[] = "skipWhitespace";
static const char __pyx_k_system_version[] = "system_version";
static const char __pyx_k_throwException[] = "throwException";
static const char __pyx_k_trim_traceback[] = "_trim_traceback";
static const char __pyx_k_unquoteResults[] = "unquoteResults";
static const char __pyx_k_update_wrapper[] = "update_wrapper";
static const char __pyx_k_C_style_comment[] = "C style comment";
static const char __pyx_k_CaselessKeyword[] = "CaselessKeyword";
static const char __pyx_k_CaselessLiteral[] = "CaselessLiteral";
static const char __pyx_k_Each_streamline[] = "Each.streamline";
static const char __pyx_k_FifoCache___len[] = "_FifoCache.__len__";
static const char __pyx_k_FifoCache_clear[] = "_FifoCache.clear";
static const char __pyx_k_Group_postParse[] = "Group.postParse";
static const char __pyx_k_NullToken___str[] = "_NullToken.__str__";
static const char __pyx_k_OneOrMore___str[] = "OneOrMore.__str__";
static const char __pyx_k_OnlyOnce___call[] = "OnlyOnce.__call__";
static const char __pyx_k_OnlyOnce___init[] = "OnlyOnce.__init__";
static const char __pyx_k_Optional___init[] = "Optional.__init__";
static const char __pyx_k_ParseExpression[] = "ParseExpression";
static const char __pyx_k_Regex_parseImpl[] = "Regex.parseImpl";
static const char __pyx_k_SimpleNamespace[] = "SimpleNamespace";
static const char __pyx_k_White_parseImpl[] = "White.parseImpl";
static const char __pyx_k_ascii_lowercase[] = "ascii_lowercase";
static const char __pyx_k_ascii_uppercase[] = "ascii_uppercase";
static const char __pyx_k_cache_successes[] = "cache_successes";
static const char __pyx_k_checkPeerIndent[] = "checkPeerIndent";
static const char __pyx_k_collections_abc[] = "collections.abc";
static const char __pyx_k_cppStyleComment[] = "cppStyleComment";
static const char __pyx_k_dblQuotedString[] = "dblQuotedString";
static const char __pyx_k_dblSlashComment[] = "dblSlashComment";
static const char __pyx_k_endQuoteCharLen[] = "endQuoteCharLen";
static const char __pyx_k_exceptionAction[] = "exceptionAction";
static const char __pyx_k_failed_runTests[] = "failed runTests";
static const char __pyx_k_illegal_nesting[] = "illegal nesting";
static const char __pyx_k_leaveWhitespace[] = "leaveWhitespace";
static const char __pyx_k_lineno_col_line[] = "lineno col line";
static const char __pyx_k_match_stringloc[] = "match_stringloc";
static const char __pyx_k_nextLevelIndent[] = "nextLevelIndent";
static const char __pyx_k_not_an_unindent[] = "not an unindent";
static const char __pyx_k_not_preceded_by[] = "not preceded by ";
static const char __pyx_k_nullDebugAction[] = "nullDebugAction";
static const char __pyx_k_originalTextFor[] = "originalTextFor";
static const char __pyx_k_packrat_context[] = "packrat_context";
static const char __pyx_k_packrat_enabled[] = "packrat_enabled";
static const char __pyx_k_self_expr_parse[] = "self_expr_parse";
static const char __pyx_k_setAdaptiveMode[] = "setAdaptiveMode";
static const char __pyx_k_setDebugActions[] = "setDebugActions";
static const char __pyx_k_sglQuotedString[] = "sglQuotedString";
static const char __pyx_k_subRecCheckList[] = "subRecCheckList";
static const char __pyx_k_transformString[] = "transformString";
static const char __pyx_k_CharsNotIn___str[] = "CharsNotIn.__str__";
static const char __pyx_k_Exception_raised[] = "Exception raised:";
static const char __pyx_k_FifoCache___init[] = "_FifoCache.__init__";
static const char __pyx_k_FifoCache_update[] = "_FifoCache.update";
static const char __pyx_k_Forward___lshift[] = "Forward.__lshift__";
static const char __pyx_k_Forward_validate[] = "Forward.validate";
static const char __pyx_k_ISO8601_datetime[] = "ISO8601 datetime";
static const char __pyx_k_LineStart___init[] = "LineStart.__init__";
static const char __pyx_k_MatchFirst___ior[] = "MatchFirst.__ior__";
static const char __pyx_k_MatchFirst___str[] = "MatchFirst.__str__";
static const char __pyx_k_NotAny_parseImpl[] = "NotAny.parseImpl";
static const char __pyx_k_NullToken___bool[] = "_NullToken.__bool__";
static const char __pyx_k_OGHAM_SPACE_MARK[] = "<OGHAM_SPACE_MARK>";
static const char __pyx_k_ParseResults_get[] = "ParseResults.get";
static const char __pyx_k_ParseResults_pop[] = "ParseResults.pop";
static const char __pyx_k_SIX_PER_EM_SPACE[] = "<SIX-PER-EM_SPACE>";
static const char __pyx_k_SkipTo_parseImpl[] = "SkipTo.parseImpl";
static const char __pyx_k_StringEnd___init[] = "StringEnd.__init__";
static const char __pyx_k_WordStart___init[] = "WordStart.__init__";
static const char __pyx_k_ZERO_WIDTH_SPACE[] = "<ZERO_WIDTH_SPACE>";
static const char __pyx_k_ZeroOrMore___str[] = "ZeroOrMore.__str__";
static const char __pyx_k_cache_size_limit[] = "cache_size_limit";
static const char __pyx_k_commonHTMLEntity[] = "commonHTMLEntity";
static const char __pyx_k_convertToInteger[] = "convertToInteger";
static const char __pyx_k_file_or_filename[] = "file_or_filename";
static const char __pyx_k_iso8601_datetime[] = "iso8601_datetime";
static const char __pyx_k_javaStyleComment[] = "javaStyleComment";
static const char __pyx_k_makeOptionalList[] = "makeOptionalList";
static const char __pyx_k_not_a_peer_entry[] = "not a peer entry";
static const char __pyx_k_parseElementList[] = "parseElementList";
static const char __pyx_k_parseImplAsMatch[] = "parseImplAsMatch";
static const char __pyx_k_parseIncremental[] = "_parseIncremental";
static const char __pyx_k_parse_action_exc[] = "parse_action_exc";
static const char __pyx_k_pyparsing_common[] = "pyparsing_common";
static const char __pyx_k_run_test_results[] = "run_test_results";
static const char __pyx_k_run_test_success[] = "run_test_success";
static const char __pyx_k_run_tests_report[] = "run_tests_report";
static const char __pyx_k_setResultsName_2[] = "setResultsName";
static const char __pyx_k_signed_integer_2[] = "signed_integer";
static const char __pyx_k_traceParseAction[] = "traceParseAction";
static const char __pyx_k_unicode_set_nums[] = "unicode_set.nums";
static const char __pyx_k_BaseWithAttribute[] = "BaseWithAttribute";
static const char __pyx_k_C_style_comment_2[] = "C++ style comment";
static const char __pyx_k_CharsNotIn___init[] = "CharsNotIn.__init__";
static const char __pyx_k_CloseMatch___init[] = "CloseMatch.__init__";
static const char __pyx_k_Combine_postParse[] = "Combine.postParse";
static const char __pyx_k_FOUR_PER_EM_SPACE[] = "<FOUR-PER-EM_SPACE>";
static const char __pyx_k_FollowedBy___init[] = "FollowedBy.__init__";
static const char __pyx_k_Forward___ilshift[] = "Forward.__ilshift__";
static const char __pyx_k_GoToColumn___init[] = "GoToColumn.__init__";
static const char __pyx_k_IDEOGRAPHIC_SPACE[] = "<IDEOGRAPHIC_SPACE>";
static const char __pyx_k_Keyword_parseImpl[] = "Keyword.parseImpl";
static const char __pyx_k_LineEnd_parseImpl[] = "LineEnd.parseImpl";
static const char __pyx_k_Literal_parseImpl[] = "Literal.parseImpl";
static const char __pyx_k_MatchFirst___init[] = "MatchFirst.__init__";
static const char __pyx_k_NoMatch_parseImpl[] = "NoMatch.parseImpl";
static const char __pyx_k_Or_checkRecursion[] = "Or.checkRecursion";
static const char __pyx_k_PUNCTUATION_SPACE[] = "<PUNCTUATION_SPACE>";
static const char __pyx_k_ParseResults_copy[] = "ParseResults.copy";
static const char __pyx_k_ParseResults_dump[] = "ParseResults.dump";
static const char __pyx_k_ParseResults_keys[] = "ParseResults.keys";
static const char __pyx_k_PendingSkip___add[] = "_PendingSkip.__add__";
static const char __pyx_k_PrecededBy___init[] = "PrecededBy.__init__";
static const char __pyx_k_SingleCharLiteral[] = "_SingleCharLiteral";
static const char __pyx_k_Suppress_suppress[] = "Suppress.suppress";
static const char __pyx_k_Unmatchable_token[] = "Unmatchable token";
static const char __pyx_k_WordEnd_parseImpl[] = "WordEnd.parseImpl";
static const char __pyx_k_ZeroOrMore___init[] = "ZeroOrMore.__init__";
static const char __pyx_k_common_prefix_len[] = "common_prefix_len";
static const char __pyx_k_common_suffix_len[] = "common_suffix_len";
static const char __pyx_k_convertToDatetime[] = "convertToDatetime";
static const char __pyx_k_d_eE_d_d_d_d_eE_d[] = "[+-]?(?:\\d+(?:[eE][+-]?\\d+)|(?:\\d+\\.\\d*|\\.\\d+)(?:[eE][+-]?\\d+)?)";
static const char __pyx_k_enableIncremental[] = "enableIncremental";
static const char __pyx_k_found_end_of_text[] = ", found end of text";
static const char __pyx_k_full_IPv6_address[] = "full IPv6 address";
static const char __pyx_k_full_ipv6_address[] = "_full_ipv6_address";
static const char __pyx_k_getrecursionlimit[] = "getrecursionlimit";
static const char __pyx_k_includeSeparators[] = "includeSeparators";
static const char __pyx_k_lazyclassproperty[] = "_lazyclassproperty";
static const char __pyx_k_matchPreviousExpr[] = "matchPreviousExpr";
static const char __pyx_k_n_r_x_x_0_9a_fA_F[] = "\"(?:[^\"\\n\\r\\\\]|(?:\"\")|(?:\\\\(?:[^x]|x[0-9a-fA-F]+)))*";
static const char __pyx_k_parseElementClass[] = "parseElementClass";
static const char __pyx_k_parseElementTrace[] = "parseElementTrace";
static const char __pyx_k_pyparsing_unicode[] = "pyparsing_unicode";
static const char __pyx_k_replaceHTMLEntity[] = "replaceHTMLEntity";
static const char __pyx_k_reversed_instring[] = "reversed_instring";
static const char __pyx_k_singleArgBuiltins[] = "singleArgBuiltins";
static const char __pyx_k_still_reset_cache[] = "still_reset_cache";
static const char __pyx_k_And_checkRecursion[] = "And.checkRecursion";
static const char __pyx_k_FifoCache___reduce[] = "_FifoCache.__reduce__";
static const char __pyx_k_Forward_streamline[] = "Forward.streamline";
static const char __pyx_k_No_match_found_for[] = "No match found for ";
static const char __pyx_k_Optional_parseImpl[] = "Optional.parseImpl";
static const char __pyx_k_Or__setResultsName[] = "Or._setResultsName";
static const char __pyx_k_ParseBaseException[] = "ParseBaseException";
static const char __pyx_k_ParseResults___add[] = "ParseResults.__add__";
static const char __pyx_k_ParseResults___dir[] = "ParseResults.__dir__";
static const char __pyx_k_ParseResults___len[] = "ParseResults.__len__";
static const char __pyx_k_ParseResults___new[] = "ParseResults.__new__";
static const char __pyx_k_ParseResults___str[] = "ParseResults.__str__";
static const char __pyx_k_ParseResults__name[] = "_ParseResults__name";
static const char __pyx_k_ParseResults_asXML[] = "ParseResults.asXML";
static const char __pyx_k_ParseResults_clear[] = "ParseResults.clear";
static const char __pyx_k_ParseResults_items[] = "ParseResults.items";
static const char __pyx_k_ParserElement___eq[] = "ParserElement.__eq__";
static const char __pyx_k_ParserElement___ne[] = "ParserElement.__ne__";
static const char __pyx_k_ParserElement___or[] = "ParserElement.__or__";
static const char __pyx_k_ParserElement_copy[] = "ParserElement.copy";
static const char __pyx_k_PendingSkip___init[] = "_PendingSkip.__init__";
static const char __pyx_k_PendingSkip___repr[] = "_PendingSkip.__repr__";
static const char __pyx_k_QuotedString___str[] = "QuotedString.__str__";
static const char __pyx_k_StringStart___init[] = "StringStart.__init__";
static const char __pyx_k_Suppress_postParse[] = "Suppress.postParse";
static const char __pyx_k_THREE_PER_EM_SPACE[] = "<THREE-PER-EM_SPACE>";
static const char __pyx_k_UnboundedCache_get[] = "_UnboundedCache.get";
static const char __pyx_k_UnboundedCache_set[] = "_UnboundedCache.set";
static const char __pyx_k_WRAP_CALL_LINE_NUM[] = "_WRAP_CALL_LINE_NUM";
static const char __pyx_k_all_parse_elements[] = "_all_parse_elements";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_blockStatementExpr[] = "blockStatementExpr";
static const char __pyx_k_cache_furthest_loc[] = "cache_furthest_loc";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_commaSeparatedList[] = "commaSeparatedList";
static const char __pyx_k_common_HTML_entity[] = "common HTML entity";
static const char __pyx_k_default_whitespace[] = "default_whitespace";
static const char __pyx_k_expected_exception[] = "expected_exception";
static const char __pyx_k_incrementalEnabled[] = "_incrementalEnabled";
static const char __pyx_k_inspect_tracebacks[] = "inspect_tracebacks";
static const char __pyx_k_literalStringClass[] = "_literalStringClass";
static const char __pyx_k_mixed_IPv6_address[] = "mixed IPv6 address";
static const char __pyx_k_mixed_ipv6_address[] = "_mixed_ipv6_address";
static const char __pyx_k_next_linebreak_loc[] = "next_linebreak_loc";
static const char __pyx_k_operatorPrecedence[] = "operatorPrecedence";
static const char __pyx_k_pa_call_line_synth[] = "pa_call_line_synth";
static const char __pyx_k_packrat_cache_lock[] = "packrat_cache_lock";
static const char __pyx_k_pythonStyleComment[] = "pythonStyleComment";
static const char __pyx_k_setWhitespaceChars[] = "setWhitespaceChars";
static const char __pyx_k_short_IPv6_address[] = "short IPv6 address";
static const char __pyx_k_short_ipv6_address[] = "_short_ipv6_address";
static const char __pyx_k_tokenMap_locals_pa[] = "tokenMap.<locals>.pa";
static const char __pyx_k_unicode_set_alphas[] = "unicode_set.alphas";
static const char __pyx_k_verbose_stacktrace[] = "verbose_stacktrace";
static const char __pyx_k_0xa1_0xbf_0xd7_0xf7[] = "[\\0xa1-\\0xbf\\0xd7\\0xf7]";
static const char __pyx_k_DEFAULT_WHITE_CHARS[] = "DEFAULT_WHITE_CHARS";
static const char __pyx_k_Each_checkRecursion[] = "Each.checkRecursion";
static const char __pyx_k_GoToColumn_preParse[] = "GoToColumn.preParse";
static const char __pyx_k_LineStart_parseImpl[] = "LineStart.parseImpl";
static const char __pyx_k_ParseElementEnhance[] = "ParseElementEnhance";
static const char __pyx_k_ParseFatalException[] = "ParseFatalException";
static const char __pyx_k_ParseResults___bool[] = "ParseResults.__bool__";
static const char __pyx_k_ParseResults___iadd[] = "ParseResults.__iadd__";
static const char __pyx_k_ParseResults___init[] = "ParseResults.__init__";
static const char __pyx_k_ParseResults___iter[] = "ParseResults.__iter__";
static const char __pyx_k_ParseResults___radd[] = "ParseResults.__radd__";
static const char __pyx_k_ParseResults___repr[] = "ParseResults.__repr__";
static const char __pyx_k_ParseResults__modal[] = "_ParseResults__modal";
static const char __pyx_k_ParseResults_append[] = "ParseResults.append";
static const char __pyx_k_ParseResults_asDict[] = "ParseResults.asDict";
static const char __pyx_k_ParseResults_asList[] = "ParseResults.asList";
static const char __pyx_k_ParseResults_extend[] = "ParseResults.extend";
static const char __pyx_k_ParseResults_insert[] = "ParseResults.insert";
static const char __pyx_k_ParseResults_pprint[] = "ParseResults.pprint";
static const char __pyx_k_ParseResults_values[] = "ParseResults.values";
static const char __pyx_k_ParserElement___add[] = "ParserElement.__add__";
static const char __pyx_k_ParserElement___and[] = "ParserElement.__and__";
static const char __pyx_k_ParserElement___mul[] = "ParserElement.__mul__";
static const char __pyx_k_ParserElement___req[] = "ParserElement.__req__";
static const char __pyx_k_ParserElement___rne[] = "ParserElement.__rne__";
static const char __pyx_k_ParserElement___ror[] = "ParserElement.__ror__";
static const char __pyx_k_ParserElement___str[] = "ParserElement.__str__";
static const char __pyx_k_ParserElement___sub[] = "ParserElement.__sub__";
static const char __pyx_k_ParserElement___xor[] = "ParserElement.__xor__";
static const char __pyx_k_ParserElement_split[] = "ParserElement.split";
static const char __pyx_k_QuotedString___init[] = "QuotedString.__init__";
static const char __pyx_k_Regex_sub_locals_pa[] = "Regex.sub.<locals>.pa";
static const char __pyx_k_StringEnd_parseImpl[] = "StringEnd.parseImpl";
static const char __pyx_k_WordRegex_parseImpl[] = "_WordRegex.parseImpl";
static const char __pyx_k_WordStart_parseImpl[] = "WordStart.parseImpl";
static const char __pyx_k_amp_gt_lt_quot_apos[] = "amp gt lt quot apos";
static const char __pyx_k_copyTokenToRepeater[] = "copyTokenToRepeater";
static const char __pyx_k_enable_all_warnings[] = "_enable_all_warnings";
static const char __pyx_k_inlineLiteralsUsing[] = "inlineLiteralsUsing";
static const char __pyx_k_n_r_x_x_0_9a_fA_F_2[] = "'(?:[^'\\n\\r\\\\]|(?:'')|(?:\\\\(?:[^x]|x[0-9a-fA-F]+)))*";
static const char __pyx_k_no_validation_for_r[] = "no validation for {!r}";
static const char __pyx_k_oneOf_locals_lambda[] = "oneOf.<locals>.<lambda>";
static const char __pyx_k_originalParseMethod[] = "_originalParseMethod";
static const char __pyx_k_packrat_cache_stats[] = "packrat_cache_stats";
static const char __pyx_k_parse_element_index[] = "parse_element_index";
static const char __pyx_k_CharsNotIn_parseImpl[] = "CharsNotIn.parseImpl";
static const char __pyx_k_CloseMatch_parseImpl[] = "CloseMatch.parseImpl";
static const char __pyx_k_Expected_end_of_line[] = "Expected end of line";
static const char __pyx_k_Expected_end_of_text[] = "Expected end of text";
static const char __pyx_k_FollowedBy_parseImpl[] = "FollowedBy.parseImpl";
static const char __pyx_k_Found_unwanted_token[] = "Found unwanted token, ";
static const char __pyx_k_GoToColumn_parseImpl[] = "GoToColumn.parseImpl";
static const char __pyx_k_MatchFirst_parseImpl[] = "MatchFirst.parseImpl";
static const char __pyx_k_MultipleMatch___init[] = "_MultipleMatch.__init__";
static const char __pyx_k_MultipleMatch_stopOn[] = "_MultipleMatch.stopOn";
static const char __pyx_k_ParseExpression_copy[] = "ParseExpression.copy";
static const char __pyx_k_ParseResults__asList[] = "_ParseResults__asList";
static const char __pyx_k_ParseResults__doinit[] = "_ParseResults__doinit";
static const char __pyx_k_ParseResults__lookup[] = "_ParseResults__lookup";
static const char __pyx_k_ParseResults__parent[] = "_ParseResults__parent";
static const char __pyx_k_ParseResults_getName[] = "ParseResults.getName";
static const char __pyx_k_ParseResults_haskeys[] = "ParseResults.haskeys";
static const char __pyx_k_ParseSyntaxException[] = "ParseSyntaxException";
static const char __pyx_k_ParserElement___call[] = "ParserElement.__call__";
static const char __pyx_k_ParserElement___hash[] = "ParserElement.__hash__";
static const char __pyx_k_ParserElement___init[] = "ParserElement.__init__";
static const char __pyx_k_ParserElement___iter[] = "ParserElement.__iter__";
static const char __pyx_k_ParserElement___radd[] = "ParserElement.__radd__";
static const char __pyx_k_ParserElement___rand[] = "ParserElement.__rand__";
static const char __pyx_k_ParserElement___repr[] = "ParserElement.__repr__";
static const char __pyx_k_ParserElement___rmul[] = "ParserElement.__rmul__";
static const char __pyx_k_ParserElement___rsub[] = "ParserElement.__rsub__";
static const char __pyx_k_ParserElement___rxor[] = "ParserElement.__rxor__";
static const char __pyx_k_ParserElement_ignore[] = "ParserElement.ignore";
static const char __pyx_k_PositionToken___init[] = "_PositionToken.__init__";
static const char __pyx_k_PrecededBy_parseImpl[] = "PrecededBy.parseImpl";
static const char __pyx_k_Python_style_comment[] = "Python style comment";
static const char __pyx_k_UnboundedCache___len[] = "_UnboundedCache.__len__";
static const char __pyx_k_UnboundedCache_clear[] = "_UnboundedCache.clear";
static const char __pyx_k_ZeroOrMore_parseImpl[] = "ZeroOrMore.parseImpl";
static const char __pyx_k_assertRunTestResults[] = "assertRunTestResults";
static const char __pyx_k_collectParseElements[] = "collectParseElements";
static const char __pyx_k_comma_separated_list[] = "comma separated list";
static const char __pyx_k_get_chars_for_ranges[] = "_get_chars_for_ranges";
static const char __pyx_k_literal_string_class[] = "literal_string_class";
static const char __pyx_k_matchPreviousLiteral[] = "matchPreviousLiteral";
static const char __pyx_k_mustMatchTheseTokens[] = "mustMatchTheseTokens";
static const char __pyx_k_oneOf_locals_genexpr[] = "oneOf.<locals>.genexpr";
static const char __pyx_k_parseImplAsGroupList[] = "parseImplAsGroupList";
static const char __pyx_k_self_skip_ignorables[] = "self_skip_ignorables";
static const char __pyx_k_srange_locals_lambda[] = "srange.<locals>.<lambda>";
static const char __pyx_k_24_Nov_2023_01_45_UTC[] = "24 Nov 2023 01:45 UTC";
static const char __pyx_k_And__ErrorStop___init[] = "And._ErrorStop.__init__";
static const char __pyx_k_DEFAULT_KEYWORD_CHARS[] = "DEFAULT_KEYWORD_CHARS";
static const char __pyx_k_MatchFirst_streamline[] = "MatchFirst.streamline";
static const char __pyx_k_ParseExpression___str[] = "ParseExpression.__str__";
static const char __pyx_k_ParseResults___lookup[] = "ParseResults.__lookup";
static const char __pyx_k_ParseResults__tokdict[] = "_ParseResults__tokdict";
static const char __pyx_k_ParseResults__toklist[] = "_ParseResults__toklist";
static const char __pyx_k_ParserElement_matches[] = "ParserElement.matches";
static const char __pyx_k_ParserElement_setName[] = "ParserElement.setName";
static const char __pyx_k_PendingSkip_parseImpl[] = "_PendingSkip.parseImpl";
static const char __pyx_k_StringStart_parseImpl[] = "StringStart.parseImpl";
static const char __pyx_k_TokenConverter___init[] = "TokenConverter.__init__";
static const char __pyx_k_UnboundedCache___init[] = "_UnboundedCache.__init__";
static const char __pyx_k_UnboundedCache_update[] = "_UnboundedCache.update";
static const char __pyx_k_cache_usefullness_obj[] = "cache_usefullness_obj";
static const char __pyx_k_copyDefaultWhiteChars[] = "copyDefaultWhiteChars";
static const char __pyx_k_countFieldParseAction[] = "countFieldParseAction";
static const char __pyx_k_default_keyword_chars[] = "default_keyword_chars";
static const char __pyx_k_enable_all_warnings_2[] = "enable_all_warnings";
static const char __pyx_k_escCharReplacePattern[] = "escCharReplacePattern";
static const char __pyx_k_escapeRegexRangeChars[] = "_escapeRegexRangeChars";
static const char __pyx_k_incrementalWithResets[] = "_incrementalWithResets";
static const char __pyx_k_no_matching_attribute[] = "no matching attribute ";
static const char __pyx_k_prefixes_and_suffixes[] = "prefixes_and_suffixes";
static const char __pyx_k_pyparsing_unicode_CJK[] = "pyparsing_unicode.CJK";
static const char __pyx_k_srange_locals_genexpr[] = "srange.<locals>.genexpr";
static const char __pyx_k_ungroup_locals_lambda[] = "ungroup.<locals>.<lambda>";
static const char __pyx_k_unicode_set_alphanums[] = "unicode_set.alphanums";
static const char __pyx_k_CaselessKeyword___init[] = "CaselessKeyword.__init__";
static const char __pyx_k_CaselessLiteral___init[] = "CaselessLiteral.__init__";
static const char __pyx_k_Expected_start_of_line[] = "Expected start of line";
static const char __pyx_k_Expected_start_of_text[] = "Expected start of text";
static const char __pyx_k_ParseException_explain[] = "ParseException.explain";
static const char __pyx_k_ParseExpression___init[] = "ParseExpression.__init__";
static const char __pyx_k_ParseExpression_append[] = "ParseExpression.append";
static const char __pyx_k_ParseExpression_ignore[] = "ParseExpression.ignore";
static const char __pyx_k_ParseResultsWithOffset[] = "_ParseResultsWithOffset";
static const char __pyx_k_ParseResults___delitem[] = "ParseResults.__delitem__";
static const char __pyx_k_ParseResults___getattr[] = "ParseResults.__getattr__";
static const char __pyx_k_ParseResults___getitem[] = "ParseResults.__getitem__";
static const char __pyx_k_ParseResults___setitem[] = "ParseResults.__setitem__";
static const char __pyx_k_ParseResults__iterkeys[] = "ParseResults._iterkeys";
static const char __pyx_k_ParseResults_from_dict[] = "ParseResults.from_dict";
static const char __pyx_k_ParserElement___invert[] = "ParserElement.__invert__";
static const char __pyx_k_ParserElement_preParse[] = "ParserElement.preParse";
static const char __pyx_k_ParserElement_runTests[] = "ParserElement.runTests";
static const char __pyx_k_ParserElement_setBreak[] = "ParserElement.setBreak";
static const char __pyx_k_ParserElement_setDebug[] = "ParserElement.setDebug";
static const char __pyx_k_ParserElement_suppress[] = "ParserElement.suppress";
static const char __pyx_k_ParserElement_tryParse[] = "ParserElement.tryParse";
static const char __pyx_k_ParserElement_validate[] = "ParserElement.validate";
static const char __pyx_k_QuotedString_parseImpl[] = "QuotedString.parseImpl";
static const char __pyx_k_Regex_parseImplAsMatch[] = "Regex.parseImplAsMatch";
static const char __pyx_k_collect_all_And_tokens[] = "collect_all_And_tokens";
static const char __pyx_k_comma_separated_list_2[] = "comma_separated_list";
static const char __pyx_k_conditionAsParseAction[] = "conditionAsParseAction";
static const char __pyx_k_expected_parse_results[] = "expected_parse_results";
static const char __pyx_k_makeTags_locals_lambda[] = "_makeTags.<locals>.<lambda>";
static const char __pyx_k_pyparsing_unicode_Thai[] = "pyparsing_unicode.Thai";
static const char __pyx_k_setDefaultKeywordChars[] = "setDefaultKeywordChars";
static const char __pyx_k_unicode_set_printables[] = "unicode_set.printables";
static const char __pyx_k_unicode_string_literal[] = "unicode string literal";
static const char __pyx_k_Forward__setResultsName[] = "Forward._setResultsName";
static const char __pyx_k_Forward_leaveWhitespace[] = "Forward.leaveWhitespace";
static const char __pyx_k_MultipleMatch_parseImpl[] = "_MultipleMatch.parseImpl";
static const char __pyx_k_ParseResults___contains[] = "ParseResults.__contains__";
static const char __pyx_k_ParseResults___getstate[] = "ParseResults.__getstate__";
static const char __pyx_k_ParseResults___reversed[] = "ParseResults.__reversed__";
static const char __pyx_k_ParseResults___setstate[] = "ParseResults.__setstate__";
static const char __pyx_k_ParseResults__iteritems[] = "ParseResults._iteritems";
static const char __pyx_k_ParserElement___getitem[] = "ParserElement.__getitem__";
static const char __pyx_k_ParserElement_parseFile[] = "ParserElement.parseFile";
static const char __pyx_k_ParserElement_parseImpl[] = "ParserElement.parseImpl";
static const char __pyx_k_ParserElement_postParse[] = "ParserElement.postParse";
static const char __pyx_k_TestParseResultsAsserts[] = "TestParseResultsAsserts";
static const char __pyx_k_UnboundedCache___reduce[] = "_UnboundedCache.__reduce__";
static const char __pyx_k_allow_unused_expr_order[] = "allow_unused_expr_order";
static const char __pyx_k_assertParseAndCheckDict[] = "assertParseAndCheckDict";
static const char __pyx_k_assertParseAndCheckList[] = "assertParseAndCheckList";
static const char __pyx_k_defaultStartDebugAction[] = "_defaultStartDebugAction";
static const char __pyx_k_lazyclassproperty___get[] = "_lazyclassproperty.__get__";
static const char __pyx_k_list_str_locals_genexpr[] = "list_str.<locals>.genexpr";
static const char __pyx_k_pyparsing_common_lambda[] = "pyparsing_common.<lambda>";
static const char __pyx_k_pyparsing_unicode_Greek[] = "pyparsing_unicode.Greek";
static const char __pyx_k_reset_pyparsing_context[] = "reset_pyparsing_context";
static const char __pyx_k_BaseWithAttribute___call[] = "BaseWithAttribute.__call__";
static const char __pyx_k_Not_at_the_end_of_a_word[] = "Not at the end of a word";
static const char __pyx_k_ParseBaseException___dir[] = "ParseBaseException.__dir__";
static const char __pyx_k_ParseBaseException___str[] = "ParseBaseException.__str__";
static const char __pyx_k_ParseExpression_validate[] = "ParseExpression.validate";
static const char __pyx_k_ParseResults__accumNames[] = "_ParseResults__accumNames";
static const char __pyx_k_ParseResults__itervalues[] = "ParseResults._itervalues";
static const char __pyx_k_ParserElement_resetCache[] = "ParserElement.resetCache";
static const char __pyx_k_ParserElement_scanString[] = "ParserElement.scanString";
static const char __pyx_k_ParserElement_streamline[] = "ParserElement.streamline";
static const char __pyx_k_assertParseResultsEquals[] = "assertParseResultsEquals";
static const char __pyx_k_convertWhitespaceEscapes[] = "convertWhitespaceEscapes";
static const char __pyx_k_gt_lt_amp_nbsp_quot_apos[] = "gt lt amp nbsp quot apos";
static const char __pyx_k_infixNotation_locals__FB[] = "infixNotation.<locals>._FB";
static const char __pyx_k_lazyclassproperty___init[] = "_lazyclassproperty.__init__";
static const char __pyx_k_nestedExpr_locals_lambda[] = "nestedExpr.<locals>.<lambda>";
static const char __pyx_k_pyparsing_unicode_Arabic[] = "pyparsing_unicode.Arabic";
static const char __pyx_k_pyparsing_unicode_Hebrew[] = "pyparsing_unicode.Hebrew";
static const char __pyx_k_pyparsing_unicode_Korean[] = "pyparsing_unicode.Korean";
static const char __pyx_k_pyparsing_unicode_Latin1[] = "pyparsing_unicode.Latin1";
static const char __pyx_k_pyparsing_unicode_LatinA[] = "pyparsing_unicode.LatinA";
static const char __pyx_k_pyparsing_unicode_LatinB[] = "pyparsing_unicode.LatinB";
static const char __pyx_k_r_object_is_not_iterable[] = "%r object is not iterable";
static const char __pyx_k_self_failOn_canParseNext[] = "self_failOn_canParseNext";
static const char __pyx_k_self_ignoreExpr_tryParse[] = "self_ignoreExpr_tryParse";
static const char __pyx_k_trim_arity_locals_lambda[] = "_trim_arity.<locals>.<lambda>";
static const char __pyx_k_CaselessLiteral_parseImpl[] = "CaselessLiteral.parseImpl";
static const char __pyx_k_MONGOLIAN_VOWEL_SEPARATOR[] = "<MONGOLIAN_VOWEL_SEPARATOR>";
static const char __pyx_k_MatchFirst_checkRecursion[] = "MatchFirst.checkRecursion";
static const char __pyx_k_Or___str___locals_genexpr[] = "Or.__str__.<locals>.genexpr";
static const char __pyx_k_ParseBaseException___init[] = "ParseBaseException.__init__";
static const char __pyx_k_ParseBaseException___repr[] = "ParseBaseException.__repr__";
static const char __pyx_k_ParseElementEnhance___str[] = "ParseElementEnhance.__str__";
static const char __pyx_k_ParseResults___getnewargs[] = "ParseResults.__getnewargs__";
static const char __pyx_k_ParserElement__parseCache[] = "ParserElement._parseCache";
static const char __pyx_k_ParserElement_parseString[] = "ParserElement.parseString";
static const char __pyx_k_RecursiveGrammarException[] = "RecursiveGrammarException";
static const char __pyx_k_adaptive_usage_check_rate[] = "adaptive_usage_check_rate";
static const char __pyx_k_defaultSuccessDebugAction[] = "_defaultSuccessDebugAction";
static const char __pyx_k_locatedExpr_locals_lambda[] = "locatedExpr.<locals>.<lambda>";
static const char __pyx_k_pyparsing_unicode_Chinese[] = "pyparsing_unicode.Chinese";
static const char __pyx_k_replaceWith_locals_lambda[] = "replaceWith.<locals>.<lambda>";
static const char __pyx_k_setDefaultWhitespaceChars[] = "setDefaultWhitespaceChars";
static const char __pyx_k_traceParseAction_locals_z[] = "traceParseAction.<locals>.z";
static const char __pyx_k_trim_arity_locals_wrapper[] = "_trim_arity.<locals>.wrapper";
static const char __pyx_k_xml_escape_locals_genexpr[] = "_xml_escape.<locals>.genexpr";
static const char __pyx_k_And___str___locals_genexpr[] = "And.__str__.<locals>.genexpr";
static const char __pyx_k_MatchFirst__setResultsName[] = "MatchFirst._setResultsName";
static const char __pyx_k_MatchFirst_setAdaptiveMode[] = "MatchFirst.setAdaptiveMode";
static const char __pyx_k_Not_at_the_start_of_a_word[] = "Not at the start of a word";
static const char __pyx_k_Or___init___locals_genexpr[] = "Or.__init__.<locals>.genexpr";
static const char __pyx_k_ParseElementEnhance___init[] = "ParseElementEnhance.__init__";
static const char __pyx_k_ParseElementEnhance_ignore[] = "ParseElementEnhance.ignore";
static const char __pyx_k_ParseExpression_streamline[] = "ParseExpression.streamline";
static const char __pyx_k_ParseResults__asStringList[] = "ParseResults._asStringList";
static const char __pyx_k_ParserElement_addCondition[] = "ParserElement.addCondition";
static const char __pyx_k_ParserElement_canParseNext[] = "ParserElement.canParseNext";
static const char __pyx_k_ParserElement_searchString[] = "ParserElement.searchString";
static const char __pyx_k_Regex_parseImplAsGroupList[] = "Regex.parseImplAsGroupList";
static const char __pyx_k_assertRaisesParseException[] = "assertRaisesParseException";
static const char __pyx_k_countedArray_locals_lambda[] = "countedArray.<locals>.<lambda>";
static const char __pyx_k_pyparsing_unicode_Cyrillic[] = "pyparsing_unicode.Cyrillic";
static const char __pyx_k_pyparsing_unicode_Japanese[] = "pyparsing_unicode.Japanese";
static const char __pyx_k_And___init___locals_genexpr[] = "And.__init__.<locals>.genexpr";
static const char __pyx_k_Each___str___locals_genexpr[] = "Each.__str__.<locals>.genexpr";
static const char __pyx_k_ParserElement__parseNoCache[] = "ParserElement._parseNoCache";
static const char __pyx_k_ParserElement_enablePackrat[] = "ParserElement.enablePackrat";
static const char __pyx_k_ParserElement_parseWithTabs[] = "ParserElement.parseWithTabs";
static const char __pyx_k_ParserElement_setFailAction[] = "ParserElement.setFailAction";
static const char __pyx_k_RecursiveGrammarException_s[] = "RecursiveGrammarException: %s";
static const char __pyx_k_SingleCharLiteral_parseImpl[] = "_SingleCharLiteral.parseImpl";
static const char __pyx_k_Text_not_in_expected_column[] = "Text not in expected column";
static const char __pyx_k_defaultExceptionDebugAction[] = "_defaultExceptionDebugAction";
static const char __pyx_k_indentedBlock_locals_lambda[] = "indentedBlock.<locals>.<lambda>";
static const char __pyx_k_quoted_string_starting_with[] = "quoted string, starting with ";
static const char __pyx_k_Each___init___locals_genexpr[] = "Each.__init__.<locals>.genexpr";
static const char __pyx_k_Optional__optionalNotMatched[] = "_Optional__optionalNotMatched";
static const char __pyx_k_Or_streamline_locals_genexpr[] = "Or.streamline.<locals>.genexpr";
static const char __pyx_k_ParseBaseException___getattr[] = "ParseBaseException.__getattr__";
static const char __pyx_k_ParseElementEnhance_validate[] = "ParseElementEnhance.validate";
static const char __pyx_k_ParserElement_addParseAction[] = "ParserElement.addParseAction";
static const char __pyx_k_ParserElement_checkRecursion[] = "ParserElement.checkRecursion";
static const char __pyx_k_ParserElement_setParseAction[] = "ParserElement.setParseAction";
static const char __pyx_k_ParserElement_setResultsName[] = "ParserElement.setResultsName";
static const char __pyx_k_Word___init___locals_genexpr[] = "Word.__init__.<locals>.genexpr";
static const char __pyx_k_outer_parent_usefullness_obj[] = "outer_parent_usefullness_obj";
static const char __pyx_k_pyparsing_unicode_Devanagari[] = "pyparsing_unicode.Devanagari";
static const char __pyx_k_trim_arity_locals_extract_tb[] = "_trim_arity.<locals>.extract_tb";
static const char __pyx_k_0xc0_0xd6_0xd8_0xf6_0xf8_0xff[] = "[\\0xc0-\\0xd6\\0xd8-\\0xf6\\0xf8-\\0xff]";
static const char __pyx_k_A_token_that_will_never_match[] = "A token that will never match.\n    ";
static const char __pyx_k_And_streamline_locals_genexpr[] = "And.streamline.<locals>.genexpr";
static const char __pyx_k_Each_parseImpl_locals_genexpr[] = "Each.parseImpl.<locals>.genexpr";
static const char __pyx_k_MultipleMatch__setResultsName[] = "_MultipleMatch._setResultsName";
static const char __pyx_k_ParseElementEnhance_parseImpl[] = "ParseElementEnhance.parseImpl";
static const char __pyx_k_ParseResultsWithOffset___init[] = "_ParseResultsWithOffset.__init__";
static const char __pyx_k_ParseResultsWithOffset___repr[] = "_ParseResultsWithOffset.__repr__";
static const char __pyx_k_ParserElement__setResultsName[] = "ParserElement._setResultsName";
static const char __pyx_k_ParserElement__skipIgnorables[] = "ParserElement._skipIgnorables";
static const char __pyx_k_ParserElement__trim_traceback[] = "ParserElement._trim_traceback";
static const char __pyx_k_ParserElement_leaveWhitespace[] = "ParserElement.leaveWhitespace";
static const char __pyx_k_ParserElement_setDebugActions[] = "ParserElement.setDebugActions";
static const char __pyx_k_ParserElement_transformString[] = "ParserElement.transformString";
static const char __pyx_k_White___init___locals_genexpr[] = "White.__init__.<locals>.genexpr";
static const char __pyx_k_failed_user_defined_condition[] = "failed user-defined condition";
static const char __pyx_k_matched_token_not_at_column_d[] = "matched token not at column %d";
static const char __pyx_k_originalTextFor_locals_lambda[] = "originalTextFor.<locals>.<lambda>";
static const char __pyx_k_update_furthest_loc_for_regex[] = "_update_furthest_loc_for_regex";
static const char __pyx_k_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a[] = "[0-9a-fA-F]{2}([:.-])[0-9a-fA-F]{2}(?:\\1[0-9a-fA-F]{2}){4}";
static const char __pyx_k_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a[] = "[0-9a-fA-F]{8}(-[0-9a-fA-F]{4}){3}-[0-9a-fA-F]{12}";
static const char __pyx_k_100_100_100_3_14159_6_02e23_1e[] = "\n        100\n        -100\n        +100\n        3.14159\n        6.02e23\n        1e-12\n        ";
static const char __pyx_k_A_namespace_class_for_defining[] = "\n    A namespace class for defining common language unicode_sets.\n    ";
static const char __pyx_k_Each_streamline_locals_genexpr[] = "Each.streamline.<locals>.genexpr";
static const char __pyx_k_Keyword_setDefaultKeywordChars[] = "Keyword.setDefaultKeywordChars";
static const char __pyx_k_P_year_d_4_P_month_d_d_P_day_d[] = "(?P<year>\\d{4})(?:-(?P<month>\\d\\d)(?:-(?P<day>\\d\\d))?)?";
static const char __pyx_k_ParseElementEnhance_streamline[] = "ParseElementEnhance.streamline";
static const char __pyx_k_Word___str___locals_charsAsStr[] = "Word.__str__.<locals>.charsAsStr";
static const char __pyx_k_incremental_parent_usefullness[] = "_incremental_parent_usefullness_obj";
static const char __pyx_k_instring_prefixes_and_suffixes[] = "_instring_prefixes_and_suffixes";
static const char __pyx_k_parse_actions_must_be_callable[] = "parse actions must be callable";
static const char __pyx_k_pyparsing_common_convertToDate[] = "pyparsing_common.convertToDate";
static const char __pyx_k_pyparsing_common_stripHTMLTags[] = "pyparsing_common.stripHTMLTags";
static const char __pyx_k_warn_name_set_on_empty_Forward[] = "warn_name_set_on_empty_Forward";
static const char __pyx_k_0_setting_results_name_0_r_on_1[] = "{0}: setting results name {0!r} on {1} expression that has no contained expression";
static const char __pyx_k_0_setting_results_name_1_r_on_2[] = "{0}: setting results name {1!r} on {2} expression collides with {3!r} on contained expression";
static const char __pyx_k_12345678_1234_5678_1234_5678123[] = "\n        12345678-1234-5678-1234-567812345678\n        ";
static const char __pyx_k_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0[] = "(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})(\\.(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})){3}";
static const char __pyx_k_A_cross_version_compatibility_c[] = "\n    A cross-version compatibility configuration for pyparsing features that will be\n    released in a future version. By setting values in this configuration to True,\n    those features can be enabled in prior versions for compatibility development\n    and testing.\n\n     - collect_all_And_tokens - flag to enable fix for Issue #63 that fixes erroneous grouping\n       of results names when an And expression is nested within an Or or MatchFirst; set to\n       True to enable bugfix released in pyparsing 2.3.0, or False to preserve\n       pre-2.3.0 handling of named results\n";
static const char __pyx_k_A_mixin_class_to_add_parse_resu[] = "\n        A mixin class to add parse results assertion methods to normal unittest.TestCase classes.\n        ";
static const char __pyx_k_A_set_of_Unicode_characters_for[] = "\n    A set of Unicode characters, for language-specific strings for\n    ``alphas``, ``nums``, ``alphanums``, and ``printables``.\n    A unicode_set is defined by a list of ranges in the Unicode character\n    set, in a class attribute ``_ranges``, such as::\n\n        _ranges = [(0x0020, 0x007e), (0x00a0, 0x00ff),]\n\n    A unicode set can also be defined using multiple inheritance of other unicode sets::\n\n        class CJK(Chinese, Japanese, Korean):\n            pass\n    ";
static const char __pyx_k_Abstract_subclass_of_class_Pars[] = "\n    Abstract subclass of :class:`ParseExpression`, for converting parsed results.\n    ";
static const char __pyx_k_Caseless_version_of_class_Keywo[] = "\n    Caseless version of :class:`Keyword`.\n\n    Example::\n\n        OneOrMore(CaselessKeyword(\"CMD\")).parseString(\"cmd CMD Cmd10\") # -> ['CMD', 'CMD']\n\n    (Contrast with example for :class:`CaselessLiteral`.)\n    ";
static const char __pyx_k_Context_manager_to_be_used_when[] = "\n        Context manager to be used when writing unit tests that modify pyparsing config values:\n         - packrat parsing\n         - default whitespace characters.\n         - default keyword characters\n         - literal string auto-conversion class\n         - __diag__ settings\n\n        Example:\n            with reset_pyparsing_context():\n                # test that literals used to construct a grammar are automatically suppressed\n                ParserElement.inlineLiteralsUsing(Suppress)\n\n                term = Word(alphas) | Word(nums)\n                group = Group('(' + term[...] + ')')\n\n                # assert that the '()' characters are not included in the parsed tokens\n                self.assertParseAndCheckLisst(group, \"(abc 123 def)\", ['abc', '123', 'def'])\n\n            # after exiting context manager, literals are converted to Literal expressions again\n        ";
static const char __pyx_k_Converter_to_return_the_matched[] = "Converter to return the matched tokens as a list - useful for\n    returning tokens of :class:`ZeroOrMore` and :class:`OneOrMore` expressions.\n\n    Example::\n\n        ident = Word(alphas)\n        num = Word(nums)\n        term = ident | num\n        func = ident + Optional(delimitedList(term))\n        print(func.parseString(\"fn a, b, 100\"))  # -> ['fn', 'a', 'b', '100']\n\n        func = ident + Group(Optional(delimitedList(term)))\n        print(func.parseString(\"fn a, b, 100\"))  # -> ['fn', ['a', 'b', '100']]\n    ";
static const char __pyx_k_Diagnostic_configuration_all_de[] = "\nDiagnostic configuration (all default to False)\n     - warn_multiple_tokens_in_named_alternation - flag to enable warnings when a results\n       name is defined on a MatchFirst or Or expression with one or more And subexpressions\n       (only warns if __compat__.collect_all_And_tokens is False)\n     - warn_ungrouped_named_tokens_in_collection - flag to enable warnings when a results\n       name is defined on a containing expression with ungrouped subexpressions that also\n       have results names\n     - warn_name_set_on_empty_Forward - flag to enable warnings whan a Forward is defined\n       with a results name, but has no contents defined\n     - warn_on_multiple_string_args_to_oneof - flag to enable warnings whan oneOf is\n       incorrectly called with multiple str arguments\n     - enable_debug_on_named_expressions - flag to auto-enable debug on all subsequent\n       calls to ParserElement.setName()\n";
static const char __pyx_k_Exception_thrown_when_parse_exp[] = "\n    Exception thrown when parse expressions don't match class;\n    supported attributes by name are:\n    - lineno - returns the line number of the exception text\n    - col - returns the column number of the exception text\n    - line - returns the line containing the exception text\n\n    Example::\n\n        try:\n            Word(nums).setName(\"integer\").parseString(\"ABC\")\n        except ParseException as pe:\n            print(pe)\n            print(\"column: {}\".format(pe.col))\n\n    prints::\n\n       Expected integer (at char 0), (line:1, col:1)\n        column: 1\n\n    ";
static const char __pyx_k_Lookahead_matching_of_the_given[] = "Lookahead matching of the given parse expression.\n    ``FollowedBy`` does *not* advance the parsing position within\n    the input string, it only verifies that the specified parse\n    expression matches at the current position.  ``FollowedBy``\n    always returns a null token list. If any results names are defined\n    in the lookahead expression, those *will* be returned for access by\n    name.\n\n    Example::\n\n        # use FollowedBy to match a label only if it is followed by a ':'\n        data_word = Word(alphas)\n        label = data_word + FollowedBy(':')\n        attr_expr = Group(label + Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join))\n\n        OneOrMore(attr_expr).parseString(\"shape: SQUARE color: BLACK posn: upper left\").pprint()\n\n    prints::\n\n        [['shape', 'SQUARE'], ['color', 'BLACK'], ['posn', 'upper left']]\n    ";
static const char __pyx_k_Matches_if_the_current_position[] = "Matches if the current position is at the beginning of a Word,\n    and is not preceded by any character in a given set of\n    ``wordChars`` (default= ``printables``). To emulate the\n    ``\010`` behavior of regular expressions, use\n    ``WordStart(alphanums)``. ``WordStart`` will also match at\n    the beginning of the string being parsed, or at the beginning of\n    a line.\n    ";
static const char __pyx_k_ParseExpression___init___locals[] = "ParseExpression.__init__.<locals>.genexpr";
static const char __pyx_k_ParseExpression__setResultsName[] = "ParseExpression._setResultsName";
static const char __pyx_k_ParseExpression_leaveWhitespace[] = "ParseExpression.leaveWhitespace";
static const char __pyx_k_ParseResultsWithOffset___getite[] = "_ParseResultsWithOffset.__getitem__";
static const char __pyx_k_ParseResultsWithOffset_setOffse[] = "_ParseResultsWithOffset.setOffset";
static const char __pyx_k_ParseResults__itervalues_locals[] = "ParseResults._itervalues.<locals>.genexpr";
static const char __pyx_k_ParserElement__parseIncremental[] = "ParserElement._parseIncremental.<locals>.<lambda>";
static const char __pyx_k_ParserElement_enableIncremental[] = "ParserElement.enableIncremental";
static const char __pyx_k_PendingSkip___add___locals_must[] = "_PendingSkip.__add__.<locals>.must_skip";
static const char __pyx_k_PendingSkip___add___locals_show[] = "_PendingSkip.__add__.<locals>.show_skip";
static const char __pyx_k_RecursiveGrammarException___str[] = "RecursiveGrammarException.__str__";
static const char __pyx_k_Requires_all_given_class_ParseE[] = "\n    Requires all given :class:`ParseExpression` s to be found in the given order.\n    Expressions may be separated by whitespace.\n    May be constructed using the ``'+'`` operator.\n    May also be constructed using the ``'-'`` operator, which will\n    suppress backtracking.\n\n    Example::\n\n        integer = Word(nums)\n        name_expr = OneOrMore(Word(alphas))\n\n        expr = And([integer(\"id\"), name_expr(\"name\"), integer(\"age\")])\n        # more easily written as:\n        expr = integer(\"id\") + name_expr(\"name\") + integer(\"age\")\n    ";
static const char __pyx_k_Token_for_matching_strings_that[] = "Token for matching strings that match a given regular\n    expression. Defined with string specifying the regular expression in\n    a form recognized by the stdlib Python  `re module <https://docs.python.org/3/library/re.html>`_.\n    If the given regex contains named groups (defined using ``(?P<name>...)``),\n    these will be preserved as named parse results.\n\n    If instead of the Python stdlib re module you wish to use a different RE module\n    (such as the `regex` module), you can replace it by either building your\n    Regex object with a compiled RE that was compiled using regex:\n\n    Example::\n\n        realnum = Regex(r\"[+-]?\\d+\\.\\d*\")\n        date = Regex(r'(?P<year>\\d{4})-(?P<month>\\d\\d?)-(?P<day>\\d\\d?)')\n        # ref: https://stackoverflow.com/questions/267399/how-do-you-match-only-valid-roman-numerals-with-a-regular-expression\n        roman = Regex(r\"M{0,4}(CM|CD|D?{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})\")\n\n        # use regex module instead of stdlib re module to construct a Regex using\n        # a compiled regular expression\n        import regex\n        parser = pp.Regex(regex.compile(r'[0-9]'))\n\n    ";
static const char __pyx_k_Unicode_set_for_Chinese_Unicode[] = "Unicode set for Chinese Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Latin_1_Unicode[] = "Unicode set for Latin-1 Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Latin_A_Unicode[] = "Unicode set for Latin-A Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Latin_B_Unicode[] = "Unicode set for Latin-B Unicode Character Range";
static const char __pyx_k_as_column_list_and_dotted_table[] = "\n        # '*' as column list and dotted table name\n        select * from SYS.XYZZY\n\n        # caseless match on \"SELECT\", and casts back to \"select\"\n        SELECT * from XYZZY, ABC\n\n        # list of column names, and mixed case SELECT keyword\n        Select AA,BB,CC from Sys.dual\n\n        # multiple tables\n        Select A, B, C from Sys.dual, Table2\n\n        # invalid SELECT keyword - should fail\n        Xelect A, B, C from Sys.dual\n\n        # incomplete command - should fail\n        Select\n\n        # invalid column name - should fail\n        Select ^^^ frox Sys.dual\n\n        ";
static const char __pyx_k_cPyparsing_is_an_alternative_im[] = "\ncPyparsing is an alternative implementation of pyparsing in Cython.\n\ncPyparsing is a module by Evan Hubinger released under the Apache 2.0 license.\n\ncPyparsing is based on pyparsing; copyright notice included below:\n\nCopyright (c) 2003-2019  Paul T. McGuire\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.\nIN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY\nCLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,\nTORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE\nSOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n";
static const char __pyx_k_cannot_specify_a_minimum_length[] = "cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted";
static const char __pyx_k_lazyclassproperty___get___local[] = "_lazyclassproperty.__get__.<locals>.genexpr";
static const char __pyx_k_matchOnlyAtCol_locals_verifyCol[] = "matchOnlyAtCol.<locals>.verifyCol";
static const char __pyx_k_namespace_class_for_classes_use[] = "\n    namespace class for classes useful in writing unit tests\n    ";
static const char __pyx_k_null_string_passed_to_Regex_use[] = "null string passed to Regex; use Empty() instead";
static const char __pyx_k_operator_must_be_unary_1_binary[] = "operator must be unary (1), binary (2), or ternary (3)";
static const char __pyx_k_operator_must_indicate_right_or[] = "operator must indicate right or left associativity";
static const char __pyx_k_should_cache_incremental_succes[] = "_should_cache_incremental_success";
static const char __pyx_k_trim_arity_locals_extract_stack[] = "_trim_arity.<locals>.extract_stack";
static const char __pyx_k_user_throwable_exception_thrown[] = "user-throwable exception thrown when inconsistent parse content\n       is found; stops all parsing immediately";
static const char __pyx_k_warn_on_multiple_string_args_to[] = "warn_on_multiple_string_args_to_oneof";
static const char __pyx_k_A_short_cut_class_for_defining_W[] = "A short-cut class for defining ``Word(characters, exact=1)``,\n    when defining a match of any single character in a string of\n    characters.\n    ";
static const char __pyx_k_A_variation_on_class_Literal_whi[] = "A variation on :class:`Literal` which matches \"close\" matches,\n    that is, strings with at most 'n' mismatching characters.\n    :class:`CloseMatch` takes parameters:\n\n     - ``match_string`` - string to be matched\n     - ``maxMismatches`` - (``default=1``) maximum number of\n       mismatches allowed to count as a match\n\n    The results from a successful parse will contain the matched text\n    from the input string and the following named results:\n\n     - ``mismatches`` - a list of the positions within the\n       match_string where mismatches were found\n     - ``original`` - the original match_string used to compare\n       against the input string\n\n    If ``mismatches`` is an empty list, then the match was an exact\n    match.\n\n    Example::\n\n        patt = CloseMatch(\"ATCATCGAATGGA\")\n        patt.parseString(\"ATCATCGAAXGGA\") # -> (['ATCATCGAAXGGA'], {'mismatches': [[9]], 'original': ['ATCATCGAATGGA']})\n        patt.parseString(\"ATCAXCGAAXGGA\") # -> Exception: Expected 'ATCATCGAATGGA' (with up to 1 mismatches) (at char 0), (line:1, col:1)\n\n        # exact match\n        patt.parseString(\"ATCATCGAATGGA\") # -> (['ATCATCGAATGGA'], {'mismatches': [[]], 'original': ['ATCATCGAATGGA']})\n\n        # close match allowing up to 2 mismatches\n        patt = CloseMatch(\"ATCATCGAATGGA\", maxMismatches=2)\n        patt.parseString(\"ATCAXCGAAXGGA\") # -> (['ATCAXCGAAXGGA'], {'mismatches': [[4, 9]], 'original': ['ATCATCGAATGGA']})\n    ";
static const char __pyx_k_Abstract_base_level_parser_eleme[] = "Abstract base level parser element class.";
static const char __pyx_k_Abstract_class_ParserElement_sub[] = "Abstract :class:`ParserElement` subclass, for defining atomic\n    matching patterns.\n    ";
static const char __pyx_k_Abstract_subclass_of_ParserEleme[] = "Abstract subclass of ParserElement, for combining and\n    post-processing parsed tokens.\n    ";
static const char __pyx_k_Abstract_subclass_of_class_Parse[] = "Abstract subclass of :class:`ParserElement`, for combining and\n    post-processing parsed tokens.\n    ";
static const char __pyx_k_An_empty_token_will_always_match[] = "An empty token, will always match.\n    ";
static const char __pyx_k_BaseWithAttribute___call___local[] = "BaseWithAttribute.__call__.<locals>.pa";
static const char __pyx_k_Cannot_combine_element_of_type_s[] = "Cannot combine element of type %s with ParserElement";
static const char __pyx_k_Converter_for_ignoring_the_resul[] = "Converter for ignoring the results of a parsed expression.\n\n    Example::\n\n        source = \"a, b, c,d\"\n        wd = Word(alphas)\n        wd_list1 = wd + ZeroOrMore(',' + wd)\n        print(wd_list1.parseString(source))\n\n        # often, delimiters that are useful during parsing are just in the\n        # way afterward - use Suppress to keep them out of the parsed output\n        wd_list2 = wd + ZeroOrMore(Suppress(',') + wd)\n        print(wd_list2.parseString(source))\n\n    prints::\n\n        ['a', ',', 'b', ',', 'c', ',', 'd']\n        ['a', 'b', 'c', 'd']\n\n    (See also :class:`delimitedList`.)\n    ";
static const char __pyx_k_Converter_to_concatenate_all_mat[] = "Converter to concatenate all matching tokens to a single string.\n    By default, the matching patterns must also be contiguous in the\n    input string; this can be disabled by specifying\n    ``'adjacent=False'`` in the constructor.\n\n    Example::\n\n        real = Word(nums) + '.' + Word(nums)\n        print(real.parseString('3.1416')) # -> ['3', '.', '1416']\n        # will also erroneously match the following\n        print(real.parseString('3. 1416')) # -> ['3', '.', '1416']\n\n        real = Combine(Word(nums) + '.' + Word(nums))\n        print(real.parseString('3.1416')) # -> ['3.1416']\n        # no match when there are internal spaces\n        print(real.parseString('3. 1416')) # -> Exception: Expected W:(0123...)\n    ";
static const char __pyx_k_Converter_to_return_a_repetitive[] = "Converter to return a repetitive expression as a list, but also\n    as a dictionary. Each element can also be referenced using the first\n    token in the expression as its key. Useful for tabular report\n    scraping when the first column can be used as a item key.\n\n    Example::\n\n        data_word = Word(alphas)\n        label = data_word + FollowedBy(':')\n        attr_expr = Group(label + Suppress(':') + OneOrMore(data_word).setParseAction(' '.join))\n\n        text = \"shape: SQUARE posn: upper left color: light blue texture: burlap\"\n        attr_expr = (label + Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join))\n\n        # print attributes as plain groups\n        print(OneOrMore(attr_expr).parseString(text).dump())\n\n        # instead of OneOrMore(expr), parse using Dict(OneOrMore(Group(expr))) - Dict will auto-assign names\n        result = Dict(OneOrMore(Group(attr_expr))).parseString(text)\n        print(result.dump())\n\n        # access named fields as dict entries, or output as dict\n        print(result['shape'])\n        print(result.asDict())\n\n    prints::\n\n        ['shape', 'SQUARE', 'posn', 'upper left', 'color', 'light blue', 'texture', 'burlap']\n        [['shape', 'SQUARE'], ['posn', 'upper left'], ['color', 'light blue'], ['texture', 'burlap']]\n        - color: light blue\n        - posn: upper left\n        - shape: SQUARE\n        - texture: burlap\n        SQUARE\n        {'color': 'light blue', 'posn': 'upper left', 'texture': 'burlap', 'shape': 'SQUARE'}\n\n    See more examples at :class:`ParseResults` of accessing fields by results name.\n    ";
static const char __pyx_k_Evan_Hubinger_evanjhub_gmail_com[] = "Evan Hubinger <evanjhub@gmail.com>";
static const char __pyx_k_Exception_creating_Regex_for_one[] = "Exception creating Regex for oneOf, building MatchFirst";
static const char __pyx_k_Forward_declaration_of_an_expres[] = "Forward declaration of an expression to be defined later -\n    used for recursive grammars, such as algebraic infix notation.\n    When the expression is known, it is assigned to the ``Forward``\n    variable using the '<<' operator.\n\n    Note: take care when assigning to ``Forward`` not to overlook\n    precedence of operators.\n\n    Specifically, '|' has a lower precedence than '<<', so that::\n\n        fwdExpr << a | b | c\n\n    will actually be evaluated as::\n\n        (fwdExpr << a) | b | c\n\n    thereby leaving b and c out as parseable alternatives.  It is recommended that you\n    explicitly group the values inserted into the ``Forward``::\n\n        fwdExpr << (a | b | c)\n\n    Converting to use the '<<=' operator instead will avoid this problem.\n\n    See :class:`ParseResults.pprint` for an example of a recursive\n    parser created using ``Forward``.\n    ";
static const char __pyx_k_Here_are_some_common_low_level_e[] = "Here are some common low-level expressions that may be useful in\n    jump-starting parser development:\n\n     - numeric forms (:class:`integers<integer>`, :class:`reals<real>`,\n       :class:`scientific notation<sci_real>`)\n     - common :class:`programming identifiers<identifier>`\n     - network addresses (:class:`MAC<mac_address>`,\n       :class:`IPv4<ipv4_address>`, :class:`IPv6<ipv6_address>`)\n     - ISO8601 :class:`dates<iso8601_date>` and\n       :class:`datetime<iso8601_datetime>`\n     - :class:`UUID<uuid>`\n     - :class:`comma-separated list<comma_separated_list>`\n\n    Parse actions:\n\n     - :class:`convertToInteger`\n     - :class:`convertToFloat`\n     - :class:`convertToDate`\n     - :class:`convertToDatetime`\n     - :class:`stripHTMLTags`\n     - :class:`upcaseTokens`\n     - :class:`downcaseTokens`\n\n    Example::\n\n        pyparsing_common.number.runTests('''\n            # any int or real number, returned as the appropriate type\n            100\n            -100\n            +100\n            3.14159\n            6.02e23\n            1e-12\n            ''')\n\n        pyparsing_common.fnumber.runTests('''\n            # any int or real number, returned as float\n            100\n            -100\n            +100\n            3.14159\n            6.02e23\n            1e-12\n            ''')\n\n        pyparsing_common.hex_integer.runTests('''\n            # hex numbers\n            100\n            FF\n            ''')\n\n        pyparsing_common.fraction.runTests('''\n            # fractions\n            1/2\n            -3/4\n            ''')\n\n        pyparsing_common.mixed_integer.runTests('''\n            # mixed fractions\n            1\n            1/2\n            -3/4\n            1-3/4\n            ''')\n\n        import uuid\n        pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))\n        pyparsing_common.uuid.runTests('''\n            # uuid\n            12345678-1234-5678-1234-567812345678\n            ''')""\n\n    prints::\n\n        # any int or real number, returned as the appropriate type\n        100\n        [100]\n\n        -100\n        [-100]\n\n        +100\n        [100]\n\n        3.14159\n        [3.14159]\n\n        6.02e23\n        [6.02e+23]\n\n        1e-12\n        [1e-12]\n\n        # any int or real number, returned as float\n        100\n        [100.0]\n\n        -100\n        [-100.0]\n\n        +100\n        [100.0]\n\n        3.14159\n        [3.14159]\n\n        6.02e23\n        [6.02e+23]\n\n        1e-12\n        [1e-12]\n\n        # hex numbers\n        100\n        [256]\n\n        FF\n        [255]\n\n        # fractions\n        1/2\n        [0.5]\n\n        -3/4\n        [-0.75]\n\n        # mixed fractions\n        1\n        [1]\n\n        1/2\n        [0.5]\n\n        -3/4\n        [-0.75]\n\n        1-3/4\n        [1.75]\n\n        # uuid\n        12345678-1234-5678-1234-567812345678\n        [UUID('12345678-1234-5678-1234-567812345678')]\n    ";
static const char __pyx_k_Invalid_argument_to_oneOf_expect[] = "Invalid argument to oneOf, expected string or iterable";
static const char __pyx_k_Lookahead_to_disallow_matching_w[] = "Lookahead to disallow matching with the given parse expression.\n    ``NotAny`` does *not* advance the parsing position within the\n    input string, it only verifies that the specified parse expression\n    does *not* match at the current position.  Also, ``NotAny`` does\n    *not* skip over leading whitespace. ``NotAny`` always returns\n    a null token list.  May be constructed using the '~' operator.\n\n    Example::\n\n        AND, OR, NOT = map(CaselessKeyword, \"AND OR NOT\".split())\n\n        # take care not to mistake keywords for identifiers\n        ident = ~(AND | OR | NOT) + Word(alphas)\n        boolean_term = Optional(NOT) + ident\n\n        # very crude boolean expression - to support parenthesis groups and\n        # operation hierarchy, use infixNotation\n        boolean_expr = boolean_term + ZeroOrMore((AND | OR) + boolean_term)\n\n        # integers that are followed by \".\" are actually floats\n        integer = Word(nums) + ~Char(\".\")\n    ";
static const char __pyx_k_Lookbehind_matching_of_the_given[] = "Lookbehind matching of the given parse expression.\n    ``PrecededBy`` does not advance the parsing position within the\n    input string, it only verifies that the specified parse expression\n    matches prior to the current position.  ``PrecededBy`` always\n    returns a null token list, but if a results name is defined on the\n    given expression, it is returned.\n\n    Parameters:\n\n     - expr - expression that must match prior to the current parse\n       location\n     - retreat - (default= ``None``) - (int) maximum number of characters\n       to lookbehind prior to the current parse location\n\n    If the lookbehind expression is a string, Literal, Keyword, or\n    a Word or CharsNotIn with a specified exact or maximum length, then\n    the retreat parameter is not required. Otherwise, retreat must be\n    specified to give a maximum number of characters to look back from\n    the current parse position for a lookbehind match.\n\n    Example::\n\n        # VB-style variable names with type prefixes\n        int_var = PrecededBy(\"#\") + pyparsing_common.identifier\n        str_var = PrecededBy(\"$\") + pyparsing_common.identifier\n\n    ";
static const char __pyx_k_MatchFirst___init___locals_genex[] = "MatchFirst.__init__.<locals>.genexpr";
static const char __pyx_k_MatchFirst___str___locals_genexp[] = "MatchFirst.__str__.<locals>.genexpr";
static const char __pyx_k_MatchFirst__setResultsName_local[] = "MatchFirst._setResultsName.<locals>.genexpr";
static const char __pyx_k_MatchFirst_streamline_locals_gen[] = "MatchFirst.streamline.<locals>.genexpr";
static const char __pyx_k_Matches_if_current_position_is_a[] = "Matches if current position is at the beginning of a line within\n    the parse string\n\n    Example::\n\n        test = '''\\\n        AAA this line\n        AAA and this line\n          AAA but not this one\n        B AAA and definitely not this one\n        '''\n\n        for t in (LineStart() + 'AAA' + restOfLine).searchString(test):\n            print(t)\n\n    prints::\n\n        ['AAA', ' this line']\n        ['AAA', ' and this line']\n\n    ";
static const char __pyx_k_Missing_one_or_more_required_ele[] = "Missing one or more required elements (%s)";
static const char __pyx_k_More_than_one_string_argument_pa[] = "More than one string argument passed to oneOf, pass choices as a list or space-delimited string";
static const char __pyx_k_Optional_matching_of_the_given_e[] = "Optional matching of the given expression.\n\n    Parameters:\n     - expr - expression that must match zero or more times\n     - default (optional) - value to be returned if the optional expression is not found.\n\n    Example::\n\n        # US postal code can be a 5-digit zip, plus optional 4-digit qualifier\n        zip = Combine(Word(nums, exact=5) + Optional('-' + Word(nums, exact=4)))\n        zip.runTests('''\n            # traditional ZIP code\n            12345\n\n            # ZIP+4 form\n            12101-0001\n\n            # invalid ZIP\n            98765-\n            ''')\n\n    prints::\n\n        # traditional ZIP code\n        12345\n        ['12345']\n\n        # ZIP+4 form\n        12101-0001\n        ['12101-0001']\n\n        # invalid ZIP\n        98765-\n             ^\n        FAIL: Expected end of text (at char 5), (line:1, col:6)\n    ";
static const char __pyx_k_Optional_repetition_of_zero_or_m[] = "Optional repetition of zero or more of the given expression.\n\n    Parameters:\n     - expr - expression that must match zero or more times\n     - stopOn - (default= ``None``) - expression for a terminating sentinel\n          (only required if the sentinel would ordinarily match the repetition\n          expression)\n\n    Example: similar to :class:`OneOrMore`\n    ";
static const char __pyx_k_Or__setResultsName_locals_genexp[] = "Or._setResultsName.<locals>.genexpr";
static const char __pyx_k_P_year_d_4_P_month_d_d_P_day_d_2[] = "(?P<year>\\d{4})-(?P<month>\\d\\d)-(?P<day>\\d\\d)[T ](?P<hour>\\d\\d):(?P<minute>\\d\\d)(:(?P<second>\\d\\d(\\.\\d*)?)?)?(?P<tz>Z|[+-]\\d\\d:?\\d\\d)?";
static const char __pyx_k_ParseBaseException__from_excepti[] = "ParseBaseException._from_exception";
static const char __pyx_k_ParseBaseException_markInputline[] = "ParseBaseException.markInputline";
static const char __pyx_k_ParseElementEnhance_checkRecursi[] = "ParseElementEnhance.checkRecursion";
static const char __pyx_k_ParseElementEnhance_leaveWhitesp[] = "ParseElementEnhance.leaveWhitespace";
static const char __pyx_k_ParseResults___iadd___locals_lam[] = "ParseResults.__iadd__.<locals>.<lambda>";
static const char __pyx_k_ParseResults___str___locals_gene[] = "ParseResults.__str__.<locals>.genexpr";
static const char __pyx_k_ParseResults__iteritems_locals_g[] = "ParseResults._iteritems.<locals>.genexpr";
static const char __pyx_k_ParseResults_asDict_locals_genex[] = "ParseResults.asDict.<locals>.genexpr";
static const char __pyx_k_ParseResults_asDict_locals_toIte[] = "ParseResults.asDict.<locals>.toItem";
static const char __pyx_k_ParseResults_asXML_locals_genexp[] = "ParseResults.asXML.<locals>.genexpr";
static const char __pyx_k_ParseResults_dump_locals_genexpr[] = "ParseResults.dump.<locals>.genexpr";
static const char __pyx_k_ParseResults_from_dict_locals_is[] = "ParseResults.from_dict.<locals>.is_iterable";
static const char __pyx_k_ParserElement___mul___locals_gen[] = "ParserElement.__mul__.<locals>.genexpr";
static const char __pyx_k_ParserElement___mul___locals_mak[] = "ParserElement.__mul__.<locals>.makeOptionalList";
static const char __pyx_k_ParserElement__update_furthest_l[] = "ParserElement._update_furthest_loc_for_regex";
static const char __pyx_k_ParserElement_collectParseElemen[] = "ParserElement.collectParseElements";
static const char __pyx_k_ParserElement_inlineLiteralsUsin[] = "ParserElement.inlineLiteralsUsing";
static const char __pyx_k_ParserElement_setBreak_locals_br[] = "ParserElement.setBreak.<locals>.breaker";
static const char __pyx_k_ParserElement_setDefaultWhitespa[] = "ParserElement.setDefaultWhitespaceChars";
static const char __pyx_k_ParserElement_setParseAction_loc[] = "ParserElement.setParseAction.<locals>.genexpr";
static const char __pyx_k_ParserElement_setWhitespaceChars[] = "ParserElement.setWhitespaceChars";
static const char __pyx_k_PrecededBy___init___locals_lambd[] = "PrecededBy.__init__.<locals>.<lambda>";
static const char __pyx_k_QuotedString___init___locals_gen[] = "QuotedString.__init__.<locals>.genexpr";
static const char __pyx_k_RecursiveGrammarException___init[] = "RecursiveGrammarException.__init__";
static const char __pyx_k_Regex_may_only_be_constructed_wi[] = "Regex may only be constructed with a string or a compiled RE object";
static const char __pyx_k_Repetition_of_one_or_more_of_the[] = "Repetition of one or more of the given expression.\n\n    Parameters:\n     - expr - expression that must match one or more times\n     - stopOn - (default= ``None``) - expression for a terminating sentinel\n          (only required if the sentinel would ordinarily match the repetition\n          expression)\n\n    Example::\n\n        data_word = Word(alphas)\n        label = data_word + FollowedBy(':')\n        attr_expr = Group(label + Suppress(':') + OneOrMore(data_word).setParseAction(' '.join))\n\n        text = \"shape: SQUARE posn: upper left color: BLACK\"\n        OneOrMore(attr_expr).parseString(text).pprint()  # Fail! read 'color' as data instead of next label -> [['shape', 'SQUARE color']]\n\n        # use stopOn attribute for OneOrMore to avoid reading label string as part of the data\n        attr_expr = Group(label + Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join))\n        OneOrMore(attr_expr).parseString(text).pprint() # Better -> [['shape', 'SQUARE'], ['posn', 'upper left'], ['color', 'BLACK']]\n\n        # could also be written as\n        (attr_expr * (1,)).parseString(text).pprint()\n    ";
static const char __pyx_k_Requires_all_given_class_ParseEx[] = "Requires all given :class:`ParseExpression` s to be found, but in\n    any order. Expressions may be separated by whitespace.\n\n    May be constructed using the ``'&'`` operator.\n\n    Example::\n\n        color = oneOf(\"RED ORANGE YELLOW GREEN BLUE PURPLE BLACK WHITE BROWN\")\n        shape_type = oneOf(\"SQUARE CIRCLE TRIANGLE STAR HEXAGON OCTAGON\")\n        integer = Word(nums)\n        shape_attr = \"shape:\" + shape_type(\"shape\")\n        posn_attr = \"posn:\" + Group(integer(\"x\") + ',' + integer(\"y\"))(\"posn\")\n        color_attr = \"color:\" + color(\"color\")\n        size_attr = \"size:\" + integer(\"size\")\n\n        # use Each (using operator '&') to accept attributes in any order\n        # (shape and posn are required, color and size are optional)\n        shape_spec = shape_attr & posn_attr & Optional(color_attr) & Optional(size_attr)\n\n        shape_spec.runTests('''\n            shape: SQUARE color: BLACK posn: 100, 120\n            shape: CIRCLE size: 50 color: BLUE posn: 50,80\n            color:GREEN size:20 shape:TRIANGLE posn:20,40\n            '''\n            )\n\n    prints::\n\n        shape: SQUARE color: BLACK posn: 100, 120\n        ['shape:', 'SQUARE', 'color:', 'BLACK', 'posn:', ['100', ',', '120']]\n        - color: BLACK\n        - posn: ['100', ',', '120']\n          - x: 100\n          - y: 120\n        - shape: SQUARE\n\n\n        shape: CIRCLE size: 50 color: BLUE posn: 50,80\n        ['shape:', 'CIRCLE', 'size:', '50', 'color:', 'BLUE', 'posn:', ['50', ',', '80']]\n        - color: BLUE\n        - posn: ['50', ',', '80']\n          - x: 50\n          - y: 80\n        - shape: CIRCLE\n        - size: 50\n\n\n        color: GREEN size: 20 shape: TRIANGLE posn: 20,40\n        ['color:', 'GREEN', 'size:', '20', 'shape:', 'TRIANGLE', 'posn:', ['20', ',', '40']]\n        - color: GREEN\n        - posn: ['20', ',', '40']\n          - x: 20\n          - y: 40\n        - shape: TRIANGLE\n        - size: 20\n    ";
static const char __pyx_k_Requires_that_at_least_one_class[] = "Requires that at least one :class:`ParseExpression` is found. If\n    two expressions match, the expression that matches the longest\n    string will be used. May be constructed using the ``'^'``\n    operator.\n\n    Example::\n\n        # construct Or using '^' operator\n\n        number = Word(nums) ^ Combine(Word(nums) + '.' + Word(nums))\n        print(number.searchString(\"123 3.1416 789\"))\n\n    prints::\n\n        [['123'], ['3.1416'], ['789']]\n    ";
static const char __pyx_k_Special_matching_class_for_match[] = "Special matching class for matching whitespace.  Normally,\n    whitespace is ignored by pyparsing grammars.  This class is included\n    when some whitespace structures are significant.  Define with\n    a string containing the whitespace characters to be matched; default\n    is ``\" \\t\\r\\n\"``.  Also takes optional ``min``,\n    ``max``, and ``exact`` arguments, as defined for the\n    :class:`Word` class.\n    ";
static const char __pyx_k_Structured_parse_results_to_prov[] = "Structured parse results, to provide multiple means of access to\n    the parsed data:\n\n       - as a list (``len(results)``)\n       - by list index (``results[0], results[1]``, etc.)\n       - by attribute (``results.<resultsName>`` - see :class:`ParserElement.setResultsName`)\n\n    Example::\n\n        integer = Word(nums)\n        date_str = (integer.setResultsName(\"year\") + '/'\n                        + integer.setResultsName(\"month\") + '/'\n                        + integer.setResultsName(\"day\"))\n        # equivalent form:\n        # date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n        # parseString returns a ParseResults object\n        result = date_str.parseString(\"1999/12/31\")\n\n        def test(s, fn=repr):\n            print(\"%s -> %s\" % (s, fn(eval(s))))\n        test(\"list(result)\")\n        test(\"result[0]\")\n        test(\"result['month']\")\n        test(\"result.day\")\n        test(\"'month' in result\")\n        test(\"'minutes' in result\")\n        test(\"result.dump()\", str)\n\n    prints::\n\n        list(result) -> ['1999', '/', '12', '/', '31']\n        result[0] -> '1999'\n        result['month'] -> '12'\n        result.day -> '31'\n        'month' in result -> True\n        'minutes' in result -> False\n        result.dump() -> ['1999', '/', '12', '/', '31']\n        - day: 31\n        - month: 12\n        - year: 1999\n    ";
static const char __pyx_k_Token_for_matching_words_compose[] = "Token for matching words composed of allowed character sets.\n    Defined with string containing all allowed initial characters, an\n    optional string containing allowed body characters (if omitted,\n    defaults to the initial character set), and an optional minimum,\n    maximum, and/or exact length.  The default value for ``min`` is\n    1 (a minimum value < 1 is not valid); the default values for\n    ``max`` and ``exact`` are 0, meaning no maximum or exact\n    length restriction. An optional ``excludeChars`` parameter can\n    list characters that might be found in the input ``bodyChars``\n    string; useful to define a word of all printables except for one or\n    two characters, for instance.\n\n    :class:`srange` is useful for defining custom character set strings\n    for defining ``Word`` expressions, using range notation from\n    regular expression character sets.\n\n    A common mistake is to use :class:`Word` to match a specific literal\n    string, as in ``Word(\"Address\")``. Remember that :class:`Word`\n    uses the string argument to define *sets* of matchable characters.\n    This expression would match \"Add\", \"AAA\", \"dAred\", or any other word\n    made up of the characters 'A', 'd', 'r', 'e', and 's'. To match an\n    exact literal string, use :class:`Literal` or :class:`Keyword`.\n\n    pyparsing includes helper strings for building Words:\n\n     - :class:`alphas`\n     - :class:`nums`\n     - :class:`alphanums`\n     - :class:`hexnums`\n     - :class:`alphas8bit` (alphabetic characters in ASCII range 128-255\n       - accented, tilded, umlauted, etc.)\n     - :class:`punc8bit` (non-alphabetic characters in ASCII range\n       128-255 - currency, symbols, superscripts, diacriticals, etc.)\n     - :class:`printables` (any non-whitespace character)\n\n    Example::\n\n        # a word composed of digits\n        integer = Word(nums) # equivalent to Word(\"0123456789\") or Word(srange(\"0-9\"))\n\n        # a word with a leading capital,"" and zero or more lowercase\n        capital_word = Word(alphas.upper(), alphas.lower())\n\n        # hostnames are alphanumeric, with leading alpha, and '-'\n        hostname = Word(alphas, alphanums + '-')\n\n        # roman numeral (not a strict parser, accepts invalid mix of characters)\n        roman = Word(\"IVXLCDM\")\n\n        # any string of non-whitespace characters, except for ','\n        csv_value = Word(printables, excludeChars=\",\")\n    ";
static const char __pyx_k_Token_for_skipping_over_all_unde[] = "Token for skipping over all undefined text until the matched\n    expression is found.\n\n    Parameters:\n     - expr - target expression marking the end of the data to be skipped\n     - include - (default= ``False``) if True, the target expression is also parsed\n          (the skipped text and target expression are returned as a 2-element list).\n     - ignore - (default= ``None``) used to define grammars (typically quoted strings and\n          comments) that might contain false matches to the target expression\n     - failOn - (default= ``None``) define expressions that are not allowed to be\n          included in the skipped test; if found before the target expression is found,\n          the SkipTo is not a match\n\n    Example::\n\n        report = '''\n            Outstanding Issues Report - 1 Jan 2000\n\n               # | Severity | Description                               |  Days Open\n            -----+----------+-------------------------------------------+-----------\n             101 | Critical | Intermittent system crash                 |          6\n              94 | Cosmetic | Spelling error on Login ('log|n')         |         14\n              79 | Minor    | System slow when running too many reports |         47\n            '''\n        integer = Word(nums)\n        SEP = Suppress('|')\n        # use SkipTo to simply match everything up until the next SEP\n        # - ignore quoted strings, so that a '|' character inside a quoted string does not match\n        # - parse action will call token.strip() for each matched token, i.e., the description body\n        string_data = SkipTo(SEP, ignore=quotedString)\n        string_data.setParseAction(tokenMap(str.strip))\n        ticket_expr = (integer(\"issue_num\") + SEP\n                      + string_data(\"sev\") + SEP\n                      + string_data(\"desc\") + SEP\n                      + integer(\"days_open\"))\n\n        for tkt in ticket_expr.searchString(report):\n            print tkt"".dump()\n\n    prints::\n\n        ['101', 'Critical', 'Intermittent system crash', '6']\n        - days_open: 6\n        - desc: Intermittent system crash\n        - issue_num: 101\n        - sev: Critical\n        ['94', 'Cosmetic', \"Spelling error on Login ('log|n')\", '14']\n        - days_open: 14\n        - desc: Spelling error on Login ('log|n')\n        - issue_num: 94\n        - sev: Cosmetic\n        ['79', 'Minor', 'System slow when running too many reports', '47']\n        - days_open: 47\n        - desc: System slow when running too many reports\n        - issue_num: 79\n        - sev: Minor\n    ";
static const char __pyx_k_Token_to_advance_to_a_specific_c[] = "Token to advance to a specific column of input text; useful for\n    tabular report scraping.\n    ";
static const char __pyx_k_Token_to_exactly_match_a_specifi[] = "Token to exactly match a specified string.\n\n    Example::\n\n        Literal('blah').parseString('blah')  # -> ['blah']\n        Literal('blah').parseString('blahfooblah')  # -> ['blah']\n        Literal('blah').parseString('bla')  # -> Exception: Expected \"blah\"\n\n    For case-insensitive matching, use :class:`CaselessLiteral`.\n\n    For keyword matching (force word break before and after the matched string),\n    use :class:`Keyword` or :class:`CaselessKeyword`.\n    ";
static const char __pyx_k_Token_to_match_a_specified_strin[] = "Token to match a specified string, ignoring case of letters.\n    Note: the matched results will always be in the case of the given\n    match string, NOT the case of the input text.\n\n    Example::\n\n        OneOrMore(CaselessLiteral(\"CMD\")).parseString(\"cmd CMD Cmd10\") # -> ['CMD', 'CMD', 'CMD']\n\n    (Contrast with example for :class:`CaselessKeyword`.)\n    ";
static const char __pyx_k_Unicode_set_for_Arabic_Unicode_C[] = "Unicode set for Arabic Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Cyrillic_Unicode[] = "Unicode set for Cyrillic Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Devanagari_Unico[] = "Unicode set for Devanagari Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Greek_Unicode_Ch[] = "Unicode set for Greek Unicode Character Ranges";
static const char __pyx_k_Unicode_set_for_Hebrew_Unicode_C[] = "Unicode set for Hebrew Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Hiragana_Unicode[] = "Unicode set for Hiragana Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Japanese_Unicode[] = "Unicode set for Japanese Unicode Character Range, combining Kanji, Hiragana, and Katakana ranges";
static const char __pyx_k_Unicode_set_for_Kanji_Unicode_Ch[] = "Unicode set for Kanji Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Katakana_Unicode[] = "Unicode set for Katakana  Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Korean_Unicode_C[] = "Unicode set for Korean Unicode Character Range";
static const char __pyx_k_Unicode_set_for_Thai_Unicode_Cha[] = "Unicode set for Thai Unicode Character Range";
static const char __pyx_k_Unicode_set_for_combined_Chinese[] = "Unicode set for combined Chinese, Japanese, and Korean (CJK) Unicode Character Range";
static const char __pyx_k_Wrapper_for_parse_actions_to_ens[] = "Wrapper for parse actions, to ensure they are only called once.\n    ";
static const char __pyx_k_base_exception_class_for_all_par[] = "base exception class for all parsing runtime exceptions";
static const char __pyx_k_cannot_construct_And_with_sequen[] = "cannot construct And with sequence ending in ...";
static const char __pyx_k_cannot_multiply_ParserElement_an[] = "cannot multiply 'ParserElement' and ('%s', '%s') objects";
static const char __pyx_k_cannot_multiply_ParserElement_by[] = "cannot multiply ParserElement by negative value";
static const char __pyx_k_cannot_use_sub_with_Regex_asGrou[] = "cannot use sub() with Regex(asGroupList=True)";
static const char __pyx_k_cannot_use_sub_with_a_callable_w[] = "cannot use sub() with a callable with Regex(asMatch=True)";
static const char __pyx_k_conditionAsParseAction_locals_pa[] = "conditionAsParseAction.<locals>.pa";
static const char __pyx_k_countedArray_locals_countFieldPa[] = "countedArray.<locals>.countFieldParseAction";
static const char __pyx_k_enable_debug_on_named_expression[] = "enable_debug_on_named_expressions";
static const char __pyx_k_endQuoteChar_cannot_be_the_empty[] = "endQuoteChar cannot be the empty string";
static const char __pyx_k_exception_raised_in_parse_action[] = "exception raised in parse action";
static const char __pyx_k_exception_thrown_by_class_Parser[] = "exception thrown by :class:`ParserElement.validate` if the\n    grammar could be improperly recursive\n    ";
static const char __pyx_k_found_multiline_regex_during_inc[] = "found multiline regex during incremental parsing; will hurt performance: ";
static const char __pyx_k_fraction_or_mixed_integer_fracti[] = "fraction or mixed integer-fraction";
static const char __pyx_k_if_numterms_3_opExpr_must_be_a_t[] = "if numterms=3, opExpr must be a tuple or list of two expressions";
static const char __pyx_k_indentedBlock_locals_checkPeerIn[] = "indentedBlock.<locals>.checkPeerIndent";
static const char __pyx_k_indentedBlock_locals_checkSubInd[] = "indentedBlock.<locals>.checkSubIndent";
static const char __pyx_k_indentedBlock_locals_checkUninde[] = "indentedBlock.<locals>.checkUnindent";
static const char __pyx_k_indentedBlock_locals_reset_stack[] = "indentedBlock.<locals>.reset_stack";
static const char __pyx_k_infixNotation_locals__FB_parseIm[] = "infixNotation.<locals>._FB.parseImpl";
static const char __pyx_k_invalid_pattern_s_passed_to_Rege[] = "invalid pattern (%s) passed to Regex";
static const char __pyx_k_just_like_class_ParseFatalExcept[] = "just like :class:`ParseFatalException`, but thrown internally\n    when an :class:`ErrorStop<And._ErrorStop>` ('-' operator) indicates\n    that parsing is to stop immediately because an unbacktrackable\n    syntax error has been found.\n    ";
static const char __pyx_k_matchPreviousExpr_locals_copyTok[] = "matchPreviousExpr.<locals>.copyTokenToRepeater.<locals>.mustMatchTheseTokens";
static const char __pyx_k_matchPreviousLiteral_locals_copy[] = "matchPreviousLiteral.<locals>.copyTokenToRepeater.<locals>.genexpr";
static const char __pyx_k_no_defined_alternatives_to_match[] = "no defined alternatives to match";
static const char __pyx_k_null_string_passed_to_Keyword_us[] = "null string passed to Keyword; use Empty() instead";
static const char __pyx_k_null_string_passed_to_Literal_us[] = "null string passed to Literal; use Empty() instead";
static const char __pyx_k_only_1_or_2_index_arguments_supp[] = "only 1 or 2 index arguments supported ({0}{1})";
static const char __pyx_k_opening_and_closing_arguments_mu[] = "opening and closing arguments must be strings if no content expression is given";
static const char __pyx_k_opening_and_closing_strings_cann[] = "opening and closing strings cannot be the same";
static const char __pyx_k_originalTextFor_locals_extractTe[] = "originalTextFor.<locals>.extractText";
static const char __pyx_k_pop_got_an_unexpected_keyword_ar[] = "pop() got an unexpected keyword argument '%s'";
static const char __pyx_k_pyparsing_common_convertToDate_l[] = "pyparsing_common.convertToDate.<locals>.cvt_fn";
static const char __pyx_k_pyparsing_common_convertToDateti[] = "pyparsing_common.convertToDatetime.<locals>.cvt_fn";
static const char __pyx_k_pyparsing_common_lambda_locals_g[] = "pyparsing_common.<lambda>.<locals>.genexpr";
static const char __pyx_k_pyparsing_test_TestParseResultsA[] = "pyparsing_test.TestParseResultsAsserts.assertRunTestResults.<locals>.genexpr";
static const char __pyx_k_pyparsing_test_reset_pyparsing_c[] = "pyparsing_test.reset_pyparsing_context";
static const char __pyx_k_pyparsing_unicode_Japanese_Hirag[] = "pyparsing_unicode.Japanese.Hiragana";
static const char __pyx_k_pyparsing_unicode_Japanese_Kanji[] = "pyparsing_unicode.Japanese.Kanji";
static const char __pyx_k_pyparsing_unicode_Japanese_Katak[] = "pyparsing_unicode.Japanese.Katakana";
static const char __pyx_k_quoteChar_cannot_be_the_empty_st[] = "quoteChar cannot be the empty string";
static const char __pyx_k_quotedString_using_single_or_dou[] = "quotedString using single or double quotes";
static const char __pyx_k_real_number_with_scientific_nota[] = "real number with scientific notation";
static const char __pyx_k_second_tuple_value_must_be_great[] = "second tuple value must be greater or equal to first tuple value";
static const char __pyx_k_srange_locals_lambda_locals_gene[] = "srange.<locals>.<lambda>.<locals>.genexpr";
static const char __pyx_k_string_enclosed_in_double_quotes[] = "string enclosed in double quotes";
static const char __pyx_k_string_enclosed_in_single_quotes[] = "string enclosed in single quotes";
static const char __pyx_k_sum_len_sorted_reversed_list_tup[] = "sum len sorted reversed list tuple set any all min max";
static const char __pyx_k_unicode_set__get_chars_for_range[] = "unicode_set._get_chars_for_ranges";
static const char __pyx_k_use_of_expression_without_follow[] = "use of `...` expression without following SkipTo target expression";
static const char __pyx_k_warn_multiple_tokens_in_named_al[] = "warn_multiple_tokens_in_named_alternation";
static const char __pyx_k_warn_on_incremental_multiline_re[] = "warn_on_incremental_multiline_regex";
static const char __pyx_k_warn_ungrouped_named_tokens_in_c[] = "warn_ungrouped_named_tokens_in_collection";
static const char __pyx_k_0_setting_results_name_1_r_on_2_2[] = "{0}: setting results name {1!r} on {2} expression may only return a single token for an And alternative, in future will return the full list of tokens";
static const char __pyx_k_Matches_if_the_current_position_2[] = "Matches if the current position is at the end of a Word, and is\n    not followed by any character in a given set of ``wordChars``\n    (default= ``printables``). To emulate the ``\010`` behavior of\n    regular expressions, use ``WordEnd(alphanums)``. ``WordEnd``\n    will also match at the end of the string being parsed, or at the end\n    of a line.\n    ";
static const char __pyx_k_ParseExpression___init___locals_2[] = "ParseExpression.__init__.<locals>.<lambda>";
static const char __pyx_k_ParserElement__parseIncremental_2[] = "ParserElement._parseIncremental";
static const char __pyx_k_Token_for_matching_strings_that_2[] = "\n    Token for matching strings that are delimited by quoting characters.\n\n    Defined with the following parameters:\n\n        - quoteChar - string of one or more characters defining the\n          quote delimiting string\n        - escChar - character to escape quotes, typically backslash\n          (default= ``None``)\n        - escQuote - special quote sequence to escape an embedded quote\n          string (such as SQL's ``\"\"`` to escape an embedded ``\"``)\n          (default= ``None``)\n        - multiline - boolean indicating whether quotes can span\n          multiple lines (default= ``False``)\n        - unquoteResults - boolean indicating whether the matched text\n          should be unquoted (default= ``True``)\n        - endQuoteChar - string of one or more characters defining the\n          end of the quote delimited string (default= ``None``  => same as\n          quoteChar)\n        - convertWhitespaceEscapes - convert escaped whitespace\n          (``'\\t'``, ``'\\n'``, etc.) to actual whitespace\n          (default= ``True``)\n\n    Example::\n\n        qs = QuotedString('\"')\n        print(qs.searchString('lsjdf \"This is the quote\" sldjf'))\n        complex_qs = QuotedString('{{', endQuoteChar='}}')\n        print(complex_qs.searchString('lsjdf {{This is the \"quote\"}} sldjf'))\n        sql_qs = QuotedString('\"', escQuote='\"\"')\n        print(sql_qs.searchString('lsjdf \"This is the quote with \"\"embedded\"\" quotes\" sldjf'))\n\n    prints::\n\n        [['This is the quote']]\n        [['This is the \"quote\"']]\n        [['This is the quote with \"embedded\" quotes']]\n    ";
static const char __pyx_k_cannot_specify_a_minimum_length_2[] = "cannot specify a minimum length < 1; use Optional(CharsNotIn()) if zero-length char group is permitted";
static const char __pyx_k_Matches_if_current_position_is_a_2[] = "Matches if current position is at the end of a line within the\n    parse string\n    ";
static const char __pyx_k_Matches_if_current_position_is_a_3[] = "Matches if current position is at the beginning of the parse\n    string\n    ";
static const char __pyx_k_Matches_if_current_position_is_a_4[] = "Matches if current position is at the end of the parse string\n    ";
static const char __pyx_k_Requires_that_at_least_one_class_2[] = "Requires that at least one :class:`ParseExpression` is found. If\n    two expressions match, the first one listed is the one that will\n    match. May be constructed using the ``'|'`` operator.\n\n    Example::\n\n        # construct MatchFirst using '|' operator\n\n        # watch the order of expressions to match\n        number = Word(nums) | Combine(Word(nums) + '.' + Word(nums))\n        print(number.searchString(\"123 3.1416 789\")) #  Fail! -> [['123'], ['3'], ['1416'], ['789']]\n\n        # put more selective expression first\n        number = Combine(Word(nums) + '.' + Word(nums)) | Word(nums)\n        print(number.searchString(\"123 3.1416 789\")) #  Better -> [['123'], ['3.1416'], ['789']]\n    ";
static const char __pyx_k_Token_for_matching_words_compose_2[] = "Token for matching words composed of characters *not* in a given\n    set (will include whitespace in matched characters if not listed in\n    the provided exclusion set - see example). Defined with string\n    containing all disallowed characters, and an optional minimum,\n    maximum, and/or exact length.  The default value for ``min`` is\n    1 (a minimum value < 1 is not valid); the default values for\n    ``max`` and ``exact`` are 0, meaning no maximum or exact\n    length restriction.\n\n    Example::\n\n        # define a comma-separated-value as anything that is not a ','\n        csv_value = CharsNotIn(',')\n        print(delimitedList(csv_value).parseString(\"dkls,lsdkjf,s12 34,@!#,213\"))\n\n    prints::\n\n        ['dkls', 'lsdkjf', 's12 34', '@!#', '213']\n    ";
static const char __pyx_k_Token_to_exactly_match_a_specifi_2[] = "Token to exactly match a specified string as a keyword, that is,\n    it must be immediately followed by a non-keyword character.  Compare\n    with :class:`Literal`:\n\n     - ``Literal(\"if\")`` will match the leading ``'if'`` in\n       ``'ifAndOnlyIf'``.\n     - ``Keyword(\"if\")`` will not; it will only match the leading\n       ``'if'`` in ``'if x=1'``, or ``'if(y==2)'``\n\n    Accepts two optional constructor arguments in addition to the\n    keyword string:\n\n     - ``identChars`` is a string of characters that would be valid\n       identifier characters, defaulting to all alphanumerics + \"_\" and\n       \"$\"\n     - ``caseless`` allows case-insensitive matching, default is ``False``.\n\n    Example::\n\n        Keyword(\"start\").parseString(\"start\")  # -> ['start']\n        Keyword(\"start\").parseString(\"starting\")  # -> Exception\n\n    For case-insensitive matching, use :class:`CaselessKeyword`.\n    ";
static const char __pyx_k_cannot_multiply_ParserElement_an_2[] = "cannot multiply 'ParserElement' and '%s' objects";
static const char __pyx_k_cannot_multiply_ParserElement_by_2[] = "cannot multiply ParserElement by 0 or (0, 0)";
static const char __pyx_k_matchPreviousExpr_locals_copyTok_2[] = "matchPreviousExpr.<locals>.copyTokenToRepeater";
static const char __pyx_k_matchPreviousLiteral_locals_copy_2[] = "matchPreviousLiteral.<locals>.copyTokenToRepeater";
static const char __pyx_k_pyparsing_common_convertToDateti_2[] = "pyparsing_common.convertToDatetime";
static const char __pyx_k_pyparsing_test_TestParseResultsA_2[] = "pyparsing_test.TestParseResultsAsserts.assertRaisesParseException";
static const char __pyx_k_pyparsing_test_TestParseResultsA_3[] = "pyparsing_test.TestParseResultsAsserts";
static const char __pyx_k_pyparsing_test_TestParseResultsA_4[] = "pyparsing_test.TestParseResultsAsserts.assertParseResultsEquals";
static const char __pyx_k_pyparsing_test_TestParseResultsA_5[] = "pyparsing_test.TestParseResultsAsserts.assertParseAndCheckList";
static const char __pyx_k_pyparsing_test_TestParseResultsA_6[] = "pyparsing_test.TestParseResultsAsserts.assertParseAndCheckDict";
static const char __pyx_k_pyparsing_test_TestParseResultsA_7[] = "pyparsing_test.TestParseResultsAsserts.assertRunTestResults";
static const char __pyx_k_pyparsing_test_reset_pyparsing_c_2[] = "pyparsing_test.reset_pyparsing_context.__init__";
static const char __pyx_k_pyparsing_test_reset_pyparsing_c_3[] = "pyparsing_test.reset_pyparsing_context.save";
static const char __pyx_k_pyparsing_test_reset_pyparsing_c_4[] = "pyparsing_test.reset_pyparsing_context.restore";
static const char __pyx_k_pyparsing_test_reset_pyparsing_c_5[] = "pyparsing_test.reset_pyparsing_context.__enter__";
static const char __pyx_k_pyparsing_test_reset_pyparsing_c_6[] = "pyparsing_test.reset_pyparsing_context.__exit__";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_10cPyparsing_78genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_81genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda54(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda55(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda56(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda61(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda62(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing__enable_all_warnings(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2repr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4_ustr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8list_str_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6list_str(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_l); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11_xml_escape_genexpr(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8_xml_escape(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_10cPyparsing_22conditionAsParseAction_pa(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10conditionAsParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fn, PyObject *__pyx_v_message, PyObject *__pyx_v_fatal); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_pstr, PyObject *__pyx_v_loc, PyObject *__pyx_v_msg, PyObject *__pyx_v_elem); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_2_from_exception(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_pe); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_4__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_aname); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_8__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_10markInputline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_markerString); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_12__dir__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14ParseException_explain(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_depth); /* proto */
static PyObject *__pyx_pf_10cPyparsing_25RecursiveGrammarException___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_25RecursiveGrammarException_2__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_p1, PyObject *__pyx_v_p2); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_2__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_6setOffset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_toklist, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_asList, CYTHON_UNUSED PyObject *__pyx_v_modal); /* proto */
static PyObject *__pyx_pf_10cPyparsing_89__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_2__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_toklist, PyObject *__pyx_v_name, PyObject *__pyx_v_asList, PyObject *__pyx_v_modal, PyObject *__pyx_v_isinstance); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_10cPyparsing_91__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6__setitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_v, PyObject *__pyx_v_isinstance); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_8__delitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_10__contains__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_k); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_12__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_14__bool__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_16__iter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_18__reversed__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_20_iterkeys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_11_itervalues_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_22_itervalues(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_10_iteritems_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_24_iteritems(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_26keys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_28values(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_30items(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_32haskeys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_34pop(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_36get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_defaultValue); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_38insert(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_insStr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_40append(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_42extend(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_itemseq); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_44clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_46__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_48__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda6(PyObject *__pyx_self, PyObject *__pyx_v_a); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_50__iadd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_52__radd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_54__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_56__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_58_asStringList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sep); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_60asList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6asDict_2genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_62asDict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_64copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_5asXML_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_66asXML(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_doctag, PyObject *__pyx_v_namedItemsOnly, PyObject *__pyx_v_indent, PyObject *__pyx_v_formatted); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_68__lookup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sub); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_70getName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4dump_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4dump_3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_72dump(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_indent, PyObject *__pyx_v_full, PyObject *__pyx_v_include_list, PyObject *__pyx_v__depth); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_74pprint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_76__getstate__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_78__setstate__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_80__getnewargs__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_82__dir__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_9from_dict_is_iterable(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_84from_dict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_other, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12col(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_loc, PyObject *__pyx_v_strg); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14lineno(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_loc, PyObject *__pyx_v_strg); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16line(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_loc, PyObject *__pyx_v_strg); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18_defaultStartDebugAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_20_defaultSuccessDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_startloc, CYTHON_UNUSED PyObject *__pyx_v_endloc, PyObject *__pyx_v_expr, PyObject *__pyx_v_toks); /* proto */
static PyObject *__pyx_pf_10cPyparsing_22_defaultExceptionDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_expr, PyObject *__pyx_v_exc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_24nullDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_extract_stack(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_limit); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_2extract_tb(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tb, PyObject *__pyx_v_limit); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_4wrapper(PyObject *__pyx_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda12(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_26_trim_arity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_maxargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_2get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_4set(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_6update(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_update_dict); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_10__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_12__reduce__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_size); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_2get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_4set(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_6update(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_update_dict); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_10__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_12__reduce__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_14__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_size); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_16get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_18set(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_20clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_22__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_24__reduce__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_setDefaultWhitespaceChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_2inlineLiteralsUsing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_4_trim_traceback(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_cls, PyObject *__pyx_v_tb); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_6collectParseElements(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_8__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_10copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_12setName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_14setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_16_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_8setBreak_breaker(PyObject *__pyx_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_18setBreak(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_breakFlag); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_14setParseAction_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_20setParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_22addParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_24addCondition(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_26setFailAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fn); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_28_skipIgnorables(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_30preParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_32parseImpl(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_34postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_36_parseNoCache(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_38tryParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_40canParseNext(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_42_parseCache(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_44_update_furthest_loc_for_regex(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_flags); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda14(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s_pl_sl); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_46_parseIncremental(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_48resetCache(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_50enableIncremental(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cache_size_limit, PyObject *__pyx_v_still_reset_cache, PyObject *__pyx_v_cache_successes); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_52enablePackrat(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cache_size_limit); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_54parseString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_parseAll); /* proto */
static PyObject *__pyx_pf_10cPyparsing_93__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_56scanString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxMatches, PyObject *__pyx_v_overlap); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_59transformString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring); /* proto */
static PyObject *__pyx_pf_10cPyparsing_95__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_61searchString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_97__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_63split(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxsplit, PyObject *__pyx_v_includeSeparators); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_66__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_68__radd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_70__sub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_72__rsub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(PyObject *__pyx_self, PyObject *__pyx_v_n); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_7__mul___2genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_74__mul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_76__rmul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_78__or__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_80__ror__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_82__xor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_84__rxor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_86__and__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_88__rand__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_90__invert__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_92__iter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_94__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_96__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_98suppress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_100leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_102setWhitespaceChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_chars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_104parseWithTabs(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_106ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_108setDebugActions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_startAction, PyObject *__pyx_v_successAction, PyObject *__pyx_v_exceptionAction); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_110setDebug(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_flag); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_112__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_114__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_116streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_118checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_120validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_validateTrace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_122parseFile(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_file_or_filename, PyObject *__pyx_v_parseAll); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_124__eq__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_126__ne__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_128__hash__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_130__req__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_132__rne__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_134matches(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_testString, PyObject *__pyx_v_parseAll); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_136runTests(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_tests, PyObject *__pyx_v_parseAll, PyObject *__pyx_v_comment, PyObject *__pyx_v_fullDump, PyObject *__pyx_v_printResults, PyObject *__pyx_v_failureTests, PyObject *__pyx_v_postParse, PyObject *__pyx_v_file); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_must_skip); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_7__add___must_skip(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_7__add___2show_skip(PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_2__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_6parseImpl(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Token___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Empty___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7NoMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7NoMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Literal___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Literal_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18_SingleCharLiteral_parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Keyword___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString, PyObject *__pyx_v_identChars, PyObject *__pyx_v_caseless); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Keyword_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Keyword_4copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Keyword_6setDefaultKeywordChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15CaselessLiteral___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15CaselessLiteral_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15CaselessKeyword___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString, PyObject *__pyx_v_identChars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CloseMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_match_string, PyObject *__pyx_v_maxMismatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CloseMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_8__init___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_8__init___3genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_initChars, PyObject *__pyx_v_bodyChars, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact, PyObject *__pyx_v_asKeyword, PyObject *__pyx_v_excludeChars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_WordRegex_parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Char___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_charset, PyObject *__pyx_v_asKeyword, PyObject *__pyx_v_excludeChars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_pattern, PyObject *__pyx_v_flags, PyObject *__pyx_v_asGroupList, PyObject *__pyx_v_asMatch); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex_4parseImplAsGroupList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex_6parseImplAsMatch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex_8__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex_3sub_pa(PyObject *__pyx_self, PyObject *__pyx_v_tokens); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex_3sub_2pa(PyObject *__pyx_self, PyObject *__pyx_v_tokens); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex_10sub(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_repl); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12QuotedString_8__init___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12QuotedString___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_quoteChar, PyObject *__pyx_v_escChar, PyObject *__pyx_v_escQuote, PyObject *__pyx_v_multiline, PyObject *__pyx_v_unquoteResults, PyObject *__pyx_v_endQuoteChar, PyObject *__pyx_v_convertWhitespaceEscapes); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12QuotedString_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12QuotedString_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_notChars, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5White_8__init___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5White_8__init___3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5White___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ws, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5White_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14_PositionToken___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10GoToColumn___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_colno); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10GoToColumn_2preParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10GoToColumn_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9LineStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9LineStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7LineEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7LineEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11StringStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11StringStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9StringEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9StringEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_99__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9WordStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_wordChars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9WordStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_101__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7WordEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_wordChars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7WordEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda22(PyObject *__pyx_self, PyObject *__pyx_v_e); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_2append(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_4leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_6ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_8__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_10streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_12validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_14copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_16_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_ErrorStop___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_10streamline_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_10streamline_3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_2streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_6__iadd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_8checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_10__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_10streamline_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_2streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_6__ixor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_8__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_10checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_15_setResultsName_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_12_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_10streamline_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_2streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_4setAdaptiveMode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_on, PyObject *__pyx_v_usage_weight, PyObject *__pyx_v_allow_unused_expr_order, PyObject *__pyx_v_adaptive_usage_check_rate); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_6parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_8__ior__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_10__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_12checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_15_setResultsName_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_14_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_10streamline_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_2streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_9parseImpl_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_9parseImpl_3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_8checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_4leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_6ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_8streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_10checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_12validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_14__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10FollowedBy___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10FollowedBy_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda40(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10PrecededBy___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_retreat); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10PrecededBy_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6NotAny___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6NotAny_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6NotAny_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_stopOn); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch_2stopOn(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ender); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch_6_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9OneOrMore___str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_stopOn); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_NullToken___bool__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_NullToken_2__str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_103__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Optional___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Optional_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Optional_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6SkipTo___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_ignore, PyObject *__pyx_v_failOn, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6SkipTo_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_2__lshift__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_4__ilshift__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_6leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_8streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_10validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_12__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_14copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_16_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14TokenConverter___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, CYTHON_UNUSED PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Combine___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_joinString, PyObject *__pyx_v_adjacent); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Combine_2ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Combine_4postParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Group___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Group_2postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Dict___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Dict_2postParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Suppress_postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Suppress_2suppress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_methodCall); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce_4reset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16traceParseAction_z(PyObject *__pyx_self, PyObject *__pyx_v_paArgs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_28traceParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_f); /* proto */
static PyObject *__pyx_pf_10cPyparsing_30delimitedList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_delim, PyObject *__pyx_v_combine); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12countedArray_countFieldParseAction(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda41(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_32countedArray(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_intExpr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_34_flatten(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_L); /* proto */
static PyObject *__pyx_pf_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_20matchPreviousLiteral_copyTokenToRepeater(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_36matchPreviousLiteral(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_mustMatchTheseTokens(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_17matchPreviousExpr_copyTokenToRepeater(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_38matchPreviousExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_40_escapeRegexRangeChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda43(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda44(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda45(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda46(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5oneOf_4genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5oneOf_7genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5oneOf_10genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_42oneOf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_strs, PyObject *__pyx_v_caseless, PyObject *__pyx_v_useRegex, PyObject *__pyx_v_asKeyword); /* proto */
static PyObject *__pyx_pf_10cPyparsing_44dictOf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15originalTextFor_extractText(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda50(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda51(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_46originalTextFor(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_asString); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda52(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_48ungroup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda53(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_50locatedExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6srange_8lambda57_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda57(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_p); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6srange_1genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_52srange(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14matchOnlyAtCol_verifyCol(PyObject *__pyx_self, PyObject *__pyx_v_strg, PyObject *__pyx_v_locn, CYTHON_UNUSED PyObject *__pyx_v_toks); /* proto */
static PyObject *__pyx_pf_10cPyparsing_54matchOnlyAtCol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_n); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda60(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_56replaceWith(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_replStr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_58removeQuotes(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8tokenMap_pa(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_60tokenMap(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_10cPyparsing_105__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda63(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda64(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda65(PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_62_makeTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr, PyObject *__pyx_v_xml, PyObject *__pyx_v_suppress_LT, PyObject *__pyx_v_suppress_GT); /* proto */
static PyObject *__pyx_pf_10cPyparsing_64makeHTMLTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_66makeXMLTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_17BaseWithAttribute_8__call___pa(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_tokens); /* proto */
static PyObject *__pyx_pf_10cPyparsing_17BaseWithAttribute___call__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_attrDict); /* proto */
static PyObject *__pyx_pf_10cPyparsing_68withClass(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_classname, PyObject *__pyx_v_namespace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_107__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13infixNotation_3_FB_parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_70infixNotation(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_baseExpr, PyObject *__pyx_v_opList, PyObject *__pyx_v_lpar, PyObject *__pyx_v_rpar); /* proto */
static PyObject *__pyx_pf_10cPyparsing_109__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda66(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda67(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda68(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda69(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_72nestedExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_opener, PyObject *__pyx_v_closer, PyObject *__pyx_v_content, PyObject *__pyx_v_ignoreExpr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_reset_stack(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_2checkPeerIndent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_4checkSubIndent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_6checkUnindent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda70(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_a, CYTHON_UNUSED PyObject *__pyx_v_b, CYTHON_UNUSED PyObject *__pyx_v_c, CYTHON_UNUSED PyObject *__pyx_v_d); /* proto */
static PyObject *__pyx_pf_10cPyparsing_74indentedBlock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_blockStatementExpr, PyObject *__pyx_v_indentStack, PyObject *__pyx_v_indent); /* proto */
static PyObject *__pyx_pf_10cPyparsing_76replaceHTMLEntity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda71(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_8lambda72_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda72(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda74(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda75(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_13convertToDate_cvt_fn(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_convertToDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fmt); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_17convertToDatetime_cvt_fn(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_2convertToDatetime(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fmt); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_4stripHTMLTags(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_tokens); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18_lazyclassproperty___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fn); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18_lazyclassproperty_7__get___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18_lazyclassproperty_2__get__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11unicode_set__get_chars_for_ranges(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11unicode_set_2printables(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11unicode_set_4alphas(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11unicode_set_6nums(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11unicode_set_8alphanums(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context_2save(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context_4restore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context_6__enter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context_8__exit__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_assertParseResultsEquals(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_result, PyObject *__pyx_v_expected_list, PyObject *__pyx_v_expected_dict, PyObject *__pyx_v_msg); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_2assertParseAndCheckList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_test_string, PyObject *__pyx_v_expected_list, PyObject *__pyx_v_msg, PyObject *__pyx_v_verbose); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_4assertParseAndCheckDict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_test_string, PyObject *__pyx_v_expected_dict, PyObject *__pyx_v_msg, PyObject *__pyx_v_verbose); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_6genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_9genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_6assertRunTestResults(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_run_tests_report, PyObject *__pyx_v_expected_parse_results, PyObject *__pyx_v_msg); /* proto */
static PyObject *__pyx_pf_10cPyparsing_111__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_8assertRaisesParseException(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc_type, PyObject *__pyx_v_msg); /* proto */
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct__genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_1_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_2_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_3_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_5__itervalues(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_6_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_7__iteritems(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_8_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_9___iadd__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_10_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_11_asDict(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_12_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_13_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_14_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_15_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_16__trim_arity(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_17_setBreak(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_18_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_19_scanString(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_20_split(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_21___mul__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_22_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_23___add__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_24___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_25_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_26_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_27_sub(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_28___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_29_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_30___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_31_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_32_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_33___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_34_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_35_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_36_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_37_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_38_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_39_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_40_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_41_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_42_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_43_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_44_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_45_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_46_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_47_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_48_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_49_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_50_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_51_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_52_traceParseAction(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_53_countedArray(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_55_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_58_oneOf(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_59_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_60_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_61_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_62_srange(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_63_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_64_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_66_replaceWith(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_67_tokenMap(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_68__makeTags(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_69___call__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_70_indentedBlock(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_71_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_72_convertToDate(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_73_convertToDatetime(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_74___get__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_75_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_76_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_77_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_78_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_79_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyList_Type_pop = {0, 0, 0, 0, 0};
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct__genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_9___iadd__;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_11_asDict;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_19_scanString;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_20_split;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_21___mul__;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_23___add__;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_24___init__;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_27_sub;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_28___init__;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_30___init__;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_33___init__;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_62_srange;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_69___call__;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_74___get__;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr;
  PyObject *__pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException;
  #endif
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_20_split;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr;
  PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException;
  PyObject *__pyx_kp_u_0;
  PyObject *__pyx_kp_u_0123456789;
  PyObject *__pyx_kp_u_0_0_7;
  PyObject *__pyx_kp_u_0_1;
  PyObject *__pyx_kp_u_0_1_2;
  PyObject *__pyx_kp_u_0_1_3;
  PyObject *__pyx_kp_u_0_2;
  PyObject *__pyx_kp_u_0_9a_fA_F_1_4;
  PyObject *__pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a;
  PyObject *__pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a;
  PyObject *__pyx_kp_u_0_failed_1_2;
  PyObject *__pyx_kp_u_0_setting_results_name_0_r_on_1;
  PyObject *__pyx_kp_u_0_setting_results_name_1_r_on_2;
  PyObject *__pyx_kp_u_0_setting_results_name_1_r_on_2_2;
  PyObject *__pyx_kp_u_0_xX_0_9a_fA_F;
  PyObject *__pyx_kp_u_0x;
  PyObject *__pyx_kp_u_0xa1_0xbf_0xd7_0xf7;
  PyObject *__pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff;
  PyObject *__pyx_kp_u_100_100_100_3_14159_6_02e23_1e;
  PyObject *__pyx_kp_u_100_FF;
  PyObject *__pyx_kp_u_12345678_1234_5678_1234_5678123;
  PyObject *__pyx_kp_u_24_Nov_2023_01_45_UTC;
  PyObject *__pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0;
  PyObject *__pyx_kp_u_2_4_7_2_3_0;
  PyObject *__pyx_n_u_ABCDEFabcdef;
  PyObject *__pyx_n_s_ANY_VALUE;
  PyObject *__pyx_kp_u_A_cross_version_compatibility_c;
  PyObject *__pyx_kp_s_A_mixin_class_to_add_parse_resu;
  PyObject *__pyx_kp_s_A_namespace_class_for_defining;
  PyObject *__pyx_kp_s_A_set_of_Unicode_characters_for;
  PyObject *__pyx_kp_s_A_short_cut_class_for_defining_W;
  PyObject *__pyx_kp_s_A_token_that_will_never_match;
  PyObject *__pyx_kp_s_A_variation_on_class_Literal_whi;
  PyObject *__pyx_kp_s_Abstract_base_level_parser_eleme;
  PyObject *__pyx_kp_s_Abstract_class_ParserElement_sub;
  PyObject *__pyx_kp_s_Abstract_subclass_of_ParserEleme;
  PyObject *__pyx_kp_s_Abstract_subclass_of_class_Pars;
  PyObject *__pyx_kp_s_Abstract_subclass_of_class_Parse;
  PyObject *__pyx_kp_s_An_empty_token_will_always_match;
  PyObject *__pyx_n_s_And;
  PyObject *__pyx_n_u_And;
  PyObject *__pyx_n_s_And__ErrorStop;
  PyObject *__pyx_n_s_And__ErrorStop___init;
  PyObject *__pyx_n_s_And___iadd;
  PyObject *__pyx_n_s_And___init;
  PyObject *__pyx_n_s_And___init___locals_genexpr;
  PyObject *__pyx_n_s_And___str;
  PyObject *__pyx_n_s_And___str___locals_genexpr;
  PyObject *__pyx_n_s_And_checkRecursion;
  PyObject *__pyx_n_s_And_parseImpl;
  PyObject *__pyx_n_s_And_streamline;
  PyObject *__pyx_n_s_And_streamline_locals_genexpr;
  PyObject *__pyx_n_s_Arabic;
  PyObject *__pyx_n_s_AttributeError;
  PyObject *__pyx_n_s_BOM;
  PyObject *__pyx_n_s_BaseWithAttribute;
  PyObject *__pyx_n_s_BaseWithAttribute___call;
  PyObject *__pyx_n_s_BaseWithAttribute___call___local;
  PyObject *__pyx_n_s_CJK;
  PyObject *__pyx_kp_u_CR;
  PyObject *__pyx_kp_u_C_style_comment;
  PyObject *__pyx_kp_u_C_style_comment_2;
  PyObject *__pyx_kp_u_Cannot_combine_element_of_type_s;
  PyObject *__pyx_n_s_CaselessKeyword;
  PyObject *__pyx_n_u_CaselessKeyword;
  PyObject *__pyx_n_s_CaselessKeyword___init;
  PyObject *__pyx_n_s_CaselessLiteral;
  PyObject *__pyx_n_u_CaselessLiteral;
  PyObject *__pyx_n_s_CaselessLiteral___init;
  PyObject *__pyx_n_s_CaselessLiteral_parseImpl;
  PyObject *__pyx_kp_s_Caseless_version_of_class_Keywo;
  PyObject *__pyx_n_s_Char;
  PyObject *__pyx_n_u_Char;
  PyObject *__pyx_n_s_Char___init;
  PyObject *__pyx_n_s_CharsNotIn;
  PyObject *__pyx_n_u_CharsNotIn;
  PyObject *__pyx_n_s_CharsNotIn___init;
  PyObject *__pyx_n_s_CharsNotIn___str;
  PyObject *__pyx_n_s_CharsNotIn_parseImpl;
  PyObject *__pyx_n_s_Chinese;
  PyObject *__pyx_n_s_CloseMatch;
  PyObject *__pyx_n_u_CloseMatch;
  PyObject *__pyx_n_s_CloseMatch___init;
  PyObject *__pyx_n_s_CloseMatch_parseImpl;
  PyObject *__pyx_n_s_Combine;
  PyObject *__pyx_n_u_Combine;
  PyObject *__pyx_n_s_Combine___init;
  PyObject *__pyx_n_s_Combine_ignore;
  PyObject *__pyx_n_s_Combine_postParse;
  PyObject *__pyx_kp_s_Context_manager_to_be_used_when;
  PyObject *__pyx_kp_s_Converter_for_ignoring_the_resul;
  PyObject *__pyx_kp_s_Converter_to_concatenate_all_mat;
  PyObject *__pyx_kp_s_Converter_to_return_a_repetitive;
  PyObject *__pyx_kp_s_Converter_to_return_the_matched;
  PyObject *__pyx_n_s_Cyrillic;
  PyObject *__pyx_n_s_DEFAULT_KEYWORD_CHARS;
  PyObject *__pyx_n_s_DEFAULT_WHITE_CHARS;
  PyObject *__pyx_n_s_DOTALL;
  PyObject *__pyx_n_s_Devanagari;
  PyObject *__pyx_kp_u_Diagnostic_configuration_all_de;
  PyObject *__pyx_n_s_Dict;
  PyObject *__pyx_n_u_Dict;
  PyObject *__pyx_n_s_Dict___init;
  PyObject *__pyx_n_s_Dict_postParse;
  PyObject *__pyx_kp_u_EM_QUAD;
  PyObject *__pyx_kp_u_EM_SPACE;
  PyObject *__pyx_kp_u_EN_QUAD;
  PyObject *__pyx_kp_u_EN_SPACE;
  PyObject *__pyx_n_s_Each;
  PyObject *__pyx_n_u_Each;
  PyObject *__pyx_n_s_Each___init;
  PyObject *__pyx_n_s_Each___init___locals_genexpr;
  PyObject *__pyx_n_s_Each___str;
  PyObject *__pyx_n_s_Each___str___locals_genexpr;
  PyObject *__pyx_n_s_Each_checkRecursion;
  PyObject *__pyx_n_s_Each_parseImpl;
  PyObject *__pyx_n_s_Each_parseImpl_locals_genexpr;
  PyObject *__pyx_n_s_Each_streamline;
  PyObject *__pyx_n_s_Each_streamline_locals_genexpr;
  PyObject *__pyx_n_s_Ellipsis;
  PyObject *__pyx_n_s_Empty;
  PyObject *__pyx_n_u_Empty;
  PyObject *__pyx_n_s_Empty___init;
  PyObject *__pyx_n_s_ErrorStop;
  PyObject *__pyx_kp_u_Evan_Hubinger_evanjhub_gmail_com;
  PyObject *__pyx_kp_u_Exception_creating_Regex_for_one;
  PyObject *__pyx_kp_u_Exception_raised;
  PyObject *__pyx_kp_s_Exception_thrown_when_parse_exp;
  PyObject *__pyx_kp_u_Expected;
  PyObject *__pyx_kp_u_Expected_end_of_line;
  PyObject *__pyx_kp_u_Expected_end_of_text;
  PyObject *__pyx_kp_u_Expected_start_of_line;
  PyObject *__pyx_kp_u_Expected_start_of_text;
  PyObject *__pyx_n_s_FAIL;
  PyObject *__pyx_kp_u_FAIL_2;
  PyObject *__pyx_kp_u_FAIL_EXCEPTION;
  PyObject *__pyx_kp_u_FATAL;
  PyObject *__pyx_n_s_FB;
  PyObject *__pyx_kp_u_FF;
  PyObject *__pyx_kp_u_FIGURE_SPACE;
  PyObject *__pyx_n_s_FILE_NAME;
  PyObject *__pyx_kp_u_FOUR_PER_EM_SPACE;
  PyObject *__pyx_n_s_FifoCache;
  PyObject *__pyx_n_s_FifoCache___init;
  PyObject *__pyx_n_s_FifoCache___len;
  PyObject *__pyx_n_s_FifoCache___reduce;
  PyObject *__pyx_n_s_FifoCache_clear;
  PyObject *__pyx_n_s_FifoCache_get;
  PyObject *__pyx_n_s_FifoCache_set;
  PyObject *__pyx_n_s_FifoCache_update;
  PyObject *__pyx_n_s_FollowedBy;
  PyObject *__pyx_n_u_FollowedBy;
  PyObject *__pyx_n_s_FollowedBy___init;
  PyObject *__pyx_n_s_FollowedBy_parseImpl;
  PyObject *__pyx_n_s_Forward;
  PyObject *__pyx_n_u_Forward;
  PyObject *__pyx_n_s_Forward___ilshift;
  PyObject *__pyx_n_s_Forward___init;
  PyObject *__pyx_n_s_Forward___lshift;
  PyObject *__pyx_n_s_Forward___str;
  PyObject *__pyx_n_s_Forward__setResultsName;
  PyObject *__pyx_n_s_Forward_copy;
  PyObject *__pyx_kp_s_Forward_declaration_of_an_expres;
  PyObject *__pyx_n_s_Forward_leaveWhitespace;
  PyObject *__pyx_n_s_Forward_streamline;
  PyObject *__pyx_n_s_Forward_validate;
  PyObject *__pyx_kp_u_Found_unwanted_token;
  PyObject *__pyx_n_s_GoToColumn;
  PyObject *__pyx_n_u_GoToColumn;
  PyObject *__pyx_n_s_GoToColumn___init;
  PyObject *__pyx_n_s_GoToColumn_parseImpl;
  PyObject *__pyx_n_s_GoToColumn_preParse;
  PyObject *__pyx_n_s_Greek;
  PyObject *__pyx_n_s_Group;
  PyObject *__pyx_n_u_Group;
  PyObject *__pyx_n_s_Group___init;
  PyObject *__pyx_n_s_Group_postParse;
  PyObject *__pyx_kp_u_HAIR_SPACE;
  PyObject *__pyx_n_s_HIT;
  PyObject *__pyx_kp_u_HTML_comment;
  PyObject *__pyx_n_s_Hebrew;
  PyObject *__pyx_kp_s_Here_are_some_common_low_level_e;
  PyObject *__pyx_n_s_Hiragana;
  PyObject *__pyx_kp_u_IDEOGRAPHIC_SPACE;
  PyObject *__pyx_n_s_INDENT;
  PyObject *__pyx_n_u_INDENT;
  PyObject *__pyx_kp_u_IPv4_address;
  PyObject *__pyx_kp_u_IPv6_address;
  PyObject *__pyx_kp_u_ISO8601_date;
  PyObject *__pyx_kp_u_ISO8601_datetime;
  PyObject *__pyx_n_u_ITEM;
  PyObject *__pyx_n_s_ImportError;
  PyObject *__pyx_n_s_IndexError;
  PyObject *__pyx_kp_u_Invalid_argument_to_oneOf_expect;
  PyObject *__pyx_n_s_Iterable;
  PyObject *__pyx_n_s_Japanese;
  PyObject *__pyx_n_s_Kanji;
  PyObject *__pyx_n_s_Katakana;
  PyObject *__pyx_n_s_KeyError;
  PyObject *__pyx_n_s_Keyword;
  PyObject *__pyx_n_u_Keyword;
  PyObject *__pyx_n_s_Keyword___init;
  PyObject *__pyx_n_s_Keyword_copy;
  PyObject *__pyx_n_s_Keyword_parseImpl;
  PyObject *__pyx_n_s_Keyword_setDefaultKeywordChars;
  PyObject *__pyx_n_s_Korean;
  PyObject *__pyx_n_s_L;
  PyObject *__pyx_n_s_LEFT;
  PyObject *__pyx_kp_u_LF;
  PyObject *__pyx_n_s_L_2;
  PyObject *__pyx_n_s_Latin1;
  PyObject *__pyx_n_s_LatinA;
  PyObject *__pyx_n_s_LatinB;
  PyObject *__pyx_n_s_LineEnd;
  PyObject *__pyx_n_u_LineEnd;
  PyObject *__pyx_n_s_LineEnd___init;
  PyObject *__pyx_n_s_LineEnd_parseImpl;
  PyObject *__pyx_n_s_LineStart;
  PyObject *__pyx_n_u_LineStart;
  PyObject *__pyx_n_s_LineStart___init;
  PyObject *__pyx_n_s_LineStart_parseImpl;
  PyObject *__pyx_n_s_Literal;
  PyObject *__pyx_n_u_Literal;
  PyObject *__pyx_n_s_Literal___init;
  PyObject *__pyx_n_s_Literal_parseImpl;
  PyObject *__pyx_kp_s_Lookahead_matching_of_the_given;
  PyObject *__pyx_kp_s_Lookahead_to_disallow_matching_w;
  PyObject *__pyx_kp_s_Lookbehind_matching_of_the_given;
  PyObject *__pyx_kp_u_MAC_address;
  PyObject *__pyx_n_s_MATCH;
  PyObject *__pyx_n_s_MAX_INT;
  PyObject *__pyx_n_s_MISS;
  PyObject *__pyx_kp_u_MMSP;
  PyObject *__pyx_kp_u_MONGOLIAN_VOWEL_SEPARATOR;
  PyObject *__pyx_n_s_MULTILINE;
  PyObject *__pyx_n_s_Mapping;
  PyObject *__pyx_kp_u_Match;
  PyObject *__pyx_n_s_MatchFirst;
  PyObject *__pyx_n_u_MatchFirst;
  PyObject *__pyx_n_s_MatchFirst___init;
  PyObject *__pyx_n_s_MatchFirst___init___locals_genex;
  PyObject *__pyx_n_s_MatchFirst___ior;
  PyObject *__pyx_n_s_MatchFirst___str;
  PyObject *__pyx_n_s_MatchFirst___str___locals_genexp;
  PyObject *__pyx_n_s_MatchFirst__setResultsName;
  PyObject *__pyx_n_s_MatchFirst__setResultsName_local;
  PyObject *__pyx_n_s_MatchFirst_checkRecursion;
  PyObject *__pyx_n_s_MatchFirst_parseImpl;
  PyObject *__pyx_n_s_MatchFirst_setAdaptiveMode;
  PyObject *__pyx_n_s_MatchFirst_streamline;
  PyObject *__pyx_n_s_MatchFirst_streamline_locals_gen;
  PyObject *__pyx_kp_u_Matched;
  PyObject *__pyx_kp_s_Matches_if_current_position_is_a;
  PyObject *__pyx_kp_s_Matches_if_current_position_is_a_2;
  PyObject *__pyx_kp_s_Matches_if_current_position_is_a_3;
  PyObject *__pyx_kp_s_Matches_if_current_position_is_a_4;
  PyObject *__pyx_kp_s_Matches_if_the_current_position;
  PyObject *__pyx_kp_s_Matches_if_the_current_position_2;
  PyObject *__pyx_kp_u_Missing_one_or_more_required_ele;
  PyObject *__pyx_kp_u_More_than_one_string_argument_pa;
  PyObject *__pyx_n_s_MultipleMatch;
  PyObject *__pyx_n_s_MultipleMatch___init;
  PyObject *__pyx_n_s_MultipleMatch__setResultsName;
  PyObject *__pyx_n_s_MultipleMatch_parseImpl;
  PyObject *__pyx_n_s_MultipleMatch_stopOn;
  PyObject *__pyx_n_s_MutableMapping;
  PyObject *__pyx_kp_u_NBSP;
  PyObject *__pyx_n_s_NL;
  PyObject *__pyx_kp_u_NNBSP;
  PyObject *__pyx_n_s_NameError;
  PyObject *__pyx_n_s_NoMatch;
  PyObject *__pyx_n_u_NoMatch;
  PyObject *__pyx_n_s_NoMatch___init;
  PyObject *__pyx_n_s_NoMatch_parseImpl;
  PyObject *__pyx_kp_u_No_match_found_for;
  PyObject *__pyx_n_s_NotAny;
  PyObject *__pyx_n_u_NotAny;
  PyObject *__pyx_n_s_NotAny___init;
  PyObject *__pyx_n_s_NotAny___str;
  PyObject *__pyx_n_s_NotAny_parseImpl;
  PyObject *__pyx_kp_u_Not_at_the_end_of_a_word;
  PyObject *__pyx_kp_u_Not_at_the_start_of_a_word;
  PyObject *__pyx_n_s_NullToken;
  PyObject *__pyx_n_s_NullToken___bool;
  PyObject *__pyx_n_s_NullToken___str;
  PyObject *__pyx_kp_u_OGHAM_SPACE_MARK;
  PyObject *__pyx_n_s_OneOrMore;
  PyObject *__pyx_n_u_OneOrMore;
  PyObject *__pyx_n_s_OneOrMore___str;
  PyObject *__pyx_n_s_OnlyOnce;
  PyObject *__pyx_n_u_OnlyOnce;
  PyObject *__pyx_n_s_OnlyOnce___call;
  PyObject *__pyx_n_s_OnlyOnce___init;
  PyObject *__pyx_n_s_OnlyOnce_reset;
  PyObject *__pyx_n_s_Optional;
  PyObject *__pyx_n_u_Optional;
  PyObject *__pyx_n_s_Optional___init;
  PyObject *__pyx_n_s_Optional___str;
  PyObject *__pyx_n_s_Optional__optionalNotMatched;
  PyObject *__pyx_kp_s_Optional_matching_of_the_given_e;
  PyObject *__pyx_n_s_Optional_parseImpl;
  PyObject *__pyx_kp_s_Optional_repetition_of_zero_or_m;
  PyObject *__pyx_n_s_Or;
  PyObject *__pyx_n_u_Or;
  PyObject *__pyx_n_s_Or___init;
  PyObject *__pyx_n_s_Or___init___locals_genexpr;
  PyObject *__pyx_n_s_Or___ixor;
  PyObject *__pyx_n_s_Or___str;
  PyObject *__pyx_n_s_Or___str___locals_genexpr;
  PyObject *__pyx_n_s_Or__setResultsName;
  PyObject *__pyx_n_s_Or__setResultsName_locals_genexp;
  PyObject *__pyx_n_s_Or_checkRecursion;
  PyObject *__pyx_n_s_Or_parseImpl;
  PyObject *__pyx_n_s_Or_streamline;
  PyObject *__pyx_n_s_Or_streamline_locals_genexpr;
  PyObject *__pyx_n_s_OrderedDict;
  PyObject *__pyx_n_s_OrderedDict_2;
  PyObject *__pyx_n_s_PEER;
  PyObject *__pyx_kp_u_PUNCTUATION_SPACE;
  PyObject *__pyx_n_s_PY_3;
  PyObject *__pyx_kp_u_P_entity;
  PyObject *__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d;
  PyObject *__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2;
  PyObject *__pyx_n_s_ParseBaseException;
  PyObject *__pyx_n_u_ParseBaseException;
  PyObject *__pyx_n_s_ParseBaseException___dir;
  PyObject *__pyx_n_s_ParseBaseException___getattr;
  PyObject *__pyx_n_s_ParseBaseException___init;
  PyObject *__pyx_n_s_ParseBaseException___repr;
  PyObject *__pyx_n_s_ParseBaseException___str;
  PyObject *__pyx_n_s_ParseBaseException__from_excepti;
  PyObject *__pyx_n_s_ParseBaseException_markInputline;
  PyObject *__pyx_n_s_ParseElementEnhance;
  PyObject *__pyx_n_u_ParseElementEnhance;
  PyObject *__pyx_n_s_ParseElementEnhance___init;
  PyObject *__pyx_n_s_ParseElementEnhance___str;
  PyObject *__pyx_n_s_ParseElementEnhance_checkRecursi;
  PyObject *__pyx_n_s_ParseElementEnhance_ignore;
  PyObject *__pyx_n_s_ParseElementEnhance_leaveWhitesp;
  PyObject *__pyx_n_s_ParseElementEnhance_parseImpl;
  PyObject *__pyx_n_s_ParseElementEnhance_streamline;
  PyObject *__pyx_n_s_ParseElementEnhance_validate;
  PyObject *__pyx_n_s_ParseException;
  PyObject *__pyx_n_u_ParseException;
  PyObject *__pyx_n_s_ParseException_explain;
  PyObject *__pyx_n_s_ParseExpression;
  PyObject *__pyx_n_u_ParseExpression;
  PyObject *__pyx_n_s_ParseExpression___init;
  PyObject *__pyx_n_s_ParseExpression___init___locals;
  PyObject *__pyx_n_s_ParseExpression___init___locals_2;
  PyObject *__pyx_n_s_ParseExpression___str;
  PyObject *__pyx_n_s_ParseExpression__setResultsName;
  PyObject *__pyx_n_s_ParseExpression_append;
  PyObject *__pyx_n_s_ParseExpression_copy;
  PyObject *__pyx_n_s_ParseExpression_ignore;
  PyObject *__pyx_n_s_ParseExpression_leaveWhitespace;
  PyObject *__pyx_n_s_ParseExpression_streamline;
  PyObject *__pyx_n_s_ParseExpression_validate;
  PyObject *__pyx_n_s_ParseFatalException;
  PyObject *__pyx_n_u_ParseFatalException;
  PyObject *__pyx_n_s_ParseResults;
  PyObject *__pyx_n_u_ParseResults;
  PyObject *__pyx_n_s_ParseResultsWithOffset;
  PyObject *__pyx_n_s_ParseResultsWithOffset___getite;
  PyObject *__pyx_n_s_ParseResultsWithOffset___init;
  PyObject *__pyx_n_s_ParseResultsWithOffset___repr;
  PyObject *__pyx_n_s_ParseResultsWithOffset_setOffse;
  PyObject *__pyx_n_s_ParseResults___add;
  PyObject *__pyx_n_s_ParseResults___bool;
  PyObject *__pyx_n_s_ParseResults___contains;
  PyObject *__pyx_n_s_ParseResults___delitem;
  PyObject *__pyx_n_s_ParseResults___dir;
  PyObject *__pyx_n_s_ParseResults___getattr;
  PyObject *__pyx_n_s_ParseResults___getitem;
  PyObject *__pyx_n_s_ParseResults___getnewargs;
  PyObject *__pyx_n_s_ParseResults___getstate;
  PyObject *__pyx_n_s_ParseResults___iadd;
  PyObject *__pyx_n_s_ParseResults___iadd___locals_lam;
  PyObject *__pyx_n_s_ParseResults___init;
  PyObject *__pyx_n_s_ParseResults___iter;
  PyObject *__pyx_n_s_ParseResults___len;
  PyObject *__pyx_n_s_ParseResults___lookup;
  PyObject *__pyx_n_s_ParseResults___new;
  PyObject *__pyx_n_s_ParseResults___radd;
  PyObject *__pyx_n_s_ParseResults___repr;
  PyObject *__pyx_n_s_ParseResults___reversed;
  PyObject *__pyx_n_s_ParseResults___setitem;
  PyObject *__pyx_n_s_ParseResults___setstate;
  PyObject *__pyx_n_s_ParseResults___str;
  PyObject *__pyx_n_s_ParseResults___str___locals_gene;
  PyObject *__pyx_n_s_ParseResults__accumNames;
  PyObject *__pyx_n_s_ParseResults__asList;
  PyObject *__pyx_n_s_ParseResults__asStringList;
  PyObject *__pyx_n_s_ParseResults__doinit;
  PyObject *__pyx_n_s_ParseResults__iteritems;
  PyObject *__pyx_n_s_ParseResults__iteritems_locals_g;
  PyObject *__pyx_n_s_ParseResults__iterkeys;
  PyObject *__pyx_n_s_ParseResults__itervalues;
  PyObject *__pyx_n_s_ParseResults__itervalues_locals;
  PyObject *__pyx_n_s_ParseResults__lookup;
  PyObject *__pyx_n_s_ParseResults__modal;
  PyObject *__pyx_n_s_ParseResults__name;
  PyObject *__pyx_n_s_ParseResults__parent;
  PyObject *__pyx_n_s_ParseResults__tokdict;
  PyObject *__pyx_n_s_ParseResults__toklist;
  PyObject *__pyx_n_s_ParseResults_append;
  PyObject *__pyx_n_s_ParseResults_asDict;
  PyObject *__pyx_n_s_ParseResults_asDict_locals_genex;
  PyObject *__pyx_n_s_ParseResults_asDict_locals_toIte;
  PyObject *__pyx_n_s_ParseResults_asList;
  PyObject *__pyx_n_s_ParseResults_asXML;
  PyObject *__pyx_n_s_ParseResults_asXML_locals_genexp;
  PyObject *__pyx_n_s_ParseResults_clear;
  PyObject *__pyx_n_s_ParseResults_copy;
  PyObject *__pyx_n_s_ParseResults_dump;
  PyObject *__pyx_n_s_ParseResults_dump_locals_genexpr;
  PyObject *__pyx_n_s_ParseResults_extend;
  PyObject *__pyx_n_s_ParseResults_from_dict;
  PyObject *__pyx_n_s_ParseResults_from_dict_locals_is;
  PyObject *__pyx_n_s_ParseResults_get;
  PyObject *__pyx_n_s_ParseResults_getName;
  PyObject *__pyx_n_s_ParseResults_haskeys;
  PyObject *__pyx_n_s_ParseResults_insert;
  PyObject *__pyx_n_s_ParseResults_items;
  PyObject *__pyx_n_s_ParseResults_keys;
  PyObject *__pyx_n_s_ParseResults_pop;
  PyObject *__pyx_n_s_ParseResults_pprint;
  PyObject *__pyx_n_s_ParseResults_values;
  PyObject *__pyx_n_s_ParseSyntaxException;
  PyObject *__pyx_n_u_ParseSyntaxException;
  PyObject *__pyx_n_s_ParserElement;
  PyObject *__pyx_n_u_ParserElement;
  PyObject *__pyx_n_s_ParserElement___add;
  PyObject *__pyx_n_s_ParserElement___and;
  PyObject *__pyx_n_s_ParserElement___call;
  PyObject *__pyx_n_s_ParserElement___eq;
  PyObject *__pyx_n_s_ParserElement___getitem;
  PyObject *__pyx_n_s_ParserElement___hash;
  PyObject *__pyx_n_s_ParserElement___init;
  PyObject *__pyx_n_s_ParserElement___invert;
  PyObject *__pyx_n_s_ParserElement___iter;
  PyObject *__pyx_n_s_ParserElement___mul;
  PyObject *__pyx_n_s_ParserElement___mul___locals_gen;
  PyObject *__pyx_n_s_ParserElement___mul___locals_mak;
  PyObject *__pyx_n_s_ParserElement___ne;
  PyObject *__pyx_n_s_ParserElement___or;
  PyObject *__pyx_n_s_ParserElement___radd;
  PyObject *__pyx_n_s_ParserElement___rand;
  PyObject *__pyx_n_s_ParserElement___repr;
  PyObject *__pyx_n_s_ParserElement___req;
  PyObject *__pyx_n_s_ParserElement___rmul;
  PyObject *__pyx_n_s_ParserElement___rne;
  PyObject *__pyx_n_s_ParserElement___ror;
  PyObject *__pyx_n_s_ParserElement___rsub;
  PyObject *__pyx_n_s_ParserElement___rxor;
  PyObject *__pyx_n_s_ParserElement___str;
  PyObject *__pyx_n_s_ParserElement___sub;
  PyObject *__pyx_n_s_ParserElement___xor;
  PyObject *__pyx_n_s_ParserElement__parseCache;
  PyObject *__pyx_n_s_ParserElement__parseIncremental;
  PyObject *__pyx_n_s_ParserElement__parseIncremental_2;
  PyObject *__pyx_n_s_ParserElement__parseNoCache;
  PyObject *__pyx_n_s_ParserElement__setResultsName;
  PyObject *__pyx_n_s_ParserElement__skipIgnorables;
  PyObject *__pyx_n_s_ParserElement__trim_traceback;
  PyObject *__pyx_n_s_ParserElement__update_furthest_l;
  PyObject *__pyx_n_s_ParserElement_addCondition;
  PyObject *__pyx_n_s_ParserElement_addParseAction;
  PyObject *__pyx_n_s_ParserElement_canParseNext;
  PyObject *__pyx_n_s_ParserElement_checkRecursion;
  PyObject *__pyx_n_s_ParserElement_collectParseElemen;
  PyObject *__pyx_n_s_ParserElement_copy;
  PyObject *__pyx_n_s_ParserElement_enableIncremental;
  PyObject *__pyx_n_s_ParserElement_enablePackrat;
  PyObject *__pyx_n_s_ParserElement_ignore;
  PyObject *__pyx_n_s_ParserElement_inlineLiteralsUsin;
  PyObject *__pyx_n_s_ParserElement_leaveWhitespace;
  PyObject *__pyx_n_s_ParserElement_matches;
  PyObject *__pyx_n_s_ParserElement_parseFile;
  PyObject *__pyx_n_s_ParserElement_parseImpl;
  PyObject *__pyx_n_s_ParserElement_parseString;
  PyObject *__pyx_n_s_ParserElement_parseWithTabs;
  PyObject *__pyx_n_s_ParserElement_postParse;
  PyObject *__pyx_n_s_ParserElement_preParse;
  PyObject *__pyx_n_s_ParserElement_resetCache;
  PyObject *__pyx_n_s_ParserElement_runTests;
  PyObject *__pyx_n_s_ParserElement_scanString;
  PyObject *__pyx_n_s_ParserElement_searchString;
  PyObject *__pyx_n_s_ParserElement_setBreak;
  PyObject *__pyx_n_s_ParserElement_setBreak_locals_br;
  PyObject *__pyx_n_s_ParserElement_setDebug;
  PyObject *__pyx_n_s_ParserElement_setDebugActions;
  PyObject *__pyx_n_s_ParserElement_setDefaultWhitespa;
  PyObject *__pyx_n_s_ParserElement_setFailAction;
  PyObject *__pyx_n_s_ParserElement_setName;
  PyObject *__pyx_n_s_ParserElement_setParseAction;
  PyObject *__pyx_n_s_ParserElement_setParseAction_loc;
  PyObject *__pyx_n_s_ParserElement_setResultsName;
  PyObject *__pyx_n_s_ParserElement_setWhitespaceChars;
  PyObject *__pyx_n_s_ParserElement_split;
  PyObject *__pyx_n_s_ParserElement_streamline;
  PyObject *__pyx_n_s_ParserElement_suppress;
  PyObject *__pyx_n_s_ParserElement_transformString;
  PyObject *__pyx_n_s_ParserElement_tryParse;
  PyObject *__pyx_n_s_ParserElement_validate;
  PyObject *__pyx_n_s_PendingSkip;
  PyObject *__pyx_n_s_PendingSkip___add;
  PyObject *__pyx_n_s_PendingSkip___add___locals_must;
  PyObject *__pyx_n_s_PendingSkip___add___locals_show;
  PyObject *__pyx_n_s_PendingSkip___init;
  PyObject *__pyx_n_s_PendingSkip___repr;
  PyObject *__pyx_n_s_PendingSkip_parseImpl;
  PyObject *__pyx_n_s_PositionToken;
  PyObject *__pyx_n_s_PositionToken___init;
  PyObject *__pyx_n_s_PrecededBy;
  PyObject *__pyx_n_u_PrecededBy;
  PyObject *__pyx_n_s_PrecededBy___init;
  PyObject *__pyx_n_s_PrecededBy___init___locals_lambd;
  PyObject *__pyx_n_s_PrecededBy_parseImpl;
  PyObject *__pyx_kp_u_Python_style_comment;
  PyObject *__pyx_n_s_QuotedString;
  PyObject *__pyx_n_u_QuotedString;
  PyObject *__pyx_n_s_QuotedString___init;
  PyObject *__pyx_n_s_QuotedString___init___locals_gen;
  PyObject *__pyx_n_s_QuotedString___str;
  PyObject *__pyx_n_s_QuotedString_parseImpl;
  PyObject *__pyx_n_s_RIGHT;
  PyObject *__pyx_n_s_RLock;
  PyObject *__pyx_kp_u_Re_s;
  PyObject *__pyx_n_s_RecursiveGrammarException;
  PyObject *__pyx_n_u_RecursiveGrammarException;
  PyObject *__pyx_n_s_RecursiveGrammarException___init;
  PyObject *__pyx_n_s_RecursiveGrammarException___str;
  PyObject *__pyx_kp_u_RecursiveGrammarException_s;
  PyObject *__pyx_n_s_Regex;
  PyObject *__pyx_n_u_Regex;
  PyObject *__pyx_n_s_Regex___init;
  PyObject *__pyx_n_s_Regex___str;
  PyObject *__pyx_kp_u_Regex_may_only_be_constructed_wi;
  PyObject *__pyx_n_s_Regex_parseImpl;
  PyObject *__pyx_n_s_Regex_parseImplAsGroupList;
  PyObject *__pyx_n_s_Regex_parseImplAsMatch;
  PyObject *__pyx_n_s_Regex_sub;
  PyObject *__pyx_n_s_Regex_sub_locals_pa;
  PyObject *__pyx_kp_s_Repetition_of_one_or_more_of_the;
  PyObject *__pyx_kp_s_Requires_all_given_class_ParseE;
  PyObject *__pyx_kp_s_Requires_all_given_class_ParseEx;
  PyObject *__pyx_kp_s_Requires_that_at_least_one_class;
  PyObject *__pyx_kp_s_Requires_that_at_least_one_class_2;
  PyObject *__pyx_kp_u_SIX_PER_EM_SPACE;
  PyObject *__pyx_kp_u_SP;
  PyObject *__pyx_n_s_SimpleNamespace;
  PyObject *__pyx_n_s_SingleCharLiteral;
  PyObject *__pyx_n_s_SingleCharLiteral_parseImpl;
  PyObject *__pyx_n_s_SkipTo;
  PyObject *__pyx_n_u_SkipTo;
  PyObject *__pyx_n_s_SkipTo___init;
  PyObject *__pyx_n_s_SkipTo_parseImpl;
  PyObject *__pyx_kp_s_Special_matching_class_for_match;
  PyObject *__pyx_n_s_StringEnd;
  PyObject *__pyx_n_u_StringEnd;
  PyObject *__pyx_n_s_StringEnd___init;
  PyObject *__pyx_n_s_StringEnd_parseImpl;
  PyObject *__pyx_n_s_StringStart;
  PyObject *__pyx_n_u_StringStart;
  PyObject *__pyx_n_s_StringStart___init;
  PyObject *__pyx_n_s_StringStart_parseImpl;
  PyObject *__pyx_kp_s_Structured_parse_results_to_prov;
  PyObject *__pyx_n_s_Suppress;
  PyObject *__pyx_n_u_Suppress;
  PyObject *__pyx_n_s_Suppress_postParse;
  PyObject *__pyx_n_s_Suppress_suppress;
  PyObject *__pyx_n_s_SyntaxError;
  PyObject *__pyx_n_s_SyntaxWarning;
  PyObject *__pyx_kp_u_TAB;
  PyObject *__pyx_kp_u_THIN_SPACE;
  PyObject *__pyx_kp_u_THREE_PER_EM_SPACE;
  PyObject *__pyx_n_s_TRY;
  PyObject *__pyx_n_s_TestParseResultsAsserts;
  PyObject *__pyx_kp_u_Text_not_in_expected_column;
  PyObject *__pyx_n_s_Thai;
  PyObject *__pyx_n_s_Token;
  PyObject *__pyx_n_u_Token;
  PyObject *__pyx_n_s_TokenConverter;
  PyObject *__pyx_n_u_TokenConverter;
  PyObject *__pyx_n_s_TokenConverter___init;
  PyObject *__pyx_n_s_Token___init;
  PyObject *__pyx_kp_s_Token_for_matching_strings_that;
  PyObject *__pyx_kp_s_Token_for_matching_strings_that_2;
  PyObject *__pyx_kp_s_Token_for_matching_words_compose;
  PyObject *__pyx_kp_s_Token_for_matching_words_compose_2;
  PyObject *__pyx_kp_s_Token_for_skipping_over_all_unde;
  PyObject *__pyx_kp_s_Token_to_advance_to_a_specific_c;
  PyObject *__pyx_kp_s_Token_to_exactly_match_a_specifi;
  PyObject *__pyx_kp_s_Token_to_exactly_match_a_specifi_2;
  PyObject *__pyx_kp_s_Token_to_match_a_specified_strin;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_n_s_UNDENT;
  PyObject *__pyx_n_u_UNINDENT;
  PyObject *__pyx_n_s_UUID;
  PyObject *__pyx_n_u_UUID;
  PyObject *__pyx_n_s_UnboundedCache;
  PyObject *__pyx_n_s_UnboundedCache___init;
  PyObject *__pyx_n_s_UnboundedCache___len;
  PyObject *__pyx_n_s_UnboundedCache___reduce;
  PyObject *__pyx_n_s_UnboundedCache_clear;
  PyObject *__pyx_n_s_UnboundedCache_get;
  PyObject *__pyx_n_s_UnboundedCache_set;
  PyObject *__pyx_n_s_UnboundedCache_update;
  PyObject *__pyx_kp_s_Unicode_set_for_Arabic_Unicode_C;
  PyObject *__pyx_kp_s_Unicode_set_for_Chinese_Unicode;
  PyObject *__pyx_kp_s_Unicode_set_for_Cyrillic_Unicode;
  PyObject *__pyx_kp_s_Unicode_set_for_Devanagari_Unico;
  PyObject *__pyx_kp_s_Unicode_set_for_Greek_Unicode_Ch;
  PyObject *__pyx_kp_s_Unicode_set_for_Hebrew_Unicode_C;
  PyObject *__pyx_kp_s_Unicode_set_for_Hiragana_Unicode;
  PyObject *__pyx_kp_s_Unicode_set_for_Japanese_Unicode;
  PyObject *__pyx_kp_s_Unicode_set_for_Kanji_Unicode_Ch;
  PyObject *__pyx_kp_s_Unicode_set_for_Katakana_Unicode;
  PyObject *__pyx_kp_s_Unicode_set_for_Korean_Unicode_C;
  PyObject *__pyx_kp_s_Unicode_set_for_Latin_1_Unicode;
  PyObject *__pyx_kp_s_Unicode_set_for_Latin_A_Unicode;
  PyObject *__pyx_kp_s_Unicode_set_for_Latin_B_Unicode;
  PyObject *__pyx_kp_s_Unicode_set_for_Thai_Unicode_Cha;
  PyObject *__pyx_kp_s_Unicode_set_for_combined_Chinese;
  PyObject *__pyx_kp_u_Unmatchable_token;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_kp_u_W;
  PyObject *__pyx_n_s_WRAP_CALL_LINE_NUM;
  PyObject *__pyx_kp_u_W_s;
  PyObject *__pyx_kp_u_W_s_2;
  PyObject *__pyx_kp_u_W_s_3;
  PyObject *__pyx_n_s_White;
  PyObject *__pyx_n_u_White;
  PyObject *__pyx_n_s_White___init;
  PyObject *__pyx_n_s_White___init___locals_genexpr;
  PyObject *__pyx_n_s_White_parseImpl;
  PyObject *__pyx_n_s_Word;
  PyObject *__pyx_n_u_Word;
  PyObject *__pyx_n_s_WordEnd;
  PyObject *__pyx_n_u_WordEnd;
  PyObject *__pyx_n_s_WordEnd___init;
  PyObject *__pyx_n_s_WordEnd_parseImpl;
  PyObject *__pyx_n_s_WordRegex;
  PyObject *__pyx_n_s_WordRegex_parseImpl;
  PyObject *__pyx_n_s_WordStart;
  PyObject *__pyx_n_u_WordStart;
  PyObject *__pyx_n_s_WordStart___init;
  PyObject *__pyx_n_s_WordStart_parseImpl;
  PyObject *__pyx_n_s_Word___init;
  PyObject *__pyx_n_s_Word___init___locals_genexpr;
  PyObject *__pyx_n_s_Word___str;
  PyObject *__pyx_n_s_Word___str___locals_charsAsStr;
  PyObject *__pyx_n_s_Word_parseImpl;
  PyObject *__pyx_kp_s_Wrapper_for_parse_actions_to_ens;
  PyObject *__pyx_kp_u_Y_m_d;
  PyObject *__pyx_kp_u_Y_m_dT_H_M_S_f;
  PyObject *__pyx_kp_u_ZERO_WIDTH_SPACE;
  PyObject *__pyx_n_s_ZeroOrMore;
  PyObject *__pyx_n_u_ZeroOrMore;
  PyObject *__pyx_n_s_ZeroOrMore___init;
  PyObject *__pyx_n_s_ZeroOrMore___str;
  PyObject *__pyx_n_s_ZeroOrMore_parseImpl;
  PyObject *__pyx_kp_u__10;
  PyObject *__pyx_kp_u__100;
  PyObject *__pyx_kp_u__102;
  PyObject *__pyx_kp_u__104;
  PyObject *__pyx_kp_u__105;
  PyObject *__pyx_kp_u__107;
  PyObject *__pyx_kp_u__108;
  PyObject *__pyx_kp_u__11;
  PyObject *__pyx_kp_u__110;
  PyObject *__pyx_kp_u__111;
  PyObject *__pyx_kp_u__112;
  PyObject *__pyx_kp_u__113;
  PyObject *__pyx_kp_u__114;
  PyObject *__pyx_kp_u__115;
  PyObject *__pyx_kp_u__116;
  PyObject *__pyx_kp_u__117;
  PyObject *__pyx_kp_u__118;
  PyObject *__pyx_kp_u__119;
  PyObject *__pyx_kp_u__12;
  PyObject *__pyx_kp_u__122;
  PyObject *__pyx_kp_u__13;
  PyObject *__pyx_kp_u__136;
  PyObject *__pyx_kp_u__14;
  PyObject *__pyx_kp_u__144;
  PyObject *__pyx_kp_u__145;
  PyObject *__pyx_kp_u__147;
  PyObject *__pyx_kp_u__148;
  PyObject *__pyx_n_s__15;
  PyObject *__pyx_kp_u__15;
  PyObject *__pyx_kp_u__150;
  PyObject *__pyx_kp_u__16;
  PyObject *__pyx_kp_u__166;
  PyObject *__pyx_kp_u__17;
  PyObject *__pyx_kp_u__19;
  PyObject *__pyx_kp_u__2;
  PyObject *__pyx_kp_u__22;
  PyObject *__pyx_kp_u__25;
  PyObject *__pyx_kp_u__26;
  PyObject *__pyx_kp_u__27;
  PyObject *__pyx_kp_u__28;
  PyObject *__pyx_kp_u__29;
  PyObject *__pyx_kp_u__3;
  PyObject *__pyx_kp_u__30;
  PyObject *__pyx_kp_u__31;
  PyObject *__pyx_kp_u__339;
  PyObject *__pyx_kp_u__34;
  PyObject *__pyx_kp_u__35;
  PyObject *__pyx_kp_u__4;
  PyObject *__pyx_kp_u__461;
  PyObject *__pyx_kp_u__5;
  PyObject *__pyx_kp_u__511;
  PyObject *__pyx_kp_u__512;
  PyObject *__pyx_kp_u__513;
  PyObject *__pyx_kp_u__514;
  PyObject *__pyx_kp_u__515;
  PyObject *__pyx_kp_u__516;
  PyObject *__pyx_kp_u__517;
  PyObject *__pyx_kp_u__518;
  PyObject *__pyx_kp_u__519;
  PyObject *__pyx_kp_u__520;
  PyObject *__pyx_kp_u__521;
  PyObject *__pyx_kp_u__522;
  PyObject *__pyx_kp_u__523;
  PyObject *__pyx_kp_u__524;
  PyObject *__pyx_kp_u__525;
  PyObject *__pyx_kp_u__526;
  PyObject *__pyx_kp_u__527;
  PyObject *__pyx_kp_u__528;
  PyObject *__pyx_kp_u__6;
  PyObject *__pyx_n_s__621;
  PyObject *__pyx_n_u__621;
  PyObject *__pyx_kp_u__65;
  PyObject *__pyx_kp_u__66;
  PyObject *__pyx_kp_u__67;
  PyObject *__pyx_kp_u__7;
  PyObject *__pyx_kp_u__718;
  PyObject *__pyx_kp_u__721;
  PyObject *__pyx_kp_u__755;
  PyObject *__pyx_kp_u__768;
  PyObject *__pyx_kp_u__770;
  PyObject *__pyx_kp_u__771;
  PyObject *__pyx_kp_u__774;
  PyObject *__pyx_kp_u__776;
  PyObject *__pyx_kp_u__780;
  PyObject *__pyx_kp_u__786;
  PyObject *__pyx_kp_u__789;
  PyObject *__pyx_kp_u__79;
  PyObject *__pyx_kp_u__795;
  PyObject *__pyx_kp_u__80;
  PyObject *__pyx_n_u__856;
  PyObject *__pyx_n_u__857;
  PyObject *__pyx_n_u__858;
  PyObject *__pyx_n_u__859;
  PyObject *__pyx_kp_u__860;
  PyObject *__pyx_n_u__861;
  PyObject *__pyx_n_u__862;
  PyObject *__pyx_n_u__863;
  PyObject *__pyx_n_u__864;
  PyObject *__pyx_n_u__865;
  PyObject *__pyx_n_u__866;
  PyObject *__pyx_kp_u__867;
  PyObject *__pyx_n_s__893;
  PyObject *__pyx_kp_u__91;
  PyObject *__pyx_kp_u__94;
  PyObject *__pyx_kp_u__95;
  PyObject *__pyx_kp_u__96;
  PyObject *__pyx_kp_u__97;
  PyObject *__pyx_kp_u__98;
  PyObject *__pyx_kp_u__99;
  PyObject *__pyx_n_s_a;
  PyObject *__pyx_n_s_adaptive_mode;
  PyObject *__pyx_n_s_adaptive_usage;
  PyObject *__pyx_n_s_adaptive_usage_check_rate;
  PyObject *__pyx_n_s_add;
  PyObject *__pyx_n_s_addCondition;
  PyObject *__pyx_n_s_addParseAction;
  PyObject *__pyx_n_s_addoffset;
  PyObject *__pyx_n_s_adjacent;
  PyObject *__pyx_n_s_all;
  PyObject *__pyx_n_s_allResults;
  PyObject *__pyx_n_s_all_2;
  PyObject *__pyx_n_s_all_names;
  PyObject *__pyx_n_s_all_parse_elements;
  PyObject *__pyx_n_s_allow_unused_expr_order;
  PyObject *__pyx_n_s_alphanums;
  PyObject *__pyx_n_u_alphanums;
  PyObject *__pyx_n_s_alphas;
  PyObject *__pyx_n_u_alphas;
  PyObject *__pyx_n_s_alphas8bit;
  PyObject *__pyx_n_u_alphas8bit;
  PyObject *__pyx_kp_u_amp_gt_lt_quot_apos;
  PyObject *__pyx_n_s_aname;
  PyObject *__pyx_n_s_anchor;
  PyObject *__pyx_n_s_and;
  PyObject *__pyx_n_s_any;
  PyObject *__pyx_n_s_anyCloseTag;
  PyObject *__pyx_n_u_anyCloseTag;
  PyObject *__pyx_n_s_anyOpenTag;
  PyObject *__pyx_n_u_anyOpenTag;
  PyObject *__pyx_kp_u_any_tag;
  PyObject *__pyx_n_s_append;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_n_u_args;
  PyObject *__pyx_n_s_arity;
  PyObject *__pyx_n_s_arrayExpr;
  PyObject *__pyx_n_u_arrayLen;
  PyObject *__pyx_n_s_asDict;
  PyObject *__pyx_n_s_asGroupList;
  PyObject *__pyx_n_s_asKeyword;
  PyObject *__pyx_n_s_asList;
  PyObject *__pyx_n_s_asMatch;
  PyObject *__pyx_n_s_asString;
  PyObject *__pyx_n_s_asStringList;
  PyObject *__pyx_n_s_asXML;
  PyObject *__pyx_kp_u_as_column_list_and_dotted_table;
  PyObject *__pyx_n_s_ascii_lowercase;
  PyObject *__pyx_n_s_ascii_uppercase;
  PyObject *__pyx_n_s_assertEqual;
  PyObject *__pyx_n_s_assertParseAndCheckDict;
  PyObject *__pyx_n_s_assertParseAndCheckList;
  PyObject *__pyx_n_s_assertParseResultsEquals;
  PyObject *__pyx_n_s_assertRaises;
  PyObject *__pyx_n_s_assertRaisesParseException;
  PyObject *__pyx_n_s_assertRunTestResults;
  PyObject *__pyx_n_s_assertTrue;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_kp_u_at_char;
  PyObject *__pyx_kp_u_at_loc;
  PyObject *__pyx_n_s_attrDict;
  PyObject *__pyx_n_s_attrName;
  PyObject *__pyx_n_s_attrValue;
  PyObject *__pyx_kp_u_attribute;
  PyObject *__pyx_n_s_attrname;
  PyObject *__pyx_n_s_attrs;
  PyObject *__pyx_n_s_author;
  PyObject *__pyx_n_u_author;
  PyObject *__pyx_kp_u_b;
  PyObject *__pyx_n_s_b_2;
  PyObject *__pyx_kp_u_b_s_b;
  PyObject *__pyx_n_s_backup_stack;
  PyObject *__pyx_n_s_baseExpr;
  PyObject *__pyx_kp_s_base_exception_class_for_all_par;
  PyObject *__pyx_n_s_basestring;
  PyObject *__pyx_n_s_best_expr;
  PyObject *__pyx_n_s_blockStatementExpr;
  PyObject *__pyx_n_s_body;
  PyObject *__pyx_n_u_body;
  PyObject *__pyx_n_s_bodyChars;
  PyObject *__pyx_n_s_bodyCharsOrig;
  PyObject *__pyx_n_s_bodychars;
  PyObject *__pyx_n_s_bool;
  PyObject *__pyx_n_s_breakFlag;
  PyObject *__pyx_n_s_breaker;
  PyObject *__pyx_n_s_bslash;
  PyObject *__pyx_n_s_builtin;
  PyObject *__pyx_n_s_c;
  PyObject *__pyx_n_s_cPyparsing;
  PyObject *__pyx_kp_s_cPyparsing_pyx;
  PyObject *__pyx_kp_u_cPyparsing_pyx;
  PyObject *__pyx_n_s_cStyleComment;
  PyObject *__pyx_n_u_cStyleComment;
  PyObject *__pyx_n_s_cache;
  PyObject *__pyx_n_u_cache;
  PyObject *__pyx_n_s_cache_furthest_loc;
  PyObject *__pyx_n_s_cache_item;
  PyObject *__pyx_n_s_cache_result;
  PyObject *__pyx_n_s_cache_size_limit;
  PyObject *__pyx_n_s_cache_successes;
  PyObject *__pyx_n_s_cache_usefullness_obj;
  PyObject *__pyx_n_s_call;
  PyObject *__pyx_n_s_callDuringTry;
  PyObject *__pyx_n_u_callDuringTry;
  PyObject *__pyx_n_s_callPreParse;
  PyObject *__pyx_n_s_callPreparse;
  PyObject *__pyx_n_s_callable;
  PyObject *__pyx_n_s_called;
  PyObject *__pyx_n_s_callers;
  PyObject *__pyx_n_s_canParseNext;
  PyObject *__pyx_kp_u_cannot_construct_And_with_sequen;
  PyObject *__pyx_kp_u_cannot_multiply_ParserElement_an;
  PyObject *__pyx_kp_u_cannot_multiply_ParserElement_an_2;
  PyObject *__pyx_kp_u_cannot_multiply_ParserElement_by;
  PyObject *__pyx_kp_u_cannot_multiply_ParserElement_by_2;
  PyObject *__pyx_kp_u_cannot_specify_a_minimum_length;
  PyObject *__pyx_kp_u_cannot_specify_a_minimum_length_2;
  PyObject *__pyx_kp_u_cannot_use_sub_with_Regex_asGrou;
  PyObject *__pyx_kp_u_cannot_use_sub_with_a_callable_w;
  PyObject *__pyx_n_s_caseless;
  PyObject *__pyx_n_s_caselessmatch;
  PyObject *__pyx_n_s_cause;
  PyObject *__pyx_n_s_cc;
  PyObject *__pyx_n_s_charRange;
  PyObject *__pyx_n_s_chars;
  PyObject *__pyx_n_s_charsAsStr;
  PyObject *__pyx_n_s_charset;
  PyObject *__pyx_n_s_checkPeerIndent;
  PyObject *__pyx_n_s_checkRecursion;
  PyObject *__pyx_n_s_checkSubIndent;
  PyObject *__pyx_n_s_checkUnindent;
  PyObject *__pyx_n_s_check_ender;
  PyObject *__pyx_n_s_chr;
  PyObject *__pyx_n_s_class;
  PyObject *__pyx_n_u_class;
  PyObject *__pyx_n_u_class_2;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_classattr;
  PyObject *__pyx_n_s_classname;
  PyObject *__pyx_n_s_clear;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_close;
  PyObject *__pyx_n_s_closeTag;
  PyObject *__pyx_n_s_closer;
  PyObject *__pyx_n_s_cls;
  PyObject *__pyx_n_s_co_name;
  PyObject *__pyx_n_s_code;
  PyObject *__pyx_n_s_col;
  PyObject *__pyx_n_u_col;
  PyObject *__pyx_kp_u_col_2;
  PyObject *__pyx_n_s_collectParseElements;
  PyObject *__pyx_n_s_collect_all_And_tokens;
  PyObject *__pyx_n_u_collect_all_And_tokens;
  PyObject *__pyx_n_s_collections;
  PyObject *__pyx_n_s_collections_abc;
  PyObject *__pyx_n_s_colno;
  PyObject *__pyx_n_s_column;
  PyObject *__pyx_n_u_column;
  PyObject *__pyx_n_s_columnName;
  PyObject *__pyx_n_s_columnNameList;
  PyObject *__pyx_n_s_columnSpec;
  PyObject *__pyx_n_u_columns;
  PyObject *__pyx_n_s_combine;
  PyObject *__pyx_n_u_commaItem;
  PyObject *__pyx_n_s_commaSeparatedList;
  PyObject *__pyx_n_u_commaSeparatedList;
  PyObject *__pyx_kp_u_comma_separated_list;
  PyObject *__pyx_n_s_comma_separated_list_2;
  PyObject *__pyx_n_u_command;
  PyObject *__pyx_n_s_commasepitem;
  PyObject *__pyx_n_s_comment;
  PyObject *__pyx_kp_u_comment_2;
  PyObject *__pyx_n_s_comments;
  PyObject *__pyx_n_s_commonHTMLEntity;
  PyObject *__pyx_n_u_commonHTMLEntity;
  PyObject *__pyx_kp_u_common_HTML_entity;
  PyObject *__pyx_n_s_common_prefix_len;
  PyObject *__pyx_n_s_common_suffix_len;
  PyObject *__pyx_n_s_commonprefix;
  PyObject *__pyx_n_s_compat;
  PyObject *__pyx_n_u_compat;
  PyObject *__pyx_n_s_compile;
  PyObject *__pyx_n_s_conditionAsParseAction;
  PyObject *__pyx_n_u_conditionAsParseAction;
  PyObject *__pyx_n_s_conditionAsParseAction_locals_pa;
  PyObject *__pyx_n_s_contains;
  PyObject *__pyx_n_s_content;
  PyObject *__pyx_n_s_context;
  PyObject *__pyx_n_s_contextlib;
  PyObject *__pyx_n_s_contextmanager;
  PyObject *__pyx_n_s_convertToDate;
  PyObject *__pyx_n_s_convertToDatetime;
  PyObject *__pyx_n_s_convertToFloat;
  PyObject *__pyx_n_s_convertToInteger;
  PyObject *__pyx_n_s_convertWhitespaceEscapes;
  PyObject *__pyx_n_s_copy;
  PyObject *__pyx_n_s_copyDefaultWhiteChars;
  PyObject *__pyx_n_s_copyTokenToRepeater;
  PyObject *__pyx_n_s_count;
  PyObject *__pyx_n_s_countFieldParseAction;
  PyObject *__pyx_n_s_countedArray;
  PyObject *__pyx_n_u_countedArray;
  PyObject *__pyx_n_s_countedArray_locals_countFieldPa;
  PyObject *__pyx_n_s_countedArray_locals_lambda;
  PyObject *__pyx_n_s_cppStyleComment;
  PyObject *__pyx_n_u_cppStyleComment;
  PyObject *__pyx_n_s_cpy;
  PyObject *__pyx_n_s_cur;
  PyObject *__pyx_n_s_curCol;
  PyObject *__pyx_n_s_cvt_fn;
  PyObject *__pyx_n_s_d;
  PyObject *__pyx_n_u_d;
  PyObject *__pyx_kp_u_d_2;
  PyObject *__pyx_kp_u_d_d_d;
  PyObject *__pyx_kp_u_d_d_eE_d;
  PyObject *__pyx_kp_u_d_eE_d_d_d_d_eE_d;
  PyObject *__pyx_n_s_data;
  PyObject *__pyx_n_s_date;
  PyObject *__pyx_n_s_datetime;
  PyObject *__pyx_n_s_dblQuotedString;
  PyObject *__pyx_n_u_dblQuotedString;
  PyObject *__pyx_n_s_dblSlashComment;
  PyObject *__pyx_n_u_dblSlashComment;
  PyObject *__pyx_n_s_debug;
  PyObject *__pyx_n_s_debugActions;
  PyObject *__pyx_n_s_debugging;
  PyObject *__pyx_n_s_decode;
  PyObject *__pyx_n_s_default;
  PyObject *__pyx_n_u_default;
  PyObject *__pyx_n_s_defaultExceptionDebugAction;
  PyObject *__pyx_n_s_defaultStartDebugAction;
  PyObject *__pyx_n_s_defaultSuccessDebugAction;
  PyObject *__pyx_n_s_defaultValue;
  PyObject *__pyx_n_u_default_keyword_chars;
  PyObject *__pyx_n_u_default_whitespace;
  PyObject *__pyx_n_s_defaultdict;
  PyObject *__pyx_n_s_defaultvalue;
  PyObject *__pyx_n_s_delim;
  PyObject *__pyx_n_s_delimitedList;
  PyObject *__pyx_n_u_delimitedList;
  PyObject *__pyx_n_s_delitem;
  PyObject *__pyx_n_s_depth;
  PyObject *__pyx_n_s_depth_2;
  PyObject *__pyx_n_s_deque;
  PyObject *__pyx_n_s_diag;
  PyObject *__pyx_n_u_diag;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_n_s_dictOf;
  PyObject *__pyx_n_u_dictOf;
  PyObject *__pyx_n_s_dictvalue;
  PyObject *__pyx_n_s_dir;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_n_s_dlName;
  PyObject *__pyx_n_s_doActions;
  PyObject *__pyx_n_s_doc;
  PyObject *__pyx_n_s_doctag;
  PyObject *__pyx_n_s_downcaseTokens;
  PyObject *__pyx_n_u_downcaseTokens;
  PyObject *__pyx_n_s_dummy;
  PyObject *__pyx_n_s_dump;
  PyObject *__pyx_n_s_e;
  PyObject *__pyx_n_s_e2;
  PyObject *__pyx_n_s_elem;
  PyObject *__pyx_n_s_empty;
  PyObject *__pyx_n_u_empty;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_enableIncremental;
  PyObject *__pyx_n_s_enablePackrat;
  PyObject *__pyx_n_u_enable_2;
  PyObject *__pyx_n_s_enable_all_warnings;
  PyObject *__pyx_n_s_enable_all_warnings_2;
  PyObject *__pyx_n_s_enable_debug_on_named_expression;
  PyObject *__pyx_n_s_end;
  PyObject *__pyx_n_u_end;
  PyObject *__pyx_n_s_endQuoteChar;
  PyObject *__pyx_n_s_endQuoteCharLen;
  PyObject *__pyx_kp_u_endQuoteChar_cannot_be_the_empty;
  PyObject *__pyx_n_s_ender;
  PyObject *__pyx_kp_u_ending_with;
  PyObject *__pyx_n_s_endloc;
  PyObject *__pyx_n_s_endlocMarker;
  PyObject *__pyx_n_s_endswith;
  PyObject *__pyx_n_s_enter;
  PyObject *__pyx_kp_u_entering;
  PyObject *__pyx_n_s_entity;
  PyObject *__pyx_n_s_enumerate;
  PyObject *__pyx_n_s_eq;
  PyObject *__pyx_n_s_err;
  PyObject *__pyx_n_s_errmsg;
  PyObject *__pyx_n_s_error;
  PyObject *__pyx_n_s_errorStop;
  PyObject *__pyx_n_s_escChar;
  PyObject *__pyx_n_s_escCharReplacePattern;
  PyObject *__pyx_n_s_escQuote;
  PyObject *__pyx_n_s_escape;
  PyObject *__pyx_n_s_escapeRegexRangeChars;
  PyObject *__pyx_n_s_escapedHexChar;
  PyObject *__pyx_n_s_escapedOctChar;
  PyObject *__pyx_n_s_escapedPunc;
  PyObject *__pyx_n_s_exact;
  PyObject *__pyx_n_s_exc;
  PyObject *__pyx_n_s_exc_info;
  PyObject *__pyx_n_s_exc_type;
  PyObject *__pyx_kp_u_exception;
  PyObject *__pyx_n_s_exceptionAction;
  PyObject *__pyx_kp_u_exception_raised_in_parse_action;
  PyObject *__pyx_kp_s_exception_thrown_by_class_Parser;
  PyObject *__pyx_n_s_excludeChars;
  PyObject *__pyx_n_s_exit;
  PyObject *__pyx_n_s_expand;
  PyObject *__pyx_n_s_expanded;
  PyObject *__pyx_n_s_expandtabs;
  PyObject *__pyx_n_s_expected;
  PyObject *__pyx_n_s_expected_dict;
  PyObject *__pyx_n_s_expected_exception;
  PyObject *__pyx_n_s_expected_list;
  PyObject *__pyx_n_s_expected_parse_results;
  PyObject *__pyx_n_s_explain;
  PyObject *__pyx_n_s_expr;
  PyObject *__pyx_n_s_expr1;
  PyObject *__pyx_n_s_expr_order;
  PyObject *__pyx_n_s_expr_parse;
  PyObject *__pyx_kp_u_expression;
  PyObject *__pyx_n_s_exprs;
  PyObject *__pyx_n_u_exprs;
  PyObject *__pyx_n_s_exprsFound;
  PyObject *__pyx_n_s_exprtokens;
  PyObject *__pyx_n_s_extend;
  PyObject *__pyx_n_s_extractText;
  PyObject *__pyx_n_s_extract_stack;
  PyObject *__pyx_n_s_extract_tb;
  PyObject *__pyx_kp_u_f;
  PyObject *__pyx_n_s_f_2;
  PyObject *__pyx_n_s_f_code;
  PyObject *__pyx_n_s_f_locals;
  PyObject *__pyx_n_s_f_self;
  PyObject *__pyx_n_s_failAction;
  PyObject *__pyx_n_s_failOn;
  PyObject *__pyx_n_s_fail_msg;
  PyObject *__pyx_n_s_failed;
  PyObject *__pyx_kp_u_failed_runTests;
  PyObject *__pyx_kp_u_failed_user_defined_condition;
  PyObject *__pyx_n_s_failureTests;
  PyObject *__pyx_n_s_fatal;
  PyObject *__pyx_n_u_fatal;
  PyObject *__pyx_n_s_ff;
  PyObject *__pyx_kp_u_ffff;
  PyObject *__pyx_n_s_file;
  PyObject *__pyx_n_s_file_contents;
  PyObject *__pyx_n_s_file_or_filename;
  PyObject *__pyx_n_s_filter;
  PyObject *__pyx_n_s_filterfalse;
  PyObject *__pyx_n_s_finalResults;
  PyObject *__pyx_n_s_find;
  PyObject *__pyx_n_s_firstMatchChar;
  PyObject *__pyx_n_s_firstQuoteChar;
  PyObject *__pyx_n_s_flag;
  PyObject *__pyx_n_s_flags;
  PyObject *__pyx_n_s_flatten;
  PyObject *__pyx_n_s_fmt;
  PyObject *__pyx_n_s_fn;
  PyObject *__pyx_n_s_fname;
  PyObject *__pyx_n_s_fns;
  PyObject *__pyx_n_s_fnumber;
  PyObject *__pyx_n_u_fnumber;
  PyObject *__pyx_n_s_format;
  PyObject *__pyx_n_s_formatted;
  PyObject *__pyx_n_s_foundArity;
  PyObject *__pyx_kp_u_found_end_of_text;
  PyObject *__pyx_kp_u_found_multiline_regex_during_inc;
  PyObject *__pyx_kp_u_found_r;
  PyObject *__pyx_n_s_foundstr;
  PyObject *__pyx_n_s_fraction;
  PyObject *__pyx_n_u_fraction;
  PyObject *__pyx_kp_u_fraction_or_mixed_integer_fracti;
  PyObject *__pyx_n_s_frame_summary;
  PyObject *__pyx_n_s_frames;
  PyObject *__pyx_n_s_frm;
  PyObject *__pyx_n_s_from;
  PyObject *__pyx_n_s_fromToken;
  PyObject *__pyx_n_u_from_2;
  PyObject *__pyx_n_s_from_dict;
  PyObject *__pyx_n_s_from_exception;
  PyObject *__pyx_n_s_from_symbols;
  PyObject *__pyx_n_s_full;
  PyObject *__pyx_n_s_fullDump;
  PyObject *__pyx_kp_u_full_IPv6_address;
  PyObject *__pyx_n_s_full_ipv6_address;
  PyObject *__pyx_n_s_func;
  PyObject *__pyx_n_s_func_name;
  PyObject *__pyx_n_s_functools;
  PyObject *__pyx_n_s_furthest_locs;
  PyObject *__pyx_kp_u_g_1;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_generatorType;
  PyObject *__pyx_n_s_genexpr;
  PyObject *__pyx_n_s_get;
  PyObject *__pyx_n_s_getName;
  PyObject *__pyx_n_s_get_2;
  PyObject *__pyx_n_s_get_chars_for_ranges;
  PyObject *__pyx_n_s_getattr;
  PyObject *__pyx_n_s_getinnerframes;
  PyObject *__pyx_n_s_getitem;
  PyObject *__pyx_n_s_getnewargs;
  PyObject *__pyx_n_s_getrecursionlimit;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_n_s_group;
  PyObject *__pyx_n_s_groupdict;
  PyObject *__pyx_n_s_groups;
  PyObject *__pyx_kp_u_gt_lt_amp_nbsp_quot_apos;
  PyObject *__pyx_n_s_hasIgnoreExprs;
  PyObject *__pyx_kp_u_has_value;
  PyObject *__pyx_n_s_hash;
  PyObject *__pyx_n_s_haskeys;
  PyObject *__pyx_kp_u_hex_integer;
  PyObject *__pyx_n_s_hex_integer_2;
  PyObject *__pyx_n_u_hex_integer_2;
  PyObject *__pyx_n_s_hexnums;
  PyObject *__pyx_n_u_hexnums;
  PyObject *__pyx_n_s_hit;
  PyObject *__pyx_n_s_htmlComment;
  PyObject *__pyx_n_u_htmlComment;
  PyObject *__pyx_n_s_htmlEntityMap;
  PyObject *__pyx_n_s_html_stripper;
  PyObject *__pyx_n_s_i;
  PyObject *__pyx_n_s_iadd;
  PyObject *__pyx_n_s_id;
  PyObject *__pyx_n_s_ident;
  PyObject *__pyx_n_s_identChars;
  PyObject *__pyx_n_s_identifier;
  PyObject *__pyx_n_u_identifier;
  PyObject *__pyx_kp_u_if_numterms_3_opExpr_must_be_a_t;
  PyObject *__pyx_n_s_ifilterfalse;
  PyObject *__pyx_n_s_ignore;
  PyObject *__pyx_n_s_ignoreExpr;
  PyObject *__pyx_n_s_ignoreExprs;
  PyObject *__pyx_n_s_ikey;
  PyObject *__pyx_kp_u_illegal_nesting;
  PyObject *__pyx_n_s_ilshift;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_inAccumNames;
  PyObject *__pyx_n_u_include;
  PyObject *__pyx_n_s_includeMatch;
  PyObject *__pyx_n_s_includeSeparators;
  PyObject *__pyx_n_s_include_2;
  PyObject *__pyx_n_s_include_list;
  PyObject *__pyx_n_s_incrementalEnabled;
  PyObject *__pyx_n_s_incrementalWithResets;
  PyObject *__pyx_n_s_incremental_parent_usefullness;
  PyObject *__pyx_n_s_ind;
  PyObject *__pyx_n_s_ind_or_e;
  PyObject *__pyx_n_s_indent;
  PyObject *__pyx_n_s_indentStack;
  PyObject *__pyx_n_s_indentedBlock;
  PyObject *__pyx_n_u_indentedBlock;
  PyObject *__pyx_n_s_indentedBlock_locals_checkPeerIn;
  PyObject *__pyx_n_s_indentedBlock_locals_checkSubInd;
  PyObject *__pyx_n_s_indentedBlock_locals_checkUninde;
  PyObject *__pyx_n_s_indentedBlock_locals_lambda;
  PyObject *__pyx_n_s_indentedBlock_locals_reset_stack;
  PyObject *__pyx_kp_u_indented_block;
  PyObject *__pyx_n_s_index;
  PyObject *__pyx_n_s_indices;
  PyObject *__pyx_n_s_infixNotation;
  PyObject *__pyx_n_u_infixNotation;
  PyObject *__pyx_n_s_infixNotation_locals__FB;
  PyObject *__pyx_n_s_infixNotation_locals__FB_parseIm;
  PyObject *__pyx_n_s_init;
  PyObject *__pyx_n_s_initChars;
  PyObject *__pyx_n_s_initCharsOrig;
  PyObject *__pyx_n_s_initExprGroups;
  PyObject *__pyx_n_s_init_subclass;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_inlineLiteralsUsing;
  PyObject *__pyx_n_s_insStr;
  PyObject *__pyx_n_s_insert;
  PyObject *__pyx_n_s_inspect;
  PyObject *__pyx_n_s_inspect_tracebacks;
  PyObject *__pyx_n_s_instring;
  PyObject *__pyx_n_s_instring_prefixes_and_suffixes;
  PyObject *__pyx_n_s_instring_slice;
  PyObject *__pyx_n_s_instrlen;
  PyObject *__pyx_n_s_intExpr;
  PyObject *__pyx_n_s_integer;
  PyObject *__pyx_n_u_integer;
  PyObject *__pyx_n_s_intern;
  PyObject *__pyx_n_u_intern;
  PyObject *__pyx_kp_u_invalid_pattern_s_passed_to_Rege;
  PyObject *__pyx_n_s_invert;
  PyObject *__pyx_n_s_ior;
  PyObject *__pyx_n_s_ipv4_address;
  PyObject *__pyx_n_s_ipv6_address;
  PyObject *__pyx_n_s_ipv6_part;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_n_s_is_instring;
  PyObject *__pyx_n_s_is_iterable;
  PyObject *__pyx_n_s_isalpha;
  PyObject *__pyx_n_s_isdigit;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_isequal;
  PyObject *__pyx_n_s_isinstance;
  PyObject *__pyx_n_s_iso8601_date;
  PyObject *__pyx_n_s_iso8601_datetime;
  PyObject *__pyx_n_s_isspace;
  PyObject *__pyx_n_s_item;
  PyObject *__pyx_n_s_item_fn;
  PyObject *__pyx_n_s_itemgetter;
  PyObject *__pyx_n_s_items;
  PyObject *__pyx_n_s_itemseq;
  PyObject *__pyx_n_s_iter;
  PyObject *__pyx_n_s_iteritems;
  PyObject *__pyx_n_s_iteritems_2;
  PyObject *__pyx_n_s_iterkeys;
  PyObject *__pyx_n_u_iterkeys;
  PyObject *__pyx_n_s_iterkeys_2;
  PyObject *__pyx_n_s_itertools;
  PyObject *__pyx_n_s_itervalues;
  PyObject *__pyx_n_s_itervalues_2;
  PyObject *__pyx_n_s_ixor;
  PyObject *__pyx_n_s_j;
  PyObject *__pyx_n_s_javaStyleComment;
  PyObject *__pyx_n_u_javaStyleComment;
  PyObject *__pyx_n_s_joinString;
  PyObject *__pyx_kp_s_just_like_class_ParseFatalExcept;
  PyObject *__pyx_n_s_k;
  PyObject *__pyx_n_s_keepMatching;
  PyObject *__pyx_n_s_keepTabs;
  PyObject *__pyx_n_s_key;
  PyObject *__pyx_n_s_key_fifo;
  PyObject *__pyx_n_u_key_fifo;
  PyObject *__pyx_n_s_keys;
  PyObject *__pyx_n_s_kwargs;
  PyObject *__pyx_n_s_l;
  PyObject *__pyx_n_s_lambda;
  PyObject *__pyx_n_s_last;
  PyObject *__pyx_n_s_lastCR;
  PyObject *__pyx_n_s_lastE;
  PyObject *__pyx_n_s_lastExpr;
  PyObject *__pyx_n_s_last_expr;
  PyObject *__pyx_n_s_lazyclassproperty;
  PyObject *__pyx_n_s_lazyclassproperty___get;
  PyObject *__pyx_n_s_lazyclassproperty___get___local;
  PyObject *__pyx_n_s_lazyclassproperty___init;
  PyObject *__pyx_n_s_leaveWhitespace;
  PyObject *__pyx_kp_u_leaving;
  PyObject *__pyx_kp_u_len;
  PyObject *__pyx_n_s_len_2;
  PyObject *__pyx_n_s_len_3;
  PyObject *__pyx_n_s_limit;
  PyObject *__pyx_n_s_line;
  PyObject *__pyx_n_u_line;
  PyObject *__pyx_n_s_lineEnd;
  PyObject *__pyx_n_u_lineEnd;
  PyObject *__pyx_n_s_lineStart;
  PyObject *__pyx_n_u_lineStart;
  PyObject *__pyx_kp_u_line_2;
  PyObject *__pyx_kp_u_line_3;
  PyObject *__pyx_n_s_line_column;
  PyObject *__pyx_n_s_line_str;
  PyObject *__pyx_n_s_lineno;
  PyObject *__pyx_n_u_lineno;
  PyObject *__pyx_kp_u_lineno_col_line;
  PyObject *__pyx_n_s_listAllMatches;
  PyObject *__pyx_n_s_list_str;
  PyObject *__pyx_n_s_list_str_locals_genexpr;
  PyObject *__pyx_n_s_literalStringClass;
  PyObject *__pyx_n_u_literal_string_class;
  PyObject *__pyx_n_s_loc;
  PyObject *__pyx_n_u_loc;
  PyObject *__pyx_n_s_loc1;
  PyObject *__pyx_n_s_loc2;
  PyObject *__pyx_n_s_locMarker;
  PyObject *__pyx_n_s_loc_in_suffix;
  PyObject *__pyx_n_s_locatedExpr;
  PyObject *__pyx_n_u_locatedExpr;
  PyObject *__pyx_n_s_locatedExpr_locals_lambda;
  PyObject *__pyx_n_s_locator;
  PyObject *__pyx_n_s_locn;
  PyObject *__pyx_n_u_locn_end;
  PyObject *__pyx_n_u_locn_start;
  PyObject *__pyx_n_s_longest;
  PyObject *__pyx_n_s_lookup;
  PyObject *__pyx_n_s_lookup_2;
  PyObject *__pyx_n_s_lookup_bools;
  PyObject *__pyx_n_s_lower;
  PyObject *__pyx_n_s_lpar;
  PyObject *__pyx_n_s_lshift;
  PyObject *__pyx_n_s_lstrip;
  PyObject *__pyx_n_s_mac_address;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_u_main;
  PyObject *__pyx_n_s_makeHTMLTags;
  PyObject *__pyx_n_u_makeHTMLTags;
  PyObject *__pyx_n_s_makeOptionalList;
  PyObject *__pyx_n_s_makeTags;
  PyObject *__pyx_n_s_makeTags_locals_lambda;
  PyObject *__pyx_n_s_makeXMLTags;
  PyObject *__pyx_n_u_makeXMLTags;
  PyObject *__pyx_n_s_map;
  PyObject *__pyx_n_s_markInputline;
  PyObject *__pyx_n_s_markerString;
  PyObject *__pyx_n_s_masks;
  PyObject *__pyx_n_s_mat;
  PyObject *__pyx_n_s_match;
  PyObject *__pyx_n_u_match;
  PyObject *__pyx_n_s_matchExpr;
  PyObject *__pyx_n_s_matchLen;
  PyObject *__pyx_n_s_matchOnlyAtCol;
  PyObject *__pyx_n_u_matchOnlyAtCol;
  PyObject *__pyx_n_s_matchOnlyAtCol_locals_verifyCol;
  PyObject *__pyx_n_s_matchOrder;
  PyObject *__pyx_n_s_matchPreviousExpr;
  PyObject *__pyx_n_u_matchPreviousExpr;
  PyObject *__pyx_n_s_matchPreviousExpr_locals_copyTok;
  PyObject *__pyx_n_s_matchPreviousExpr_locals_copyTok_2;
  PyObject *__pyx_n_s_matchPreviousLiteral;
  PyObject *__pyx_n_u_matchPreviousLiteral;
  PyObject *__pyx_n_s_matchPreviousLiteral_locals_copy;
  PyObject *__pyx_n_s_matchPreviousLiteral_locals_copy_2;
  PyObject *__pyx_n_s_matchString;
  PyObject *__pyx_n_s_matchTokens;
  PyObject *__pyx_n_s_matchWhite;
  PyObject *__pyx_n_s_match_string;
  PyObject *__pyx_n_s_match_stringloc;
  PyObject *__pyx_kp_u_matched_token_not_at_column_d;
  PyObject *__pyx_n_s_matches;
  PyObject *__pyx_n_s_max;
  PyObject *__pyx_n_s_maxExcLoc;
  PyObject *__pyx_n_s_maxException;
  PyObject *__pyx_n_s_maxLen;
  PyObject *__pyx_n_s_maxMatches;
  PyObject *__pyx_n_s_maxMismatches;
  PyObject *__pyx_n_s_maxSpecified;
  PyObject *__pyx_n_s_maxargs;
  PyObject *__pyx_n_s_maxint;
  PyObject *__pyx_n_s_maxlen;
  PyObject *__pyx_n_s_maxloc;
  PyObject *__pyx_n_s_maxsize;
  PyObject *__pyx_n_s_maxsplit;
  PyObject *__pyx_n_s_maxunicode;
  PyObject *__pyx_n_s_mayIndexError;
  PyObject *__pyx_n_s_mayReturnEmpty;
  PyObject *__pyx_n_s_merged;
  PyObject *__pyx_n_s_message;
  PyObject *__pyx_n_u_message;
  PyObject *__pyx_n_s_metaclass;
  PyObject *__pyx_n_s_methodCall;
  PyObject *__pyx_n_s_min;
  PyObject *__pyx_n_s_minElements;
  PyObject *__pyx_n_s_minLen;
  PyObject *__pyx_kp_u_mismatches;
  PyObject *__pyx_n_s_mismatches_2;
  PyObject *__pyx_n_u_mismatches_2;
  PyObject *__pyx_kp_u_missing;
  PyObject *__pyx_n_s_missing_2;
  PyObject *__pyx_kp_u_mixed_IPv6_address;
  PyObject *__pyx_n_s_mixed_integer;
  PyObject *__pyx_n_s_mixed_ipv6_address;
  PyObject *__pyx_n_s_modal;
  PyObject *__pyx_n_s_modalResults;
  PyObject *__pyx_n_s_module;
  PyObject *__pyx_kp_u_module_2;
  PyObject *__pyx_n_s_mro;
  PyObject *__pyx_n_s_mro_entries;
  PyObject *__pyx_n_s_msg;
  PyObject *__pyx_n_u_msg;
  PyObject *__pyx_n_s_mul;
  PyObject *__pyx_n_s_multiline;
  PyObject *__pyx_n_s_multioptionals;
  PyObject *__pyx_n_s_multirequired;
  PyObject *__pyx_n_s_mustMatchTheseTokens;
  PyObject *__pyx_kp_u_must_be;
  PyObject *__pyx_n_s_must_skip;
  PyObject *__pyx_n_s_mylen;
  PyObject *__pyx_n_s_n;
  PyObject *__pyx_kp_u_n_2;
  PyObject *__pyx_kp_u_n_n;
  PyObject *__pyx_kp_u_n_r;
  PyObject *__pyx_kp_u_n_r_x_x_0_9a_fA_F;
  PyObject *__pyx_kp_u_n_r_x_x_0_9a_fA_F_2;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_u_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_u_name_2;
  PyObject *__pyx_n_s_namedItems;
  PyObject *__pyx_n_s_namedItemsOnly;
  PyObject *__pyx_n_s_namespace;
  PyObject *__pyx_kp_s_namespace_class_for_classes_use;
  PyObject *__pyx_n_s_ne;
  PyObject *__pyx_n_u_negate;
  PyObject *__pyx_kp_u_nested;
  PyObject *__pyx_n_s_nestedExpr;
  PyObject *__pyx_n_u_nestedExpr;
  PyObject *__pyx_n_s_nestedExpr_locals_lambda;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_n_s_new_loc;
  PyObject *__pyx_n_s_newloc;
  PyObject *__pyx_n_s_newself;
  PyObject *__pyx_n_s_nextCR;
  PyObject *__pyx_n_s_nextLevelIndent;
  PyObject *__pyx_n_s_nextLoc;
  PyObject *__pyx_n_s_next_linebreak_loc;
  PyObject *__pyx_n_s_nextloc;
  PyObject *__pyx_n_s_nl;
  PyObject *__pyx_kp_u_no_defined_alternatives_to_match;
  PyObject *__pyx_kp_u_no_matching_attribute;
  PyObject *__pyx_kp_u_no_validation_for_r;
  PyObject *__pyx_n_s_nonzero;
  PyObject *__pyx_n_s_notChars;
  PyObject *__pyx_kp_u_not_a_peer_entry;
  PyObject *__pyx_kp_u_not_a_subentry;
  PyObject *__pyx_kp_u_not_an_unindent;
  PyObject *__pyx_n_s_not_ender;
  PyObject *__pyx_n_s_not_in_cache;
  PyObject *__pyx_kp_u_not_preceded_by;
  PyObject *__pyx_n_s_notchars;
  PyObject *__pyx_n_s_nullDebugAction;
  PyObject *__pyx_n_u_nullDebugAction;
  PyObject *__pyx_kp_u_null_string_passed_to_Keyword_us;
  PyObject *__pyx_kp_u_null_string_passed_to_Literal_us;
  PyObject *__pyx_kp_u_null_string_passed_to_Regex_use;
  PyObject *__pyx_n_s_number;
  PyObject *__pyx_n_s_nums;
  PyObject *__pyx_n_u_nums;
  PyObject *__pyx_n_s_o;
  PyObject *__pyx_n_s_obj;
  PyObject *__pyx_n_s_object;
  PyObject *__pyx_n_s_occurrences;
  PyObject *__pyx_n_s_offset;
  PyObject *__pyx_n_s_on;
  PyObject *__pyx_n_s_oneOf;
  PyObject *__pyx_n_u_oneOf;
  PyObject *__pyx_n_s_oneOf_locals_genexpr;
  PyObject *__pyx_n_s_oneOf_locals_lambda;
  PyObject *__pyx_kp_u_only_1_or_2_index_arguments_supp;
  PyObject *__pyx_n_s_opAssoc;
  PyObject *__pyx_n_u_opAssoc;
  PyObject *__pyx_n_s_opExpr;
  PyObject *__pyx_n_s_opExpr1;
  PyObject *__pyx_n_s_opExpr2;
  PyObject *__pyx_n_s_opList;
  PyObject *__pyx_n_s_open;
  PyObject *__pyx_n_s_openTag;
  PyObject *__pyx_n_s_opener;
  PyObject *__pyx_kp_u_opening_and_closing_arguments_mu;
  PyObject *__pyx_kp_u_opening_and_closing_strings_cann;
  PyObject *__pyx_n_s_operDef;
  PyObject *__pyx_n_s_operator;
  PyObject *__pyx_n_s_operatorPrecedence;
  PyObject *__pyx_n_u_operatorPrecedence;
  PyObject *__pyx_kp_u_operator_must_be_unary_1_binary;
  PyObject *__pyx_kp_u_operator_must_indicate_right_or;
  PyObject *__pyx_n_s_opt1;
  PyObject *__pyx_n_s_opt1map;
  PyObject *__pyx_n_s_opt2;
  PyObject *__pyx_n_s_optElements;
  PyObject *__pyx_n_s_optionals;
  PyObject *__pyx_n_s_or;
  PyObject *__pyx_n_s_ordereddict;
  PyObject *__pyx_n_u_original;
  PyObject *__pyx_n_s_originalParseMethod;
  PyObject *__pyx_n_u_originalParseMethod;
  PyObject *__pyx_n_s_originalTextFor;
  PyObject *__pyx_n_u_originalTextFor;
  PyObject *__pyx_n_s_originalTextFor_locals_extractTe;
  PyObject *__pyx_n_s_originalTextFor_locals_lambda;
  PyObject *__pyx_n_s_original_end;
  PyObject *__pyx_n_u_original_end;
  PyObject *__pyx_n_s_original_start;
  PyObject *__pyx_n_u_original_start;
  PyObject *__pyx_n_s_os_path;
  PyObject *__pyx_n_s_other;
  PyObject *__pyx_n_s_other_instring;
  PyObject *__pyx_n_s_otherdictitems;
  PyObject *__pyx_n_s_otheritems;
  PyObject *__pyx_n_s_out;
  PyObject *__pyx_n_s_outer_parent_usefullness_obj;
  PyObject *__pyx_n_s_overlap;
  PyObject *__pyx_n_s_p;
  PyObject *__pyx_n_s_p1;
  PyObject *__pyx_n_s_p2;
  PyObject *__pyx_n_s_pa;
  PyObject *__pyx_n_s_paArgs;
  PyObject *__pyx_n_s_pa_call_line_synth;
  PyObject *__pyx_n_s_packratEnabled;
  PyObject *__pyx_n_s_packrat_cache;
  PyObject *__pyx_n_s_packrat_cache_lock;
  PyObject *__pyx_n_s_packrat_cache_stats;
  PyObject *__pyx_n_s_packrat_context;
  PyObject *__pyx_n_u_packrat_enabled;
  PyObject *__pyx_n_u_packrat_parse;
  PyObject *__pyx_n_s_par;
  PyObject *__pyx_n_s_parse;
  PyObject *__pyx_n_s_parseAction;
  PyObject *__pyx_n_s_parseAll;
  PyObject *__pyx_n_s_parseCache;
  PyObject *__pyx_n_s_parseElementClass;
  PyObject *__pyx_n_s_parseElementList;
  PyObject *__pyx_n_s_parseElementTrace;
  PyObject *__pyx_n_s_parseFile;
  PyObject *__pyx_n_s_parseFn;
  PyObject *__pyx_n_s_parseImpl;
  PyObject *__pyx_n_u_parseImpl;
  PyObject *__pyx_n_s_parseImplAsGroupList;
  PyObject *__pyx_n_s_parseImplAsMatch;
  PyObject *__pyx_n_s_parseIncremental;
  PyObject *__pyx_n_s_parseMethod;
  PyObject *__pyx_n_s_parseNoCache;
  PyObject *__pyx_n_u_parseNoCache;
  PyObject *__pyx_n_s_parseString;
  PyObject *__pyx_n_s_parseWithTabs;
  PyObject *__pyx_kp_u_parse_action;
  PyObject *__pyx_n_s_parse_action_exc;
  PyObject *__pyx_kp_u_parse_actions_must_be_callable;
  PyObject *__pyx_n_s_parse_element_index;
  PyObject *__pyx_n_s_parserElement;
  PyObject *__pyx_n_u_parserElement;
  PyObject *__pyx_n_s_pattern;
  PyObject *__pyx_n_u_pattern;
  PyObject *__pyx_n_s_pbe;
  PyObject *__pyx_n_s_pdb;
  PyObject *__pyx_n_s_pe;
  PyObject *__pyx_n_s_pop;
  PyObject *__pyx_kp_u_pop_got_an_unexpected_keyword_ar;
  PyObject *__pyx_n_s_popitem;
  PyObject *__pyx_n_s_popleft;
  PyObject *__pyx_n_s_position;
  PyObject *__pyx_n_s_postParse;
  PyObject *__pyx_n_s_pp_value;
  PyObject *__pyx_n_s_pprint;
  PyObject *__pyx_n_s_preParse;
  PyObject *__pyx_n_s_prefix_len;
  PyObject *__pyx_n_s_prefix_lookup;
  PyObject *__pyx_n_s_prefixes_and_suffixes;
  PyObject *__pyx_n_s_preloc;
  PyObject *__pyx_n_s_prepare;
  PyObject *__pyx_n_s_preparseFn;
  PyObject *__pyx_kp_u_prev;
  PyObject *__pyx_n_s_print;
  PyObject *__pyx_n_s_printResults;
  PyObject *__pyx_n_s_print_2;
  PyObject *__pyx_n_s_printable;
  PyObject *__pyx_n_s_printables;
  PyObject *__pyx_n_u_printables;
  PyObject *__pyx_n_s_pstr;
  PyObject *__pyx_n_u_pstr;
  PyObject *__pyx_n_s_punc8bit;
  PyObject *__pyx_n_u_punc8bit;
  PyObject *__pyx_n_s_py_repr;
  PyObject *__pyx_n_s_py_str;
  PyObject *__pyx_n_s_pyparsing_common;
  PyObject *__pyx_n_u_pyparsing_common;
  PyObject *__pyx_n_s_pyparsing_common_convertToDate;
  PyObject *__pyx_n_s_pyparsing_common_convertToDate_l;
  PyObject *__pyx_n_s_pyparsing_common_convertToDateti;
  PyObject *__pyx_n_s_pyparsing_common_convertToDateti_2;
  PyObject *__pyx_n_s_pyparsing_common_lambda;
  PyObject *__pyx_n_s_pyparsing_common_lambda_locals_g;
  PyObject *__pyx_n_s_pyparsing_common_stripHTMLTags;
  PyObject *__pyx_n_s_pyparsing_test;
  PyObject *__pyx_n_s_pyparsing_test_TestParseResultsA;
  PyObject *__pyx_n_s_pyparsing_test_TestParseResultsA_2;
  PyObject *__pyx_n_s_pyparsing_test_TestParseResultsA_3;
  PyObject *__pyx_n_s_pyparsing_test_TestParseResultsA_4;
  PyObject *__pyx_n_s_pyparsing_test_TestParseResultsA_5;
  PyObject *__pyx_n_s_pyparsing_test_TestParseResultsA_6;
  PyObject *__pyx_n_s_pyparsing_test_TestParseResultsA_7;
  PyObject *__pyx_n_s_pyparsing_test_reset_pyparsing_c;
  PyObject *__pyx_n_s_pyparsing_test_reset_pyparsing_c_2;
  PyObject *__pyx_n_s_pyparsing_test_reset_pyparsing_c_3;
  PyObject *__pyx_n_s_pyparsing_test_reset_pyparsing_c_4;
  PyObject *__pyx_n_s_pyparsing_test_reset_pyparsing_c_5;
  PyObject *__pyx_n_s_pyparsing_test_reset_pyparsing_c_6;
  PyObject *__pyx_n_s_pyparsing_unicode;
  PyObject *__pyx_n_u_pyparsing_unicode;
  PyObject *__pyx_n_s_pyparsing_unicode_Arabic;
  PyObject *__pyx_n_s_pyparsing_unicode_CJK;
  PyObject *__pyx_n_s_pyparsing_unicode_Chinese;
  PyObject *__pyx_n_s_pyparsing_unicode_Cyrillic;
  PyObject *__pyx_n_s_pyparsing_unicode_Devanagari;
  PyObject *__pyx_n_s_pyparsing_unicode_Greek;
  PyObject *__pyx_n_s_pyparsing_unicode_Hebrew;
  PyObject *__pyx_n_s_pyparsing_unicode_Japanese;
  PyObject *__pyx_n_s_pyparsing_unicode_Japanese_Hirag;
  PyObject *__pyx_n_s_pyparsing_unicode_Japanese_Kanji;
  PyObject *__pyx_n_s_pyparsing_unicode_Japanese_Katak;
  PyObject *__pyx_n_s_pyparsing_unicode_Korean;
  PyObject *__pyx_n_s_pyparsing_unicode_Latin1;
  PyObject *__pyx_n_s_pyparsing_unicode_LatinA;
  PyObject *__pyx_n_s_pyparsing_unicode_LatinB;
  PyObject *__pyx_n_s_pyparsing_unicode_Thai;
  PyObject *__pyx_n_s_pythonStyleComment;
  PyObject *__pyx_n_u_pythonStyleComment;
  PyObject *__pyx_n_s_qualname;
  PyObject *__pyx_n_s_quoteChar;
  PyObject *__pyx_n_s_quoteCharLen;
  PyObject *__pyx_kp_u_quoteChar_cannot_be_the_empty_st;
  PyObject *__pyx_n_s_quotedString;
  PyObject *__pyx_n_u_quotedString;
  PyObject *__pyx_kp_u_quotedString_using_single_or_dou;
  PyObject *__pyx_kp_u_quoted_string_starting_with;
  PyObject *__pyx_n_u_r;
  PyObject *__pyx_kp_u_r_2;
  PyObject *__pyx_kp_u_r_object_is_not_iterable;
  PyObject *__pyx_n_s_radd;
  PyObject *__pyx_n_s_rand;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_ranges;
  PyObject *__pyx_n_s_re;
  PyObject *__pyx_n_u_re;
  PyObject *__pyx_n_s_reBracketExpr;
  PyObject *__pyx_n_s_reString;
  PyObject *__pyx_n_s_re_match;
  PyObject *__pyx_n_s_read;
  PyObject *__pyx_n_s_real;
  PyObject *__pyx_kp_u_real_number;
  PyObject *__pyx_kp_u_real_number_with_scientific_nota;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_ref;
  PyObject *__pyx_n_s_register;
  PyObject *__pyx_n_s_remove;
  PyObject *__pyx_n_s_removeQuotes;
  PyObject *__pyx_n_u_removeQuotes;
  PyObject *__pyx_n_s_removed;
  PyObject *__pyx_n_s_rep;
  PyObject *__pyx_n_s_repl;
  PyObject *__pyx_n_s_replStr;
  PyObject *__pyx_n_s_replace;
  PyObject *__pyx_n_s_replaceHTMLEntity;
  PyObject *__pyx_n_u_replaceHTMLEntity;
  PyObject *__pyx_n_s_replaceWith;
  PyObject *__pyx_n_u_replaceWith;
  PyObject *__pyx_n_s_replaceWith_locals_lambda;
  PyObject *__pyx_n_s_repr;
  PyObject *__pyx_n_s_repr_2;
  PyObject *__pyx_n_s_req;
  PyObject *__pyx_n_s_required;
  PyObject *__pyx_n_s_res;
  PyObject *__pyx_n_s_resTag;
  PyObject *__pyx_n_s_reset;
  PyObject *__pyx_n_s_resetCache;
  PyObject *__pyx_n_s_reset_pyparsing_context;
  PyObject *__pyx_n_s_reset_stack;
  PyObject *__pyx_n_s_resname;
  PyObject *__pyx_n_s_restOfLine;
  PyObject *__pyx_n_u_restOfLine;
  PyObject *__pyx_kp_u_rest_of_line;
  PyObject *__pyx_n_s_restore;
  PyObject *__pyx_n_s_result;
  PyObject *__pyx_n_s_resultlist;
  PyObject *__pyx_n_s_results;
  PyObject *__pyx_n_s_resultsName;
  PyObject *__pyx_n_s_ret;
  PyObject *__pyx_n_s_retTokens;
  PyObject *__pyx_n_s_retToks;
  PyObject *__pyx_kp_u_ret_2;
  PyObject *__pyx_n_s_ret_toks;
  PyObject *__pyx_n_s_retobj;
  PyObject *__pyx_n_s_retreat;
  PyObject *__pyx_n_s_returnString;
  PyObject *__pyx_n_s_reverse;
  PyObject *__pyx_n_s_reversed;
  PyObject *__pyx_n_s_reversed_2;
  PyObject *__pyx_n_s_reversed_instring;
  PyObject *__pyx_n_s_rfind;
  PyObject *__pyx_n_s_rightLeftAssoc;
  PyObject *__pyx_n_s_rmul;
  PyObject *__pyx_n_s_rne;
  PyObject *__pyx_n_s_ror;
  PyObject *__pyx_n_s_rpar;
  PyObject *__pyx_n_s_rpt;
  PyObject *__pyx_n_s_rr;
  PyObject *__pyx_n_s_rstrip;
  PyObject *__pyx_n_s_rsub;
  PyObject *__pyx_n_s_runTests;
  PyObject *__pyx_n_s_run_test_results;
  PyObject *__pyx_n_s_run_test_success;
  PyObject *__pyx_n_s_run_tests_report;
  PyObject *__pyx_n_s_rxor;
  PyObject *__pyx_n_s_s;
  PyObject *__pyx_kp_u_s_10;
  PyObject *__pyx_kp_u_s_2;
  PyObject *__pyx_kp_u_s_3;
  PyObject *__pyx_kp_u_s_4;
  PyObject *__pyx_kp_u_s_5;
  PyObject *__pyx_kp_u_s_6;
  PyObject *__pyx_kp_u_s_7;
  PyObject *__pyx_kp_u_s_8;
  PyObject *__pyx_kp_u_s_9;
  PyObject *__pyx_kp_u_s_S;
  PyObject *__pyx_kp_u_s_class;
  PyObject *__pyx_n_s_s_m;
  PyObject *__pyx_n_s_s_pl_sl;
  PyObject *__pyx_kp_u_s_s_term;
  PyObject *__pyx_kp_u_s_term;
  PyObject *__pyx_n_s_save;
  PyObject *__pyx_n_s_saveAsList;
  PyObject *__pyx_n_s_save_context;
  PyObject *__pyx_n_s_savelist;
  PyObject *__pyx_n_s_scanString;
  PyObject *__pyx_n_s_sci_real;
  PyObject *__pyx_n_s_se;
  PyObject *__pyx_n_s_searchString;
  PyObject *__pyx_kp_u_second_tuple_value_must_be_great;
  PyObject *__pyx_n_s_seen;
  PyObject *__pyx_n_u_select;
  PyObject *__pyx_n_s_selectToken;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_n_u_self;
  PyObject *__pyx_n_s_selfTag;
  PyObject *__pyx_n_s_self_expr_parse;
  PyObject *__pyx_n_s_self_failOn_canParseNext;
  PyObject *__pyx_n_s_self_ignoreExpr_tryParse;
  PyObject *__pyx_n_s_self_skip_ignorables;
  PyObject *__pyx_n_s_self_type;
  PyObject *__pyx_n_s_send;
  PyObject *__pyx_n_s_sep;
  PyObject *__pyx_n_s_set;
  PyObject *__pyx_n_s_setAdaptiveMode;
  PyObject *__pyx_n_s_setBreak;
  PyObject *__pyx_n_s_setDebug;
  PyObject *__pyx_n_s_setDebugActions;
  PyObject *__pyx_n_s_setDefaultKeywordChars;
  PyObject *__pyx_n_s_setDefaultWhitespaceChars;
  PyObject *__pyx_n_s_setFailAction;
  PyObject *__pyx_n_s_setName;
  PyObject *__pyx_n_s_setOffset;
  PyObject *__pyx_n_s_setParseAction;
  PyObject *__pyx_n_s_setResultsName;
  PyObject *__pyx_n_s_setResultsName_2;
  PyObject *__pyx_n_s_setWhitespaceChars;
  PyObject *__pyx_n_s_set_name;
  PyObject *__pyx_n_s_set_trace;
  PyObject *__pyx_n_s_setitem;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_sglQuotedString;
  PyObject *__pyx_n_u_sglQuotedString;
  PyObject *__pyx_kp_u_short_IPv6_address;
  PyObject *__pyx_n_s_short_ipv6_address;
  PyObject *__pyx_n_s_should_cache_incremental_succes;
  PyObject *__pyx_n_s_show_skip;
  PyObject *__pyx_kp_u_signed_integer;
  PyObject *__pyx_n_s_signed_integer_2;
  PyObject *__pyx_n_s_simpleSQL;
  PyObject *__pyx_n_s_singleArgBuiltins;
  PyObject *__pyx_n_s_singleChar;
  PyObject *__pyx_n_s_size;
  PyObject *__pyx_n_s_skipIgnorables;
  PyObject *__pyx_n_s_skipWhitespace;
  PyObject *__pyx_kp_u_skipped;
  PyObject *__pyx_n_s_skipped_2;
  PyObject *__pyx_n_u_skipped_2;
  PyObject *__pyx_n_s_skipped_3;
  PyObject *__pyx_n_s_skipper;
  PyObject *__pyx_n_s_skipresult;
  PyObject *__pyx_n_s_skiptext;
  PyObject *__pyx_n_s_skipto_arg;
  PyObject *__pyx_n_s_slots;
  PyObject *__pyx_n_s_smExpr;
  PyObject *__pyx_n_s_sort;
  PyObject *__pyx_n_s_sorted;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_split;
  PyObject *__pyx_n_s_splitlines;
  PyObject *__pyx_n_s_splits;
  PyObject *__pyx_n_s_srange;
  PyObject *__pyx_n_u_srange;
  PyObject *__pyx_n_s_srange_locals_genexpr;
  PyObject *__pyx_n_s_srange_locals_lambda;
  PyObject *__pyx_n_s_srange_locals_lambda_locals_gene;
  PyObject *__pyx_n_s_src;
  PyObject *__pyx_n_s_sre_constants;
  PyObject *__pyx_n_s_stacklevel;
  PyObject *__pyx_n_s_start;
  PyObject *__pyx_n_u_start;
  PyObject *__pyx_n_s_startAction;
  PyObject *__pyx_n_s_startloc;
  PyObject *__pyx_n_s_startswith;
  PyObject *__pyx_n_s_state;
  PyObject *__pyx_n_s_staticmethod;
  PyObject *__pyx_n_s_stderr;
  PyObject *__pyx_n_s_stdout;
  PyObject *__pyx_n_s_still_reset_cache;
  PyObject *__pyx_n_s_stopOn;
  PyObject *__pyx_n_s_str;
  PyObject *__pyx_n_s_strRepr;
  PyObject *__pyx_n_s_str_2;
  PyObject *__pyx_n_s_streamline;
  PyObject *__pyx_n_s_streamlined;
  PyObject *__pyx_n_s_strg;
  PyObject *__pyx_n_s_string;
  PyObject *__pyx_n_s_stringEnd;
  PyObject *__pyx_n_u_stringEnd;
  PyObject *__pyx_n_s_stringStart;
  PyObject *__pyx_n_u_stringStart;
  PyObject *__pyx_kp_u_string_enclosed_in_double_quotes;
  PyObject *__pyx_kp_u_string_enclosed_in_single_quotes;
  PyObject *__pyx_n_s_strip;
  PyObject *__pyx_n_s_stripHTMLTags;
  PyObject *__pyx_n_s_strptime;
  PyObject *__pyx_n_s_strs;
  PyObject *__pyx_n_s_sub;
  PyObject *__pyx_n_s_subRecCheckList;
  PyObject *__pyx_n_s_sub_2;
  PyObject *__pyx_n_s_success;
  PyObject *__pyx_n_s_successAction;
  PyObject *__pyx_n_s_suffix_len;
  PyObject *__pyx_n_s_suffix_lookup;
  PyObject *__pyx_n_s_sum;
  PyObject *__pyx_kp_u_sum_len_sorted_reversed_list_tup;
  PyObject *__pyx_n_s_super;
  PyObject *__pyx_n_s_suppress;
  PyObject *__pyx_n_s_suppress_GT;
  PyObject *__pyx_n_s_suppress_LT;
  PyObject *__pyx_n_s_symbols;
  PyObject *__pyx_n_s_sys;
  PyObject *__pyx_n_s_system_version;
  PyObject *__pyx_n_s_t;
  PyObject *__pyx_kp_u_t_2;
  PyObject *__pyx_n_s_tableName;
  PyObject *__pyx_n_s_tableNameList;
  PyObject *__pyx_n_u_tables;
  PyObject *__pyx_n_s_tag;
  PyObject *__pyx_n_u_tag;
  PyObject *__pyx_n_s_tagAttrName;
  PyObject *__pyx_n_s_tagAttrValue;
  PyObject *__pyx_n_s_tagStr;
  PyObject *__pyx_n_s_tag_body;
  PyObject *__pyx_n_s_tb;
  PyObject *__pyx_n_s_tb_next;
  PyObject *__pyx_n_s_termName;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_testString;
  PyObject *__pyx_n_s_test_expr;
  PyObject *__pyx_n_s_test_string;
  PyObject *__pyx_n_s_tests;
  PyObject *__pyx_n_s_tflat;
  PyObject *__pyx_n_s_theseTokens;
  PyObject *__pyx_n_s_thisExpr;
  PyObject *__pyx_n_s_thisFunc;
  PyObject *__pyx_n_s_thiscol;
  PyObject *__pyx_n_s_thread;
  PyObject *__pyx_n_s_threading;
  PyObject *__pyx_n_s_throw;
  PyObject *__pyx_n_s_throwException;
  PyObject *__pyx_n_s_title;
  PyObject *__pyx_n_s_tmp;
  PyObject *__pyx_n_s_tmpExprs;
  PyObject *__pyx_n_s_tmpLoc;
  PyObject *__pyx_n_s_tmpOpt;
  PyObject *__pyx_n_s_tmpReqd;
  PyObject *__pyx_n_s_tmploc;
  PyObject *__pyx_n_s_tmptokens;
  PyObject *__pyx_n_s_to;
  PyObject *__pyx_n_s_toItem;
  PyObject *__pyx_n_s_to_symbols;
  PyObject *__pyx_n_s_tok;
  PyObject *__pyx_n_s_tokenMap;
  PyObject *__pyx_n_u_tokenMap;
  PyObject *__pyx_n_s_tokenMap_locals_pa;
  PyObject *__pyx_n_s_tokenlist;
  PyObject *__pyx_n_s_tokens;
  PyObject *__pyx_n_s_tokensStart;
  PyObject *__pyx_n_s_toklist;
  PyObject *__pyx_n_s_tokn;
  PyObject *__pyx_n_s_toks;
  PyObject *__pyx_n_s_traceParseAction;
  PyObject *__pyx_n_u_traceParseAction;
  PyObject *__pyx_n_s_traceParseAction_locals_z;
  PyObject *__pyx_n_s_traceback;
  PyObject *__pyx_n_u_traceback;
  PyObject *__pyx_n_s_traceback_2;
  PyObject *__pyx_n_s_transformString;
  PyObject *__pyx_n_s_trim_arity;
  PyObject *__pyx_n_s_trim_arity_locals_extract_stack;
  PyObject *__pyx_n_s_trim_arity_locals_extract_tb;
  PyObject *__pyx_n_s_trim_arity_locals_lambda;
  PyObject *__pyx_n_s_trim_arity_locals_wrapper;
  PyObject *__pyx_n_s_trim_traceback;
  PyObject *__pyx_n_s_tryParse;
  PyObject *__pyx_n_s_try_not_ender;
  PyObject *__pyx_n_s_tup;
  PyObject *__pyx_n_s_types;
  PyObject *__pyx_n_u_u;
  PyObject *__pyx_n_s_ungroup;
  PyObject *__pyx_n_u_ungroup;
  PyObject *__pyx_n_s_ungroup_locals_lambda;
  PyObject *__pyx_n_s_unichr;
  PyObject *__pyx_n_s_unicode;
  PyObject *__pyx_n_s_unicodeString;
  PyObject *__pyx_n_u_unicodeString;
  PyObject *__pyx_n_s_unicode_set;
  PyObject *__pyx_n_u_unicode_set;
  PyObject *__pyx_n_s_unicode_set__get_chars_for_range;
  PyObject *__pyx_n_s_unicode_set_alphanums;
  PyObject *__pyx_n_s_unicode_set_alphas;
  PyObject *__pyx_n_s_unicode_set_nums;
  PyObject *__pyx_n_s_unicode_set_printables;
  PyObject *__pyx_kp_u_unicode_string_literal;
  PyObject *__pyx_n_s_unquoteResults;
  PyObject *__pyx_n_s_upcaseTokens;
  PyObject *__pyx_n_u_upcaseTokens;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_update_dict;
  PyObject *__pyx_n_s_update_furthest_loc_for_regex;
  PyObject *__pyx_n_s_update_wrapper;
  PyObject *__pyx_n_s_upper;
  PyObject *__pyx_n_s_usage;
  PyObject *__pyx_n_s_usage_weight;
  PyObject *__pyx_n_s_useRegex;
  PyObject *__pyx_kp_u_use_of_expression_without_follow;
  PyObject *__pyx_kp_s_user_throwable_exception_thrown;
  PyObject *__pyx_n_s_ustr;
  PyObject *__pyx_n_u_utf8;
  PyObject *__pyx_n_s_uuid;
  PyObject *__pyx_n_s_v;
  PyObject *__pyx_n_s_validate;
  PyObject *__pyx_n_s_validateTrace;
  PyObject *__pyx_n_s_value;
  PyObject *__pyx_n_u_value;
  PyObject *__pyx_n_s_values;
  PyObject *__pyx_n_s_vars;
  PyObject *__pyx_n_s_ve;
  PyObject *__pyx_n_s_verbose;
  PyObject *__pyx_n_s_verbose_stacktrace;
  PyObject *__pyx_n_s_verifyCol;
  PyObject *__pyx_n_s_version;
  PyObject *__pyx_n_u_version;
  PyObject *__pyx_n_s_versionTime;
  PyObject *__pyx_n_u_versionTime;
  PyObject *__pyx_n_s_version_info;
  PyObject *__pyx_n_s_vlist;
  PyObject *__pyx_n_s_vv;
  PyObject *__pyx_n_s_warn;
  PyObject *__pyx_n_u_warn_2;
  PyObject *__pyx_n_s_warn_multiple_tokens_in_named_al;
  PyObject *__pyx_n_u_warn_multiple_tokens_in_named_al;
  PyObject *__pyx_n_s_warn_name_set_on_empty_Forward;
  PyObject *__pyx_n_u_warn_name_set_on_empty_Forward;
  PyObject *__pyx_n_s_warn_on_incremental_multiline_re;
  PyObject *__pyx_n_s_warn_on_multiple_string_args_to;
  PyObject *__pyx_n_s_warn_ungrouped_named_tokens_in_c;
  PyObject *__pyx_n_u_warn_ungrouped_named_tokens_in_c;
  PyObject *__pyx_n_s_warnings;
  PyObject *__pyx_n_s_weakref;
  PyObject *__pyx_n_s_whiteChars;
  PyObject *__pyx_n_s_whiteStrs;
  PyObject *__pyx_n_s_whitespace;
  PyObject *__pyx_n_s_withAttribute;
  PyObject *__pyx_n_u_withAttribute;
  PyObject *__pyx_n_s_withClass;
  PyObject *__pyx_n_u_withClass;
  PyObject *__pyx_kp_u_with_up_to;
  PyObject *__pyx_n_s_wkref;
  PyObject *__pyx_n_s_wordChars;
  PyObject *__pyx_n_s_wrapper;
  PyObject *__pyx_n_u_wrapper;
  PyObject *__pyx_n_s_wraps;
  PyObject *__pyx_n_s_write;
  PyObject *__pyx_n_s_ws;
  PyObject *__pyx_n_s_ws_map;
  PyObject *__pyx_n_s_wschar;
  PyObject *__pyx_n_s_wslit;
  PyObject *__pyx_n_s_wt;
  PyObject *__pyx_n_s_xml;
  PyObject *__pyx_n_s_xmlBodyText;
  PyObject *__pyx_n_s_xml_escape;
  PyObject *__pyx_n_s_xml_escape_locals_genexpr;
  PyObject *__pyx_n_s_xor;
  PyObject *__pyx_n_s_xrange;
  PyObject *__pyx_n_s_z;
  PyObject *__pyx_n_s_zip;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_2;
  PyObject *__pyx_int_3;
  PyObject *__pyx_int_4;
  PyObject *__pyx_int_5;
  PyObject *__pyx_int_6;
  PyObject *__pyx_int_7;
  PyObject *__pyx_int_8;
  PyObject *__pyx_int_11;
  PyObject *__pyx_int_16;
  PyObject *__pyx_int_32;
  PyObject *__pyx_int_92;
  PyObject *__pyx_int_126;
  PyObject *__pyx_int_128;
  PyObject *__pyx_int_160;
  PyObject *__pyx_int_255;
  PyObject *__pyx_int_256;
  PyObject *__pyx_int_383;
  PyObject *__pyx_int_384;
  PyObject *__pyx_int_591;
  PyObject *__pyx_int_880;
  PyObject *__pyx_int_1023;
  PyObject *__pyx_int_1024;
  PyObject *__pyx_int_1279;
  PyObject *__pyx_int_1328;
  PyObject *__pyx_int_1424;
  PyObject *__pyx_int_1535;
  PyObject *__pyx_int_1536;
  PyObject *__pyx_int_1563;
  PyObject *__pyx_int_1566;
  PyObject *__pyx_int_1791;
  PyObject *__pyx_int_1792;
  PyObject *__pyx_int_1919;
  PyObject *__pyx_int_2304;
  PyObject *__pyx_int_2431;
  PyObject *__pyx_int_3585;
  PyObject *__pyx_int_3642;
  PyObject *__pyx_int_3647;
  PyObject *__pyx_int_3675;
  PyObject *__pyx_int_4352;
  PyObject *__pyx_int_4607;
  PyObject *__pyx_int_7936;
  PyObject *__pyx_int_7957;
  PyObject *__pyx_int_7960;
  PyObject *__pyx_int_7965;
  PyObject *__pyx_int_7968;
  PyObject *__pyx_int_8005;
  PyObject *__pyx_int_8008;
  PyObject *__pyx_int_8013;
  PyObject *__pyx_int_8016;
  PyObject *__pyx_int_8023;
  PyObject *__pyx_int_8025;
  PyObject *__pyx_int_8027;
  PyObject *__pyx_int_8029;
  PyObject *__pyx_int_8031;
  PyObject *__pyx_int_8061;
  PyObject *__pyx_int_8064;
  PyObject *__pyx_int_8116;
  PyObject *__pyx_int_8118;
  PyObject *__pyx_int_8132;
  PyObject *__pyx_int_8134;
  PyObject *__pyx_int_8147;
  PyObject *__pyx_int_8150;
  PyObject *__pyx_int_8155;
  PyObject *__pyx_int_8157;
  PyObject *__pyx_int_8175;
  PyObject *__pyx_int_8178;
  PyObject *__pyx_int_8180;
  PyObject *__pyx_int_8182;
  PyObject *__pyx_int_8190;
  PyObject *__pyx_int_12288;
  PyObject *__pyx_int_12351;
  PyObject *__pyx_int_12352;
  PyObject *__pyx_int_12447;
  PyObject *__pyx_int_12448;
  PyObject *__pyx_int_12543;
  PyObject *__pyx_int_12592;
  PyObject *__pyx_int_12687;
  PyObject *__pyx_int_19968;
  PyObject *__pyx_int_40895;
  PyObject *__pyx_int_40959;
  PyObject *__pyx_int_43232;
  PyObject *__pyx_int_43263;
  PyObject *__pyx_int_43360;
  PyObject *__pyx_int_43391;
  PyObject *__pyx_int_44032;
  PyObject *__pyx_int_55215;
  PyObject *__pyx_int_55216;
  PyObject *__pyx_int_55295;
  PyObject *__pyx_int_neg_1;
  PyObject *__pyx_slice_;
  PyObject *__pyx_tuple__8;
  PyObject *__pyx_slice__20;
  PyObject *__pyx_slice__21;
  PyObject *__pyx_slice__37;
  PyObject *__pyx_slice__47;
  PyObject *__pyx_slice__55;
  PyObject *__pyx_slice__64;
  PyObject *__pyx_slice__70;
  PyObject *__pyx_slice__81;
  PyObject *__pyx_tuple__18;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__32;
  PyObject *__pyx_tuple__36;
  PyObject *__pyx_tuple__38;
  PyObject *__pyx_tuple__39;
  PyObject *__pyx_tuple__41;
  PyObject *__pyx_tuple__42;
  PyObject *__pyx_tuple__44;
  PyObject *__pyx_tuple__46;
  PyObject *__pyx_tuple__48;
  PyObject *__pyx_tuple__50;
  PyObject *__pyx_tuple__51;
  PyObject *__pyx_tuple__54;
  PyObject *__pyx_tuple__56;
  PyObject *__pyx_tuple__57;
  PyObject *__pyx_tuple__58;
  PyObject *__pyx_tuple__59;
  PyObject *__pyx_tuple__60;
  PyObject *__pyx_tuple__61;
  PyObject *__pyx_tuple__62;
  PyObject *__pyx_tuple__68;
  PyObject *__pyx_tuple__69;
  PyObject *__pyx_tuple__71;
  PyObject *__pyx_tuple__73;
  PyObject *__pyx_tuple__75;
  PyObject *__pyx_tuple__76;
  PyObject *__pyx_tuple__77;
  PyObject *__pyx_tuple__78;
  PyObject *__pyx_tuple__82;
  PyObject *__pyx_tuple__84;
  PyObject *__pyx_tuple__85;
  PyObject *__pyx_tuple__86;
  PyObject *__pyx_tuple__87;
  PyObject *__pyx_tuple__88;
  PyObject *__pyx_tuple__92;
  PyObject *__pyx_tuple__93;
  PyObject *__pyx_codeobj__9;
  PyObject *__pyx_slice__141;
  PyObject *__pyx_tuple__101;
  PyObject *__pyx_tuple__103;
  PyObject *__pyx_tuple__106;
  PyObject *__pyx_tuple__109;
  PyObject *__pyx_tuple__120;
  PyObject *__pyx_tuple__123;
  PyObject *__pyx_tuple__125;
  PyObject *__pyx_tuple__127;
  PyObject *__pyx_tuple__128;
  PyObject *__pyx_tuple__130;
  PyObject *__pyx_tuple__132;
  PyObject *__pyx_tuple__133;
  PyObject *__pyx_tuple__134;
  PyObject *__pyx_tuple__135;
  PyObject *__pyx_tuple__137;
  PyObject *__pyx_tuple__139;
  PyObject *__pyx_tuple__142;
  PyObject *__pyx_tuple__146;
  PyObject *__pyx_tuple__149;
  PyObject *__pyx_tuple__151;
  PyObject *__pyx_tuple__153;
  PyObject *__pyx_tuple__155;
  PyObject *__pyx_tuple__156;
  PyObject *__pyx_tuple__157;
  PyObject *__pyx_tuple__158;
  PyObject *__pyx_tuple__159;
  PyObject *__pyx_tuple__160;
  PyObject *__pyx_tuple__162;
  PyObject *__pyx_tuple__167;
  PyObject *__pyx_tuple__171;
  PyObject *__pyx_tuple__175;
  PyObject *__pyx_tuple__177;
  PyObject *__pyx_tuple__178;
  PyObject *__pyx_tuple__180;
  PyObject *__pyx_tuple__181;
  PyObject *__pyx_tuple__183;
  PyObject *__pyx_tuple__184;
  PyObject *__pyx_tuple__185;
  PyObject *__pyx_tuple__187;
  PyObject *__pyx_tuple__188;
  PyObject *__pyx_tuple__190;
  PyObject *__pyx_tuple__192;
  PyObject *__pyx_tuple__194;
  PyObject *__pyx_tuple__196;
  PyObject *__pyx_tuple__198;
  PyObject *__pyx_tuple__200;
  PyObject *__pyx_tuple__202;
  PyObject *__pyx_tuple__203;
  PyObject *__pyx_tuple__206;
  PyObject *__pyx_tuple__207;
  PyObject *__pyx_tuple__208;
  PyObject *__pyx_tuple__210;
  PyObject *__pyx_tuple__214;
  PyObject *__pyx_tuple__215;
  PyObject *__pyx_tuple__216;
  PyObject *__pyx_tuple__218;
  PyObject *__pyx_tuple__219;
  PyObject *__pyx_tuple__221;
  PyObject *__pyx_tuple__223;
  PyObject *__pyx_tuple__225;
  PyObject *__pyx_tuple__227;
  PyObject *__pyx_tuple__234;
  PyObject *__pyx_tuple__241;
  PyObject *__pyx_tuple__243;
  PyObject *__pyx_tuple__245;
  PyObject *__pyx_tuple__247;
  PyObject *__pyx_tuple__249;
  PyObject *__pyx_tuple__252;
  PyObject *__pyx_tuple__254;
  PyObject *__pyx_tuple__256;
  PyObject *__pyx_tuple__258;
  PyObject *__pyx_tuple__262;
  PyObject *__pyx_tuple__264;
  PyObject *__pyx_tuple__265;
  PyObject *__pyx_tuple__267;
  PyObject *__pyx_tuple__269;
  PyObject *__pyx_tuple__271;
  PyObject *__pyx_tuple__273;
  PyObject *__pyx_tuple__274;
  PyObject *__pyx_tuple__276;
  PyObject *__pyx_tuple__278;
  PyObject *__pyx_tuple__280;
  PyObject *__pyx_tuple__281;
  PyObject *__pyx_tuple__284;
  PyObject *__pyx_tuple__288;
  PyObject *__pyx_tuple__290;
  PyObject *__pyx_tuple__292;
  PyObject *__pyx_tuple__294;
  PyObject *__pyx_tuple__296;
  PyObject *__pyx_tuple__298;
  PyObject *__pyx_tuple__300;
  PyObject *__pyx_tuple__302;
  PyObject *__pyx_tuple__304;
  PyObject *__pyx_tuple__306;
  PyObject *__pyx_tuple__307;
  PyObject *__pyx_tuple__308;
  PyObject *__pyx_tuple__310;
  PyObject *__pyx_tuple__312;
  PyObject *__pyx_tuple__314;
  PyObject *__pyx_tuple__319;
  PyObject *__pyx_tuple__320;
  PyObject *__pyx_tuple__321;
  PyObject *__pyx_tuple__329;
  PyObject *__pyx_tuple__330;
  PyObject *__pyx_tuple__337;
  PyObject *__pyx_tuple__338;
  PyObject *__pyx_tuple__340;
  PyObject *__pyx_tuple__342;
  PyObject *__pyx_tuple__344;
  PyObject *__pyx_tuple__347;
  PyObject *__pyx_tuple__349;
  PyObject *__pyx_tuple__350;
  PyObject *__pyx_tuple__353;
  PyObject *__pyx_tuple__355;
  PyObject *__pyx_tuple__357;
  PyObject *__pyx_tuple__359;
  PyObject *__pyx_tuple__361;
  PyObject *__pyx_tuple__363;
  PyObject *__pyx_tuple__365;
  PyObject *__pyx_tuple__367;
  PyObject *__pyx_tuple__369;
  PyObject *__pyx_tuple__372;
  PyObject *__pyx_tuple__374;
  PyObject *__pyx_tuple__376;
  PyObject *__pyx_tuple__379;
  PyObject *__pyx_tuple__381;
  PyObject *__pyx_tuple__383;
  PyObject *__pyx_tuple__386;
  PyObject *__pyx_tuple__388;
  PyObject *__pyx_tuple__389;
  PyObject *__pyx_tuple__391;
  PyObject *__pyx_tuple__392;
  PyObject *__pyx_tuple__394;
  PyObject *__pyx_tuple__395;
  PyObject *__pyx_tuple__397;
  PyObject *__pyx_tuple__399;
  PyObject *__pyx_tuple__404;
  PyObject *__pyx_tuple__415;
  PyObject *__pyx_tuple__420;
  PyObject *__pyx_tuple__424;
  PyObject *__pyx_tuple__426;
  PyObject *__pyx_tuple__432;
  PyObject *__pyx_tuple__434;
  PyObject *__pyx_tuple__441;
  PyObject *__pyx_tuple__443;
  PyObject *__pyx_tuple__445;
  PyObject *__pyx_tuple__446;
  PyObject *__pyx_tuple__448;
  PyObject *__pyx_tuple__451;
  PyObject *__pyx_tuple__457;
  PyObject *__pyx_tuple__462;
  PyObject *__pyx_tuple__465;
  PyObject *__pyx_tuple__470;
  PyObject *__pyx_tuple__472;
  PyObject *__pyx_tuple__474;
  PyObject *__pyx_tuple__476;
  PyObject *__pyx_tuple__478;
  PyObject *__pyx_tuple__479;
  PyObject *__pyx_tuple__481;
  PyObject *__pyx_tuple__483;
  PyObject *__pyx_tuple__485;
  PyObject *__pyx_tuple__487;
  PyObject *__pyx_tuple__488;
  PyObject *__pyx_tuple__490;
  PyObject *__pyx_tuple__491;
  PyObject *__pyx_tuple__493;
  PyObject *__pyx_tuple__497;
  PyObject *__pyx_tuple__499;
  PyObject *__pyx_tuple__501;
  PyObject *__pyx_tuple__502;
  PyObject *__pyx_tuple__505;
  PyObject *__pyx_tuple__507;
  PyObject *__pyx_tuple__508;
  PyObject *__pyx_tuple__529;
  PyObject *__pyx_tuple__531;
  PyObject *__pyx_tuple__532;
  PyObject *__pyx_tuple__535;
  PyObject *__pyx_tuple__537;
  PyObject *__pyx_tuple__539;
  PyObject *__pyx_tuple__549;
  PyObject *__pyx_tuple__553;
  PyObject *__pyx_tuple__555;
  PyObject *__pyx_tuple__558;
  PyObject *__pyx_tuple__560;
  PyObject *__pyx_tuple__563;
  PyObject *__pyx_tuple__565;
  PyObject *__pyx_tuple__567;
  PyObject *__pyx_tuple__569;
  PyObject *__pyx_tuple__572;
  PyObject *__pyx_tuple__574;
  PyObject *__pyx_tuple__576;
  PyObject *__pyx_tuple__579;
  PyObject *__pyx_tuple__584;
  PyObject *__pyx_tuple__589;
  PyObject *__pyx_tuple__593;
  PyObject *__pyx_tuple__595;
  PyObject *__pyx_tuple__596;
  PyObject *__pyx_tuple__604;
  PyObject *__pyx_tuple__608;
  PyObject *__pyx_tuple__614;
  PyObject *__pyx_tuple__616;
  PyObject *__pyx_tuple__619;
  PyObject *__pyx_tuple__622;
  PyObject *__pyx_tuple__624;
  PyObject *__pyx_tuple__626;
  PyObject *__pyx_tuple__628;
  PyObject *__pyx_tuple__632;
  PyObject *__pyx_tuple__634;
  PyObject *__pyx_tuple__636;
  PyObject *__pyx_tuple__640;
  PyObject *__pyx_tuple__644;
  PyObject *__pyx_tuple__645;
  PyObject *__pyx_tuple__648;
  PyObject *__pyx_tuple__650;
  PyObject *__pyx_tuple__653;
  PyObject *__pyx_tuple__655;
  PyObject *__pyx_tuple__667;
  PyObject *__pyx_tuple__669;
  PyObject *__pyx_tuple__671;
  PyObject *__pyx_tuple__676;
  PyObject *__pyx_tuple__680;
  PyObject *__pyx_tuple__681;
  PyObject *__pyx_tuple__682;
  PyObject *__pyx_tuple__684;
  PyObject *__pyx_tuple__687;
  PyObject *__pyx_tuple__689;
  PyObject *__pyx_tuple__691;
  PyObject *__pyx_tuple__692;
  PyObject *__pyx_tuple__694;
  PyObject *__pyx_tuple__696;
  PyObject *__pyx_tuple__698;
  PyObject *__pyx_tuple__700;
  PyObject *__pyx_tuple__702;
  PyObject *__pyx_tuple__704;
  PyObject *__pyx_tuple__705;
  PyObject *__pyx_tuple__707;
  PyObject *__pyx_tuple__709;
  PyObject *__pyx_tuple__711;
  PyObject *__pyx_tuple__713;
  PyObject *__pyx_tuple__714;
  PyObject *__pyx_tuple__715;
  PyObject *__pyx_tuple__716;
  PyObject *__pyx_tuple__717;
  PyObject *__pyx_tuple__719;
  PyObject *__pyx_tuple__720;
  PyObject *__pyx_tuple__722;
  PyObject *__pyx_tuple__723;
  PyObject *__pyx_tuple__724;
  PyObject *__pyx_tuple__725;
  PyObject *__pyx_tuple__726;
  PyObject *__pyx_tuple__727;
  PyObject *__pyx_tuple__728;
  PyObject *__pyx_tuple__730;
  PyObject *__pyx_tuple__732;
  PyObject *__pyx_tuple__735;
  PyObject *__pyx_tuple__737;
  PyObject *__pyx_tuple__739;
  PyObject *__pyx_tuple__740;
  PyObject *__pyx_tuple__741;
  PyObject *__pyx_tuple__744;
  PyObject *__pyx_tuple__745;
  PyObject *__pyx_tuple__746;
  PyObject *__pyx_tuple__748;
  PyObject *__pyx_tuple__750;
  PyObject *__pyx_tuple__752;
  PyObject *__pyx_tuple__753;
  PyObject *__pyx_tuple__754;
  PyObject *__pyx_tuple__756;
  PyObject *__pyx_tuple__757;
  PyObject *__pyx_tuple__758;
  PyObject *__pyx_tuple__759;
  PyObject *__pyx_tuple__760;
  PyObject *__pyx_tuple__761;
  PyObject *__pyx_tuple__762;
  PyObject *__pyx_tuple__764;
  PyObject *__pyx_tuple__766;
  PyObject *__pyx_tuple__767;
  PyObject *__pyx_tuple__769;
  PyObject *__pyx_tuple__772;
  PyObject *__pyx_tuple__775;
  PyObject *__pyx_tuple__777;
  PyObject *__pyx_tuple__778;
  PyObject *__pyx_tuple__779;
  PyObject *__pyx_tuple__781;
  PyObject *__pyx_tuple__782;
  PyObject *__pyx_tuple__783;
  PyObject *__pyx_tuple__784;
  PyObject *__pyx_tuple__785;
  PyObject *__pyx_tuple__787;
  PyObject *__pyx_tuple__788;
  PyObject *__pyx_tuple__790;
  PyObject *__pyx_tuple__791;
  PyObject *__pyx_tuple__792;
  PyObject *__pyx_tuple__793;
  PyObject *__pyx_tuple__794;
  PyObject *__pyx_tuple__796;
  PyObject *__pyx_tuple__798;
  PyObject *__pyx_tuple__800;
  PyObject *__pyx_tuple__801;
  PyObject *__pyx_tuple__803;
  PyObject *__pyx_tuple__804;
  PyObject *__pyx_tuple__806;
  PyObject *__pyx_tuple__808;
  PyObject *__pyx_tuple__809;
  PyObject *__pyx_tuple__810;
  PyObject *__pyx_tuple__816;
  PyObject *__pyx_tuple__817;
  PyObject *__pyx_tuple__818;
  PyObject *__pyx_tuple__819;
  PyObject *__pyx_tuple__820;
  PyObject *__pyx_tuple__821;
  PyObject *__pyx_tuple__822;
  PyObject *__pyx_tuple__823;
  PyObject *__pyx_tuple__824;
  PyObject *__pyx_tuple__825;
  PyObject *__pyx_tuple__826;
  PyObject *__pyx_tuple__827;
  PyObject *__pyx_tuple__828;
  PyObject *__pyx_tuple__829;
  PyObject *__pyx_tuple__830;
  PyObject *__pyx_tuple__831;
  PyObject *__pyx_tuple__832;
  PyObject *__pyx_tuple__833;
  PyObject *__pyx_tuple__834;
  PyObject *__pyx_tuple__835;
  PyObject *__pyx_tuple__836;
  PyObject *__pyx_tuple__837;
  PyObject *__pyx_tuple__838;
  PyObject *__pyx_tuple__839;
  PyObject *__pyx_tuple__840;
  PyObject *__pyx_tuple__841;
  PyObject *__pyx_tuple__842;
  PyObject *__pyx_tuple__843;
  PyObject *__pyx_tuple__844;
  PyObject *__pyx_tuple__845;
  PyObject *__pyx_tuple__846;
  PyObject *__pyx_tuple__847;
  PyObject *__pyx_tuple__848;
  PyObject *__pyx_tuple__849;
  PyObject *__pyx_tuple__850;
  PyObject *__pyx_tuple__851;
  PyObject *__pyx_tuple__852;
  PyObject *__pyx_tuple__853;
  PyObject *__pyx_tuple__854;
  PyObject *__pyx_tuple__855;
  PyObject *__pyx_tuple__870;
  PyObject *__pyx_tuple__874;
  PyObject *__pyx_tuple__876;
  PyObject *__pyx_tuple__878;
  PyObject *__pyx_tuple__879;
  PyObject *__pyx_tuple__881;
  PyObject *__pyx_tuple__883;
  PyObject *__pyx_tuple__884;
  PyObject *__pyx_tuple__885;
  PyObject *__pyx_tuple__886;
  PyObject *__pyx_tuple__887;
  PyObject *__pyx_tuple__888;
  PyObject *__pyx_tuple__889;
  PyObject *__pyx_tuple__890;
  PyObject *__pyx_tuple__891;
  PyObject *__pyx_tuple__892;
  PyObject *__pyx_codeobj__24;
  PyObject *__pyx_codeobj__33;
  PyObject *__pyx_codeobj__40;
  PyObject *__pyx_codeobj__43;
  PyObject *__pyx_codeobj__45;
  PyObject *__pyx_codeobj__49;
  PyObject *__pyx_codeobj__52;
  PyObject *__pyx_codeobj__53;
  PyObject *__pyx_codeobj__63;
  PyObject *__pyx_codeobj__72;
  PyObject *__pyx_codeobj__74;
  PyObject *__pyx_codeobj__83;
  PyObject *__pyx_codeobj__89;
  PyObject *__pyx_codeobj__90;
  PyObject *__pyx_codeobj__121;
  PyObject *__pyx_codeobj__124;
  PyObject *__pyx_codeobj__126;
  PyObject *__pyx_codeobj__129;
  PyObject *__pyx_codeobj__131;
  PyObject *__pyx_codeobj__138;
  PyObject *__pyx_codeobj__140;
  PyObject *__pyx_codeobj__143;
  PyObject *__pyx_codeobj__152;
  PyObject *__pyx_codeobj__154;
  PyObject *__pyx_codeobj__161;
  PyObject *__pyx_codeobj__163;
  PyObject *__pyx_codeobj__164;
  PyObject *__pyx_codeobj__165;
  PyObject *__pyx_codeobj__168;
  PyObject *__pyx_codeobj__169;
  PyObject *__pyx_codeobj__170;
  PyObject *__pyx_codeobj__172;
  PyObject *__pyx_codeobj__173;
  PyObject *__pyx_codeobj__174;
  PyObject *__pyx_codeobj__176;
  PyObject *__pyx_codeobj__179;
  PyObject *__pyx_codeobj__182;
  PyObject *__pyx_codeobj__186;
  PyObject *__pyx_codeobj__189;
  PyObject *__pyx_codeobj__191;
  PyObject *__pyx_codeobj__193;
  PyObject *__pyx_codeobj__195;
  PyObject *__pyx_codeobj__197;
  PyObject *__pyx_codeobj__199;
  PyObject *__pyx_codeobj__201;
  PyObject *__pyx_codeobj__204;
  PyObject *__pyx_codeobj__205;
  PyObject *__pyx_codeobj__209;
  PyObject *__pyx_codeobj__211;
  PyObject *__pyx_codeobj__212;
  PyObject *__pyx_codeobj__213;
  PyObject *__pyx_codeobj__217;
  PyObject *__pyx_codeobj__220;
  PyObject *__pyx_codeobj__222;
  PyObject *__pyx_codeobj__224;
  PyObject *__pyx_codeobj__226;
  PyObject *__pyx_codeobj__228;
  PyObject *__pyx_codeobj__229;
  PyObject *__pyx_codeobj__230;
  PyObject *__pyx_codeobj__231;
  PyObject *__pyx_codeobj__232;
  PyObject *__pyx_codeobj__233;
  PyObject *__pyx_codeobj__235;
  PyObject *__pyx_codeobj__236;
  PyObject *__pyx_codeobj__237;
  PyObject *__pyx_codeobj__238;
  PyObject *__pyx_codeobj__239;
  PyObject *__pyx_codeobj__240;
  PyObject *__pyx_codeobj__242;
  PyObject *__pyx_codeobj__244;
  PyObject *__pyx_codeobj__246;
  PyObject *__pyx_codeobj__248;
  PyObject *__pyx_codeobj__250;
  PyObject *__pyx_codeobj__251;
  PyObject *__pyx_codeobj__253;
  PyObject *__pyx_codeobj__255;
  PyObject *__pyx_codeobj__257;
  PyObject *__pyx_codeobj__259;
  PyObject *__pyx_codeobj__260;
  PyObject *__pyx_codeobj__261;
  PyObject *__pyx_codeobj__263;
  PyObject *__pyx_codeobj__266;
  PyObject *__pyx_codeobj__268;
  PyObject *__pyx_codeobj__270;
  PyObject *__pyx_codeobj__272;
  PyObject *__pyx_codeobj__275;
  PyObject *__pyx_codeobj__277;
  PyObject *__pyx_codeobj__279;
  PyObject *__pyx_codeobj__282;
  PyObject *__pyx_codeobj__283;
  PyObject *__pyx_codeobj__285;
  PyObject *__pyx_codeobj__286;
  PyObject *__pyx_codeobj__287;
  PyObject *__pyx_codeobj__289;
  PyObject *__pyx_codeobj__291;
  PyObject *__pyx_codeobj__293;
  PyObject *__pyx_codeobj__295;
  PyObject *__pyx_codeobj__297;
  PyObject *__pyx_codeobj__299;
  PyObject *__pyx_codeobj__301;
  PyObject *__pyx_codeobj__303;
  PyObject *__pyx_codeobj__305;
  PyObject *__pyx_codeobj__309;
  PyObject *__pyx_codeobj__311;
  PyObject *__pyx_codeobj__313;
  PyObject *__pyx_codeobj__315;
  PyObject *__pyx_codeobj__316;
  PyObject *__pyx_codeobj__317;
  PyObject *__pyx_codeobj__318;
  PyObject *__pyx_codeobj__322;
  PyObject *__pyx_codeobj__323;
  PyObject *__pyx_codeobj__324;
  PyObject *__pyx_codeobj__325;
  PyObject *__pyx_codeobj__326;
  PyObject *__pyx_codeobj__327;
  PyObject *__pyx_codeobj__328;
  PyObject *__pyx_codeobj__331;
  PyObject *__pyx_codeobj__332;
  PyObject *__pyx_codeobj__333;
  PyObject *__pyx_codeobj__334;
  PyObject *__pyx_codeobj__335;
  PyObject *__pyx_codeobj__336;
  PyObject *__pyx_codeobj__341;
  PyObject *__pyx_codeobj__343;
  PyObject *__pyx_codeobj__345;
  PyObject *__pyx_codeobj__346;
  PyObject *__pyx_codeobj__348;
  PyObject *__pyx_codeobj__351;
  PyObject *__pyx_codeobj__352;
  PyObject *__pyx_codeobj__354;
  PyObject *__pyx_codeobj__356;
  PyObject *__pyx_codeobj__358;
  PyObject *__pyx_codeobj__360;
  PyObject *__pyx_codeobj__362;
  PyObject *__pyx_codeobj__364;
  PyObject *__pyx_codeobj__366;
  PyObject *__pyx_codeobj__368;
  PyObject *__pyx_codeobj__370;
  PyObject *__pyx_codeobj__371;
  PyObject *__pyx_codeobj__373;
  PyObject *__pyx_codeobj__375;
  PyObject *__pyx_codeobj__377;
  PyObject *__pyx_codeobj__378;
  PyObject *__pyx_codeobj__380;
  PyObject *__pyx_codeobj__382;
  PyObject *__pyx_codeobj__384;
  PyObject *__pyx_codeobj__385;
  PyObject *__pyx_codeobj__387;
  PyObject *__pyx_codeobj__390;
  PyObject *__pyx_codeobj__393;
  PyObject *__pyx_codeobj__396;
  PyObject *__pyx_codeobj__398;
  PyObject *__pyx_codeobj__400;
  PyObject *__pyx_codeobj__401;
  PyObject *__pyx_codeobj__402;
  PyObject *__pyx_codeobj__403;
  PyObject *__pyx_codeobj__405;
  PyObject *__pyx_codeobj__406;
  PyObject *__pyx_codeobj__407;
  PyObject *__pyx_codeobj__408;
  PyObject *__pyx_codeobj__409;
  PyObject *__pyx_codeobj__410;
  PyObject *__pyx_codeobj__411;
  PyObject *__pyx_codeobj__412;
  PyObject *__pyx_codeobj__413;
  PyObject *__pyx_codeobj__414;
  PyObject *__pyx_codeobj__416;
  PyObject *__pyx_codeobj__417;
  PyObject *__pyx_codeobj__418;
  PyObject *__pyx_codeobj__419;
  PyObject *__pyx_codeobj__421;
  PyObject *__pyx_codeobj__422;
  PyObject *__pyx_codeobj__423;
  PyObject *__pyx_codeobj__425;
  PyObject *__pyx_codeobj__427;
  PyObject *__pyx_codeobj__428;
  PyObject *__pyx_codeobj__429;
  PyObject *__pyx_codeobj__430;
  PyObject *__pyx_codeobj__431;
  PyObject *__pyx_codeobj__433;
  PyObject *__pyx_codeobj__435;
  PyObject *__pyx_codeobj__436;
  PyObject *__pyx_codeobj__437;
  PyObject *__pyx_codeobj__438;
  PyObject *__pyx_codeobj__439;
  PyObject *__pyx_codeobj__440;
  PyObject *__pyx_codeobj__442;
  PyObject *__pyx_codeobj__444;
  PyObject *__pyx_codeobj__447;
  PyObject *__pyx_codeobj__449;
  PyObject *__pyx_codeobj__450;
  PyObject *__pyx_codeobj__452;
  PyObject *__pyx_codeobj__453;
  PyObject *__pyx_codeobj__454;
  PyObject *__pyx_codeobj__455;
  PyObject *__pyx_codeobj__456;
  PyObject *__pyx_codeobj__458;
  PyObject *__pyx_codeobj__459;
  PyObject *__pyx_codeobj__460;
  PyObject *__pyx_codeobj__463;
  PyObject *__pyx_codeobj__464;
  PyObject *__pyx_codeobj__466;
  PyObject *__pyx_codeobj__467;
  PyObject *__pyx_codeobj__468;
  PyObject *__pyx_codeobj__469;
  PyObject *__pyx_codeobj__471;
  PyObject *__pyx_codeobj__473;
  PyObject *__pyx_codeobj__475;
  PyObject *__pyx_codeobj__477;
  PyObject *__pyx_codeobj__480;
  PyObject *__pyx_codeobj__482;
  PyObject *__pyx_codeobj__484;
  PyObject *__pyx_codeobj__486;
  PyObject *__pyx_codeobj__489;
  PyObject *__pyx_codeobj__492;
  PyObject *__pyx_codeobj__494;
  PyObject *__pyx_codeobj__495;
  PyObject *__pyx_codeobj__496;
  PyObject *__pyx_codeobj__498;
  PyObject *__pyx_codeobj__500;
  PyObject *__pyx_codeobj__503;
  PyObject *__pyx_codeobj__504;
  PyObject *__pyx_codeobj__506;
  PyObject *__pyx_codeobj__509;
  PyObject *__pyx_codeobj__510;
  PyObject *__pyx_codeobj__530;
  PyObject *__pyx_codeobj__533;
  PyObject *__pyx_codeobj__534;
  PyObject *__pyx_codeobj__536;
  PyObject *__pyx_codeobj__538;
  PyObject *__pyx_codeobj__540;
  PyObject *__pyx_codeobj__541;
  PyObject *__pyx_codeobj__542;
  PyObject *__pyx_codeobj__543;
  PyObject *__pyx_codeobj__544;
  PyObject *__pyx_codeobj__545;
  PyObject *__pyx_codeobj__546;
  PyObject *__pyx_codeobj__547;
  PyObject *__pyx_codeobj__548;
  PyObject *__pyx_codeobj__550;
  PyObject *__pyx_codeobj__551;
  PyObject *__pyx_codeobj__552;
  PyObject *__pyx_codeobj__554;
  PyObject *__pyx_codeobj__556;
  PyObject *__pyx_codeobj__557;
  PyObject *__pyx_codeobj__559;
  PyObject *__pyx_codeobj__561;
  PyObject *__pyx_codeobj__562;
  PyObject *__pyx_codeobj__564;
  PyObject *__pyx_codeobj__566;
  PyObject *__pyx_codeobj__568;
  PyObject *__pyx_codeobj__570;
  PyObject *__pyx_codeobj__571;
  PyObject *__pyx_codeobj__573;
  PyObject *__pyx_codeobj__575;
  PyObject *__pyx_codeobj__577;
  PyObject *__pyx_codeobj__578;
  PyObject *__pyx_codeobj__580;
  PyObject *__pyx_codeobj__581;
  PyObject *__pyx_codeobj__582;
  PyObject *__pyx_codeobj__583;
  PyObject *__pyx_codeobj__585;
  PyObject *__pyx_codeobj__586;
  PyObject *__pyx_codeobj__587;
  PyObject *__pyx_codeobj__588;
  PyObject *__pyx_codeobj__590;
  PyObject *__pyx_codeobj__591;
  PyObject *__pyx_codeobj__592;
  PyObject *__pyx_codeobj__594;
  PyObject *__pyx_codeobj__597;
  PyObject *__pyx_codeobj__598;
  PyObject *__pyx_codeobj__599;
  PyObject *__pyx_codeobj__600;
  PyObject *__pyx_codeobj__601;
  PyObject *__pyx_codeobj__602;
  PyObject *__pyx_codeobj__603;
  PyObject *__pyx_codeobj__605;
  PyObject *__pyx_codeobj__606;
  PyObject *__pyx_codeobj__607;
  PyObject *__pyx_codeobj__609;
  PyObject *__pyx_codeobj__610;
  PyObject *__pyx_codeobj__611;
  PyObject *__pyx_codeobj__612;
  PyObject *__pyx_codeobj__613;
  PyObject *__pyx_codeobj__615;
  PyObject *__pyx_codeobj__617;
  PyObject *__pyx_codeobj__618;
  PyObject *__pyx_codeobj__620;
  PyObject *__pyx_codeobj__623;
  PyObject *__pyx_codeobj__625;
  PyObject *__pyx_codeobj__627;
  PyObject *__pyx_codeobj__629;
  PyObject *__pyx_codeobj__630;
  PyObject *__pyx_codeobj__631;
  PyObject *__pyx_codeobj__633;
  PyObject *__pyx_codeobj__635;
  PyObject *__pyx_codeobj__637;
  PyObject *__pyx_codeobj__638;
  PyObject *__pyx_codeobj__639;
  PyObject *__pyx_codeobj__641;
  PyObject *__pyx_codeobj__642;
  PyObject *__pyx_codeobj__643;
  PyObject *__pyx_codeobj__646;
  PyObject *__pyx_codeobj__647;
  PyObject *__pyx_codeobj__649;
  PyObject *__pyx_codeobj__651;
  PyObject *__pyx_codeobj__652;
  PyObject *__pyx_codeobj__654;
  PyObject *__pyx_codeobj__656;
  PyObject *__pyx_codeobj__657;
  PyObject *__pyx_codeobj__658;
  PyObject *__pyx_codeobj__659;
  PyObject *__pyx_codeobj__660;
  PyObject *__pyx_codeobj__661;
  PyObject *__pyx_codeobj__662;
  PyObject *__pyx_codeobj__663;
  PyObject *__pyx_codeobj__664;
  PyObject *__pyx_codeobj__665;
  PyObject *__pyx_codeobj__666;
  PyObject *__pyx_codeobj__668;
  PyObject *__pyx_codeobj__670;
  PyObject *__pyx_codeobj__672;
  PyObject *__pyx_codeobj__673;
  PyObject *__pyx_codeobj__674;
  PyObject *__pyx_codeobj__675;
  PyObject *__pyx_codeobj__677;
  PyObject *__pyx_codeobj__678;
  PyObject *__pyx_codeobj__679;
  PyObject *__pyx_codeobj__683;
  PyObject *__pyx_codeobj__685;
  PyObject *__pyx_codeobj__686;
  PyObject *__pyx_codeobj__688;
  PyObject *__pyx_codeobj__690;
  PyObject *__pyx_codeobj__693;
  PyObject *__pyx_codeobj__695;
  PyObject *__pyx_codeobj__697;
  PyObject *__pyx_codeobj__699;
  PyObject *__pyx_codeobj__701;
  PyObject *__pyx_codeobj__703;
  PyObject *__pyx_codeobj__706;
  PyObject *__pyx_codeobj__708;
  PyObject *__pyx_codeobj__710;
  PyObject *__pyx_codeobj__712;
  PyObject *__pyx_codeobj__729;
  PyObject *__pyx_codeobj__731;
  PyObject *__pyx_codeobj__733;
  PyObject *__pyx_codeobj__734;
  PyObject *__pyx_codeobj__736;
  PyObject *__pyx_codeobj__738;
  PyObject *__pyx_codeobj__742;
  PyObject *__pyx_codeobj__743;
  PyObject *__pyx_codeobj__747;
  PyObject *__pyx_codeobj__749;
  PyObject *__pyx_codeobj__751;
  PyObject *__pyx_codeobj__763;
  PyObject *__pyx_codeobj__765;
  PyObject *__pyx_codeobj__773;
  PyObject *__pyx_codeobj__797;
  PyObject *__pyx_codeobj__799;
  PyObject *__pyx_codeobj__802;
  PyObject *__pyx_codeobj__805;
  PyObject *__pyx_codeobj__807;
  PyObject *__pyx_codeobj__811;
  PyObject *__pyx_codeobj__812;
  PyObject *__pyx_codeobj__813;
  PyObject *__pyx_codeobj__814;
  PyObject *__pyx_codeobj__815;
  PyObject *__pyx_codeobj__868;
  PyObject *__pyx_codeobj__869;
  PyObject *__pyx_codeobj__871;
  PyObject *__pyx_codeobj__872;
  PyObject *__pyx_codeobj__873;
  PyObject *__pyx_codeobj__875;
  PyObject *__pyx_codeobj__877;
  PyObject *__pyx_codeobj__880;
  PyObject *__pyx_codeobj__882;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct__genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_9___iadd__);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_11_asDict);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_19_scanString);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_20_split);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_20_split);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_21___mul__);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_23___add__);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_24___init__);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_27_sub);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_28___init__);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_30___init__);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_33___init__);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_62_srange);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_69___call__);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_74___get__);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException);
  Py_CLEAR(clear_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0123456789);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_0_7);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_1);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_1_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_1_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_9a_fA_F_1_4);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_failed_1_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_setting_results_name_0_r_on_1);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_setting_results_name_1_r_on_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_setting_results_name_1_r_on_2_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_xX_0_9a_fA_F);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0x);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0xa1_0xbf_0xd7_0xf7);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff);
  Py_CLEAR(clear_module_state->__pyx_kp_u_100_100_100_3_14159_6_02e23_1e);
  Py_CLEAR(clear_module_state->__pyx_kp_u_100_FF);
  Py_CLEAR(clear_module_state->__pyx_kp_u_12345678_1234_5678_1234_5678123);
  Py_CLEAR(clear_module_state->__pyx_kp_u_24_Nov_2023_01_45_UTC);
  Py_CLEAR(clear_module_state->__pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0);
  Py_CLEAR(clear_module_state->__pyx_kp_u_2_4_7_2_3_0);
  Py_CLEAR(clear_module_state->__pyx_n_u_ABCDEFabcdef);
  Py_CLEAR(clear_module_state->__pyx_n_s_ANY_VALUE);
  Py_CLEAR(clear_module_state->__pyx_kp_u_A_cross_version_compatibility_c);
  Py_CLEAR(clear_module_state->__pyx_kp_s_A_mixin_class_to_add_parse_resu);
  Py_CLEAR(clear_module_state->__pyx_kp_s_A_namespace_class_for_defining);
  Py_CLEAR(clear_module_state->__pyx_kp_s_A_set_of_Unicode_characters_for);
  Py_CLEAR(clear_module_state->__pyx_kp_s_A_short_cut_class_for_defining_W);
  Py_CLEAR(clear_module_state->__pyx_kp_s_A_token_that_will_never_match);
  Py_CLEAR(clear_module_state->__pyx_kp_s_A_variation_on_class_Literal_whi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Abstract_base_level_parser_eleme);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Abstract_class_ParserElement_sub);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Abstract_subclass_of_ParserEleme);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Abstract_subclass_of_class_Pars);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Abstract_subclass_of_class_Parse);
  Py_CLEAR(clear_module_state->__pyx_kp_s_An_empty_token_will_always_match);
  Py_CLEAR(clear_module_state->__pyx_n_s_And);
  Py_CLEAR(clear_module_state->__pyx_n_u_And);
  Py_CLEAR(clear_module_state->__pyx_n_s_And__ErrorStop);
  Py_CLEAR(clear_module_state->__pyx_n_s_And__ErrorStop___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_And___iadd);
  Py_CLEAR(clear_module_state->__pyx_n_s_And___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_And___init___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_And___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_And___str___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_And_checkRecursion);
  Py_CLEAR(clear_module_state->__pyx_n_s_And_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_And_streamline);
  Py_CLEAR(clear_module_state->__pyx_n_s_And_streamline_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Arabic);
  Py_CLEAR(clear_module_state->__pyx_n_s_AttributeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_BOM);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseWithAttribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseWithAttribute___call);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseWithAttribute___call___local);
  Py_CLEAR(clear_module_state->__pyx_n_s_CJK);
  Py_CLEAR(clear_module_state->__pyx_kp_u_CR);
  Py_CLEAR(clear_module_state->__pyx_kp_u_C_style_comment);
  Py_CLEAR(clear_module_state->__pyx_kp_u_C_style_comment_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Cannot_combine_element_of_type_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_CaselessKeyword);
  Py_CLEAR(clear_module_state->__pyx_n_u_CaselessKeyword);
  Py_CLEAR(clear_module_state->__pyx_n_s_CaselessKeyword___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_CaselessLiteral);
  Py_CLEAR(clear_module_state->__pyx_n_u_CaselessLiteral);
  Py_CLEAR(clear_module_state->__pyx_n_s_CaselessLiteral___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_CaselessLiteral_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Caseless_version_of_class_Keywo);
  Py_CLEAR(clear_module_state->__pyx_n_s_Char);
  Py_CLEAR(clear_module_state->__pyx_n_u_Char);
  Py_CLEAR(clear_module_state->__pyx_n_s_Char___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_CharsNotIn);
  Py_CLEAR(clear_module_state->__pyx_n_u_CharsNotIn);
  Py_CLEAR(clear_module_state->__pyx_n_s_CharsNotIn___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_CharsNotIn___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_CharsNotIn_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Chinese);
  Py_CLEAR(clear_module_state->__pyx_n_s_CloseMatch);
  Py_CLEAR(clear_module_state->__pyx_n_u_CloseMatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_CloseMatch___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_CloseMatch_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Combine);
  Py_CLEAR(clear_module_state->__pyx_n_u_Combine);
  Py_CLEAR(clear_module_state->__pyx_n_s_Combine___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Combine_ignore);
  Py_CLEAR(clear_module_state->__pyx_n_s_Combine_postParse);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Context_manager_to_be_used_when);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Converter_for_ignoring_the_resul);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Converter_to_concatenate_all_mat);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Converter_to_return_a_repetitive);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Converter_to_return_the_matched);
  Py_CLEAR(clear_module_state->__pyx_n_s_Cyrillic);
  Py_CLEAR(clear_module_state->__pyx_n_s_DEFAULT_KEYWORD_CHARS);
  Py_CLEAR(clear_module_state->__pyx_n_s_DEFAULT_WHITE_CHARS);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOTALL);
  Py_CLEAR(clear_module_state->__pyx_n_s_Devanagari);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Diagnostic_configuration_all_de);
  Py_CLEAR(clear_module_state->__pyx_n_s_Dict);
  Py_CLEAR(clear_module_state->__pyx_n_u_Dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_Dict___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Dict_postParse);
  Py_CLEAR(clear_module_state->__pyx_kp_u_EM_QUAD);
  Py_CLEAR(clear_module_state->__pyx_kp_u_EM_SPACE);
  Py_CLEAR(clear_module_state->__pyx_kp_u_EN_QUAD);
  Py_CLEAR(clear_module_state->__pyx_kp_u_EN_SPACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each);
  Py_CLEAR(clear_module_state->__pyx_n_u_Each);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each___init___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each___str___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each_checkRecursion);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each_parseImpl_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each_streamline);
  Py_CLEAR(clear_module_state->__pyx_n_s_Each_streamline_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ellipsis);
  Py_CLEAR(clear_module_state->__pyx_n_s_Empty);
  Py_CLEAR(clear_module_state->__pyx_n_u_Empty);
  Py_CLEAR(clear_module_state->__pyx_n_s_Empty___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_ErrorStop);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Evan_Hubinger_evanjhub_gmail_com);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Exception_creating_Regex_for_one);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Exception_raised);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Exception_thrown_when_parse_exp);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Expected);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Expected_end_of_line);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Expected_end_of_text);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Expected_start_of_line);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Expected_start_of_text);
  Py_CLEAR(clear_module_state->__pyx_n_s_FAIL);
  Py_CLEAR(clear_module_state->__pyx_kp_u_FAIL_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_FAIL_EXCEPTION);
  Py_CLEAR(clear_module_state->__pyx_kp_u_FATAL);
  Py_CLEAR(clear_module_state->__pyx_n_s_FB);
  Py_CLEAR(clear_module_state->__pyx_kp_u_FF);
  Py_CLEAR(clear_module_state->__pyx_kp_u_FIGURE_SPACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_FILE_NAME);
  Py_CLEAR(clear_module_state->__pyx_kp_u_FOUR_PER_EM_SPACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_FifoCache);
  Py_CLEAR(clear_module_state->__pyx_n_s_FifoCache___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_FifoCache___len);
  Py_CLEAR(clear_module_state->__pyx_n_s_FifoCache___reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_FifoCache_clear);
  Py_CLEAR(clear_module_state->__pyx_n_s_FifoCache_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_FifoCache_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_FifoCache_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_FollowedBy);
  Py_CLEAR(clear_module_state->__pyx_n_u_FollowedBy);
  Py_CLEAR(clear_module_state->__pyx_n_s_FollowedBy___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_FollowedBy_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward);
  Py_CLEAR(clear_module_state->__pyx_n_u_Forward);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward___ilshift);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward___lshift);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward__setResultsName);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward_copy);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Forward_declaration_of_an_expres);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward_leaveWhitespace);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward_streamline);
  Py_CLEAR(clear_module_state->__pyx_n_s_Forward_validate);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Found_unwanted_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_GoToColumn);
  Py_CLEAR(clear_module_state->__pyx_n_u_GoToColumn);
  Py_CLEAR(clear_module_state->__pyx_n_s_GoToColumn___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_GoToColumn_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_GoToColumn_preParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_Greek);
  Py_CLEAR(clear_module_state->__pyx_n_s_Group);
  Py_CLEAR(clear_module_state->__pyx_n_u_Group);
  Py_CLEAR(clear_module_state->__pyx_n_s_Group___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Group_postParse);
  Py_CLEAR(clear_module_state->__pyx_kp_u_HAIR_SPACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_HIT);
  Py_CLEAR(clear_module_state->__pyx_kp_u_HTML_comment);
  Py_CLEAR(clear_module_state->__pyx_n_s_Hebrew);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Here_are_some_common_low_level_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_Hiragana);
  Py_CLEAR(clear_module_state->__pyx_kp_u_IDEOGRAPHIC_SPACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_INDENT);
  Py_CLEAR(clear_module_state->__pyx_n_u_INDENT);
  Py_CLEAR(clear_module_state->__pyx_kp_u_IPv4_address);
  Py_CLEAR(clear_module_state->__pyx_kp_u_IPv6_address);
  Py_CLEAR(clear_module_state->__pyx_kp_u_ISO8601_date);
  Py_CLEAR(clear_module_state->__pyx_kp_u_ISO8601_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_u_ITEM);
  Py_CLEAR(clear_module_state->__pyx_n_s_ImportError);
  Py_CLEAR(clear_module_state->__pyx_n_s_IndexError);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_argument_to_oneOf_expect);
  Py_CLEAR(clear_module_state->__pyx_n_s_Iterable);
  Py_CLEAR(clear_module_state->__pyx_n_s_Japanese);
  Py_CLEAR(clear_module_state->__pyx_n_s_Kanji);
  Py_CLEAR(clear_module_state->__pyx_n_s_Katakana);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyError);
  Py_CLEAR(clear_module_state->__pyx_n_s_Keyword);
  Py_CLEAR(clear_module_state->__pyx_n_u_Keyword);
  Py_CLEAR(clear_module_state->__pyx_n_s_Keyword___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Keyword_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_Keyword_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Keyword_setDefaultKeywordChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_Korean);
  Py_CLEAR(clear_module_state->__pyx_n_s_L);
  Py_CLEAR(clear_module_state->__pyx_n_s_LEFT);
  Py_CLEAR(clear_module_state->__pyx_kp_u_LF);
  Py_CLEAR(clear_module_state->__pyx_n_s_L_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Latin1);
  Py_CLEAR(clear_module_state->__pyx_n_s_LatinA);
  Py_CLEAR(clear_module_state->__pyx_n_s_LatinB);
  Py_CLEAR(clear_module_state->__pyx_n_s_LineEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_LineEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_LineEnd___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_LineEnd_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_LineStart);
  Py_CLEAR(clear_module_state->__pyx_n_u_LineStart);
  Py_CLEAR(clear_module_state->__pyx_n_s_LineStart___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_LineStart_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Literal);
  Py_CLEAR(clear_module_state->__pyx_n_u_Literal);
  Py_CLEAR(clear_module_state->__pyx_n_s_Literal___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Literal_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Lookahead_matching_of_the_given);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Lookahead_to_disallow_matching_w);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Lookbehind_matching_of_the_given);
  Py_CLEAR(clear_module_state->__pyx_kp_u_MAC_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_MATCH);
  Py_CLEAR(clear_module_state->__pyx_n_s_MAX_INT);
  Py_CLEAR(clear_module_state->__pyx_n_s_MISS);
  Py_CLEAR(clear_module_state->__pyx_kp_u_MMSP);
  Py_CLEAR(clear_module_state->__pyx_kp_u_MONGOLIAN_VOWEL_SEPARATOR);
  Py_CLEAR(clear_module_state->__pyx_n_s_MULTILINE);
  Py_CLEAR(clear_module_state->__pyx_n_s_Mapping);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Match);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst);
  Py_CLEAR(clear_module_state->__pyx_n_u_MatchFirst);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst___init___locals_genex);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst___ior);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst___str___locals_genexp);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst__setResultsName);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst__setResultsName_local);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst_checkRecursion);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst_setAdaptiveMode);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst_streamline);
  Py_CLEAR(clear_module_state->__pyx_n_s_MatchFirst_streamline_locals_gen);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Matched);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Matches_if_current_position_is_a);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Matches_if_current_position_is_a_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Matches_if_current_position_is_a_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Matches_if_current_position_is_a_4);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Matches_if_the_current_position);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Matches_if_the_current_position_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Missing_one_or_more_required_ele);
  Py_CLEAR(clear_module_state->__pyx_kp_u_More_than_one_string_argument_pa);
  Py_CLEAR(clear_module_state->__pyx_n_s_MultipleMatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_MultipleMatch___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_MultipleMatch__setResultsName);
  Py_CLEAR(clear_module_state->__pyx_n_s_MultipleMatch_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_MultipleMatch_stopOn);
  Py_CLEAR(clear_module_state->__pyx_n_s_MutableMapping);
  Py_CLEAR(clear_module_state->__pyx_kp_u_NBSP);
  Py_CLEAR(clear_module_state->__pyx_n_s_NL);
  Py_CLEAR(clear_module_state->__pyx_kp_u_NNBSP);
  Py_CLEAR(clear_module_state->__pyx_n_s_NameError);
  Py_CLEAR(clear_module_state->__pyx_n_s_NoMatch);
  Py_CLEAR(clear_module_state->__pyx_n_u_NoMatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_NoMatch___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_NoMatch_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_u_No_match_found_for);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotAny);
  Py_CLEAR(clear_module_state->__pyx_n_u_NotAny);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotAny___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotAny___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotAny_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Not_at_the_end_of_a_word);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Not_at_the_start_of_a_word);
  Py_CLEAR(clear_module_state->__pyx_n_s_NullToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_NullToken___bool);
  Py_CLEAR(clear_module_state->__pyx_n_s_NullToken___str);
  Py_CLEAR(clear_module_state->__pyx_kp_u_OGHAM_SPACE_MARK);
  Py_CLEAR(clear_module_state->__pyx_n_s_OneOrMore);
  Py_CLEAR(clear_module_state->__pyx_n_u_OneOrMore);
  Py_CLEAR(clear_module_state->__pyx_n_s_OneOrMore___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_OnlyOnce);
  Py_CLEAR(clear_module_state->__pyx_n_u_OnlyOnce);
  Py_CLEAR(clear_module_state->__pyx_n_s_OnlyOnce___call);
  Py_CLEAR(clear_module_state->__pyx_n_s_OnlyOnce___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_OnlyOnce_reset);
  Py_CLEAR(clear_module_state->__pyx_n_s_Optional);
  Py_CLEAR(clear_module_state->__pyx_n_u_Optional);
  Py_CLEAR(clear_module_state->__pyx_n_s_Optional___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Optional___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_Optional__optionalNotMatched);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Optional_matching_of_the_given_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_Optional_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Optional_repetition_of_zero_or_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or);
  Py_CLEAR(clear_module_state->__pyx_n_u_Or);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or___init___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or___ixor);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or___str___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or__setResultsName);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or__setResultsName_locals_genexp);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or_checkRecursion);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or_streamline);
  Py_CLEAR(clear_module_state->__pyx_n_s_Or_streamline_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_OrderedDict);
  Py_CLEAR(clear_module_state->__pyx_n_s_OrderedDict_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_PEER);
  Py_CLEAR(clear_module_state->__pyx_kp_u_PUNCTUATION_SPACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_PY_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_P_entity);
  Py_CLEAR(clear_module_state->__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d);
  Py_CLEAR(clear_module_state->__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseBaseException);
  Py_CLEAR(clear_module_state->__pyx_n_u_ParseBaseException);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseBaseException___dir);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseBaseException___getattr);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseBaseException___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseBaseException___repr);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseBaseException___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseBaseException__from_excepti);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseBaseException_markInputline);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseElementEnhance);
  Py_CLEAR(clear_module_state->__pyx_n_u_ParseElementEnhance);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseElementEnhance___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseElementEnhance___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseElementEnhance_checkRecursi);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseElementEnhance_ignore);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseElementEnhance_leaveWhitesp);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseElementEnhance_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseElementEnhance_streamline);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseElementEnhance_validate);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseException);
  Py_CLEAR(clear_module_state->__pyx_n_u_ParseException);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseException_explain);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression);
  Py_CLEAR(clear_module_state->__pyx_n_u_ParseExpression);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression___init___locals);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression___init___locals_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression__setResultsName);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression_append);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression_ignore);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression_leaveWhitespace);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression_streamline);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseExpression_validate);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseFatalException);
  Py_CLEAR(clear_module_state->__pyx_n_u_ParseFatalException);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults);
  Py_CLEAR(clear_module_state->__pyx_n_u_ParseResults);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResultsWithOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResultsWithOffset___getite);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResultsWithOffset___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResultsWithOffset___repr);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResultsWithOffset_setOffse);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___add);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___bool);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___contains);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___delitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___dir);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___getattr);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___getnewargs);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___iadd);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___iadd___locals_lam);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___iter);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___len);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___new);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___radd);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___repr);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___reversed);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___setitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults___str___locals_gene);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__accumNames);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__asList);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__asStringList);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__doinit);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__iteritems);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__iteritems_locals_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__iterkeys);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__itervalues);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__itervalues_locals);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__modal);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__name);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__parent);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__tokdict);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults__toklist);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_append);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_asDict);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_asDict_locals_genex);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_asDict_locals_toIte);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_asList);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_asXML);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_asXML_locals_genexp);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_clear);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_dump_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_extend);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_from_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_from_dict_locals_is);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_getName);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_haskeys);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_insert);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_pop);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_pprint);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseResults_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParseSyntaxException);
  Py_CLEAR(clear_module_state->__pyx_n_u_ParseSyntaxException);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement);
  Py_CLEAR(clear_module_state->__pyx_n_u_ParserElement);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___add);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___and);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___call);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___eq);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___hash);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___invert);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___iter);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___mul);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___mul___locals_gen);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___mul___locals_mak);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___ne);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___or);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___radd);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___rand);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___repr);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___req);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___rmul);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___rne);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___ror);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___rsub);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___rxor);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___sub);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement___xor);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement__parseCache);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement__parseIncremental);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement__parseIncremental_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement__parseNoCache);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement__setResultsName);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement__skipIgnorables);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement__trim_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement__update_furthest_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_addCondition);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_addParseAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_canParseNext);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_checkRecursion);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_collectParseElemen);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_enableIncremental);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_enablePackrat);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_ignore);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_inlineLiteralsUsin);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_leaveWhitespace);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_matches);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_parseFile);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_parseString);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_parseWithTabs);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_postParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_preParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_resetCache);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_runTests);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_scanString);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_searchString);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setBreak);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setBreak_locals_br);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setDebug);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setDebugActions);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setDefaultWhitespa);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setFailAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setName);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setParseAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setParseAction_loc);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setResultsName);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_setWhitespaceChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_split);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_streamline);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_suppress);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_transformString);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_tryParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserElement_validate);
  Py_CLEAR(clear_module_state->__pyx_n_s_PendingSkip);
  Py_CLEAR(clear_module_state->__pyx_n_s_PendingSkip___add);
  Py_CLEAR(clear_module_state->__pyx_n_s_PendingSkip___add___locals_must);
  Py_CLEAR(clear_module_state->__pyx_n_s_PendingSkip___add___locals_show);
  Py_CLEAR(clear_module_state->__pyx_n_s_PendingSkip___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_PendingSkip___repr);
  Py_CLEAR(clear_module_state->__pyx_n_s_PendingSkip_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_PositionToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_PositionToken___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_PrecededBy);
  Py_CLEAR(clear_module_state->__pyx_n_u_PrecededBy);
  Py_CLEAR(clear_module_state->__pyx_n_s_PrecededBy___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_PrecededBy___init___locals_lambd);
  Py_CLEAR(clear_module_state->__pyx_n_s_PrecededBy_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Python_style_comment);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuotedString);
  Py_CLEAR(clear_module_state->__pyx_n_u_QuotedString);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuotedString___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuotedString___init___locals_gen);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuotedString___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuotedString_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_RIGHT);
  Py_CLEAR(clear_module_state->__pyx_n_s_RLock);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Re_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_RecursiveGrammarException);
  Py_CLEAR(clear_module_state->__pyx_n_u_RecursiveGrammarException);
  Py_CLEAR(clear_module_state->__pyx_n_s_RecursiveGrammarException___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_RecursiveGrammarException___str);
  Py_CLEAR(clear_module_state->__pyx_kp_u_RecursiveGrammarException_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_Regex);
  Py_CLEAR(clear_module_state->__pyx_n_u_Regex);
  Py_CLEAR(clear_module_state->__pyx_n_s_Regex___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Regex___str);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Regex_may_only_be_constructed_wi);
  Py_CLEAR(clear_module_state->__pyx_n_s_Regex_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Regex_parseImplAsGroupList);
  Py_CLEAR(clear_module_state->__pyx_n_s_Regex_parseImplAsMatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_Regex_sub);
  Py_CLEAR(clear_module_state->__pyx_n_s_Regex_sub_locals_pa);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Repetition_of_one_or_more_of_the);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Requires_all_given_class_ParseE);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Requires_all_given_class_ParseEx);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Requires_that_at_least_one_class);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Requires_that_at_least_one_class_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_SIX_PER_EM_SPACE);
  Py_CLEAR(clear_module_state->__pyx_kp_u_SP);
  Py_CLEAR(clear_module_state->__pyx_n_s_SimpleNamespace);
  Py_CLEAR(clear_module_state->__pyx_n_s_SingleCharLiteral);
  Py_CLEAR(clear_module_state->__pyx_n_s_SingleCharLiteral_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_SkipTo);
  Py_CLEAR(clear_module_state->__pyx_n_u_SkipTo);
  Py_CLEAR(clear_module_state->__pyx_n_s_SkipTo___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_SkipTo_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Special_matching_class_for_match);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_StringEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringEnd___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringEnd_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringStart);
  Py_CLEAR(clear_module_state->__pyx_n_u_StringStart);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringStart___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringStart_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Structured_parse_results_to_prov);
  Py_CLEAR(clear_module_state->__pyx_n_s_Suppress);
  Py_CLEAR(clear_module_state->__pyx_n_u_Suppress);
  Py_CLEAR(clear_module_state->__pyx_n_s_Suppress_postParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_Suppress_suppress);
  Py_CLEAR(clear_module_state->__pyx_n_s_SyntaxError);
  Py_CLEAR(clear_module_state->__pyx_n_s_SyntaxWarning);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TAB);
  Py_CLEAR(clear_module_state->__pyx_kp_u_THIN_SPACE);
  Py_CLEAR(clear_module_state->__pyx_kp_u_THREE_PER_EM_SPACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_TRY);
  Py_CLEAR(clear_module_state->__pyx_n_s_TestParseResultsAsserts);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Text_not_in_expected_column);
  Py_CLEAR(clear_module_state->__pyx_n_s_Thai);
  Py_CLEAR(clear_module_state->__pyx_n_s_Token);
  Py_CLEAR(clear_module_state->__pyx_n_u_Token);
  Py_CLEAR(clear_module_state->__pyx_n_s_TokenConverter);
  Py_CLEAR(clear_module_state->__pyx_n_u_TokenConverter);
  Py_CLEAR(clear_module_state->__pyx_n_s_TokenConverter___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Token___init);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Token_for_matching_strings_that);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Token_for_matching_strings_that_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Token_for_matching_words_compose);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Token_for_matching_words_compose_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Token_for_skipping_over_all_unde);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Token_to_advance_to_a_specific_c);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Token_to_exactly_match_a_specifi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Token_to_exactly_match_a_specifi_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Token_to_match_a_specified_strin);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_UNDENT);
  Py_CLEAR(clear_module_state->__pyx_n_u_UNINDENT);
  Py_CLEAR(clear_module_state->__pyx_n_s_UUID);
  Py_CLEAR(clear_module_state->__pyx_n_u_UUID);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnboundedCache);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnboundedCache___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnboundedCache___len);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnboundedCache___reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnboundedCache_clear);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnboundedCache_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnboundedCache_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnboundedCache_update);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Arabic_Unicode_C);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Chinese_Unicode);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Cyrillic_Unicode);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Devanagari_Unico);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Greek_Unicode_Ch);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Hebrew_Unicode_C);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Hiragana_Unicode);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Japanese_Unicode);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Kanji_Unicode_Ch);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Katakana_Unicode);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Korean_Unicode_C);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Latin_1_Unicode);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Latin_A_Unicode);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Latin_B_Unicode);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_Thai_Unicode_Cha);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unicode_set_for_combined_Chinese);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unmatchable_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_kp_u_W);
  Py_CLEAR(clear_module_state->__pyx_n_s_WRAP_CALL_LINE_NUM);
  Py_CLEAR(clear_module_state->__pyx_kp_u_W_s);
  Py_CLEAR(clear_module_state->__pyx_kp_u_W_s_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_W_s_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_White);
  Py_CLEAR(clear_module_state->__pyx_n_u_White);
  Py_CLEAR(clear_module_state->__pyx_n_s_White___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_White___init___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_White_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Word);
  Py_CLEAR(clear_module_state->__pyx_n_u_Word);
  Py_CLEAR(clear_module_state->__pyx_n_s_WordEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_WordEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_WordEnd___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_WordEnd_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_WordRegex);
  Py_CLEAR(clear_module_state->__pyx_n_s_WordRegex_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_WordStart);
  Py_CLEAR(clear_module_state->__pyx_n_u_WordStart);
  Py_CLEAR(clear_module_state->__pyx_n_s_WordStart___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_WordStart_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Word___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_Word___init___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Word___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_Word___str___locals_charsAsStr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Word_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Wrapper_for_parse_actions_to_ens);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Y_m_d);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Y_m_dT_H_M_S_f);
  Py_CLEAR(clear_module_state->__pyx_kp_u_ZERO_WIDTH_SPACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZeroOrMore);
  Py_CLEAR(clear_module_state->__pyx_n_u_ZeroOrMore);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZeroOrMore___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZeroOrMore___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZeroOrMore_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_kp_u__10);
  Py_CLEAR(clear_module_state->__pyx_kp_u__100);
  Py_CLEAR(clear_module_state->__pyx_kp_u__102);
  Py_CLEAR(clear_module_state->__pyx_kp_u__104);
  Py_CLEAR(clear_module_state->__pyx_kp_u__105);
  Py_CLEAR(clear_module_state->__pyx_kp_u__107);
  Py_CLEAR(clear_module_state->__pyx_kp_u__108);
  Py_CLEAR(clear_module_state->__pyx_kp_u__11);
  Py_CLEAR(clear_module_state->__pyx_kp_u__110);
  Py_CLEAR(clear_module_state->__pyx_kp_u__111);
  Py_CLEAR(clear_module_state->__pyx_kp_u__112);
  Py_CLEAR(clear_module_state->__pyx_kp_u__113);
  Py_CLEAR(clear_module_state->__pyx_kp_u__114);
  Py_CLEAR(clear_module_state->__pyx_kp_u__115);
  Py_CLEAR(clear_module_state->__pyx_kp_u__116);
  Py_CLEAR(clear_module_state->__pyx_kp_u__117);
  Py_CLEAR(clear_module_state->__pyx_kp_u__118);
  Py_CLEAR(clear_module_state->__pyx_kp_u__119);
  Py_CLEAR(clear_module_state->__pyx_kp_u__12);
  Py_CLEAR(clear_module_state->__pyx_kp_u__122);
  Py_CLEAR(clear_module_state->__pyx_kp_u__13);
  Py_CLEAR(clear_module_state->__pyx_kp_u__136);
  Py_CLEAR(clear_module_state->__pyx_kp_u__14);
  Py_CLEAR(clear_module_state->__pyx_kp_u__144);
  Py_CLEAR(clear_module_state->__pyx_kp_u__145);
  Py_CLEAR(clear_module_state->__pyx_kp_u__147);
  Py_CLEAR(clear_module_state->__pyx_kp_u__148);
  Py_CLEAR(clear_module_state->__pyx_n_s__15);
  Py_CLEAR(clear_module_state->__pyx_kp_u__15);
  Py_CLEAR(clear_module_state->__pyx_kp_u__150);
  Py_CLEAR(clear_module_state->__pyx_kp_u__16);
  Py_CLEAR(clear_module_state->__pyx_kp_u__166);
  Py_CLEAR(clear_module_state->__pyx_kp_u__17);
  Py_CLEAR(clear_module_state->__pyx_kp_u__19);
  Py_CLEAR(clear_module_state->__pyx_kp_u__2);
  Py_CLEAR(clear_module_state->__pyx_kp_u__22);
  Py_CLEAR(clear_module_state->__pyx_kp_u__25);
  Py_CLEAR(clear_module_state->__pyx_kp_u__26);
  Py_CLEAR(clear_module_state->__pyx_kp_u__27);
  Py_CLEAR(clear_module_state->__pyx_kp_u__28);
  Py_CLEAR(clear_module_state->__pyx_kp_u__29);
  Py_CLEAR(clear_module_state->__pyx_kp_u__3);
  Py_CLEAR(clear_module_state->__pyx_kp_u__30);
  Py_CLEAR(clear_module_state->__pyx_kp_u__31);
  Py_CLEAR(clear_module_state->__pyx_kp_u__339);
  Py_CLEAR(clear_module_state->__pyx_kp_u__34);
  Py_CLEAR(clear_module_state->__pyx_kp_u__35);
  Py_CLEAR(clear_module_state->__pyx_kp_u__4);
  Py_CLEAR(clear_module_state->__pyx_kp_u__461);
  Py_CLEAR(clear_module_state->__pyx_kp_u__5);
  Py_CLEAR(clear_module_state->__pyx_kp_u__511);
  Py_CLEAR(clear_module_state->__pyx_kp_u__512);
  Py_CLEAR(clear_module_state->__pyx_kp_u__513);
  Py_CLEAR(clear_module_state->__pyx_kp_u__514);
  Py_CLEAR(clear_module_state->__pyx_kp_u__515);
  Py_CLEAR(clear_module_state->__pyx_kp_u__516);
  Py_CLEAR(clear_module_state->__pyx_kp_u__517);
  Py_CLEAR(clear_module_state->__pyx_kp_u__518);
  Py_CLEAR(clear_module_state->__pyx_kp_u__519);
  Py_CLEAR(clear_module_state->__pyx_kp_u__520);
  Py_CLEAR(clear_module_state->__pyx_kp_u__521);
  Py_CLEAR(clear_module_state->__pyx_kp_u__522);
  Py_CLEAR(clear_module_state->__pyx_kp_u__523);
  Py_CLEAR(clear_module_state->__pyx_kp_u__524);
  Py_CLEAR(clear_module_state->__pyx_kp_u__525);
  Py_CLEAR(clear_module_state->__pyx_kp_u__526);
  Py_CLEAR(clear_module_state->__pyx_kp_u__527);
  Py_CLEAR(clear_module_state->__pyx_kp_u__528);
  Py_CLEAR(clear_module_state->__pyx_kp_u__6);
  Py_CLEAR(clear_module_state->__pyx_n_s__621);
  Py_CLEAR(clear_module_state->__pyx_n_u__621);
  Py_CLEAR(clear_module_state->__pyx_kp_u__65);
  Py_CLEAR(clear_module_state->__pyx_kp_u__66);
  Py_CLEAR(clear_module_state->__pyx_kp_u__67);
  Py_CLEAR(clear_module_state->__pyx_kp_u__7);
  Py_CLEAR(clear_module_state->__pyx_kp_u__718);
  Py_CLEAR(clear_module_state->__pyx_kp_u__721);
  Py_CLEAR(clear_module_state->__pyx_kp_u__755);
  Py_CLEAR(clear_module_state->__pyx_kp_u__768);
  Py_CLEAR(clear_module_state->__pyx_kp_u__770);
  Py_CLEAR(clear_module_state->__pyx_kp_u__771);
  Py_CLEAR(clear_module_state->__pyx_kp_u__774);
  Py_CLEAR(clear_module_state->__pyx_kp_u__776);
  Py_CLEAR(clear_module_state->__pyx_kp_u__780);
  Py_CLEAR(clear_module_state->__pyx_kp_u__786);
  Py_CLEAR(clear_module_state->__pyx_kp_u__789);
  Py_CLEAR(clear_module_state->__pyx_kp_u__79);
  Py_CLEAR(clear_module_state->__pyx_kp_u__795);
  Py_CLEAR(clear_module_state->__pyx_kp_u__80);
  Py_CLEAR(clear_module_state->__pyx_n_u__856);
  Py_CLEAR(clear_module_state->__pyx_n_u__857);
  Py_CLEAR(clear_module_state->__pyx_n_u__858);
  Py_CLEAR(clear_module_state->__pyx_n_u__859);
  Py_CLEAR(clear_module_state->__pyx_kp_u__860);
  Py_CLEAR(clear_module_state->__pyx_n_u__861);
  Py_CLEAR(clear_module_state->__pyx_n_u__862);
  Py_CLEAR(clear_module_state->__pyx_n_u__863);
  Py_CLEAR(clear_module_state->__pyx_n_u__864);
  Py_CLEAR(clear_module_state->__pyx_n_u__865);
  Py_CLEAR(clear_module_state->__pyx_n_u__866);
  Py_CLEAR(clear_module_state->__pyx_kp_u__867);
  Py_CLEAR(clear_module_state->__pyx_n_s__893);
  Py_CLEAR(clear_module_state->__pyx_kp_u__91);
  Py_CLEAR(clear_module_state->__pyx_kp_u__94);
  Py_CLEAR(clear_module_state->__pyx_kp_u__95);
  Py_CLEAR(clear_module_state->__pyx_kp_u__96);
  Py_CLEAR(clear_module_state->__pyx_kp_u__97);
  Py_CLEAR(clear_module_state->__pyx_kp_u__98);
  Py_CLEAR(clear_module_state->__pyx_kp_u__99);
  Py_CLEAR(clear_module_state->__pyx_n_s_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_adaptive_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_adaptive_usage);
  Py_CLEAR(clear_module_state->__pyx_n_s_adaptive_usage_check_rate);
  Py_CLEAR(clear_module_state->__pyx_n_s_add);
  Py_CLEAR(clear_module_state->__pyx_n_s_addCondition);
  Py_CLEAR(clear_module_state->__pyx_n_s_addParseAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_addoffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_adjacent);
  Py_CLEAR(clear_module_state->__pyx_n_s_all);
  Py_CLEAR(clear_module_state->__pyx_n_s_allResults);
  Py_CLEAR(clear_module_state->__pyx_n_s_all_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_all_names);
  Py_CLEAR(clear_module_state->__pyx_n_s_all_parse_elements);
  Py_CLEAR(clear_module_state->__pyx_n_s_allow_unused_expr_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_alphanums);
  Py_CLEAR(clear_module_state->__pyx_n_u_alphanums);
  Py_CLEAR(clear_module_state->__pyx_n_s_alphas);
  Py_CLEAR(clear_module_state->__pyx_n_u_alphas);
  Py_CLEAR(clear_module_state->__pyx_n_s_alphas8bit);
  Py_CLEAR(clear_module_state->__pyx_n_u_alphas8bit);
  Py_CLEAR(clear_module_state->__pyx_kp_u_amp_gt_lt_quot_apos);
  Py_CLEAR(clear_module_state->__pyx_n_s_aname);
  Py_CLEAR(clear_module_state->__pyx_n_s_anchor);
  Py_CLEAR(clear_module_state->__pyx_n_s_and);
  Py_CLEAR(clear_module_state->__pyx_n_s_any);
  Py_CLEAR(clear_module_state->__pyx_n_s_anyCloseTag);
  Py_CLEAR(clear_module_state->__pyx_n_u_anyCloseTag);
  Py_CLEAR(clear_module_state->__pyx_n_s_anyOpenTag);
  Py_CLEAR(clear_module_state->__pyx_n_u_anyOpenTag);
  Py_CLEAR(clear_module_state->__pyx_kp_u_any_tag);
  Py_CLEAR(clear_module_state->__pyx_n_s_append);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_n_u_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_arity);
  Py_CLEAR(clear_module_state->__pyx_n_s_arrayExpr);
  Py_CLEAR(clear_module_state->__pyx_n_u_arrayLen);
  Py_CLEAR(clear_module_state->__pyx_n_s_asDict);
  Py_CLEAR(clear_module_state->__pyx_n_s_asGroupList);
  Py_CLEAR(clear_module_state->__pyx_n_s_asKeyword);
  Py_CLEAR(clear_module_state->__pyx_n_s_asList);
  Py_CLEAR(clear_module_state->__pyx_n_s_asMatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_asString);
  Py_CLEAR(clear_module_state->__pyx_n_s_asStringList);
  Py_CLEAR(clear_module_state->__pyx_n_s_asXML);
  Py_CLEAR(clear_module_state->__pyx_kp_u_as_column_list_and_dotted_table);
  Py_CLEAR(clear_module_state->__pyx_n_s_ascii_lowercase);
  Py_CLEAR(clear_module_state->__pyx_n_s_ascii_uppercase);
  Py_CLEAR(clear_module_state->__pyx_n_s_assertEqual);
  Py_CLEAR(clear_module_state->__pyx_n_s_assertParseAndCheckDict);
  Py_CLEAR(clear_module_state->__pyx_n_s_assertParseAndCheckList);
  Py_CLEAR(clear_module_state->__pyx_n_s_assertParseResultsEquals);
  Py_CLEAR(clear_module_state->__pyx_n_s_assertRaises);
  Py_CLEAR(clear_module_state->__pyx_n_s_assertRaisesParseException);
  Py_CLEAR(clear_module_state->__pyx_n_s_assertRunTestResults);
  Py_CLEAR(clear_module_state->__pyx_n_s_assertTrue);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_kp_u_at_char);
  Py_CLEAR(clear_module_state->__pyx_kp_u_at_loc);
  Py_CLEAR(clear_module_state->__pyx_n_s_attrDict);
  Py_CLEAR(clear_module_state->__pyx_n_s_attrName);
  Py_CLEAR(clear_module_state->__pyx_n_s_attrValue);
  Py_CLEAR(clear_module_state->__pyx_kp_u_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_attrname);
  Py_CLEAR(clear_module_state->__pyx_n_s_attrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_author);
  Py_CLEAR(clear_module_state->__pyx_n_u_author);
  Py_CLEAR(clear_module_state->__pyx_kp_u_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_b_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_b_s_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_backup_stack);
  Py_CLEAR(clear_module_state->__pyx_n_s_baseExpr);
  Py_CLEAR(clear_module_state->__pyx_kp_s_base_exception_class_for_all_par);
  Py_CLEAR(clear_module_state->__pyx_n_s_basestring);
  Py_CLEAR(clear_module_state->__pyx_n_s_best_expr);
  Py_CLEAR(clear_module_state->__pyx_n_s_blockStatementExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_body);
  Py_CLEAR(clear_module_state->__pyx_n_u_body);
  Py_CLEAR(clear_module_state->__pyx_n_s_bodyChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_bodyCharsOrig);
  Py_CLEAR(clear_module_state->__pyx_n_s_bodychars);
  Py_CLEAR(clear_module_state->__pyx_n_s_bool);
  Py_CLEAR(clear_module_state->__pyx_n_s_breakFlag);
  Py_CLEAR(clear_module_state->__pyx_n_s_breaker);
  Py_CLEAR(clear_module_state->__pyx_n_s_bslash);
  Py_CLEAR(clear_module_state->__pyx_n_s_builtin);
  Py_CLEAR(clear_module_state->__pyx_n_s_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_cPyparsing);
  Py_CLEAR(clear_module_state->__pyx_kp_s_cPyparsing_pyx);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cPyparsing_pyx);
  Py_CLEAR(clear_module_state->__pyx_n_s_cStyleComment);
  Py_CLEAR(clear_module_state->__pyx_n_u_cStyleComment);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache);
  Py_CLEAR(clear_module_state->__pyx_n_u_cache);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache_furthest_loc);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache_size_limit);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache_successes);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache_usefullness_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_call);
  Py_CLEAR(clear_module_state->__pyx_n_s_callDuringTry);
  Py_CLEAR(clear_module_state->__pyx_n_u_callDuringTry);
  Py_CLEAR(clear_module_state->__pyx_n_s_callPreParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_callPreparse);
  Py_CLEAR(clear_module_state->__pyx_n_s_callable);
  Py_CLEAR(clear_module_state->__pyx_n_s_called);
  Py_CLEAR(clear_module_state->__pyx_n_s_callers);
  Py_CLEAR(clear_module_state->__pyx_n_s_canParseNext);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_construct_And_with_sequen);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_multiply_ParserElement_an);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_multiply_ParserElement_an_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_multiply_ParserElement_by);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_multiply_ParserElement_by_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_specify_a_minimum_length);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_specify_a_minimum_length_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_use_sub_with_Regex_asGrou);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_use_sub_with_a_callable_w);
  Py_CLEAR(clear_module_state->__pyx_n_s_caseless);
  Py_CLEAR(clear_module_state->__pyx_n_s_caselessmatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_cause);
  Py_CLEAR(clear_module_state->__pyx_n_s_cc);
  Py_CLEAR(clear_module_state->__pyx_n_s_charRange);
  Py_CLEAR(clear_module_state->__pyx_n_s_chars);
  Py_CLEAR(clear_module_state->__pyx_n_s_charsAsStr);
  Py_CLEAR(clear_module_state->__pyx_n_s_charset);
  Py_CLEAR(clear_module_state->__pyx_n_s_checkPeerIndent);
  Py_CLEAR(clear_module_state->__pyx_n_s_checkRecursion);
  Py_CLEAR(clear_module_state->__pyx_n_s_checkSubIndent);
  Py_CLEAR(clear_module_state->__pyx_n_s_checkUnindent);
  Py_CLEAR(clear_module_state->__pyx_n_s_check_ender);
  Py_CLEAR(clear_module_state->__pyx_n_s_chr);
  Py_CLEAR(clear_module_state->__pyx_n_s_class);
  Py_CLEAR(clear_module_state->__pyx_n_u_class);
  Py_CLEAR(clear_module_state->__pyx_n_u_class_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_classattr);
  Py_CLEAR(clear_module_state->__pyx_n_s_classname);
  Py_CLEAR(clear_module_state->__pyx_n_s_clear);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_closeTag);
  Py_CLEAR(clear_module_state->__pyx_n_s_closer);
  Py_CLEAR(clear_module_state->__pyx_n_s_cls);
  Py_CLEAR(clear_module_state->__pyx_n_s_co_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_col);
  Py_CLEAR(clear_module_state->__pyx_n_u_col);
  Py_CLEAR(clear_module_state->__pyx_kp_u_col_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_collectParseElements);
  Py_CLEAR(clear_module_state->__pyx_n_s_collect_all_And_tokens);
  Py_CLEAR(clear_module_state->__pyx_n_u_collect_all_And_tokens);
  Py_CLEAR(clear_module_state->__pyx_n_s_collections);
  Py_CLEAR(clear_module_state->__pyx_n_s_collections_abc);
  Py_CLEAR(clear_module_state->__pyx_n_s_colno);
  Py_CLEAR(clear_module_state->__pyx_n_s_column);
  Py_CLEAR(clear_module_state->__pyx_n_u_column);
  Py_CLEAR(clear_module_state->__pyx_n_s_columnName);
  Py_CLEAR(clear_module_state->__pyx_n_s_columnNameList);
  Py_CLEAR(clear_module_state->__pyx_n_s_columnSpec);
  Py_CLEAR(clear_module_state->__pyx_n_u_columns);
  Py_CLEAR(clear_module_state->__pyx_n_s_combine);
  Py_CLEAR(clear_module_state->__pyx_n_u_commaItem);
  Py_CLEAR(clear_module_state->__pyx_n_s_commaSeparatedList);
  Py_CLEAR(clear_module_state->__pyx_n_u_commaSeparatedList);
  Py_CLEAR(clear_module_state->__pyx_kp_u_comma_separated_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_comma_separated_list_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_command);
  Py_CLEAR(clear_module_state->__pyx_n_s_commasepitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_comment);
  Py_CLEAR(clear_module_state->__pyx_kp_u_comment_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_comments);
  Py_CLEAR(clear_module_state->__pyx_n_s_commonHTMLEntity);
  Py_CLEAR(clear_module_state->__pyx_n_u_commonHTMLEntity);
  Py_CLEAR(clear_module_state->__pyx_kp_u_common_HTML_entity);
  Py_CLEAR(clear_module_state->__pyx_n_s_common_prefix_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_common_suffix_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_commonprefix);
  Py_CLEAR(clear_module_state->__pyx_n_s_compat);
  Py_CLEAR(clear_module_state->__pyx_n_u_compat);
  Py_CLEAR(clear_module_state->__pyx_n_s_compile);
  Py_CLEAR(clear_module_state->__pyx_n_s_conditionAsParseAction);
  Py_CLEAR(clear_module_state->__pyx_n_u_conditionAsParseAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_conditionAsParseAction_locals_pa);
  Py_CLEAR(clear_module_state->__pyx_n_s_contains);
  Py_CLEAR(clear_module_state->__pyx_n_s_content);
  Py_CLEAR(clear_module_state->__pyx_n_s_context);
  Py_CLEAR(clear_module_state->__pyx_n_s_contextlib);
  Py_CLEAR(clear_module_state->__pyx_n_s_contextmanager);
  Py_CLEAR(clear_module_state->__pyx_n_s_convertToDate);
  Py_CLEAR(clear_module_state->__pyx_n_s_convertToDatetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_convertToFloat);
  Py_CLEAR(clear_module_state->__pyx_n_s_convertToInteger);
  Py_CLEAR(clear_module_state->__pyx_n_s_convertWhitespaceEscapes);
  Py_CLEAR(clear_module_state->__pyx_n_s_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_copyDefaultWhiteChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_copyTokenToRepeater);
  Py_CLEAR(clear_module_state->__pyx_n_s_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_countFieldParseAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_countedArray);
  Py_CLEAR(clear_module_state->__pyx_n_u_countedArray);
  Py_CLEAR(clear_module_state->__pyx_n_s_countedArray_locals_countFieldPa);
  Py_CLEAR(clear_module_state->__pyx_n_s_countedArray_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_cppStyleComment);
  Py_CLEAR(clear_module_state->__pyx_n_u_cppStyleComment);
  Py_CLEAR(clear_module_state->__pyx_n_s_cpy);
  Py_CLEAR(clear_module_state->__pyx_n_s_cur);
  Py_CLEAR(clear_module_state->__pyx_n_s_curCol);
  Py_CLEAR(clear_module_state->__pyx_n_s_cvt_fn);
  Py_CLEAR(clear_module_state->__pyx_n_s_d);
  Py_CLEAR(clear_module_state->__pyx_n_u_d);
  Py_CLEAR(clear_module_state->__pyx_kp_u_d_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_d_d_d);
  Py_CLEAR(clear_module_state->__pyx_kp_u_d_d_eE_d);
  Py_CLEAR(clear_module_state->__pyx_kp_u_d_eE_d_d_d_d_eE_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_dblQuotedString);
  Py_CLEAR(clear_module_state->__pyx_n_u_dblQuotedString);
  Py_CLEAR(clear_module_state->__pyx_n_s_dblSlashComment);
  Py_CLEAR(clear_module_state->__pyx_n_u_dblSlashComment);
  Py_CLEAR(clear_module_state->__pyx_n_s_debug);
  Py_CLEAR(clear_module_state->__pyx_n_s_debugActions);
  Py_CLEAR(clear_module_state->__pyx_n_s_debugging);
  Py_CLEAR(clear_module_state->__pyx_n_s_decode);
  Py_CLEAR(clear_module_state->__pyx_n_s_default);
  Py_CLEAR(clear_module_state->__pyx_n_u_default);
  Py_CLEAR(clear_module_state->__pyx_n_s_defaultExceptionDebugAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_defaultStartDebugAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_defaultSuccessDebugAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_defaultValue);
  Py_CLEAR(clear_module_state->__pyx_n_u_default_keyword_chars);
  Py_CLEAR(clear_module_state->__pyx_n_u_default_whitespace);
  Py_CLEAR(clear_module_state->__pyx_n_s_defaultdict);
  Py_CLEAR(clear_module_state->__pyx_n_s_defaultvalue);
  Py_CLEAR(clear_module_state->__pyx_n_s_delim);
  Py_CLEAR(clear_module_state->__pyx_n_s_delimitedList);
  Py_CLEAR(clear_module_state->__pyx_n_u_delimitedList);
  Py_CLEAR(clear_module_state->__pyx_n_s_delitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_depth);
  Py_CLEAR(clear_module_state->__pyx_n_s_depth_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_deque);
  Py_CLEAR(clear_module_state->__pyx_n_s_diag);
  Py_CLEAR(clear_module_state->__pyx_n_u_diag);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_dictOf);
  Py_CLEAR(clear_module_state->__pyx_n_u_dictOf);
  Py_CLEAR(clear_module_state->__pyx_n_s_dictvalue);
  Py_CLEAR(clear_module_state->__pyx_n_s_dir);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_n_s_dlName);
  Py_CLEAR(clear_module_state->__pyx_n_s_doActions);
  Py_CLEAR(clear_module_state->__pyx_n_s_doc);
  Py_CLEAR(clear_module_state->__pyx_n_s_doctag);
  Py_CLEAR(clear_module_state->__pyx_n_s_downcaseTokens);
  Py_CLEAR(clear_module_state->__pyx_n_u_downcaseTokens);
  Py_CLEAR(clear_module_state->__pyx_n_s_dummy);
  Py_CLEAR(clear_module_state->__pyx_n_s_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_e2);
  Py_CLEAR(clear_module_state->__pyx_n_s_elem);
  Py_CLEAR(clear_module_state->__pyx_n_s_empty);
  Py_CLEAR(clear_module_state->__pyx_n_u_empty);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_enableIncremental);
  Py_CLEAR(clear_module_state->__pyx_n_s_enablePackrat);
  Py_CLEAR(clear_module_state->__pyx_n_u_enable_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_enable_all_warnings);
  Py_CLEAR(clear_module_state->__pyx_n_s_enable_all_warnings_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_enable_debug_on_named_expression);
  Py_CLEAR(clear_module_state->__pyx_n_s_end);
  Py_CLEAR(clear_module_state->__pyx_n_u_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_endQuoteChar);
  Py_CLEAR(clear_module_state->__pyx_n_s_endQuoteCharLen);
  Py_CLEAR(clear_module_state->__pyx_kp_u_endQuoteChar_cannot_be_the_empty);
  Py_CLEAR(clear_module_state->__pyx_n_s_ender);
  Py_CLEAR(clear_module_state->__pyx_kp_u_ending_with);
  Py_CLEAR(clear_module_state->__pyx_n_s_endloc);
  Py_CLEAR(clear_module_state->__pyx_n_s_endlocMarker);
  Py_CLEAR(clear_module_state->__pyx_n_s_endswith);
  Py_CLEAR(clear_module_state->__pyx_n_s_enter);
  Py_CLEAR(clear_module_state->__pyx_kp_u_entering);
  Py_CLEAR(clear_module_state->__pyx_n_s_entity);
  Py_CLEAR(clear_module_state->__pyx_n_s_enumerate);
  Py_CLEAR(clear_module_state->__pyx_n_s_eq);
  Py_CLEAR(clear_module_state->__pyx_n_s_err);
  Py_CLEAR(clear_module_state->__pyx_n_s_errmsg);
  Py_CLEAR(clear_module_state->__pyx_n_s_error);
  Py_CLEAR(clear_module_state->__pyx_n_s_errorStop);
  Py_CLEAR(clear_module_state->__pyx_n_s_escChar);
  Py_CLEAR(clear_module_state->__pyx_n_s_escCharReplacePattern);
  Py_CLEAR(clear_module_state->__pyx_n_s_escQuote);
  Py_CLEAR(clear_module_state->__pyx_n_s_escape);
  Py_CLEAR(clear_module_state->__pyx_n_s_escapeRegexRangeChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_escapedHexChar);
  Py_CLEAR(clear_module_state->__pyx_n_s_escapedOctChar);
  Py_CLEAR(clear_module_state->__pyx_n_s_escapedPunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_exact);
  Py_CLEAR(clear_module_state->__pyx_n_s_exc);
  Py_CLEAR(clear_module_state->__pyx_n_s_exc_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_exc_type);
  Py_CLEAR(clear_module_state->__pyx_kp_u_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_exceptionAction);
  Py_CLEAR(clear_module_state->__pyx_kp_u_exception_raised_in_parse_action);
  Py_CLEAR(clear_module_state->__pyx_kp_s_exception_thrown_by_class_Parser);
  Py_CLEAR(clear_module_state->__pyx_n_s_excludeChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_exit);
  Py_CLEAR(clear_module_state->__pyx_n_s_expand);
  Py_CLEAR(clear_module_state->__pyx_n_s_expanded);
  Py_CLEAR(clear_module_state->__pyx_n_s_expandtabs);
  Py_CLEAR(clear_module_state->__pyx_n_s_expected);
  Py_CLEAR(clear_module_state->__pyx_n_s_expected_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_expected_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_expected_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_expected_parse_results);
  Py_CLEAR(clear_module_state->__pyx_n_s_explain);
  Py_CLEAR(clear_module_state->__pyx_n_s_expr);
  Py_CLEAR(clear_module_state->__pyx_n_s_expr1);
  Py_CLEAR(clear_module_state->__pyx_n_s_expr_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_expr_parse);
  Py_CLEAR(clear_module_state->__pyx_kp_u_expression);
  Py_CLEAR(clear_module_state->__pyx_n_s_exprs);
  Py_CLEAR(clear_module_state->__pyx_n_u_exprs);
  Py_CLEAR(clear_module_state->__pyx_n_s_exprsFound);
  Py_CLEAR(clear_module_state->__pyx_n_s_exprtokens);
  Py_CLEAR(clear_module_state->__pyx_n_s_extend);
  Py_CLEAR(clear_module_state->__pyx_n_s_extractText);
  Py_CLEAR(clear_module_state->__pyx_n_s_extract_stack);
  Py_CLEAR(clear_module_state->__pyx_n_s_extract_tb);
  Py_CLEAR(clear_module_state->__pyx_kp_u_f);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_locals);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_self);
  Py_CLEAR(clear_module_state->__pyx_n_s_failAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_failOn);
  Py_CLEAR(clear_module_state->__pyx_n_s_fail_msg);
  Py_CLEAR(clear_module_state->__pyx_n_s_failed);
  Py_CLEAR(clear_module_state->__pyx_kp_u_failed_runTests);
  Py_CLEAR(clear_module_state->__pyx_kp_u_failed_user_defined_condition);
  Py_CLEAR(clear_module_state->__pyx_n_s_failureTests);
  Py_CLEAR(clear_module_state->__pyx_n_s_fatal);
  Py_CLEAR(clear_module_state->__pyx_n_u_fatal);
  Py_CLEAR(clear_module_state->__pyx_n_s_ff);
  Py_CLEAR(clear_module_state->__pyx_kp_u_ffff);
  Py_CLEAR(clear_module_state->__pyx_n_s_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_file_contents);
  Py_CLEAR(clear_module_state->__pyx_n_s_file_or_filename);
  Py_CLEAR(clear_module_state->__pyx_n_s_filter);
  Py_CLEAR(clear_module_state->__pyx_n_s_filterfalse);
  Py_CLEAR(clear_module_state->__pyx_n_s_finalResults);
  Py_CLEAR(clear_module_state->__pyx_n_s_find);
  Py_CLEAR(clear_module_state->__pyx_n_s_firstMatchChar);
  Py_CLEAR(clear_module_state->__pyx_n_s_firstQuoteChar);
  Py_CLEAR(clear_module_state->__pyx_n_s_flag);
  Py_CLEAR(clear_module_state->__pyx_n_s_flags);
  Py_CLEAR(clear_module_state->__pyx_n_s_flatten);
  Py_CLEAR(clear_module_state->__pyx_n_s_fmt);
  Py_CLEAR(clear_module_state->__pyx_n_s_fn);
  Py_CLEAR(clear_module_state->__pyx_n_s_fname);
  Py_CLEAR(clear_module_state->__pyx_n_s_fns);
  Py_CLEAR(clear_module_state->__pyx_n_s_fnumber);
  Py_CLEAR(clear_module_state->__pyx_n_u_fnumber);
  Py_CLEAR(clear_module_state->__pyx_n_s_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_formatted);
  Py_CLEAR(clear_module_state->__pyx_n_s_foundArity);
  Py_CLEAR(clear_module_state->__pyx_kp_u_found_end_of_text);
  Py_CLEAR(clear_module_state->__pyx_kp_u_found_multiline_regex_during_inc);
  Py_CLEAR(clear_module_state->__pyx_kp_u_found_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_foundstr);
  Py_CLEAR(clear_module_state->__pyx_n_s_fraction);
  Py_CLEAR(clear_module_state->__pyx_n_u_fraction);
  Py_CLEAR(clear_module_state->__pyx_kp_u_fraction_or_mixed_integer_fracti);
  Py_CLEAR(clear_module_state->__pyx_n_s_frame_summary);
  Py_CLEAR(clear_module_state->__pyx_n_s_frames);
  Py_CLEAR(clear_module_state->__pyx_n_s_frm);
  Py_CLEAR(clear_module_state->__pyx_n_s_from);
  Py_CLEAR(clear_module_state->__pyx_n_s_fromToken);
  Py_CLEAR(clear_module_state->__pyx_n_u_from_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_from_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_from_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_from_symbols);
  Py_CLEAR(clear_module_state->__pyx_n_s_full);
  Py_CLEAR(clear_module_state->__pyx_n_s_fullDump);
  Py_CLEAR(clear_module_state->__pyx_kp_u_full_IPv6_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_full_ipv6_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_func);
  Py_CLEAR(clear_module_state->__pyx_n_s_func_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_functools);
  Py_CLEAR(clear_module_state->__pyx_n_s_furthest_locs);
  Py_CLEAR(clear_module_state->__pyx_kp_u_g_1);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_generatorType);
  Py_CLEAR(clear_module_state->__pyx_n_s_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_getName);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_chars_for_ranges);
  Py_CLEAR(clear_module_state->__pyx_n_s_getattr);
  Py_CLEAR(clear_module_state->__pyx_n_s_getinnerframes);
  Py_CLEAR(clear_module_state->__pyx_n_s_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_getnewargs);
  Py_CLEAR(clear_module_state->__pyx_n_s_getrecursionlimit);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_group);
  Py_CLEAR(clear_module_state->__pyx_n_s_groupdict);
  Py_CLEAR(clear_module_state->__pyx_n_s_groups);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gt_lt_amp_nbsp_quot_apos);
  Py_CLEAR(clear_module_state->__pyx_n_s_hasIgnoreExprs);
  Py_CLEAR(clear_module_state->__pyx_kp_u_has_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_hash);
  Py_CLEAR(clear_module_state->__pyx_n_s_haskeys);
  Py_CLEAR(clear_module_state->__pyx_kp_u_hex_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_hex_integer_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_hex_integer_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_hexnums);
  Py_CLEAR(clear_module_state->__pyx_n_u_hexnums);
  Py_CLEAR(clear_module_state->__pyx_n_s_hit);
  Py_CLEAR(clear_module_state->__pyx_n_s_htmlComment);
  Py_CLEAR(clear_module_state->__pyx_n_u_htmlComment);
  Py_CLEAR(clear_module_state->__pyx_n_s_htmlEntityMap);
  Py_CLEAR(clear_module_state->__pyx_n_s_html_stripper);
  Py_CLEAR(clear_module_state->__pyx_n_s_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_iadd);
  Py_CLEAR(clear_module_state->__pyx_n_s_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_ident);
  Py_CLEAR(clear_module_state->__pyx_n_s_identChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_identifier);
  Py_CLEAR(clear_module_state->__pyx_n_u_identifier);
  Py_CLEAR(clear_module_state->__pyx_kp_u_if_numterms_3_opExpr_must_be_a_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_ifilterfalse);
  Py_CLEAR(clear_module_state->__pyx_n_s_ignore);
  Py_CLEAR(clear_module_state->__pyx_n_s_ignoreExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_ignoreExprs);
  Py_CLEAR(clear_module_state->__pyx_n_s_ikey);
  Py_CLEAR(clear_module_state->__pyx_kp_u_illegal_nesting);
  Py_CLEAR(clear_module_state->__pyx_n_s_ilshift);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_inAccumNames);
  Py_CLEAR(clear_module_state->__pyx_n_u_include);
  Py_CLEAR(clear_module_state->__pyx_n_s_includeMatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_includeSeparators);
  Py_CLEAR(clear_module_state->__pyx_n_s_include_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_include_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_incrementalEnabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_incrementalWithResets);
  Py_CLEAR(clear_module_state->__pyx_n_s_incremental_parent_usefullness);
  Py_CLEAR(clear_module_state->__pyx_n_s_ind);
  Py_CLEAR(clear_module_state->__pyx_n_s_ind_or_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_indent);
  Py_CLEAR(clear_module_state->__pyx_n_s_indentStack);
  Py_CLEAR(clear_module_state->__pyx_n_s_indentedBlock);
  Py_CLEAR(clear_module_state->__pyx_n_u_indentedBlock);
  Py_CLEAR(clear_module_state->__pyx_n_s_indentedBlock_locals_checkPeerIn);
  Py_CLEAR(clear_module_state->__pyx_n_s_indentedBlock_locals_checkSubInd);
  Py_CLEAR(clear_module_state->__pyx_n_s_indentedBlock_locals_checkUninde);
  Py_CLEAR(clear_module_state->__pyx_n_s_indentedBlock_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_indentedBlock_locals_reset_stack);
  Py_CLEAR(clear_module_state->__pyx_kp_u_indented_block);
  Py_CLEAR(clear_module_state->__pyx_n_s_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_indices);
  Py_CLEAR(clear_module_state->__pyx_n_s_infixNotation);
  Py_CLEAR(clear_module_state->__pyx_n_u_infixNotation);
  Py_CLEAR(clear_module_state->__pyx_n_s_infixNotation_locals__FB);
  Py_CLEAR(clear_module_state->__pyx_n_s_infixNotation_locals__FB_parseIm);
  Py_CLEAR(clear_module_state->__pyx_n_s_init);
  Py_CLEAR(clear_module_state->__pyx_n_s_initChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_initCharsOrig);
  Py_CLEAR(clear_module_state->__pyx_n_s_initExprGroups);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_subclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_inlineLiteralsUsing);
  Py_CLEAR(clear_module_state->__pyx_n_s_insStr);
  Py_CLEAR(clear_module_state->__pyx_n_s_insert);
  Py_CLEAR(clear_module_state->__pyx_n_s_inspect);
  Py_CLEAR(clear_module_state->__pyx_n_s_inspect_tracebacks);
  Py_CLEAR(clear_module_state->__pyx_n_s_instring);
  Py_CLEAR(clear_module_state->__pyx_n_s_instring_prefixes_and_suffixes);
  Py_CLEAR(clear_module_state->__pyx_n_s_instring_slice);
  Py_CLEAR(clear_module_state->__pyx_n_s_instrlen);
  Py_CLEAR(clear_module_state->__pyx_n_s_intExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_integer);
  Py_CLEAR(clear_module_state->__pyx_n_u_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_intern);
  Py_CLEAR(clear_module_state->__pyx_n_u_intern);
  Py_CLEAR(clear_module_state->__pyx_kp_u_invalid_pattern_s_passed_to_Rege);
  Py_CLEAR(clear_module_state->__pyx_n_s_invert);
  Py_CLEAR(clear_module_state->__pyx_n_s_ior);
  Py_CLEAR(clear_module_state->__pyx_n_s_ipv4_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_ipv6_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_ipv6_part);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_instring);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_iterable);
  Py_CLEAR(clear_module_state->__pyx_n_s_isalpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_isdigit);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_isequal);
  Py_CLEAR(clear_module_state->__pyx_n_s_isinstance);
  Py_CLEAR(clear_module_state->__pyx_n_s_iso8601_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_iso8601_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_isspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_item_fn);
  Py_CLEAR(clear_module_state->__pyx_n_s_itemgetter);
  Py_CLEAR(clear_module_state->__pyx_n_s_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_itemseq);
  Py_CLEAR(clear_module_state->__pyx_n_s_iter);
  Py_CLEAR(clear_module_state->__pyx_n_s_iteritems);
  Py_CLEAR(clear_module_state->__pyx_n_s_iteritems_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_iterkeys);
  Py_CLEAR(clear_module_state->__pyx_n_u_iterkeys);
  Py_CLEAR(clear_module_state->__pyx_n_s_iterkeys_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_itertools);
  Py_CLEAR(clear_module_state->__pyx_n_s_itervalues);
  Py_CLEAR(clear_module_state->__pyx_n_s_itervalues_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ixor);
  Py_CLEAR(clear_module_state->__pyx_n_s_j);
  Py_CLEAR(clear_module_state->__pyx_n_s_javaStyleComment);
  Py_CLEAR(clear_module_state->__pyx_n_u_javaStyleComment);
  Py_CLEAR(clear_module_state->__pyx_n_s_joinString);
  Py_CLEAR(clear_module_state->__pyx_kp_s_just_like_class_ParseFatalExcept);
  Py_CLEAR(clear_module_state->__pyx_n_s_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_keepMatching);
  Py_CLEAR(clear_module_state->__pyx_n_s_keepTabs);
  Py_CLEAR(clear_module_state->__pyx_n_s_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_key_fifo);
  Py_CLEAR(clear_module_state->__pyx_n_u_key_fifo);
  Py_CLEAR(clear_module_state->__pyx_n_s_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_kwargs);
  Py_CLEAR(clear_module_state->__pyx_n_s_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_last);
  Py_CLEAR(clear_module_state->__pyx_n_s_lastCR);
  Py_CLEAR(clear_module_state->__pyx_n_s_lastE);
  Py_CLEAR(clear_module_state->__pyx_n_s_lastExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_last_expr);
  Py_CLEAR(clear_module_state->__pyx_n_s_lazyclassproperty);
  Py_CLEAR(clear_module_state->__pyx_n_s_lazyclassproperty___get);
  Py_CLEAR(clear_module_state->__pyx_n_s_lazyclassproperty___get___local);
  Py_CLEAR(clear_module_state->__pyx_n_s_lazyclassproperty___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_leaveWhitespace);
  Py_CLEAR(clear_module_state->__pyx_kp_u_leaving);
  Py_CLEAR(clear_module_state->__pyx_kp_u_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_len_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_len_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_limit);
  Py_CLEAR(clear_module_state->__pyx_n_s_line);
  Py_CLEAR(clear_module_state->__pyx_n_u_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_lineEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_lineEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_lineStart);
  Py_CLEAR(clear_module_state->__pyx_n_u_lineStart);
  Py_CLEAR(clear_module_state->__pyx_kp_u_line_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_line_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_column);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_lineno);
  Py_CLEAR(clear_module_state->__pyx_n_u_lineno);
  Py_CLEAR(clear_module_state->__pyx_kp_u_lineno_col_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_listAllMatches);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_str_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_literalStringClass);
  Py_CLEAR(clear_module_state->__pyx_n_u_literal_string_class);
  Py_CLEAR(clear_module_state->__pyx_n_s_loc);
  Py_CLEAR(clear_module_state->__pyx_n_u_loc);
  Py_CLEAR(clear_module_state->__pyx_n_s_loc1);
  Py_CLEAR(clear_module_state->__pyx_n_s_loc2);
  Py_CLEAR(clear_module_state->__pyx_n_s_locMarker);
  Py_CLEAR(clear_module_state->__pyx_n_s_loc_in_suffix);
  Py_CLEAR(clear_module_state->__pyx_n_s_locatedExpr);
  Py_CLEAR(clear_module_state->__pyx_n_u_locatedExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_locatedExpr_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_locator);
  Py_CLEAR(clear_module_state->__pyx_n_s_locn);
  Py_CLEAR(clear_module_state->__pyx_n_u_locn_end);
  Py_CLEAR(clear_module_state->__pyx_n_u_locn_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_longest);
  Py_CLEAR(clear_module_state->__pyx_n_s_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_lookup_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_lookup_bools);
  Py_CLEAR(clear_module_state->__pyx_n_s_lower);
  Py_CLEAR(clear_module_state->__pyx_n_s_lpar);
  Py_CLEAR(clear_module_state->__pyx_n_s_lshift);
  Py_CLEAR(clear_module_state->__pyx_n_s_lstrip);
  Py_CLEAR(clear_module_state->__pyx_n_s_mac_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_u_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_makeHTMLTags);
  Py_CLEAR(clear_module_state->__pyx_n_u_makeHTMLTags);
  Py_CLEAR(clear_module_state->__pyx_n_s_makeOptionalList);
  Py_CLEAR(clear_module_state->__pyx_n_s_makeTags);
  Py_CLEAR(clear_module_state->__pyx_n_s_makeTags_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_makeXMLTags);
  Py_CLEAR(clear_module_state->__pyx_n_u_makeXMLTags);
  Py_CLEAR(clear_module_state->__pyx_n_s_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_markInputline);
  Py_CLEAR(clear_module_state->__pyx_n_s_markerString);
  Py_CLEAR(clear_module_state->__pyx_n_s_masks);
  Py_CLEAR(clear_module_state->__pyx_n_s_mat);
  Py_CLEAR(clear_module_state->__pyx_n_s_match);
  Py_CLEAR(clear_module_state->__pyx_n_u_match);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchLen);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchOnlyAtCol);
  Py_CLEAR(clear_module_state->__pyx_n_u_matchOnlyAtCol);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchOnlyAtCol_locals_verifyCol);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchOrder);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchPreviousExpr);
  Py_CLEAR(clear_module_state->__pyx_n_u_matchPreviousExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchPreviousExpr_locals_copyTok);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchPreviousExpr_locals_copyTok_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchPreviousLiteral);
  Py_CLEAR(clear_module_state->__pyx_n_u_matchPreviousLiteral);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchPreviousLiteral_locals_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchPreviousLiteral_locals_copy_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchString);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchTokens);
  Py_CLEAR(clear_module_state->__pyx_n_s_matchWhite);
  Py_CLEAR(clear_module_state->__pyx_n_s_match_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_match_stringloc);
  Py_CLEAR(clear_module_state->__pyx_kp_u_matched_token_not_at_column_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_matches);
  Py_CLEAR(clear_module_state->__pyx_n_s_max);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxExcLoc);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxException);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxLen);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxMatches);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxMismatches);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxSpecified);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxargs);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxint);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxlen);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxloc);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxsize);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxsplit);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxunicode);
  Py_CLEAR(clear_module_state->__pyx_n_s_mayIndexError);
  Py_CLEAR(clear_module_state->__pyx_n_s_mayReturnEmpty);
  Py_CLEAR(clear_module_state->__pyx_n_s_merged);
  Py_CLEAR(clear_module_state->__pyx_n_s_message);
  Py_CLEAR(clear_module_state->__pyx_n_u_message);
  Py_CLEAR(clear_module_state->__pyx_n_s_metaclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_methodCall);
  Py_CLEAR(clear_module_state->__pyx_n_s_min);
  Py_CLEAR(clear_module_state->__pyx_n_s_minElements);
  Py_CLEAR(clear_module_state->__pyx_n_s_minLen);
  Py_CLEAR(clear_module_state->__pyx_kp_u_mismatches);
  Py_CLEAR(clear_module_state->__pyx_n_s_mismatches_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_mismatches_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_missing);
  Py_CLEAR(clear_module_state->__pyx_n_s_missing_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_mixed_IPv6_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_mixed_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_mixed_ipv6_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_modal);
  Py_CLEAR(clear_module_state->__pyx_n_s_modalResults);
  Py_CLEAR(clear_module_state->__pyx_n_s_module);
  Py_CLEAR(clear_module_state->__pyx_kp_u_module_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_mro);
  Py_CLEAR(clear_module_state->__pyx_n_s_mro_entries);
  Py_CLEAR(clear_module_state->__pyx_n_s_msg);
  Py_CLEAR(clear_module_state->__pyx_n_u_msg);
  Py_CLEAR(clear_module_state->__pyx_n_s_mul);
  Py_CLEAR(clear_module_state->__pyx_n_s_multiline);
  Py_CLEAR(clear_module_state->__pyx_n_s_multioptionals);
  Py_CLEAR(clear_module_state->__pyx_n_s_multirequired);
  Py_CLEAR(clear_module_state->__pyx_n_s_mustMatchTheseTokens);
  Py_CLEAR(clear_module_state->__pyx_kp_u_must_be);
  Py_CLEAR(clear_module_state->__pyx_n_s_must_skip);
  Py_CLEAR(clear_module_state->__pyx_n_s_mylen);
  Py_CLEAR(clear_module_state->__pyx_n_s_n);
  Py_CLEAR(clear_module_state->__pyx_kp_u_n_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_n_n);
  Py_CLEAR(clear_module_state->__pyx_kp_u_n_r);
  Py_CLEAR(clear_module_state->__pyx_kp_u_n_r_x_x_0_9a_fA_F);
  Py_CLEAR(clear_module_state->__pyx_kp_u_n_r_x_x_0_9a_fA_F_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_u_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_namedItems);
  Py_CLEAR(clear_module_state->__pyx_n_s_namedItemsOnly);
  Py_CLEAR(clear_module_state->__pyx_n_s_namespace);
  Py_CLEAR(clear_module_state->__pyx_kp_s_namespace_class_for_classes_use);
  Py_CLEAR(clear_module_state->__pyx_n_s_ne);
  Py_CLEAR(clear_module_state->__pyx_n_u_negate);
  Py_CLEAR(clear_module_state->__pyx_kp_u_nested);
  Py_CLEAR(clear_module_state->__pyx_n_s_nestedExpr);
  Py_CLEAR(clear_module_state->__pyx_n_u_nestedExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_nestedExpr_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_n_s_new_loc);
  Py_CLEAR(clear_module_state->__pyx_n_s_newloc);
  Py_CLEAR(clear_module_state->__pyx_n_s_newself);
  Py_CLEAR(clear_module_state->__pyx_n_s_nextCR);
  Py_CLEAR(clear_module_state->__pyx_n_s_nextLevelIndent);
  Py_CLEAR(clear_module_state->__pyx_n_s_nextLoc);
  Py_CLEAR(clear_module_state->__pyx_n_s_next_linebreak_loc);
  Py_CLEAR(clear_module_state->__pyx_n_s_nextloc);
  Py_CLEAR(clear_module_state->__pyx_n_s_nl);
  Py_CLEAR(clear_module_state->__pyx_kp_u_no_defined_alternatives_to_match);
  Py_CLEAR(clear_module_state->__pyx_kp_u_no_matching_attribute);
  Py_CLEAR(clear_module_state->__pyx_kp_u_no_validation_for_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonzero);
  Py_CLEAR(clear_module_state->__pyx_n_s_notChars);
  Py_CLEAR(clear_module_state->__pyx_kp_u_not_a_peer_entry);
  Py_CLEAR(clear_module_state->__pyx_kp_u_not_a_subentry);
  Py_CLEAR(clear_module_state->__pyx_kp_u_not_an_unindent);
  Py_CLEAR(clear_module_state->__pyx_n_s_not_ender);
  Py_CLEAR(clear_module_state->__pyx_n_s_not_in_cache);
  Py_CLEAR(clear_module_state->__pyx_kp_u_not_preceded_by);
  Py_CLEAR(clear_module_state->__pyx_n_s_notchars);
  Py_CLEAR(clear_module_state->__pyx_n_s_nullDebugAction);
  Py_CLEAR(clear_module_state->__pyx_n_u_nullDebugAction);
  Py_CLEAR(clear_module_state->__pyx_kp_u_null_string_passed_to_Keyword_us);
  Py_CLEAR(clear_module_state->__pyx_kp_u_null_string_passed_to_Literal_us);
  Py_CLEAR(clear_module_state->__pyx_kp_u_null_string_passed_to_Regex_use);
  Py_CLEAR(clear_module_state->__pyx_n_s_number);
  Py_CLEAR(clear_module_state->__pyx_n_s_nums);
  Py_CLEAR(clear_module_state->__pyx_n_u_nums);
  Py_CLEAR(clear_module_state->__pyx_n_s_o);
  Py_CLEAR(clear_module_state->__pyx_n_s_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_occurrences);
  Py_CLEAR(clear_module_state->__pyx_n_s_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_on);
  Py_CLEAR(clear_module_state->__pyx_n_s_oneOf);
  Py_CLEAR(clear_module_state->__pyx_n_u_oneOf);
  Py_CLEAR(clear_module_state->__pyx_n_s_oneOf_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_oneOf_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_kp_u_only_1_or_2_index_arguments_supp);
  Py_CLEAR(clear_module_state->__pyx_n_s_opAssoc);
  Py_CLEAR(clear_module_state->__pyx_n_u_opAssoc);
  Py_CLEAR(clear_module_state->__pyx_n_s_opExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_opExpr1);
  Py_CLEAR(clear_module_state->__pyx_n_s_opExpr2);
  Py_CLEAR(clear_module_state->__pyx_n_s_opList);
  Py_CLEAR(clear_module_state->__pyx_n_s_open);
  Py_CLEAR(clear_module_state->__pyx_n_s_openTag);
  Py_CLEAR(clear_module_state->__pyx_n_s_opener);
  Py_CLEAR(clear_module_state->__pyx_kp_u_opening_and_closing_arguments_mu);
  Py_CLEAR(clear_module_state->__pyx_kp_u_opening_and_closing_strings_cann);
  Py_CLEAR(clear_module_state->__pyx_n_s_operDef);
  Py_CLEAR(clear_module_state->__pyx_n_s_operator);
  Py_CLEAR(clear_module_state->__pyx_n_s_operatorPrecedence);
  Py_CLEAR(clear_module_state->__pyx_n_u_operatorPrecedence);
  Py_CLEAR(clear_module_state->__pyx_kp_u_operator_must_be_unary_1_binary);
  Py_CLEAR(clear_module_state->__pyx_kp_u_operator_must_indicate_right_or);
  Py_CLEAR(clear_module_state->__pyx_n_s_opt1);
  Py_CLEAR(clear_module_state->__pyx_n_s_opt1map);
  Py_CLEAR(clear_module_state->__pyx_n_s_opt2);
  Py_CLEAR(clear_module_state->__pyx_n_s_optElements);
  Py_CLEAR(clear_module_state->__pyx_n_s_optionals);
  Py_CLEAR(clear_module_state->__pyx_n_s_or);
  Py_CLEAR(clear_module_state->__pyx_n_s_ordereddict);
  Py_CLEAR(clear_module_state->__pyx_n_u_original);
  Py_CLEAR(clear_module_state->__pyx_n_s_originalParseMethod);
  Py_CLEAR(clear_module_state->__pyx_n_u_originalParseMethod);
  Py_CLEAR(clear_module_state->__pyx_n_s_originalTextFor);
  Py_CLEAR(clear_module_state->__pyx_n_u_originalTextFor);
  Py_CLEAR(clear_module_state->__pyx_n_s_originalTextFor_locals_extractTe);
  Py_CLEAR(clear_module_state->__pyx_n_s_originalTextFor_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_original_end);
  Py_CLEAR(clear_module_state->__pyx_n_u_original_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_original_start);
  Py_CLEAR(clear_module_state->__pyx_n_u_original_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_os_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_other);
  Py_CLEAR(clear_module_state->__pyx_n_s_other_instring);
  Py_CLEAR(clear_module_state->__pyx_n_s_otherdictitems);
  Py_CLEAR(clear_module_state->__pyx_n_s_otheritems);
  Py_CLEAR(clear_module_state->__pyx_n_s_out);
  Py_CLEAR(clear_module_state->__pyx_n_s_outer_parent_usefullness_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_overlap);
  Py_CLEAR(clear_module_state->__pyx_n_s_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_p1);
  Py_CLEAR(clear_module_state->__pyx_n_s_p2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pa);
  Py_CLEAR(clear_module_state->__pyx_n_s_paArgs);
  Py_CLEAR(clear_module_state->__pyx_n_s_pa_call_line_synth);
  Py_CLEAR(clear_module_state->__pyx_n_s_packratEnabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_packrat_cache);
  Py_CLEAR(clear_module_state->__pyx_n_s_packrat_cache_lock);
  Py_CLEAR(clear_module_state->__pyx_n_s_packrat_cache_stats);
  Py_CLEAR(clear_module_state->__pyx_n_s_packrat_context);
  Py_CLEAR(clear_module_state->__pyx_n_u_packrat_enabled);
  Py_CLEAR(clear_module_state->__pyx_n_u_packrat_parse);
  Py_CLEAR(clear_module_state->__pyx_n_s_par);
  Py_CLEAR(clear_module_state->__pyx_n_s_parse);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseAll);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseCache);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseElementClass);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseElementList);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseElementTrace);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseFile);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseFn);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_u_parseImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseImplAsGroupList);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseImplAsMatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseIncremental);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseMethod);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseNoCache);
  Py_CLEAR(clear_module_state->__pyx_n_u_parseNoCache);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseString);
  Py_CLEAR(clear_module_state->__pyx_n_s_parseWithTabs);
  Py_CLEAR(clear_module_state->__pyx_kp_u_parse_action);
  Py_CLEAR(clear_module_state->__pyx_n_s_parse_action_exc);
  Py_CLEAR(clear_module_state->__pyx_kp_u_parse_actions_must_be_callable);
  Py_CLEAR(clear_module_state->__pyx_n_s_parse_element_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_parserElement);
  Py_CLEAR(clear_module_state->__pyx_n_u_parserElement);
  Py_CLEAR(clear_module_state->__pyx_n_s_pattern);
  Py_CLEAR(clear_module_state->__pyx_n_u_pattern);
  Py_CLEAR(clear_module_state->__pyx_n_s_pbe);
  Py_CLEAR(clear_module_state->__pyx_n_s_pdb);
  Py_CLEAR(clear_module_state->__pyx_n_s_pe);
  Py_CLEAR(clear_module_state->__pyx_n_s_pop);
  Py_CLEAR(clear_module_state->__pyx_kp_u_pop_got_an_unexpected_keyword_ar);
  Py_CLEAR(clear_module_state->__pyx_n_s_popitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_popleft);
  Py_CLEAR(clear_module_state->__pyx_n_s_position);
  Py_CLEAR(clear_module_state->__pyx_n_s_postParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_pp_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_pprint);
  Py_CLEAR(clear_module_state->__pyx_n_s_preParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_prefix_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_prefix_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_prefixes_and_suffixes);
  Py_CLEAR(clear_module_state->__pyx_n_s_preloc);
  Py_CLEAR(clear_module_state->__pyx_n_s_prepare);
  Py_CLEAR(clear_module_state->__pyx_n_s_preparseFn);
  Py_CLEAR(clear_module_state->__pyx_kp_u_prev);
  Py_CLEAR(clear_module_state->__pyx_n_s_print);
  Py_CLEAR(clear_module_state->__pyx_n_s_printResults);
  Py_CLEAR(clear_module_state->__pyx_n_s_print_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_printable);
  Py_CLEAR(clear_module_state->__pyx_n_s_printables);
  Py_CLEAR(clear_module_state->__pyx_n_u_printables);
  Py_CLEAR(clear_module_state->__pyx_n_s_pstr);
  Py_CLEAR(clear_module_state->__pyx_n_u_pstr);
  Py_CLEAR(clear_module_state->__pyx_n_s_punc8bit);
  Py_CLEAR(clear_module_state->__pyx_n_u_punc8bit);
  Py_CLEAR(clear_module_state->__pyx_n_s_py_repr);
  Py_CLEAR(clear_module_state->__pyx_n_s_py_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_common);
  Py_CLEAR(clear_module_state->__pyx_n_u_pyparsing_common);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_common_convertToDate);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_common_convertToDate_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_common_convertToDateti);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_common_convertToDateti_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_common_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_common_lambda_locals_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_common_stripHTMLTags);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode);
  Py_CLEAR(clear_module_state->__pyx_n_u_pyparsing_unicode);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Arabic);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_CJK);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Chinese);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Cyrillic);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Devanagari);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Greek);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Hebrew);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Japanese);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Japanese_Hirag);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Japanese_Kanji);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Japanese_Katak);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Korean);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Latin1);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_LatinA);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_LatinB);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyparsing_unicode_Thai);
  Py_CLEAR(clear_module_state->__pyx_n_s_pythonStyleComment);
  Py_CLEAR(clear_module_state->__pyx_n_u_pythonStyleComment);
  Py_CLEAR(clear_module_state->__pyx_n_s_qualname);
  Py_CLEAR(clear_module_state->__pyx_n_s_quoteChar);
  Py_CLEAR(clear_module_state->__pyx_n_s_quoteCharLen);
  Py_CLEAR(clear_module_state->__pyx_kp_u_quoteChar_cannot_be_the_empty_st);
  Py_CLEAR(clear_module_state->__pyx_n_s_quotedString);
  Py_CLEAR(clear_module_state->__pyx_n_u_quotedString);
  Py_CLEAR(clear_module_state->__pyx_kp_u_quotedString_using_single_or_dou);
  Py_CLEAR(clear_module_state->__pyx_kp_u_quoted_string_starting_with);
  Py_CLEAR(clear_module_state->__pyx_n_u_r);
  Py_CLEAR(clear_module_state->__pyx_kp_u_r_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_r_object_is_not_iterable);
  Py_CLEAR(clear_module_state->__pyx_n_s_radd);
  Py_CLEAR(clear_module_state->__pyx_n_s_rand);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_ranges);
  Py_CLEAR(clear_module_state->__pyx_n_s_re);
  Py_CLEAR(clear_module_state->__pyx_n_u_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_reBracketExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_reString);
  Py_CLEAR(clear_module_state->__pyx_n_s_re_match);
  Py_CLEAR(clear_module_state->__pyx_n_s_read);
  Py_CLEAR(clear_module_state->__pyx_n_s_real);
  Py_CLEAR(clear_module_state->__pyx_kp_u_real_number);
  Py_CLEAR(clear_module_state->__pyx_kp_u_real_number_with_scientific_nota);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_ref);
  Py_CLEAR(clear_module_state->__pyx_n_s_register);
  Py_CLEAR(clear_module_state->__pyx_n_s_remove);
  Py_CLEAR(clear_module_state->__pyx_n_s_removeQuotes);
  Py_CLEAR(clear_module_state->__pyx_n_u_removeQuotes);
  Py_CLEAR(clear_module_state->__pyx_n_s_removed);
  Py_CLEAR(clear_module_state->__pyx_n_s_rep);
  Py_CLEAR(clear_module_state->__pyx_n_s_repl);
  Py_CLEAR(clear_module_state->__pyx_n_s_replStr);
  Py_CLEAR(clear_module_state->__pyx_n_s_replace);
  Py_CLEAR(clear_module_state->__pyx_n_s_replaceHTMLEntity);
  Py_CLEAR(clear_module_state->__pyx_n_u_replaceHTMLEntity);
  Py_CLEAR(clear_module_state->__pyx_n_s_replaceWith);
  Py_CLEAR(clear_module_state->__pyx_n_u_replaceWith);
  Py_CLEAR(clear_module_state->__pyx_n_s_replaceWith_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_repr);
  Py_CLEAR(clear_module_state->__pyx_n_s_repr_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_req);
  Py_CLEAR(clear_module_state->__pyx_n_s_required);
  Py_CLEAR(clear_module_state->__pyx_n_s_res);
  Py_CLEAR(clear_module_state->__pyx_n_s_resTag);
  Py_CLEAR(clear_module_state->__pyx_n_s_reset);
  Py_CLEAR(clear_module_state->__pyx_n_s_resetCache);
  Py_CLEAR(clear_module_state->__pyx_n_s_reset_pyparsing_context);
  Py_CLEAR(clear_module_state->__pyx_n_s_reset_stack);
  Py_CLEAR(clear_module_state->__pyx_n_s_resname);
  Py_CLEAR(clear_module_state->__pyx_n_s_restOfLine);
  Py_CLEAR(clear_module_state->__pyx_n_u_restOfLine);
  Py_CLEAR(clear_module_state->__pyx_kp_u_rest_of_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_restore);
  Py_CLEAR(clear_module_state->__pyx_n_s_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_resultlist);
  Py_CLEAR(clear_module_state->__pyx_n_s_results);
  Py_CLEAR(clear_module_state->__pyx_n_s_resultsName);
  Py_CLEAR(clear_module_state->__pyx_n_s_ret);
  Py_CLEAR(clear_module_state->__pyx_n_s_retTokens);
  Py_CLEAR(clear_module_state->__pyx_n_s_retToks);
  Py_CLEAR(clear_module_state->__pyx_kp_u_ret_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ret_toks);
  Py_CLEAR(clear_module_state->__pyx_n_s_retobj);
  Py_CLEAR(clear_module_state->__pyx_n_s_retreat);
  Py_CLEAR(clear_module_state->__pyx_n_s_returnString);
  Py_CLEAR(clear_module_state->__pyx_n_s_reverse);
  Py_CLEAR(clear_module_state->__pyx_n_s_reversed);
  Py_CLEAR(clear_module_state->__pyx_n_s_reversed_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_reversed_instring);
  Py_CLEAR(clear_module_state->__pyx_n_s_rfind);
  Py_CLEAR(clear_module_state->__pyx_n_s_rightLeftAssoc);
  Py_CLEAR(clear_module_state->__pyx_n_s_rmul);
  Py_CLEAR(clear_module_state->__pyx_n_s_rne);
  Py_CLEAR(clear_module_state->__pyx_n_s_ror);
  Py_CLEAR(clear_module_state->__pyx_n_s_rpar);
  Py_CLEAR(clear_module_state->__pyx_n_s_rpt);
  Py_CLEAR(clear_module_state->__pyx_n_s_rr);
  Py_CLEAR(clear_module_state->__pyx_n_s_rstrip);
  Py_CLEAR(clear_module_state->__pyx_n_s_rsub);
  Py_CLEAR(clear_module_state->__pyx_n_s_runTests);
  Py_CLEAR(clear_module_state->__pyx_n_s_run_test_results);
  Py_CLEAR(clear_module_state->__pyx_n_s_run_test_success);
  Py_CLEAR(clear_module_state->__pyx_n_s_run_tests_report);
  Py_CLEAR(clear_module_state->__pyx_n_s_rxor);
  Py_CLEAR(clear_module_state->__pyx_n_s_s);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_10);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_4);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_5);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_6);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_7);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_8);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_9);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_S);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_class);
  Py_CLEAR(clear_module_state->__pyx_n_s_s_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_s_pl_sl);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_s_term);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_term);
  Py_CLEAR(clear_module_state->__pyx_n_s_save);
  Py_CLEAR(clear_module_state->__pyx_n_s_saveAsList);
  Py_CLEAR(clear_module_state->__pyx_n_s_save_context);
  Py_CLEAR(clear_module_state->__pyx_n_s_savelist);
  Py_CLEAR(clear_module_state->__pyx_n_s_scanString);
  Py_CLEAR(clear_module_state->__pyx_n_s_sci_real);
  Py_CLEAR(clear_module_state->__pyx_n_s_se);
  Py_CLEAR(clear_module_state->__pyx_n_s_searchString);
  Py_CLEAR(clear_module_state->__pyx_kp_u_second_tuple_value_must_be_great);
  Py_CLEAR(clear_module_state->__pyx_n_s_seen);
  Py_CLEAR(clear_module_state->__pyx_n_u_select);
  Py_CLEAR(clear_module_state->__pyx_n_s_selectToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_n_u_self);
  Py_CLEAR(clear_module_state->__pyx_n_s_selfTag);
  Py_CLEAR(clear_module_state->__pyx_n_s_self_expr_parse);
  Py_CLEAR(clear_module_state->__pyx_n_s_self_failOn_canParseNext);
  Py_CLEAR(clear_module_state->__pyx_n_s_self_ignoreExpr_tryParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_self_skip_ignorables);
  Py_CLEAR(clear_module_state->__pyx_n_s_self_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_send);
  Py_CLEAR(clear_module_state->__pyx_n_s_sep);
  Py_CLEAR(clear_module_state->__pyx_n_s_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_setAdaptiveMode);
  Py_CLEAR(clear_module_state->__pyx_n_s_setBreak);
  Py_CLEAR(clear_module_state->__pyx_n_s_setDebug);
  Py_CLEAR(clear_module_state->__pyx_n_s_setDebugActions);
  Py_CLEAR(clear_module_state->__pyx_n_s_setDefaultKeywordChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_setDefaultWhitespaceChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_setFailAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_setName);
  Py_CLEAR(clear_module_state->__pyx_n_s_setOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_setParseAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_setResultsName);
  Py_CLEAR(clear_module_state->__pyx_n_s_setResultsName_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_setWhitespaceChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_trace);
  Py_CLEAR(clear_module_state->__pyx_n_s_setitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_sglQuotedString);
  Py_CLEAR(clear_module_state->__pyx_n_u_sglQuotedString);
  Py_CLEAR(clear_module_state->__pyx_kp_u_short_IPv6_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_short_ipv6_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_should_cache_incremental_succes);
  Py_CLEAR(clear_module_state->__pyx_n_s_show_skip);
  Py_CLEAR(clear_module_state->__pyx_kp_u_signed_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_signed_integer_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_simpleSQL);
  Py_CLEAR(clear_module_state->__pyx_n_s_singleArgBuiltins);
  Py_CLEAR(clear_module_state->__pyx_n_s_singleChar);
  Py_CLEAR(clear_module_state->__pyx_n_s_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_skipIgnorables);
  Py_CLEAR(clear_module_state->__pyx_n_s_skipWhitespace);
  Py_CLEAR(clear_module_state->__pyx_kp_u_skipped);
  Py_CLEAR(clear_module_state->__pyx_n_s_skipped_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_skipped_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_skipped_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_skipper);
  Py_CLEAR(clear_module_state->__pyx_n_s_skipresult);
  Py_CLEAR(clear_module_state->__pyx_n_s_skiptext);
  Py_CLEAR(clear_module_state->__pyx_n_s_skipto_arg);
  Py_CLEAR(clear_module_state->__pyx_n_s_slots);
  Py_CLEAR(clear_module_state->__pyx_n_s_smExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_sort);
  Py_CLEAR(clear_module_state->__pyx_n_s_sorted);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_split);
  Py_CLEAR(clear_module_state->__pyx_n_s_splitlines);
  Py_CLEAR(clear_module_state->__pyx_n_s_splits);
  Py_CLEAR(clear_module_state->__pyx_n_s_srange);
  Py_CLEAR(clear_module_state->__pyx_n_u_srange);
  Py_CLEAR(clear_module_state->__pyx_n_s_srange_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_srange_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_srange_locals_lambda_locals_gene);
  Py_CLEAR(clear_module_state->__pyx_n_s_src);
  Py_CLEAR(clear_module_state->__pyx_n_s_sre_constants);
  Py_CLEAR(clear_module_state->__pyx_n_s_stacklevel);
  Py_CLEAR(clear_module_state->__pyx_n_s_start);
  Py_CLEAR(clear_module_state->__pyx_n_u_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_startAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_startloc);
  Py_CLEAR(clear_module_state->__pyx_n_s_startswith);
  Py_CLEAR(clear_module_state->__pyx_n_s_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_staticmethod);
  Py_CLEAR(clear_module_state->__pyx_n_s_stderr);
  Py_CLEAR(clear_module_state->__pyx_n_s_stdout);
  Py_CLEAR(clear_module_state->__pyx_n_s_still_reset_cache);
  Py_CLEAR(clear_module_state->__pyx_n_s_stopOn);
  Py_CLEAR(clear_module_state->__pyx_n_s_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_strRepr);
  Py_CLEAR(clear_module_state->__pyx_n_s_str_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_streamline);
  Py_CLEAR(clear_module_state->__pyx_n_s_streamlined);
  Py_CLEAR(clear_module_state->__pyx_n_s_strg);
  Py_CLEAR(clear_module_state->__pyx_n_s_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_stringEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_stringEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_stringStart);
  Py_CLEAR(clear_module_state->__pyx_n_u_stringStart);
  Py_CLEAR(clear_module_state->__pyx_kp_u_string_enclosed_in_double_quotes);
  Py_CLEAR(clear_module_state->__pyx_kp_u_string_enclosed_in_single_quotes);
  Py_CLEAR(clear_module_state->__pyx_n_s_strip);
  Py_CLEAR(clear_module_state->__pyx_n_s_stripHTMLTags);
  Py_CLEAR(clear_module_state->__pyx_n_s_strptime);
  Py_CLEAR(clear_module_state->__pyx_n_s_strs);
  Py_CLEAR(clear_module_state->__pyx_n_s_sub);
  Py_CLEAR(clear_module_state->__pyx_n_s_subRecCheckList);
  Py_CLEAR(clear_module_state->__pyx_n_s_sub_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_success);
  Py_CLEAR(clear_module_state->__pyx_n_s_successAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_suffix_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_suffix_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_sum);
  Py_CLEAR(clear_module_state->__pyx_kp_u_sum_len_sorted_reversed_list_tup);
  Py_CLEAR(clear_module_state->__pyx_n_s_super);
  Py_CLEAR(clear_module_state->__pyx_n_s_suppress);
  Py_CLEAR(clear_module_state->__pyx_n_s_suppress_GT);
  Py_CLEAR(clear_module_state->__pyx_n_s_suppress_LT);
  Py_CLEAR(clear_module_state->__pyx_n_s_symbols);
  Py_CLEAR(clear_module_state->__pyx_n_s_sys);
  Py_CLEAR(clear_module_state->__pyx_n_s_system_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_t);
  Py_CLEAR(clear_module_state->__pyx_kp_u_t_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_tableName);
  Py_CLEAR(clear_module_state->__pyx_n_s_tableNameList);
  Py_CLEAR(clear_module_state->__pyx_n_u_tables);
  Py_CLEAR(clear_module_state->__pyx_n_s_tag);
  Py_CLEAR(clear_module_state->__pyx_n_u_tag);
  Py_CLEAR(clear_module_state->__pyx_n_s_tagAttrName);
  Py_CLEAR(clear_module_state->__pyx_n_s_tagAttrValue);
  Py_CLEAR(clear_module_state->__pyx_n_s_tagStr);
  Py_CLEAR(clear_module_state->__pyx_n_s_tag_body);
  Py_CLEAR(clear_module_state->__pyx_n_s_tb);
  Py_CLEAR(clear_module_state->__pyx_n_s_tb_next);
  Py_CLEAR(clear_module_state->__pyx_n_s_termName);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_testString);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_expr);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_tests);
  Py_CLEAR(clear_module_state->__pyx_n_s_tflat);
  Py_CLEAR(clear_module_state->__pyx_n_s_theseTokens);
  Py_CLEAR(clear_module_state->__pyx_n_s_thisExpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_thisFunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_thiscol);
  Py_CLEAR(clear_module_state->__pyx_n_s_thread);
  Py_CLEAR(clear_module_state->__pyx_n_s_threading);
  Py_CLEAR(clear_module_state->__pyx_n_s_throw);
  Py_CLEAR(clear_module_state->__pyx_n_s_throwException);
  Py_CLEAR(clear_module_state->__pyx_n_s_title);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmp);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmpExprs);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmpLoc);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmpOpt);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmpReqd);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmploc);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmptokens);
  Py_CLEAR(clear_module_state->__pyx_n_s_to);
  Py_CLEAR(clear_module_state->__pyx_n_s_toItem);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_symbols);
  Py_CLEAR(clear_module_state->__pyx_n_s_tok);
  Py_CLEAR(clear_module_state->__pyx_n_s_tokenMap);
  Py_CLEAR(clear_module_state->__pyx_n_u_tokenMap);
  Py_CLEAR(clear_module_state->__pyx_n_s_tokenMap_locals_pa);
  Py_CLEAR(clear_module_state->__pyx_n_s_tokenlist);
  Py_CLEAR(clear_module_state->__pyx_n_s_tokens);
  Py_CLEAR(clear_module_state->__pyx_n_s_tokensStart);
  Py_CLEAR(clear_module_state->__pyx_n_s_toklist);
  Py_CLEAR(clear_module_state->__pyx_n_s_tokn);
  Py_CLEAR(clear_module_state->__pyx_n_s_toks);
  Py_CLEAR(clear_module_state->__pyx_n_s_traceParseAction);
  Py_CLEAR(clear_module_state->__pyx_n_u_traceParseAction);
  Py_CLEAR(clear_module_state->__pyx_n_s_traceParseAction_locals_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_u_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_traceback_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_transformString);
  Py_CLEAR(clear_module_state->__pyx_n_s_trim_arity);
  Py_CLEAR(clear_module_state->__pyx_n_s_trim_arity_locals_extract_stack);
  Py_CLEAR(clear_module_state->__pyx_n_s_trim_arity_locals_extract_tb);
  Py_CLEAR(clear_module_state->__pyx_n_s_trim_arity_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_trim_arity_locals_wrapper);
  Py_CLEAR(clear_module_state->__pyx_n_s_trim_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_tryParse);
  Py_CLEAR(clear_module_state->__pyx_n_s_try_not_ender);
  Py_CLEAR(clear_module_state->__pyx_n_s_tup);
  Py_CLEAR(clear_module_state->__pyx_n_s_types);
  Py_CLEAR(clear_module_state->__pyx_n_u_u);
  Py_CLEAR(clear_module_state->__pyx_n_s_ungroup);
  Py_CLEAR(clear_module_state->__pyx_n_u_ungroup);
  Py_CLEAR(clear_module_state->__pyx_n_s_ungroup_locals_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_unichr);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicode);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicodeString);
  Py_CLEAR(clear_module_state->__pyx_n_u_unicodeString);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicode_set);
  Py_CLEAR(clear_module_state->__pyx_n_u_unicode_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicode_set__get_chars_for_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicode_set_alphanums);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicode_set_alphas);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicode_set_nums);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicode_set_printables);
  Py_CLEAR(clear_module_state->__pyx_kp_u_unicode_string_literal);
  Py_CLEAR(clear_module_state->__pyx_n_s_unquoteResults);
  Py_CLEAR(clear_module_state->__pyx_n_s_upcaseTokens);
  Py_CLEAR(clear_module_state->__pyx_n_u_upcaseTokens);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_update_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_update_furthest_loc_for_regex);
  Py_CLEAR(clear_module_state->__pyx_n_s_update_wrapper);
  Py_CLEAR(clear_module_state->__pyx_n_s_upper);
  Py_CLEAR(clear_module_state->__pyx_n_s_usage);
  Py_CLEAR(clear_module_state->__pyx_n_s_usage_weight);
  Py_CLEAR(clear_module_state->__pyx_n_s_useRegex);
  Py_CLEAR(clear_module_state->__pyx_kp_u_use_of_expression_without_follow);
  Py_CLEAR(clear_module_state->__pyx_kp_s_user_throwable_exception_thrown);
  Py_CLEAR(clear_module_state->__pyx_n_s_ustr);
  Py_CLEAR(clear_module_state->__pyx_n_u_utf8);
  Py_CLEAR(clear_module_state->__pyx_n_s_uuid);
  Py_CLEAR(clear_module_state->__pyx_n_s_v);
  Py_CLEAR(clear_module_state->__pyx_n_s_validate);
  Py_CLEAR(clear_module_state->__pyx_n_s_validateTrace);
  Py_CLEAR(clear_module_state->__pyx_n_s_value);
  Py_CLEAR(clear_module_state->__pyx_n_u_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_vars);
  Py_CLEAR(clear_module_state->__pyx_n_s_ve);
  Py_CLEAR(clear_module_state->__pyx_n_s_verbose);
  Py_CLEAR(clear_module_state->__pyx_n_s_verbose_stacktrace);
  Py_CLEAR(clear_module_state->__pyx_n_s_verifyCol);
  Py_CLEAR(clear_module_state->__pyx_n_s_version);
  Py_CLEAR(clear_module_state->__pyx_n_u_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_versionTime);
  Py_CLEAR(clear_module_state->__pyx_n_u_versionTime);
  Py_CLEAR(clear_module_state->__pyx_n_s_version_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_vlist);
  Py_CLEAR(clear_module_state->__pyx_n_s_vv);
  Py_CLEAR(clear_module_state->__pyx_n_s_warn);
  Py_CLEAR(clear_module_state->__pyx_n_u_warn_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_warn_multiple_tokens_in_named_al);
  Py_CLEAR(clear_module_state->__pyx_n_u_warn_multiple_tokens_in_named_al);
  Py_CLEAR(clear_module_state->__pyx_n_s_warn_name_set_on_empty_Forward);
  Py_CLEAR(clear_module_state->__pyx_n_u_warn_name_set_on_empty_Forward);
  Py_CLEAR(clear_module_state->__pyx_n_s_warn_on_incremental_multiline_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_warn_on_multiple_string_args_to);
  Py_CLEAR(clear_module_state->__pyx_n_s_warn_ungrouped_named_tokens_in_c);
  Py_CLEAR(clear_module_state->__pyx_n_u_warn_ungrouped_named_tokens_in_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_warnings);
  Py_CLEAR(clear_module_state->__pyx_n_s_weakref);
  Py_CLEAR(clear_module_state->__pyx_n_s_whiteChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_whiteStrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_whitespace);
  Py_CLEAR(clear_module_state->__pyx_n_s_withAttribute);
  Py_CLEAR(clear_module_state->__pyx_n_u_withAttribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_withClass);
  Py_CLEAR(clear_module_state->__pyx_n_u_withClass);
  Py_CLEAR(clear_module_state->__pyx_kp_u_with_up_to);
  Py_CLEAR(clear_module_state->__pyx_n_s_wkref);
  Py_CLEAR(clear_module_state->__pyx_n_s_wordChars);
  Py_CLEAR(clear_module_state->__pyx_n_s_wrapper);
  Py_CLEAR(clear_module_state->__pyx_n_u_wrapper);
  Py_CLEAR(clear_module_state->__pyx_n_s_wraps);
  Py_CLEAR(clear_module_state->__pyx_n_s_write);
  Py_CLEAR(clear_module_state->__pyx_n_s_ws);
  Py_CLEAR(clear_module_state->__pyx_n_s_ws_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_wschar);
  Py_CLEAR(clear_module_state->__pyx_n_s_wslit);
  Py_CLEAR(clear_module_state->__pyx_n_s_wt);
  Py_CLEAR(clear_module_state->__pyx_n_s_xml);
  Py_CLEAR(clear_module_state->__pyx_n_s_xmlBodyText);
  Py_CLEAR(clear_module_state->__pyx_n_s_xml_escape);
  Py_CLEAR(clear_module_state->__pyx_n_s_xml_escape_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_xor);
  Py_CLEAR(clear_module_state->__pyx_n_s_xrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_zip);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_2);
  Py_CLEAR(clear_module_state->__pyx_int_3);
  Py_CLEAR(clear_module_state->__pyx_int_4);
  Py_CLEAR(clear_module_state->__pyx_int_5);
  Py_CLEAR(clear_module_state->__pyx_int_6);
  Py_CLEAR(clear_module_state->__pyx_int_7);
  Py_CLEAR(clear_module_state->__pyx_int_8);
  Py_CLEAR(clear_module_state->__pyx_int_11);
  Py_CLEAR(clear_module_state->__pyx_int_16);
  Py_CLEAR(clear_module_state->__pyx_int_32);
  Py_CLEAR(clear_module_state->__pyx_int_92);
  Py_CLEAR(clear_module_state->__pyx_int_126);
  Py_CLEAR(clear_module_state->__pyx_int_128);
  Py_CLEAR(clear_module_state->__pyx_int_160);
  Py_CLEAR(clear_module_state->__pyx_int_255);
  Py_CLEAR(clear_module_state->__pyx_int_256);
  Py_CLEAR(clear_module_state->__pyx_int_383);
  Py_CLEAR(clear_module_state->__pyx_int_384);
  Py_CLEAR(clear_module_state->__pyx_int_591);
  Py_CLEAR(clear_module_state->__pyx_int_880);
  Py_CLEAR(clear_module_state->__pyx_int_1023);
  Py_CLEAR(clear_module_state->__pyx_int_1024);
  Py_CLEAR(clear_module_state->__pyx_int_1279);
  Py_CLEAR(clear_module_state->__pyx_int_1328);
  Py_CLEAR(clear_module_state->__pyx_int_1424);
  Py_CLEAR(clear_module_state->__pyx_int_1535);
  Py_CLEAR(clear_module_state->__pyx_int_1536);
  Py_CLEAR(clear_module_state->__pyx_int_1563);
  Py_CLEAR(clear_module_state->__pyx_int_1566);
  Py_CLEAR(clear_module_state->__pyx_int_1791);
  Py_CLEAR(clear_module_state->__pyx_int_1792);
  Py_CLEAR(clear_module_state->__pyx_int_1919);
  Py_CLEAR(clear_module_state->__pyx_int_2304);
  Py_CLEAR(clear_module_state->__pyx_int_2431);
  Py_CLEAR(clear_module_state->__pyx_int_3585);
  Py_CLEAR(clear_module_state->__pyx_int_3642);
  Py_CLEAR(clear_module_state->__pyx_int_3647);
  Py_CLEAR(clear_module_state->__pyx_int_3675);
  Py_CLEAR(clear_module_state->__pyx_int_4352);
  Py_CLEAR(clear_module_state->__pyx_int_4607);
  Py_CLEAR(clear_module_state->__pyx_int_7936);
  Py_CLEAR(clear_module_state->__pyx_int_7957);
  Py_CLEAR(clear_module_state->__pyx_int_7960);
  Py_CLEAR(clear_module_state->__pyx_int_7965);
  Py_CLEAR(clear_module_state->__pyx_int_7968);
  Py_CLEAR(clear_module_state->__pyx_int_8005);
  Py_CLEAR(clear_module_state->__pyx_int_8008);
  Py_CLEAR(clear_module_state->__pyx_int_8013);
  Py_CLEAR(clear_module_state->__pyx_int_8016);
  Py_CLEAR(clear_module_state->__pyx_int_8023);
  Py_CLEAR(clear_module_state->__pyx_int_8025);
  Py_CLEAR(clear_module_state->__pyx_int_8027);
  Py_CLEAR(clear_module_state->__pyx_int_8029);
  Py_CLEAR(clear_module_state->__pyx_int_8031);
  Py_CLEAR(clear_module_state->__pyx_int_8061);
  Py_CLEAR(clear_module_state->__pyx_int_8064);
  Py_CLEAR(clear_module_state->__pyx_int_8116);
  Py_CLEAR(clear_module_state->__pyx_int_8118);
  Py_CLEAR(clear_module_state->__pyx_int_8132);
  Py_CLEAR(clear_module_state->__pyx_int_8134);
  Py_CLEAR(clear_module_state->__pyx_int_8147);
  Py_CLEAR(clear_module_state->__pyx_int_8150);
  Py_CLEAR(clear_module_state->__pyx_int_8155);
  Py_CLEAR(clear_module_state->__pyx_int_8157);
  Py_CLEAR(clear_module_state->__pyx_int_8175);
  Py_CLEAR(clear_module_state->__pyx_int_8178);
  Py_CLEAR(clear_module_state->__pyx_int_8180);
  Py_CLEAR(clear_module_state->__pyx_int_8182);
  Py_CLEAR(clear_module_state->__pyx_int_8190);
  Py_CLEAR(clear_module_state->__pyx_int_12288);
  Py_CLEAR(clear_module_state->__pyx_int_12351);
  Py_CLEAR(clear_module_state->__pyx_int_12352);
  Py_CLEAR(clear_module_state->__pyx_int_12447);
  Py_CLEAR(clear_module_state->__pyx_int_12448);
  Py_CLEAR(clear_module_state->__pyx_int_12543);
  Py_CLEAR(clear_module_state->__pyx_int_12592);
  Py_CLEAR(clear_module_state->__pyx_int_12687);
  Py_CLEAR(clear_module_state->__pyx_int_19968);
  Py_CLEAR(clear_module_state->__pyx_int_40895);
  Py_CLEAR(clear_module_state->__pyx_int_40959);
  Py_CLEAR(clear_module_state->__pyx_int_43232);
  Py_CLEAR(clear_module_state->__pyx_int_43263);
  Py_CLEAR(clear_module_state->__pyx_int_43360);
  Py_CLEAR(clear_module_state->__pyx_int_43391);
  Py_CLEAR(clear_module_state->__pyx_int_44032);
  Py_CLEAR(clear_module_state->__pyx_int_55215);
  Py_CLEAR(clear_module_state->__pyx_int_55216);
  Py_CLEAR(clear_module_state->__pyx_int_55295);
  Py_CLEAR(clear_module_state->__pyx_int_neg_1);
  Py_CLEAR(clear_module_state->__pyx_slice_);
  Py_CLEAR(clear_module_state->__pyx_tuple__8);
  Py_CLEAR(clear_module_state->__pyx_slice__20);
  Py_CLEAR(clear_module_state->__pyx_slice__21);
  Py_CLEAR(clear_module_state->__pyx_slice__37);
  Py_CLEAR(clear_module_state->__pyx_slice__47);
  Py_CLEAR(clear_module_state->__pyx_slice__55);
  Py_CLEAR(clear_module_state->__pyx_slice__64);
  Py_CLEAR(clear_module_state->__pyx_slice__70);
  Py_CLEAR(clear_module_state->__pyx_slice__81);
  Py_CLEAR(clear_module_state->__pyx_tuple__18);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__32);
  Py_CLEAR(clear_module_state->__pyx_tuple__36);
  Py_CLEAR(clear_module_state->__pyx_tuple__38);
  Py_CLEAR(clear_module_state->__pyx_tuple__39);
  Py_CLEAR(clear_module_state->__pyx_tuple__41);
  Py_CLEAR(clear_module_state->__pyx_tuple__42);
  Py_CLEAR(clear_module_state->__pyx_tuple__44);
  Py_CLEAR(clear_module_state->__pyx_tuple__46);
  Py_CLEAR(clear_module_state->__pyx_tuple__48);
  Py_CLEAR(clear_module_state->__pyx_tuple__50);
  Py_CLEAR(clear_module_state->__pyx_tuple__51);
  Py_CLEAR(clear_module_state->__pyx_tuple__54);
  Py_CLEAR(clear_module_state->__pyx_tuple__56);
  Py_CLEAR(clear_module_state->__pyx_tuple__57);
  Py_CLEAR(clear_module_state->__pyx_tuple__58);
  Py_CLEAR(clear_module_state->__pyx_tuple__59);
  Py_CLEAR(clear_module_state->__pyx_tuple__60);
  Py_CLEAR(clear_module_state->__pyx_tuple__61);
  Py_CLEAR(clear_module_state->__pyx_tuple__62);
  Py_CLEAR(clear_module_state->__pyx_tuple__68);
  Py_CLEAR(clear_module_state->__pyx_tuple__69);
  Py_CLEAR(clear_module_state->__pyx_tuple__71);
  Py_CLEAR(clear_module_state->__pyx_tuple__73);
  Py_CLEAR(clear_module_state->__pyx_tuple__75);
  Py_CLEAR(clear_module_state->__pyx_tuple__76);
  Py_CLEAR(clear_module_state->__pyx_tuple__77);
  Py_CLEAR(clear_module_state->__pyx_tuple__78);
  Py_CLEAR(clear_module_state->__pyx_tuple__82);
  Py_CLEAR(clear_module_state->__pyx_tuple__84);
  Py_CLEAR(clear_module_state->__pyx_tuple__85);
  Py_CLEAR(clear_module_state->__pyx_tuple__86);
  Py_CLEAR(clear_module_state->__pyx_tuple__87);
  Py_CLEAR(clear_module_state->__pyx_tuple__88);
  Py_CLEAR(clear_module_state->__pyx_tuple__92);
  Py_CLEAR(clear_module_state->__pyx_tuple__93);
  Py_CLEAR(clear_module_state->__pyx_codeobj__9);
  Py_CLEAR(clear_module_state->__pyx_slice__141);
  Py_CLEAR(clear_module_state->__pyx_tuple__101);
  Py_CLEAR(clear_module_state->__pyx_tuple__103);
  Py_CLEAR(clear_module_state->__pyx_tuple__106);
  Py_CLEAR(clear_module_state->__pyx_tuple__109);
  Py_CLEAR(clear_module_state->__pyx_tuple__120);
  Py_CLEAR(clear_module_state->__pyx_tuple__123);
  Py_CLEAR(clear_module_state->__pyx_tuple__125);
  Py_CLEAR(clear_module_state->__pyx_tuple__127);
  Py_CLEAR(clear_module_state->__pyx_tuple__128);
  Py_CLEAR(clear_module_state->__pyx_tuple__130);
  Py_CLEAR(clear_module_state->__pyx_tuple__132);
  Py_CLEAR(clear_module_state->__pyx_tuple__133);
  Py_CLEAR(clear_module_state->__pyx_tuple__134);
  Py_CLEAR(clear_module_state->__pyx_tuple__135);
  Py_CLEAR(clear_module_state->__pyx_tuple__137);
  Py_CLEAR(clear_module_state->__pyx_tuple__139);
  Py_CLEAR(clear_module_state->__pyx_tuple__142);
  Py_CLEAR(clear_module_state->__pyx_tuple__146);
  Py_CLEAR(clear_module_state->__pyx_tuple__149);
  Py_CLEAR(clear_module_state->__pyx_tuple__151);
  Py_CLEAR(clear_module_state->__pyx_tuple__153);
  Py_CLEAR(clear_module_state->__pyx_tuple__155);
  Py_CLEAR(clear_module_state->__pyx_tuple__156);
  Py_CLEAR(clear_module_state->__pyx_tuple__157);
  Py_CLEAR(clear_module_state->__pyx_tuple__158);
  Py_CLEAR(clear_module_state->__pyx_tuple__159);
  Py_CLEAR(clear_module_state->__pyx_tuple__160);
  Py_CLEAR(clear_module_state->__pyx_tuple__162);
  Py_CLEAR(clear_module_state->__pyx_tuple__167);
  Py_CLEAR(clear_module_state->__pyx_tuple__171);
  Py_CLEAR(clear_module_state->__pyx_tuple__175);
  Py_CLEAR(clear_module_state->__pyx_tuple__177);
  Py_CLEAR(clear_module_state->__pyx_tuple__178);
  Py_CLEAR(clear_module_state->__pyx_tuple__180);
  Py_CLEAR(clear_module_state->__pyx_tuple__181);
  Py_CLEAR(clear_module_state->__pyx_tuple__183);
  Py_CLEAR(clear_module_state->__pyx_tuple__184);
  Py_CLEAR(clear_module_state->__pyx_tuple__185);
  Py_CLEAR(clear_module_state->__pyx_tuple__187);
  Py_CLEAR(clear_module_state->__pyx_tuple__188);
  Py_CLEAR(clear_module_state->__pyx_tuple__190);
  Py_CLEAR(clear_module_state->__pyx_tuple__192);
  Py_CLEAR(clear_module_state->__pyx_tuple__194);
  Py_CLEAR(clear_module_state->__pyx_tuple__196);
  Py_CLEAR(clear_module_state->__pyx_tuple__198);
  Py_CLEAR(clear_module_state->__pyx_tuple__200);
  Py_CLEAR(clear_module_state->__pyx_tuple__202);
  Py_CLEAR(clear_module_state->__pyx_tuple__203);
  Py_CLEAR(clear_module_state->__pyx_tuple__206);
  Py_CLEAR(clear_module_state->__pyx_tuple__207);
  Py_CLEAR(clear_module_state->__pyx_tuple__208);
  Py_CLEAR(clear_module_state->__pyx_tuple__210);
  Py_CLEAR(clear_module_state->__pyx_tuple__214);
  Py_CLEAR(clear_module_state->__pyx_tuple__215);
  Py_CLEAR(clear_module_state->__pyx_tuple__216);
  Py_CLEAR(clear_module_state->__pyx_tuple__218);
  Py_CLEAR(clear_module_state->__pyx_tuple__219);
  Py_CLEAR(clear_module_state->__pyx_tuple__221);
  Py_CLEAR(clear_module_state->__pyx_tuple__223);
  Py_CLEAR(clear_module_state->__pyx_tuple__225);
  Py_CLEAR(clear_module_state->__pyx_tuple__227);
  Py_CLEAR(clear_module_state->__pyx_tuple__234);
  Py_CLEAR(clear_module_state->__pyx_tuple__241);
  Py_CLEAR(clear_module_state->__pyx_tuple__243);
  Py_CLEAR(clear_module_state->__pyx_tuple__245);
  Py_CLEAR(clear_module_state->__pyx_tuple__247);
  Py_CLEAR(clear_module_state->__pyx_tuple__249);
  Py_CLEAR(clear_module_state->__pyx_tuple__252);
  Py_CLEAR(clear_module_state->__pyx_tuple__254);
  Py_CLEAR(clear_module_state->__pyx_tuple__256);
  Py_CLEAR(clear_module_state->__pyx_tuple__258);
  Py_CLEAR(clear_module_state->__pyx_tuple__262);
  Py_CLEAR(clear_module_state->__pyx_tuple__264);
  Py_CLEAR(clear_module_state->__pyx_tuple__265);
  Py_CLEAR(clear_module_state->__pyx_tuple__267);
  Py_CLEAR(clear_module_state->__pyx_tuple__269);
  Py_CLEAR(clear_module_state->__pyx_tuple__271);
  Py_CLEAR(clear_module_state->__pyx_tuple__273);
  Py_CLEAR(clear_module_state->__pyx_tuple__274);
  Py_CLEAR(clear_module_state->__pyx_tuple__276);
  Py_CLEAR(clear_module_state->__pyx_tuple__278);
  Py_CLEAR(clear_module_state->__pyx_tuple__280);
  Py_CLEAR(clear_module_state->__pyx_tuple__281);
  Py_CLEAR(clear_module_state->__pyx_tuple__284);
  Py_CLEAR(clear_module_state->__pyx_tuple__288);
  Py_CLEAR(clear_module_state->__pyx_tuple__290);
  Py_CLEAR(clear_module_state->__pyx_tuple__292);
  Py_CLEAR(clear_module_state->__pyx_tuple__294);
  Py_CLEAR(clear_module_state->__pyx_tuple__296);
  Py_CLEAR(clear_module_state->__pyx_tuple__298);
  Py_CLEAR(clear_module_state->__pyx_tuple__300);
  Py_CLEAR(clear_module_state->__pyx_tuple__302);
  Py_CLEAR(clear_module_state->__pyx_tuple__304);
  Py_CLEAR(clear_module_state->__pyx_tuple__306);
  Py_CLEAR(clear_module_state->__pyx_tuple__307);
  Py_CLEAR(clear_module_state->__pyx_tuple__308);
  Py_CLEAR(clear_module_state->__pyx_tuple__310);
  Py_CLEAR(clear_module_state->__pyx_tuple__312);
  Py_CLEAR(clear_module_state->__pyx_tuple__314);
  Py_CLEAR(clear_module_state->__pyx_tuple__319);
  Py_CLEAR(clear_module_state->__pyx_tuple__320);
  Py_CLEAR(clear_module_state->__pyx_tuple__321);
  Py_CLEAR(clear_module_state->__pyx_tuple__329);
  Py_CLEAR(clear_module_state->__pyx_tuple__330);
  Py_CLEAR(clear_module_state->__pyx_tuple__337);
  Py_CLEAR(clear_module_state->__pyx_tuple__338);
  Py_CLEAR(clear_module_state->__pyx_tuple__340);
  Py_CLEAR(clear_module_state->__pyx_tuple__342);
  Py_CLEAR(clear_module_state->__pyx_tuple__344);
  Py_CLEAR(clear_module_state->__pyx_tuple__347);
  Py_CLEAR(clear_module_state->__pyx_tuple__349);
  Py_CLEAR(clear_module_state->__pyx_tuple__350);
  Py_CLEAR(clear_module_state->__pyx_tuple__353);
  Py_CLEAR(clear_module_state->__pyx_tuple__355);
  Py_CLEAR(clear_module_state->__pyx_tuple__357);
  Py_CLEAR(clear_module_state->__pyx_tuple__359);
  Py_CLEAR(clear_module_state->__pyx_tuple__361);
  Py_CLEAR(clear_module_state->__pyx_tuple__363);
  Py_CLEAR(clear_module_state->__pyx_tuple__365);
  Py_CLEAR(clear_module_state->__pyx_tuple__367);
  Py_CLEAR(clear_module_state->__pyx_tuple__369);
  Py_CLEAR(clear_module_state->__pyx_tuple__372);
  Py_CLEAR(clear_module_state->__pyx_tuple__374);
  Py_CLEAR(clear_module_state->__pyx_tuple__376);
  Py_CLEAR(clear_module_state->__pyx_tuple__379);
  Py_CLEAR(clear_module_state->__pyx_tuple__381);
  Py_CLEAR(clear_module_state->__pyx_tuple__383);
  Py_CLEAR(clear_module_state->__pyx_tuple__386);
  Py_CLEAR(clear_module_state->__pyx_tuple__388);
  Py_CLEAR(clear_module_state->__pyx_tuple__389);
  Py_CLEAR(clear_module_state->__pyx_tuple__391);
  Py_CLEAR(clear_module_state->__pyx_tuple__392);
  Py_CLEAR(clear_module_state->__pyx_tuple__394);
  Py_CLEAR(clear_module_state->__pyx_tuple__395);
  Py_CLEAR(clear_module_state->__pyx_tuple__397);
  Py_CLEAR(clear_module_state->__pyx_tuple__399);
  Py_CLEAR(clear_module_state->__pyx_tuple__404);
  Py_CLEAR(clear_module_state->__pyx_tuple__415);
  Py_CLEAR(clear_module_state->__pyx_tuple__420);
  Py_CLEAR(clear_module_state->__pyx_tuple__424);
  Py_CLEAR(clear_module_state->__pyx_tuple__426);
  Py_CLEAR(clear_module_state->__pyx_tuple__432);
  Py_CLEAR(clear_module_state->__pyx_tuple__434);
  Py_CLEAR(clear_module_state->__pyx_tuple__441);
  Py_CLEAR(clear_module_state->__pyx_tuple__443);
  Py_CLEAR(clear_module_state->__pyx_tuple__445);
  Py_CLEAR(clear_module_state->__pyx_tuple__446);
  Py_CLEAR(clear_module_state->__pyx_tuple__448);
  Py_CLEAR(clear_module_state->__pyx_tuple__451);
  Py_CLEAR(clear_module_state->__pyx_tuple__457);
  Py_CLEAR(clear_module_state->__pyx_tuple__462);
  Py_CLEAR(clear_module_state->__pyx_tuple__465);
  Py_CLEAR(clear_module_state->__pyx_tuple__470);
  Py_CLEAR(clear_module_state->__pyx_tuple__472);
  Py_CLEAR(clear_module_state->__pyx_tuple__474);
  Py_CLEAR(clear_module_state->__pyx_tuple__476);
  Py_CLEAR(clear_module_state->__pyx_tuple__478);
  Py_CLEAR(clear_module_state->__pyx_tuple__479);
  Py_CLEAR(clear_module_state->__pyx_tuple__481);
  Py_CLEAR(clear_module_state->__pyx_tuple__483);
  Py_CLEAR(clear_module_state->__pyx_tuple__485);
  Py_CLEAR(clear_module_state->__pyx_tuple__487);
  Py_CLEAR(clear_module_state->__pyx_tuple__488);
  Py_CLEAR(clear_module_state->__pyx_tuple__490);
  Py_CLEAR(clear_module_state->__pyx_tuple__491);
  Py_CLEAR(clear_module_state->__pyx_tuple__493);
  Py_CLEAR(clear_module_state->__pyx_tuple__497);
  Py_CLEAR(clear_module_state->__pyx_tuple__499);
  Py_CLEAR(clear_module_state->__pyx_tuple__501);
  Py_CLEAR(clear_module_state->__pyx_tuple__502);
  Py_CLEAR(clear_module_state->__pyx_tuple__505);
  Py_CLEAR(clear_module_state->__pyx_tuple__507);
  Py_CLEAR(clear_module_state->__pyx_tuple__508);
  Py_CLEAR(clear_module_state->__pyx_tuple__529);
  Py_CLEAR(clear_module_state->__pyx_tuple__531);
  Py_CLEAR(clear_module_state->__pyx_tuple__532);
  Py_CLEAR(clear_module_state->__pyx_tuple__535);
  Py_CLEAR(clear_module_state->__pyx_tuple__537);
  Py_CLEAR(clear_module_state->__pyx_tuple__539);
  Py_CLEAR(clear_module_state->__pyx_tuple__549);
  Py_CLEAR(clear_module_state->__pyx_tuple__553);
  Py_CLEAR(clear_module_state->__pyx_tuple__555);
  Py_CLEAR(clear_module_state->__pyx_tuple__558);
  Py_CLEAR(clear_module_state->__pyx_tuple__560);
  Py_CLEAR(clear_module_state->__pyx_tuple__563);
  Py_CLEAR(clear_module_state->__pyx_tuple__565);
  Py_CLEAR(clear_module_state->__pyx_tuple__567);
  Py_CLEAR(clear_module_state->__pyx_tuple__569);
  Py_CLEAR(clear_module_state->__pyx_tuple__572);
  Py_CLEAR(clear_module_state->__pyx_tuple__574);
  Py_CLEAR(clear_module_state->__pyx_tuple__576);
  Py_CLEAR(clear_module_state->__pyx_tuple__579);
  Py_CLEAR(clear_module_state->__pyx_tuple__584);
  Py_CLEAR(clear_module_state->__pyx_tuple__589);
  Py_CLEAR(clear_module_state->__pyx_tuple__593);
  Py_CLEAR(clear_module_state->__pyx_tuple__595);
  Py_CLEAR(clear_module_state->__pyx_tuple__596);
  Py_CLEAR(clear_module_state->__pyx_tuple__604);
  Py_CLEAR(clear_module_state->__pyx_tuple__608);
  Py_CLEAR(clear_module_state->__pyx_tuple__614);
  Py_CLEAR(clear_module_state->__pyx_tuple__616);
  Py_CLEAR(clear_module_state->__pyx_tuple__619);
  Py_CLEAR(clear_module_state->__pyx_tuple__622);
  Py_CLEAR(clear_module_state->__pyx_tuple__624);
  Py_CLEAR(clear_module_state->__pyx_tuple__626);
  Py_CLEAR(clear_module_state->__pyx_tuple__628);
  Py_CLEAR(clear_module_state->__pyx_tuple__632);
  Py_CLEAR(clear_module_state->__pyx_tuple__634);
  Py_CLEAR(clear_module_state->__pyx_tuple__636);
  Py_CLEAR(clear_module_state->__pyx_tuple__640);
  Py_CLEAR(clear_module_state->__pyx_tuple__644);
  Py_CLEAR(clear_module_state->__pyx_tuple__645);
  Py_CLEAR(clear_module_state->__pyx_tuple__648);
  Py_CLEAR(clear_module_state->__pyx_tuple__650);
  Py_CLEAR(clear_module_state->__pyx_tuple__653);
  Py_CLEAR(clear_module_state->__pyx_tuple__655);
  Py_CLEAR(clear_module_state->__pyx_tuple__667);
  Py_CLEAR(clear_module_state->__pyx_tuple__669);
  Py_CLEAR(clear_module_state->__pyx_tuple__671);
  Py_CLEAR(clear_module_state->__pyx_tuple__676);
  Py_CLEAR(clear_module_state->__pyx_tuple__680);
  Py_CLEAR(clear_module_state->__pyx_tuple__681);
  Py_CLEAR(clear_module_state->__pyx_tuple__682);
  Py_CLEAR(clear_module_state->__pyx_tuple__684);
  Py_CLEAR(clear_module_state->__pyx_tuple__687);
  Py_CLEAR(clear_module_state->__pyx_tuple__689);
  Py_CLEAR(clear_module_state->__pyx_tuple__691);
  Py_CLEAR(clear_module_state->__pyx_tuple__692);
  Py_CLEAR(clear_module_state->__pyx_tuple__694);
  Py_CLEAR(clear_module_state->__pyx_tuple__696);
  Py_CLEAR(clear_module_state->__pyx_tuple__698);
  Py_CLEAR(clear_module_state->__pyx_tuple__700);
  Py_CLEAR(clear_module_state->__pyx_tuple__702);
  Py_CLEAR(clear_module_state->__pyx_tuple__704);
  Py_CLEAR(clear_module_state->__pyx_tuple__705);
  Py_CLEAR(clear_module_state->__pyx_tuple__707);
  Py_CLEAR(clear_module_state->__pyx_tuple__709);
  Py_CLEAR(clear_module_state->__pyx_tuple__711);
  Py_CLEAR(clear_module_state->__pyx_tuple__713);
  Py_CLEAR(clear_module_state->__pyx_tuple__714);
  Py_CLEAR(clear_module_state->__pyx_tuple__715);
  Py_CLEAR(clear_module_state->__pyx_tuple__716);
  Py_CLEAR(clear_module_state->__pyx_tuple__717);
  Py_CLEAR(clear_module_state->__pyx_tuple__719);
  Py_CLEAR(clear_module_state->__pyx_tuple__720);
  Py_CLEAR(clear_module_state->__pyx_tuple__722);
  Py_CLEAR(clear_module_state->__pyx_tuple__723);
  Py_CLEAR(clear_module_state->__pyx_tuple__724);
  Py_CLEAR(clear_module_state->__pyx_tuple__725);
  Py_CLEAR(clear_module_state->__pyx_tuple__726);
  Py_CLEAR(clear_module_state->__pyx_tuple__727);
  Py_CLEAR(clear_module_state->__pyx_tuple__728);
  Py_CLEAR(clear_module_state->__pyx_tuple__730);
  Py_CLEAR(clear_module_state->__pyx_tuple__732);
  Py_CLEAR(clear_module_state->__pyx_tuple__735);
  Py_CLEAR(clear_module_state->__pyx_tuple__737);
  Py_CLEAR(clear_module_state->__pyx_tuple__739);
  Py_CLEAR(clear_module_state->__pyx_tuple__740);
  Py_CLEAR(clear_module_state->__pyx_tuple__741);
  Py_CLEAR(clear_module_state->__pyx_tuple__744);
  Py_CLEAR(clear_module_state->__pyx_tuple__745);
  Py_CLEAR(clear_module_state->__pyx_tuple__746);
  Py_CLEAR(clear_module_state->__pyx_tuple__748);
  Py_CLEAR(clear_module_state->__pyx_tuple__750);
  Py_CLEAR(clear_module_state->__pyx_tuple__752);
  Py_CLEAR(clear_module_state->__pyx_tuple__753);
  Py_CLEAR(clear_module_state->__pyx_tuple__754);
  Py_CLEAR(clear_module_state->__pyx_tuple__756);
  Py_CLEAR(clear_module_state->__pyx_tuple__757);
  Py_CLEAR(clear_module_state->__pyx_tuple__758);
  Py_CLEAR(clear_module_state->__pyx_tuple__759);
  Py_CLEAR(clear_module_state->__pyx_tuple__760);
  Py_CLEAR(clear_module_state->__pyx_tuple__761);
  Py_CLEAR(clear_module_state->__pyx_tuple__762);
  Py_CLEAR(clear_module_state->__pyx_tuple__764);
  Py_CLEAR(clear_module_state->__pyx_tuple__766);
  Py_CLEAR(clear_module_state->__pyx_tuple__767);
  Py_CLEAR(clear_module_state->__pyx_tuple__769);
  Py_CLEAR(clear_module_state->__pyx_tuple__772);
  Py_CLEAR(clear_module_state->__pyx_tuple__775);
  Py_CLEAR(clear_module_state->__pyx_tuple__777);
  Py_CLEAR(clear_module_state->__pyx_tuple__778);
  Py_CLEAR(clear_module_state->__pyx_tuple__779);
  Py_CLEAR(clear_module_state->__pyx_tuple__781);
  Py_CLEAR(clear_module_state->__pyx_tuple__782);
  Py_CLEAR(clear_module_state->__pyx_tuple__783);
  Py_CLEAR(clear_module_state->__pyx_tuple__784);
  Py_CLEAR(clear_module_state->__pyx_tuple__785);
  Py_CLEAR(clear_module_state->__pyx_tuple__787);
  Py_CLEAR(clear_module_state->__pyx_tuple__788);
  Py_CLEAR(clear_module_state->__pyx_tuple__790);
  Py_CLEAR(clear_module_state->__pyx_tuple__791);
  Py_CLEAR(clear_module_state->__pyx_tuple__792);
  Py_CLEAR(clear_module_state->__pyx_tuple__793);
  Py_CLEAR(clear_module_state->__pyx_tuple__794);
  Py_CLEAR(clear_module_state->__pyx_tuple__796);
  Py_CLEAR(clear_module_state->__pyx_tuple__798);
  Py_CLEAR(clear_module_state->__pyx_tuple__800);
  Py_CLEAR(clear_module_state->__pyx_tuple__801);
  Py_CLEAR(clear_module_state->__pyx_tuple__803);
  Py_CLEAR(clear_module_state->__pyx_tuple__804);
  Py_CLEAR(clear_module_state->__pyx_tuple__806);
  Py_CLEAR(clear_module_state->__pyx_tuple__808);
  Py_CLEAR(clear_module_state->__pyx_tuple__809);
  Py_CLEAR(clear_module_state->__pyx_tuple__810);
  Py_CLEAR(clear_module_state->__pyx_tuple__816);
  Py_CLEAR(clear_module_state->__pyx_tuple__817);
  Py_CLEAR(clear_module_state->__pyx_tuple__818);
  Py_CLEAR(clear_module_state->__pyx_tuple__819);
  Py_CLEAR(clear_module_state->__pyx_tuple__820);
  Py_CLEAR(clear_module_state->__pyx_tuple__821);
  Py_CLEAR(clear_module_state->__pyx_tuple__822);
  Py_CLEAR(clear_module_state->__pyx_tuple__823);
  Py_CLEAR(clear_module_state->__pyx_tuple__824);
  Py_CLEAR(clear_module_state->__pyx_tuple__825);
  Py_CLEAR(clear_module_state->__pyx_tuple__826);
  Py_CLEAR(clear_module_state->__pyx_tuple__827);
  Py_CLEAR(clear_module_state->__pyx_tuple__828);
  Py_CLEAR(clear_module_state->__pyx_tuple__829);
  Py_CLEAR(clear_module_state->__pyx_tuple__830);
  Py_CLEAR(clear_module_state->__pyx_tuple__831);
  Py_CLEAR(clear_module_state->__pyx_tuple__832);
  Py_CLEAR(clear_module_state->__pyx_tuple__833);
  Py_CLEAR(clear_module_state->__pyx_tuple__834);
  Py_CLEAR(clear_module_state->__pyx_tuple__835);
  Py_CLEAR(clear_module_state->__pyx_tuple__836);
  Py_CLEAR(clear_module_state->__pyx_tuple__837);
  Py_CLEAR(clear_module_state->__pyx_tuple__838);
  Py_CLEAR(clear_module_state->__pyx_tuple__839);
  Py_CLEAR(clear_module_state->__pyx_tuple__840);
  Py_CLEAR(clear_module_state->__pyx_tuple__841);
  Py_CLEAR(clear_module_state->__pyx_tuple__842);
  Py_CLEAR(clear_module_state->__pyx_tuple__843);
  Py_CLEAR(clear_module_state->__pyx_tuple__844);
  Py_CLEAR(clear_module_state->__pyx_tuple__845);
  Py_CLEAR(clear_module_state->__pyx_tuple__846);
  Py_CLEAR(clear_module_state->__pyx_tuple__847);
  Py_CLEAR(clear_module_state->__pyx_tuple__848);
  Py_CLEAR(clear_module_state->__pyx_tuple__849);
  Py_CLEAR(clear_module_state->__pyx_tuple__850);
  Py_CLEAR(clear_module_state->__pyx_tuple__851);
  Py_CLEAR(clear_module_state->__pyx_tuple__852);
  Py_CLEAR(clear_module_state->__pyx_tuple__853);
  Py_CLEAR(clear_module_state->__pyx_tuple__854);
  Py_CLEAR(clear_module_state->__pyx_tuple__855);
  Py_CLEAR(clear_module_state->__pyx_tuple__870);
  Py_CLEAR(clear_module_state->__pyx_tuple__874);
  Py_CLEAR(clear_module_state->__pyx_tuple__876);
  Py_CLEAR(clear_module_state->__pyx_tuple__878);
  Py_CLEAR(clear_module_state->__pyx_tuple__879);
  Py_CLEAR(clear_module_state->__pyx_tuple__881);
  Py_CLEAR(clear_module_state->__pyx_tuple__883);
  Py_CLEAR(clear_module_state->__pyx_tuple__884);
  Py_CLEAR(clear_module_state->__pyx_tuple__885);
  Py_CLEAR(clear_module_state->__pyx_tuple__886);
  Py_CLEAR(clear_module_state->__pyx_tuple__887);
  Py_CLEAR(clear_module_state->__pyx_tuple__888);
  Py_CLEAR(clear_module_state->__pyx_tuple__889);
  Py_CLEAR(clear_module_state->__pyx_tuple__890);
  Py_CLEAR(clear_module_state->__pyx_tuple__891);
  Py_CLEAR(clear_module_state->__pyx_tuple__892);
  Py_CLEAR(clear_module_state->__pyx_codeobj__24);
  Py_CLEAR(clear_module_state->__pyx_codeobj__33);
  Py_CLEAR(clear_module_state->__pyx_codeobj__40);
  Py_CLEAR(clear_module_state->__pyx_codeobj__43);
  Py_CLEAR(clear_module_state->__pyx_codeobj__45);
  Py_CLEAR(clear_module_state->__pyx_codeobj__49);
  Py_CLEAR(clear_module_state->__pyx_codeobj__52);
  Py_CLEAR(clear_module_state->__pyx_codeobj__53);
  Py_CLEAR(clear_module_state->__pyx_codeobj__63);
  Py_CLEAR(clear_module_state->__pyx_codeobj__72);
  Py_CLEAR(clear_module_state->__pyx_codeobj__74);
  Py_CLEAR(clear_module_state->__pyx_codeobj__83);
  Py_CLEAR(clear_module_state->__pyx_codeobj__89);
  Py_CLEAR(clear_module_state->__pyx_codeobj__90);
  Py_CLEAR(clear_module_state->__pyx_codeobj__121);
  Py_CLEAR(clear_module_state->__pyx_codeobj__124);
  Py_CLEAR(clear_module_state->__pyx_codeobj__126);
  Py_CLEAR(clear_module_state->__pyx_codeobj__129);
  Py_CLEAR(clear_module_state->__pyx_codeobj__131);
  Py_CLEAR(clear_module_state->__pyx_codeobj__138);
  Py_CLEAR(clear_module_state->__pyx_codeobj__140);
  Py_CLEAR(clear_module_state->__pyx_codeobj__143);
  Py_CLEAR(clear_module_state->__pyx_codeobj__152);
  Py_CLEAR(clear_module_state->__pyx_codeobj__154);
  Py_CLEAR(clear_module_state->__pyx_codeobj__161);
  Py_CLEAR(clear_module_state->__pyx_codeobj__163);
  Py_CLEAR(clear_module_state->__pyx_codeobj__164);
  Py_CLEAR(clear_module_state->__pyx_codeobj__165);
  Py_CLEAR(clear_module_state->__pyx_codeobj__168);
  Py_CLEAR(clear_module_state->__pyx_codeobj__169);
  Py_CLEAR(clear_module_state->__pyx_codeobj__170);
  Py_CLEAR(clear_module_state->__pyx_codeobj__172);
  Py_CLEAR(clear_module_state->__pyx_codeobj__173);
  Py_CLEAR(clear_module_state->__pyx_codeobj__174);
  Py_CLEAR(clear_module_state->__pyx_codeobj__176);
  Py_CLEAR(clear_module_state->__pyx_codeobj__179);
  Py_CLEAR(clear_module_state->__pyx_codeobj__182);
  Py_CLEAR(clear_module_state->__pyx_codeobj__186);
  Py_CLEAR(clear_module_state->__pyx_codeobj__189);
  Py_CLEAR(clear_module_state->__pyx_codeobj__191);
  Py_CLEAR(clear_module_state->__pyx_codeobj__193);
  Py_CLEAR(clear_module_state->__pyx_codeobj__195);
  Py_CLEAR(clear_module_state->__pyx_codeobj__197);
  Py_CLEAR(clear_module_state->__pyx_codeobj__199);
  Py_CLEAR(clear_module_state->__pyx_codeobj__201);
  Py_CLEAR(clear_module_state->__pyx_codeobj__204);
  Py_CLEAR(clear_module_state->__pyx_codeobj__205);
  Py_CLEAR(clear_module_state->__pyx_codeobj__209);
  Py_CLEAR(clear_module_state->__pyx_codeobj__211);
  Py_CLEAR(clear_module_state->__pyx_codeobj__212);
  Py_CLEAR(clear_module_state->__pyx_codeobj__213);
  Py_CLEAR(clear_module_state->__pyx_codeobj__217);
  Py_CLEAR(clear_module_state->__pyx_codeobj__220);
  Py_CLEAR(clear_module_state->__pyx_codeobj__222);
  Py_CLEAR(clear_module_state->__pyx_codeobj__224);
  Py_CLEAR(clear_module_state->__pyx_codeobj__226);
  Py_CLEAR(clear_module_state->__pyx_codeobj__228);
  Py_CLEAR(clear_module_state->__pyx_codeobj__229);
  Py_CLEAR(clear_module_state->__pyx_codeobj__230);
  Py_CLEAR(clear_module_state->__pyx_codeobj__231);
  Py_CLEAR(clear_module_state->__pyx_codeobj__232);
  Py_CLEAR(clear_module_state->__pyx_codeobj__233);
  Py_CLEAR(clear_module_state->__pyx_codeobj__235);
  Py_CLEAR(clear_module_state->__pyx_codeobj__236);
  Py_CLEAR(clear_module_state->__pyx_codeobj__237);
  Py_CLEAR(clear_module_state->__pyx_codeobj__238);
  Py_CLEAR(clear_module_state->__pyx_codeobj__239);
  Py_CLEAR(clear_module_state->__pyx_codeobj__240);
  Py_CLEAR(clear_module_state->__pyx_codeobj__242);
  Py_CLEAR(clear_module_state->__pyx_codeobj__244);
  Py_CLEAR(clear_module_state->__pyx_codeobj__246);
  Py_CLEAR(clear_module_state->__pyx_codeobj__248);
  Py_CLEAR(clear_module_state->__pyx_codeobj__250);
  Py_CLEAR(clear_module_state->__pyx_codeobj__251);
  Py_CLEAR(clear_module_state->__pyx_codeobj__253);
  Py_CLEAR(clear_module_state->__pyx_codeobj__255);
  Py_CLEAR(clear_module_state->__pyx_codeobj__257);
  Py_CLEAR(clear_module_state->__pyx_codeobj__259);
  Py_CLEAR(clear_module_state->__pyx_codeobj__260);
  Py_CLEAR(clear_module_state->__pyx_codeobj__261);
  Py_CLEAR(clear_module_state->__pyx_codeobj__263);
  Py_CLEAR(clear_module_state->__pyx_codeobj__266);
  Py_CLEAR(clear_module_state->__pyx_codeobj__268);
  Py_CLEAR(clear_module_state->__pyx_codeobj__270);
  Py_CLEAR(clear_module_state->__pyx_codeobj__272);
  Py_CLEAR(clear_module_state->__pyx_codeobj__275);
  Py_CLEAR(clear_module_state->__pyx_codeobj__277);
  Py_CLEAR(clear_module_state->__pyx_codeobj__279);
  Py_CLEAR(clear_module_state->__pyx_codeobj__282);
  Py_CLEAR(clear_module_state->__pyx_codeobj__283);
  Py_CLEAR(clear_module_state->__pyx_codeobj__285);
  Py_CLEAR(clear_module_state->__pyx_codeobj__286);
  Py_CLEAR(clear_module_state->__pyx_codeobj__287);
  Py_CLEAR(clear_module_state->__pyx_codeobj__289);
  Py_CLEAR(clear_module_state->__pyx_codeobj__291);
  Py_CLEAR(clear_module_state->__pyx_codeobj__293);
  Py_CLEAR(clear_module_state->__pyx_codeobj__295);
  Py_CLEAR(clear_module_state->__pyx_codeobj__297);
  Py_CLEAR(clear_module_state->__pyx_codeobj__299);
  Py_CLEAR(clear_module_state->__pyx_codeobj__301);
  Py_CLEAR(clear_module_state->__pyx_codeobj__303);
  Py_CLEAR(clear_module_state->__pyx_codeobj__305);
  Py_CLEAR(clear_module_state->__pyx_codeobj__309);
  Py_CLEAR(clear_module_state->__pyx_codeobj__311);
  Py_CLEAR(clear_module_state->__pyx_codeobj__313);
  Py_CLEAR(clear_module_state->__pyx_codeobj__315);
  Py_CLEAR(clear_module_state->__pyx_codeobj__316);
  Py_CLEAR(clear_module_state->__pyx_codeobj__317);
  Py_CLEAR(clear_module_state->__pyx_codeobj__318);
  Py_CLEAR(clear_module_state->__pyx_codeobj__322);
  Py_CLEAR(clear_module_state->__pyx_codeobj__323);
  Py_CLEAR(clear_module_state->__pyx_codeobj__324);
  Py_CLEAR(clear_module_state->__pyx_codeobj__325);
  Py_CLEAR(clear_module_state->__pyx_codeobj__326);
  Py_CLEAR(clear_module_state->__pyx_codeobj__327);
  Py_CLEAR(clear_module_state->__pyx_codeobj__328);
  Py_CLEAR(clear_module_state->__pyx_codeobj__331);
  Py_CLEAR(clear_module_state->__pyx_codeobj__332);
  Py_CLEAR(clear_module_state->__pyx_codeobj__333);
  Py_CLEAR(clear_module_state->__pyx_codeobj__334);
  Py_CLEAR(clear_module_state->__pyx_codeobj__335);
  Py_CLEAR(clear_module_state->__pyx_codeobj__336);
  Py_CLEAR(clear_module_state->__pyx_codeobj__341);
  Py_CLEAR(clear_module_state->__pyx_codeobj__343);
  Py_CLEAR(clear_module_state->__pyx_codeobj__345);
  Py_CLEAR(clear_module_state->__pyx_codeobj__346);
  Py_CLEAR(clear_module_state->__pyx_codeobj__348);
  Py_CLEAR(clear_module_state->__pyx_codeobj__351);
  Py_CLEAR(clear_module_state->__pyx_codeobj__352);
  Py_CLEAR(clear_module_state->__pyx_codeobj__354);
  Py_CLEAR(clear_module_state->__pyx_codeobj__356);
  Py_CLEAR(clear_module_state->__pyx_codeobj__358);
  Py_CLEAR(clear_module_state->__pyx_codeobj__360);
  Py_CLEAR(clear_module_state->__pyx_codeobj__362);
  Py_CLEAR(clear_module_state->__pyx_codeobj__364);
  Py_CLEAR(clear_module_state->__pyx_codeobj__366);
  Py_CLEAR(clear_module_state->__pyx_codeobj__368);
  Py_CLEAR(clear_module_state->__pyx_codeobj__370);
  Py_CLEAR(clear_module_state->__pyx_codeobj__371);
  Py_CLEAR(clear_module_state->__pyx_codeobj__373);
  Py_CLEAR(clear_module_state->__pyx_codeobj__375);
  Py_CLEAR(clear_module_state->__pyx_codeobj__377);
  Py_CLEAR(clear_module_state->__pyx_codeobj__378);
  Py_CLEAR(clear_module_state->__pyx_codeobj__380);
  Py_CLEAR(clear_module_state->__pyx_codeobj__382);
  Py_CLEAR(clear_module_state->__pyx_codeobj__384);
  Py_CLEAR(clear_module_state->__pyx_codeobj__385);
  Py_CLEAR(clear_module_state->__pyx_codeobj__387);
  Py_CLEAR(clear_module_state->__pyx_codeobj__390);
  Py_CLEAR(clear_module_state->__pyx_codeobj__393);
  Py_CLEAR(clear_module_state->__pyx_codeobj__396);
  Py_CLEAR(clear_module_state->__pyx_codeobj__398);
  Py_CLEAR(clear_module_state->__pyx_codeobj__400);
  Py_CLEAR(clear_module_state->__pyx_codeobj__401);
  Py_CLEAR(clear_module_state->__pyx_codeobj__402);
  Py_CLEAR(clear_module_state->__pyx_codeobj__403);
  Py_CLEAR(clear_module_state->__pyx_codeobj__405);
  Py_CLEAR(clear_module_state->__pyx_codeobj__406);
  Py_CLEAR(clear_module_state->__pyx_codeobj__407);
  Py_CLEAR(clear_module_state->__pyx_codeobj__408);
  Py_CLEAR(clear_module_state->__pyx_codeobj__409);
  Py_CLEAR(clear_module_state->__pyx_codeobj__410);
  Py_CLEAR(clear_module_state->__pyx_codeobj__411);
  Py_CLEAR(clear_module_state->__pyx_codeobj__412);
  Py_CLEAR(clear_module_state->__pyx_codeobj__413);
  Py_CLEAR(clear_module_state->__pyx_codeobj__414);
  Py_CLEAR(clear_module_state->__pyx_codeobj__416);
  Py_CLEAR(clear_module_state->__pyx_codeobj__417);
  Py_CLEAR(clear_module_state->__pyx_codeobj__418);
  Py_CLEAR(clear_module_state->__pyx_codeobj__419);
  Py_CLEAR(clear_module_state->__pyx_codeobj__421);
  Py_CLEAR(clear_module_state->__pyx_codeobj__422);
  Py_CLEAR(clear_module_state->__pyx_codeobj__423);
  Py_CLEAR(clear_module_state->__pyx_codeobj__425);
  Py_CLEAR(clear_module_state->__pyx_codeobj__427);
  Py_CLEAR(clear_module_state->__pyx_codeobj__428);
  Py_CLEAR(clear_module_state->__pyx_codeobj__429);
  Py_CLEAR(clear_module_state->__pyx_codeobj__430);
  Py_CLEAR(clear_module_state->__pyx_codeobj__431);
  Py_CLEAR(clear_module_state->__pyx_codeobj__433);
  Py_CLEAR(clear_module_state->__pyx_codeobj__435);
  Py_CLEAR(clear_module_state->__pyx_codeobj__436);
  Py_CLEAR(clear_module_state->__pyx_codeobj__437);
  Py_CLEAR(clear_module_state->__pyx_codeobj__438);
  Py_CLEAR(clear_module_state->__pyx_codeobj__439);
  Py_CLEAR(clear_module_state->__pyx_codeobj__440);
  Py_CLEAR(clear_module_state->__pyx_codeobj__442);
  Py_CLEAR(clear_module_state->__pyx_codeobj__444);
  Py_CLEAR(clear_module_state->__pyx_codeobj__447);
  Py_CLEAR(clear_module_state->__pyx_codeobj__449);
  Py_CLEAR(clear_module_state->__pyx_codeobj__450);
  Py_CLEAR(clear_module_state->__pyx_codeobj__452);
  Py_CLEAR(clear_module_state->__pyx_codeobj__453);
  Py_CLEAR(clear_module_state->__pyx_codeobj__454);
  Py_CLEAR(clear_module_state->__pyx_codeobj__455);
  Py_CLEAR(clear_module_state->__pyx_codeobj__456);
  Py_CLEAR(clear_module_state->__pyx_codeobj__458);
  Py_CLEAR(clear_module_state->__pyx_codeobj__459);
  Py_CLEAR(clear_module_state->__pyx_codeobj__460);
  Py_CLEAR(clear_module_state->__pyx_codeobj__463);
  Py_CLEAR(clear_module_state->__pyx_codeobj__464);
  Py_CLEAR(clear_module_state->__pyx_codeobj__466);
  Py_CLEAR(clear_module_state->__pyx_codeobj__467);
  Py_CLEAR(clear_module_state->__pyx_codeobj__468);
  Py_CLEAR(clear_module_state->__pyx_codeobj__469);
  Py_CLEAR(clear_module_state->__pyx_codeobj__471);
  Py_CLEAR(clear_module_state->__pyx_codeobj__473);
  Py_CLEAR(clear_module_state->__pyx_codeobj__475);
  Py_CLEAR(clear_module_state->__pyx_codeobj__477);
  Py_CLEAR(clear_module_state->__pyx_codeobj__480);
  Py_CLEAR(clear_module_state->__pyx_codeobj__482);
  Py_CLEAR(clear_module_state->__pyx_codeobj__484);
  Py_CLEAR(clear_module_state->__pyx_codeobj__486);
  Py_CLEAR(clear_module_state->__pyx_codeobj__489);
  Py_CLEAR(clear_module_state->__pyx_codeobj__492);
  Py_CLEAR(clear_module_state->__pyx_codeobj__494);
  Py_CLEAR(clear_module_state->__pyx_codeobj__495);
  Py_CLEAR(clear_module_state->__pyx_codeobj__496);
  Py_CLEAR(clear_module_state->__pyx_codeobj__498);
  Py_CLEAR(clear_module_state->__pyx_codeobj__500);
  Py_CLEAR(clear_module_state->__pyx_codeobj__503);
  Py_CLEAR(clear_module_state->__pyx_codeobj__504);
  Py_CLEAR(clear_module_state->__pyx_codeobj__506);
  Py_CLEAR(clear_module_state->__pyx_codeobj__509);
  Py_CLEAR(clear_module_state->__pyx_codeobj__510);
  Py_CLEAR(clear_module_state->__pyx_codeobj__530);
  Py_CLEAR(clear_module_state->__pyx_codeobj__533);
  Py_CLEAR(clear_module_state->__pyx_codeobj__534);
  Py_CLEAR(clear_module_state->__pyx_codeobj__536);
  Py_CLEAR(clear_module_state->__pyx_codeobj__538);
  Py_CLEAR(clear_module_state->__pyx_codeobj__540);
  Py_CLEAR(clear_module_state->__pyx_codeobj__541);
  Py_CLEAR(clear_module_state->__pyx_codeobj__542);
  Py_CLEAR(clear_module_state->__pyx_codeobj__543);
  Py_CLEAR(clear_module_state->__pyx_codeobj__544);
  Py_CLEAR(clear_module_state->__pyx_codeobj__545);
  Py_CLEAR(clear_module_state->__pyx_codeobj__546);
  Py_CLEAR(clear_module_state->__pyx_codeobj__547);
  Py_CLEAR(clear_module_state->__pyx_codeobj__548);
  Py_CLEAR(clear_module_state->__pyx_codeobj__550);
  Py_CLEAR(clear_module_state->__pyx_codeobj__551);
  Py_CLEAR(clear_module_state->__pyx_codeobj__552);
  Py_CLEAR(clear_module_state->__pyx_codeobj__554);
  Py_CLEAR(clear_module_state->__pyx_codeobj__556);
  Py_CLEAR(clear_module_state->__pyx_codeobj__557);
  Py_CLEAR(clear_module_state->__pyx_codeobj__559);
  Py_CLEAR(clear_module_state->__pyx_codeobj__561);
  Py_CLEAR(clear_module_state->__pyx_codeobj__562);
  Py_CLEAR(clear_module_state->__pyx_codeobj__564);
  Py_CLEAR(clear_module_state->__pyx_codeobj__566);
  Py_CLEAR(clear_module_state->__pyx_codeobj__568);
  Py_CLEAR(clear_module_state->__pyx_codeobj__570);
  Py_CLEAR(clear_module_state->__pyx_codeobj__571);
  Py_CLEAR(clear_module_state->__pyx_codeobj__573);
  Py_CLEAR(clear_module_state->__pyx_codeobj__575);
  Py_CLEAR(clear_module_state->__pyx_codeobj__577);
  Py_CLEAR(clear_module_state->__pyx_codeobj__578);
  Py_CLEAR(clear_module_state->__pyx_codeobj__580);
  Py_CLEAR(clear_module_state->__pyx_codeobj__581);
  Py_CLEAR(clear_module_state->__pyx_codeobj__582);
  Py_CLEAR(clear_module_state->__pyx_codeobj__583);
  Py_CLEAR(clear_module_state->__pyx_codeobj__585);
  Py_CLEAR(clear_module_state->__pyx_codeobj__586);
  Py_CLEAR(clear_module_state->__pyx_codeobj__587);
  Py_CLEAR(clear_module_state->__pyx_codeobj__588);
  Py_CLEAR(clear_module_state->__pyx_codeobj__590);
  Py_CLEAR(clear_module_state->__pyx_codeobj__591);
  Py_CLEAR(clear_module_state->__pyx_codeobj__592);
  Py_CLEAR(clear_module_state->__pyx_codeobj__594);
  Py_CLEAR(clear_module_state->__pyx_codeobj__597);
  Py_CLEAR(clear_module_state->__pyx_codeobj__598);
  Py_CLEAR(clear_module_state->__pyx_codeobj__599);
  Py_CLEAR(clear_module_state->__pyx_codeobj__600);
  Py_CLEAR(clear_module_state->__pyx_codeobj__601);
  Py_CLEAR(clear_module_state->__pyx_codeobj__602);
  Py_CLEAR(clear_module_state->__pyx_codeobj__603);
  Py_CLEAR(clear_module_state->__pyx_codeobj__605);
  Py_CLEAR(clear_module_state->__pyx_codeobj__606);
  Py_CLEAR(clear_module_state->__pyx_codeobj__607);
  Py_CLEAR(clear_module_state->__pyx_codeobj__609);
  Py_CLEAR(clear_module_state->__pyx_codeobj__610);
  Py_CLEAR(clear_module_state->__pyx_codeobj__611);
  Py_CLEAR(clear_module_state->__pyx_codeobj__612);
  Py_CLEAR(clear_module_state->__pyx_codeobj__613);
  Py_CLEAR(clear_module_state->__pyx_codeobj__615);
  Py_CLEAR(clear_module_state->__pyx_codeobj__617);
  Py_CLEAR(clear_module_state->__pyx_codeobj__618);
  Py_CLEAR(clear_module_state->__pyx_codeobj__620);
  Py_CLEAR(clear_module_state->__pyx_codeobj__623);
  Py_CLEAR(clear_module_state->__pyx_codeobj__625);
  Py_CLEAR(clear_module_state->__pyx_codeobj__627);
  Py_CLEAR(clear_module_state->__pyx_codeobj__629);
  Py_CLEAR(clear_module_state->__pyx_codeobj__630);
  Py_CLEAR(clear_module_state->__pyx_codeobj__631);
  Py_CLEAR(clear_module_state->__pyx_codeobj__633);
  Py_CLEAR(clear_module_state->__pyx_codeobj__635);
  Py_CLEAR(clear_module_state->__pyx_codeobj__637);
  Py_CLEAR(clear_module_state->__pyx_codeobj__638);
  Py_CLEAR(clear_module_state->__pyx_codeobj__639);
  Py_CLEAR(clear_module_state->__pyx_codeobj__641);
  Py_CLEAR(clear_module_state->__pyx_codeobj__642);
  Py_CLEAR(clear_module_state->__pyx_codeobj__643);
  Py_CLEAR(clear_module_state->__pyx_codeobj__646);
  Py_CLEAR(clear_module_state->__pyx_codeobj__647);
  Py_CLEAR(clear_module_state->__pyx_codeobj__649);
  Py_CLEAR(clear_module_state->__pyx_codeobj__651);
  Py_CLEAR(clear_module_state->__pyx_codeobj__652);
  Py_CLEAR(clear_module_state->__pyx_codeobj__654);
  Py_CLEAR(clear_module_state->__pyx_codeobj__656);
  Py_CLEAR(clear_module_state->__pyx_codeobj__657);
  Py_CLEAR(clear_module_state->__pyx_codeobj__658);
  Py_CLEAR(clear_module_state->__pyx_codeobj__659);
  Py_CLEAR(clear_module_state->__pyx_codeobj__660);
  Py_CLEAR(clear_module_state->__pyx_codeobj__661);
  Py_CLEAR(clear_module_state->__pyx_codeobj__662);
  Py_CLEAR(clear_module_state->__pyx_codeobj__663);
  Py_CLEAR(clear_module_state->__pyx_codeobj__664);
  Py_CLEAR(clear_module_state->__pyx_codeobj__665);
  Py_CLEAR(clear_module_state->__pyx_codeobj__666);
  Py_CLEAR(clear_module_state->__pyx_codeobj__668);
  Py_CLEAR(clear_module_state->__pyx_codeobj__670);
  Py_CLEAR(clear_module_state->__pyx_codeobj__672);
  Py_CLEAR(clear_module_state->__pyx_codeobj__673);
  Py_CLEAR(clear_module_state->__pyx_codeobj__674);
  Py_CLEAR(clear_module_state->__pyx_codeobj__675);
  Py_CLEAR(clear_module_state->__pyx_codeobj__677);
  Py_CLEAR(clear_module_state->__pyx_codeobj__678);
  Py_CLEAR(clear_module_state->__pyx_codeobj__679);
  Py_CLEAR(clear_module_state->__pyx_codeobj__683);
  Py_CLEAR(clear_module_state->__pyx_codeobj__685);
  Py_CLEAR(clear_module_state->__pyx_codeobj__686);
  Py_CLEAR(clear_module_state->__pyx_codeobj__688);
  Py_CLEAR(clear_module_state->__pyx_codeobj__690);
  Py_CLEAR(clear_module_state->__pyx_codeobj__693);
  Py_CLEAR(clear_module_state->__pyx_codeobj__695);
  Py_CLEAR(clear_module_state->__pyx_codeobj__697);
  Py_CLEAR(clear_module_state->__pyx_codeobj__699);
  Py_CLEAR(clear_module_state->__pyx_codeobj__701);
  Py_CLEAR(clear_module_state->__pyx_codeobj__703);
  Py_CLEAR(clear_module_state->__pyx_codeobj__706);
  Py_CLEAR(clear_module_state->__pyx_codeobj__708);
  Py_CLEAR(clear_module_state->__pyx_codeobj__710);
  Py_CLEAR(clear_module_state->__pyx_codeobj__712);
  Py_CLEAR(clear_module_state->__pyx_codeobj__729);
  Py_CLEAR(clear_module_state->__pyx_codeobj__731);
  Py_CLEAR(clear_module_state->__pyx_codeobj__733);
  Py_CLEAR(clear_module_state->__pyx_codeobj__734);
  Py_CLEAR(clear_module_state->__pyx_codeobj__736);
  Py_CLEAR(clear_module_state->__pyx_codeobj__738);
  Py_CLEAR(clear_module_state->__pyx_codeobj__742);
  Py_CLEAR(clear_module_state->__pyx_codeobj__743);
  Py_CLEAR(clear_module_state->__pyx_codeobj__747);
  Py_CLEAR(clear_module_state->__pyx_codeobj__749);
  Py_CLEAR(clear_module_state->__pyx_codeobj__751);
  Py_CLEAR(clear_module_state->__pyx_codeobj__763);
  Py_CLEAR(clear_module_state->__pyx_codeobj__765);
  Py_CLEAR(clear_module_state->__pyx_codeobj__773);
  Py_CLEAR(clear_module_state->__pyx_codeobj__797);
  Py_CLEAR(clear_module_state->__pyx_codeobj__799);
  Py_CLEAR(clear_module_state->__pyx_codeobj__802);
  Py_CLEAR(clear_module_state->__pyx_codeobj__805);
  Py_CLEAR(clear_module_state->__pyx_codeobj__807);
  Py_CLEAR(clear_module_state->__pyx_codeobj__811);
  Py_CLEAR(clear_module_state->__pyx_codeobj__812);
  Py_CLEAR(clear_module_state->__pyx_codeobj__813);
  Py_CLEAR(clear_module_state->__pyx_codeobj__814);
  Py_CLEAR(clear_module_state->__pyx_codeobj__815);
  Py_CLEAR(clear_module_state->__pyx_codeobj__868);
  Py_CLEAR(clear_module_state->__pyx_codeobj__869);
  Py_CLEAR(clear_module_state->__pyx_codeobj__871);
  Py_CLEAR(clear_module_state->__pyx_codeobj__872);
  Py_CLEAR(clear_module_state->__pyx_codeobj__873);
  Py_CLEAR(clear_module_state->__pyx_codeobj__875);
  Py_CLEAR(clear_module_state->__pyx_codeobj__877);
  Py_CLEAR(clear_module_state->__pyx_codeobj__880);
  Py_CLEAR(clear_module_state->__pyx_codeobj__882);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct__genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_9___iadd__);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_11_asDict);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_19_scanString);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_20_split);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_20_split);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_21___mul__);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_23___add__);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_24___init__);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_27_sub);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_28___init__);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_30___init__);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_33___init__);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_62_srange);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_69___call__);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_74___get__);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException);
  Py_VISIT(traverse_module_state->__pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0123456789);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_0_7);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_1);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_1_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_1_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_9a_fA_F_1_4);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_failed_1_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_setting_results_name_0_r_on_1);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_setting_results_name_1_r_on_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_setting_results_name_1_r_on_2_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_xX_0_9a_fA_F);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0x);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0xa1_0xbf_0xd7_0xf7);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff);
  Py_VISIT(traverse_module_state->__pyx_kp_u_100_100_100_3_14159_6_02e23_1e);
  Py_VISIT(traverse_module_state->__pyx_kp_u_100_FF);
  Py_VISIT(traverse_module_state->__pyx_kp_u_12345678_1234_5678_1234_5678123);
  Py_VISIT(traverse_module_state->__pyx_kp_u_24_Nov_2023_01_45_UTC);
  Py_VISIT(traverse_module_state->__pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0);
  Py_VISIT(traverse_module_state->__pyx_kp_u_2_4_7_2_3_0);
  Py_VISIT(traverse_module_state->__pyx_n_u_ABCDEFabcdef);
  Py_VISIT(traverse_module_state->__pyx_n_s_ANY_VALUE);
  Py_VISIT(traverse_module_state->__pyx_kp_u_A_cross_version_compatibility_c);
  Py_VISIT(traverse_module_state->__pyx_kp_s_A_mixin_class_to_add_parse_resu);
  Py_VISIT(traverse_module_state->__pyx_kp_s_A_namespace_class_for_defining);
  Py_VISIT(traverse_module_state->__pyx_kp_s_A_set_of_Unicode_characters_for);
  Py_VISIT(traverse_module_state->__pyx_kp_s_A_short_cut_class_for_defining_W);
  Py_VISIT(traverse_module_state->__pyx_kp_s_A_token_that_will_never_match);
  Py_VISIT(traverse_module_state->__pyx_kp_s_A_variation_on_class_Literal_whi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Abstract_base_level_parser_eleme);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Abstract_class_ParserElement_sub);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Abstract_subclass_of_ParserEleme);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Abstract_subclass_of_class_Pars);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Abstract_subclass_of_class_Parse);
  Py_VISIT(traverse_module_state->__pyx_kp_s_An_empty_token_will_always_match);
  Py_VISIT(traverse_module_state->__pyx_n_s_And);
  Py_VISIT(traverse_module_state->__pyx_n_u_And);
  Py_VISIT(traverse_module_state->__pyx_n_s_And__ErrorStop);
  Py_VISIT(traverse_module_state->__pyx_n_s_And__ErrorStop___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_And___iadd);
  Py_VISIT(traverse_module_state->__pyx_n_s_And___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_And___init___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_And___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_And___str___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_And_checkRecursion);
  Py_VISIT(traverse_module_state->__pyx_n_s_And_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_And_streamline);
  Py_VISIT(traverse_module_state->__pyx_n_s_And_streamline_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Arabic);
  Py_VISIT(traverse_module_state->__pyx_n_s_AttributeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_BOM);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseWithAttribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseWithAttribute___call);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseWithAttribute___call___local);
  Py_VISIT(traverse_module_state->__pyx_n_s_CJK);
  Py_VISIT(traverse_module_state->__pyx_kp_u_CR);
  Py_VISIT(traverse_module_state->__pyx_kp_u_C_style_comment);
  Py_VISIT(traverse_module_state->__pyx_kp_u_C_style_comment_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Cannot_combine_element_of_type_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_CaselessKeyword);
  Py_VISIT(traverse_module_state->__pyx_n_u_CaselessKeyword);
  Py_VISIT(traverse_module_state->__pyx_n_s_CaselessKeyword___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_CaselessLiteral);
  Py_VISIT(traverse_module_state->__pyx_n_u_CaselessLiteral);
  Py_VISIT(traverse_module_state->__pyx_n_s_CaselessLiteral___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_CaselessLiteral_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Caseless_version_of_class_Keywo);
  Py_VISIT(traverse_module_state->__pyx_n_s_Char);
  Py_VISIT(traverse_module_state->__pyx_n_u_Char);
  Py_VISIT(traverse_module_state->__pyx_n_s_Char___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_CharsNotIn);
  Py_VISIT(traverse_module_state->__pyx_n_u_CharsNotIn);
  Py_VISIT(traverse_module_state->__pyx_n_s_CharsNotIn___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_CharsNotIn___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_CharsNotIn_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Chinese);
  Py_VISIT(traverse_module_state->__pyx_n_s_CloseMatch);
  Py_VISIT(traverse_module_state->__pyx_n_u_CloseMatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_CloseMatch___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_CloseMatch_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Combine);
  Py_VISIT(traverse_module_state->__pyx_n_u_Combine);
  Py_VISIT(traverse_module_state->__pyx_n_s_Combine___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Combine_ignore);
  Py_VISIT(traverse_module_state->__pyx_n_s_Combine_postParse);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Context_manager_to_be_used_when);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Converter_for_ignoring_the_resul);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Converter_to_concatenate_all_mat);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Converter_to_return_a_repetitive);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Converter_to_return_the_matched);
  Py_VISIT(traverse_module_state->__pyx_n_s_Cyrillic);
  Py_VISIT(traverse_module_state->__pyx_n_s_DEFAULT_KEYWORD_CHARS);
  Py_VISIT(traverse_module_state->__pyx_n_s_DEFAULT_WHITE_CHARS);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOTALL);
  Py_VISIT(traverse_module_state->__pyx_n_s_Devanagari);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Diagnostic_configuration_all_de);
  Py_VISIT(traverse_module_state->__pyx_n_s_Dict);
  Py_VISIT(traverse_module_state->__pyx_n_u_Dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_Dict___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Dict_postParse);
  Py_VISIT(traverse_module_state->__pyx_kp_u_EM_QUAD);
  Py_VISIT(traverse_module_state->__pyx_kp_u_EM_SPACE);
  Py_VISIT(traverse_module_state->__pyx_kp_u_EN_QUAD);
  Py_VISIT(traverse_module_state->__pyx_kp_u_EN_SPACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each);
  Py_VISIT(traverse_module_state->__pyx_n_u_Each);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each___init___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each___str___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each_checkRecursion);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each_parseImpl_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each_streamline);
  Py_VISIT(traverse_module_state->__pyx_n_s_Each_streamline_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ellipsis);
  Py_VISIT(traverse_module_state->__pyx_n_s_Empty);
  Py_VISIT(traverse_module_state->__pyx_n_u_Empty);
  Py_VISIT(traverse_module_state->__pyx_n_s_Empty___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_ErrorStop);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Evan_Hubinger_evanjhub_gmail_com);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Exception_creating_Regex_for_one);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Exception_raised);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Exception_thrown_when_parse_exp);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Expected);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Expected_end_of_line);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Expected_end_of_text);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Expected_start_of_line);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Expected_start_of_text);
  Py_VISIT(traverse_module_state->__pyx_n_s_FAIL);
  Py_VISIT(traverse_module_state->__pyx_kp_u_FAIL_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_FAIL_EXCEPTION);
  Py_VISIT(traverse_module_state->__pyx_kp_u_FATAL);
  Py_VISIT(traverse_module_state->__pyx_n_s_FB);
  Py_VISIT(traverse_module_state->__pyx_kp_u_FF);
  Py_VISIT(traverse_module_state->__pyx_kp_u_FIGURE_SPACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_FILE_NAME);
  Py_VISIT(traverse_module_state->__pyx_kp_u_FOUR_PER_EM_SPACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_FifoCache);
  Py_VISIT(traverse_module_state->__pyx_n_s_FifoCache___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_FifoCache___len);
  Py_VISIT(traverse_module_state->__pyx_n_s_FifoCache___reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_FifoCache_clear);
  Py_VISIT(traverse_module_state->__pyx_n_s_FifoCache_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_FifoCache_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_FifoCache_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_FollowedBy);
  Py_VISIT(traverse_module_state->__pyx_n_u_FollowedBy);
  Py_VISIT(traverse_module_state->__pyx_n_s_FollowedBy___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_FollowedBy_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward);
  Py_VISIT(traverse_module_state->__pyx_n_u_Forward);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward___ilshift);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward___lshift);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward__setResultsName);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward_copy);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Forward_declaration_of_an_expres);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward_leaveWhitespace);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward_streamline);
  Py_VISIT(traverse_module_state->__pyx_n_s_Forward_validate);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Found_unwanted_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_GoToColumn);
  Py_VISIT(traverse_module_state->__pyx_n_u_GoToColumn);
  Py_VISIT(traverse_module_state->__pyx_n_s_GoToColumn___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_GoToColumn_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_GoToColumn_preParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_Greek);
  Py_VISIT(traverse_module_state->__pyx_n_s_Group);
  Py_VISIT(traverse_module_state->__pyx_n_u_Group);
  Py_VISIT(traverse_module_state->__pyx_n_s_Group___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Group_postParse);
  Py_VISIT(traverse_module_state->__pyx_kp_u_HAIR_SPACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_HIT);
  Py_VISIT(traverse_module_state->__pyx_kp_u_HTML_comment);
  Py_VISIT(traverse_module_state->__pyx_n_s_Hebrew);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Here_are_some_common_low_level_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_Hiragana);
  Py_VISIT(traverse_module_state->__pyx_kp_u_IDEOGRAPHIC_SPACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_INDENT);
  Py_VISIT(traverse_module_state->__pyx_n_u_INDENT);
  Py_VISIT(traverse_module_state->__pyx_kp_u_IPv4_address);
  Py_VISIT(traverse_module_state->__pyx_kp_u_IPv6_address);
  Py_VISIT(traverse_module_state->__pyx_kp_u_ISO8601_date);
  Py_VISIT(traverse_module_state->__pyx_kp_u_ISO8601_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_u_ITEM);
  Py_VISIT(traverse_module_state->__pyx_n_s_ImportError);
  Py_VISIT(traverse_module_state->__pyx_n_s_IndexError);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_argument_to_oneOf_expect);
  Py_VISIT(traverse_module_state->__pyx_n_s_Iterable);
  Py_VISIT(traverse_module_state->__pyx_n_s_Japanese);
  Py_VISIT(traverse_module_state->__pyx_n_s_Kanji);
  Py_VISIT(traverse_module_state->__pyx_n_s_Katakana);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyError);
  Py_VISIT(traverse_module_state->__pyx_n_s_Keyword);
  Py_VISIT(traverse_module_state->__pyx_n_u_Keyword);
  Py_VISIT(traverse_module_state->__pyx_n_s_Keyword___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Keyword_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_Keyword_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Keyword_setDefaultKeywordChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_Korean);
  Py_VISIT(traverse_module_state->__pyx_n_s_L);
  Py_VISIT(traverse_module_state->__pyx_n_s_LEFT);
  Py_VISIT(traverse_module_state->__pyx_kp_u_LF);
  Py_VISIT(traverse_module_state->__pyx_n_s_L_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Latin1);
  Py_VISIT(traverse_module_state->__pyx_n_s_LatinA);
  Py_VISIT(traverse_module_state->__pyx_n_s_LatinB);
  Py_VISIT(traverse_module_state->__pyx_n_s_LineEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_LineEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_LineEnd___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_LineEnd_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_LineStart);
  Py_VISIT(traverse_module_state->__pyx_n_u_LineStart);
  Py_VISIT(traverse_module_state->__pyx_n_s_LineStart___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_LineStart_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Literal);
  Py_VISIT(traverse_module_state->__pyx_n_u_Literal);
  Py_VISIT(traverse_module_state->__pyx_n_s_Literal___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Literal_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Lookahead_matching_of_the_given);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Lookahead_to_disallow_matching_w);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Lookbehind_matching_of_the_given);
  Py_VISIT(traverse_module_state->__pyx_kp_u_MAC_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_MATCH);
  Py_VISIT(traverse_module_state->__pyx_n_s_MAX_INT);
  Py_VISIT(traverse_module_state->__pyx_n_s_MISS);
  Py_VISIT(traverse_module_state->__pyx_kp_u_MMSP);
  Py_VISIT(traverse_module_state->__pyx_kp_u_MONGOLIAN_VOWEL_SEPARATOR);
  Py_VISIT(traverse_module_state->__pyx_n_s_MULTILINE);
  Py_VISIT(traverse_module_state->__pyx_n_s_Mapping);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Match);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst);
  Py_VISIT(traverse_module_state->__pyx_n_u_MatchFirst);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst___init___locals_genex);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst___ior);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst___str___locals_genexp);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst__setResultsName);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst__setResultsName_local);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst_checkRecursion);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst_setAdaptiveMode);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst_streamline);
  Py_VISIT(traverse_module_state->__pyx_n_s_MatchFirst_streamline_locals_gen);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Matched);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Matches_if_current_position_is_a);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Matches_if_current_position_is_a_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Matches_if_current_position_is_a_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Matches_if_current_position_is_a_4);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Matches_if_the_current_position);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Matches_if_the_current_position_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Missing_one_or_more_required_ele);
  Py_VISIT(traverse_module_state->__pyx_kp_u_More_than_one_string_argument_pa);
  Py_VISIT(traverse_module_state->__pyx_n_s_MultipleMatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_MultipleMatch___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_MultipleMatch__setResultsName);
  Py_VISIT(traverse_module_state->__pyx_n_s_MultipleMatch_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_MultipleMatch_stopOn);
  Py_VISIT(traverse_module_state->__pyx_n_s_MutableMapping);
  Py_VISIT(traverse_module_state->__pyx_kp_u_NBSP);
  Py_VISIT(traverse_module_state->__pyx_n_s_NL);
  Py_VISIT(traverse_module_state->__pyx_kp_u_NNBSP);
  Py_VISIT(traverse_module_state->__pyx_n_s_NameError);
  Py_VISIT(traverse_module_state->__pyx_n_s_NoMatch);
  Py_VISIT(traverse_module_state->__pyx_n_u_NoMatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_NoMatch___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_NoMatch_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_u_No_match_found_for);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotAny);
  Py_VISIT(traverse_module_state->__pyx_n_u_NotAny);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotAny___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotAny___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotAny_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Not_at_the_end_of_a_word);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Not_at_the_start_of_a_word);
  Py_VISIT(traverse_module_state->__pyx_n_s_NullToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_NullToken___bool);
  Py_VISIT(traverse_module_state->__pyx_n_s_NullToken___str);
  Py_VISIT(traverse_module_state->__pyx_kp_u_OGHAM_SPACE_MARK);
  Py_VISIT(traverse_module_state->__pyx_n_s_OneOrMore);
  Py_VISIT(traverse_module_state->__pyx_n_u_OneOrMore);
  Py_VISIT(traverse_module_state->__pyx_n_s_OneOrMore___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_OnlyOnce);
  Py_VISIT(traverse_module_state->__pyx_n_u_OnlyOnce);
  Py_VISIT(traverse_module_state->__pyx_n_s_OnlyOnce___call);
  Py_VISIT(traverse_module_state->__pyx_n_s_OnlyOnce___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_OnlyOnce_reset);
  Py_VISIT(traverse_module_state->__pyx_n_s_Optional);
  Py_VISIT(traverse_module_state->__pyx_n_u_Optional);
  Py_VISIT(traverse_module_state->__pyx_n_s_Optional___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Optional___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_Optional__optionalNotMatched);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Optional_matching_of_the_given_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_Optional_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Optional_repetition_of_zero_or_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or);
  Py_VISIT(traverse_module_state->__pyx_n_u_Or);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or___init___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or___ixor);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or___str___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or__setResultsName);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or__setResultsName_locals_genexp);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or_checkRecursion);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or_streamline);
  Py_VISIT(traverse_module_state->__pyx_n_s_Or_streamline_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_OrderedDict);
  Py_VISIT(traverse_module_state->__pyx_n_s_OrderedDict_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_PEER);
  Py_VISIT(traverse_module_state->__pyx_kp_u_PUNCTUATION_SPACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_PY_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_P_entity);
  Py_VISIT(traverse_module_state->__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d);
  Py_VISIT(traverse_module_state->__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseBaseException);
  Py_VISIT(traverse_module_state->__pyx_n_u_ParseBaseException);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseBaseException___dir);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseBaseException___getattr);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseBaseException___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseBaseException___repr);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseBaseException___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseBaseException__from_excepti);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseBaseException_markInputline);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseElementEnhance);
  Py_VISIT(traverse_module_state->__pyx_n_u_ParseElementEnhance);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseElementEnhance___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseElementEnhance___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseElementEnhance_checkRecursi);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseElementEnhance_ignore);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseElementEnhance_leaveWhitesp);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseElementEnhance_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseElementEnhance_streamline);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseElementEnhance_validate);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseException);
  Py_VISIT(traverse_module_state->__pyx_n_u_ParseException);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseException_explain);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression);
  Py_VISIT(traverse_module_state->__pyx_n_u_ParseExpression);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression___init___locals);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression___init___locals_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression__setResultsName);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression_append);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression_ignore);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression_leaveWhitespace);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression_streamline);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseExpression_validate);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseFatalException);
  Py_VISIT(traverse_module_state->__pyx_n_u_ParseFatalException);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults);
  Py_VISIT(traverse_module_state->__pyx_n_u_ParseResults);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResultsWithOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResultsWithOffset___getite);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResultsWithOffset___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResultsWithOffset___repr);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResultsWithOffset_setOffse);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___add);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___bool);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___contains);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___delitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___dir);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___getattr);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___getnewargs);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___iadd);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___iadd___locals_lam);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___iter);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___len);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___new);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___radd);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___repr);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___reversed);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___setitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults___str___locals_gene);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__accumNames);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__asList);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__asStringList);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__doinit);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__iteritems);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__iteritems_locals_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__iterkeys);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__itervalues);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__itervalues_locals);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__modal);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__name);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__parent);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__tokdict);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults__toklist);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_append);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_asDict);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_asDict_locals_genex);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_asDict_locals_toIte);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_asList);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_asXML);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_asXML_locals_genexp);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_clear);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_dump_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_extend);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_from_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_from_dict_locals_is);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_getName);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_haskeys);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_insert);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_pop);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_pprint);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseResults_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParseSyntaxException);
  Py_VISIT(traverse_module_state->__pyx_n_u_ParseSyntaxException);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement);
  Py_VISIT(traverse_module_state->__pyx_n_u_ParserElement);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___add);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___and);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___call);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___eq);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___hash);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___invert);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___iter);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___mul);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___mul___locals_gen);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___mul___locals_mak);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___ne);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___or);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___radd);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___rand);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___repr);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___req);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___rmul);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___rne);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___ror);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___rsub);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___rxor);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___sub);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement___xor);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement__parseCache);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement__parseIncremental);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement__parseIncremental_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement__parseNoCache);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement__setResultsName);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement__skipIgnorables);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement__trim_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement__update_furthest_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_addCondition);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_addParseAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_canParseNext);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_checkRecursion);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_collectParseElemen);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_enableIncremental);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_enablePackrat);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_ignore);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_inlineLiteralsUsin);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_leaveWhitespace);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_matches);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_parseFile);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_parseString);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_parseWithTabs);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_postParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_preParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_resetCache);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_runTests);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_scanString);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_searchString);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setBreak);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setBreak_locals_br);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setDebug);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setDebugActions);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setDefaultWhitespa);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setFailAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setName);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setParseAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setParseAction_loc);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setResultsName);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_setWhitespaceChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_split);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_streamline);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_suppress);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_transformString);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_tryParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserElement_validate);
  Py_VISIT(traverse_module_state->__pyx_n_s_PendingSkip);
  Py_VISIT(traverse_module_state->__pyx_n_s_PendingSkip___add);
  Py_VISIT(traverse_module_state->__pyx_n_s_PendingSkip___add___locals_must);
  Py_VISIT(traverse_module_state->__pyx_n_s_PendingSkip___add___locals_show);
  Py_VISIT(traverse_module_state->__pyx_n_s_PendingSkip___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_PendingSkip___repr);
  Py_VISIT(traverse_module_state->__pyx_n_s_PendingSkip_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_PositionToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_PositionToken___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_PrecededBy);
  Py_VISIT(traverse_module_state->__pyx_n_u_PrecededBy);
  Py_VISIT(traverse_module_state->__pyx_n_s_PrecededBy___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_PrecededBy___init___locals_lambd);
  Py_VISIT(traverse_module_state->__pyx_n_s_PrecededBy_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Python_style_comment);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuotedString);
  Py_VISIT(traverse_module_state->__pyx_n_u_QuotedString);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuotedString___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuotedString___init___locals_gen);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuotedString___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuotedString_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_RIGHT);
  Py_VISIT(traverse_module_state->__pyx_n_s_RLock);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Re_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_RecursiveGrammarException);
  Py_VISIT(traverse_module_state->__pyx_n_u_RecursiveGrammarException);
  Py_VISIT(traverse_module_state->__pyx_n_s_RecursiveGrammarException___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_RecursiveGrammarException___str);
  Py_VISIT(traverse_module_state->__pyx_kp_u_RecursiveGrammarException_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_Regex);
  Py_VISIT(traverse_module_state->__pyx_n_u_Regex);
  Py_VISIT(traverse_module_state->__pyx_n_s_Regex___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Regex___str);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Regex_may_only_be_constructed_wi);
  Py_VISIT(traverse_module_state->__pyx_n_s_Regex_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Regex_parseImplAsGroupList);
  Py_VISIT(traverse_module_state->__pyx_n_s_Regex_parseImplAsMatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_Regex_sub);
  Py_VISIT(traverse_module_state->__pyx_n_s_Regex_sub_locals_pa);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Repetition_of_one_or_more_of_the);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Requires_all_given_class_ParseE);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Requires_all_given_class_ParseEx);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Requires_that_at_least_one_class);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Requires_that_at_least_one_class_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_SIX_PER_EM_SPACE);
  Py_VISIT(traverse_module_state->__pyx_kp_u_SP);
  Py_VISIT(traverse_module_state->__pyx_n_s_SimpleNamespace);
  Py_VISIT(traverse_module_state->__pyx_n_s_SingleCharLiteral);
  Py_VISIT(traverse_module_state->__pyx_n_s_SingleCharLiteral_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_SkipTo);
  Py_VISIT(traverse_module_state->__pyx_n_u_SkipTo);
  Py_VISIT(traverse_module_state->__pyx_n_s_SkipTo___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_SkipTo_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Special_matching_class_for_match);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_StringEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringEnd___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringEnd_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringStart);
  Py_VISIT(traverse_module_state->__pyx_n_u_StringStart);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringStart___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringStart_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Structured_parse_results_to_prov);
  Py_VISIT(traverse_module_state->__pyx_n_s_Suppress);
  Py_VISIT(traverse_module_state->__pyx_n_u_Suppress);
  Py_VISIT(traverse_module_state->__pyx_n_s_Suppress_postParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_Suppress_suppress);
  Py_VISIT(traverse_module_state->__pyx_n_s_SyntaxError);
  Py_VISIT(traverse_module_state->__pyx_n_s_SyntaxWarning);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TAB);
  Py_VISIT(traverse_module_state->__pyx_kp_u_THIN_SPACE);
  Py_VISIT(traverse_module_state->__pyx_kp_u_THREE_PER_EM_SPACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_TRY);
  Py_VISIT(traverse_module_state->__pyx_n_s_TestParseResultsAsserts);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Text_not_in_expected_column);
  Py_VISIT(traverse_module_state->__pyx_n_s_Thai);
  Py_VISIT(traverse_module_state->__pyx_n_s_Token);
  Py_VISIT(traverse_module_state->__pyx_n_u_Token);
  Py_VISIT(traverse_module_state->__pyx_n_s_TokenConverter);
  Py_VISIT(traverse_module_state->__pyx_n_u_TokenConverter);
  Py_VISIT(traverse_module_state->__pyx_n_s_TokenConverter___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Token___init);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Token_for_matching_strings_that);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Token_for_matching_strings_that_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Token_for_matching_words_compose);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Token_for_matching_words_compose_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Token_for_skipping_over_all_unde);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Token_to_advance_to_a_specific_c);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Token_to_exactly_match_a_specifi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Token_to_exactly_match_a_specifi_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Token_to_match_a_specified_strin);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_UNDENT);
  Py_VISIT(traverse_module_state->__pyx_n_u_UNINDENT);
  Py_VISIT(traverse_module_state->__pyx_n_s_UUID);
  Py_VISIT(traverse_module_state->__pyx_n_u_UUID);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnboundedCache);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnboundedCache___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnboundedCache___len);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnboundedCache___reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnboundedCache_clear);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnboundedCache_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnboundedCache_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnboundedCache_update);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Arabic_Unicode_C);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Chinese_Unicode);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Cyrillic_Unicode);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Devanagari_Unico);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Greek_Unicode_Ch);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Hebrew_Unicode_C);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Hiragana_Unicode);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Japanese_Unicode);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Kanji_Unicode_Ch);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Katakana_Unicode);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Korean_Unicode_C);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Latin_1_Unicode);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Latin_A_Unicode);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Latin_B_Unicode);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_Thai_Unicode_Cha);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unicode_set_for_combined_Chinese);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unmatchable_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_kp_u_W);
  Py_VISIT(traverse_module_state->__pyx_n_s_WRAP_CALL_LINE_NUM);
  Py_VISIT(traverse_module_state->__pyx_kp_u_W_s);
  Py_VISIT(traverse_module_state->__pyx_kp_u_W_s_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_W_s_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_White);
  Py_VISIT(traverse_module_state->__pyx_n_u_White);
  Py_VISIT(traverse_module_state->__pyx_n_s_White___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_White___init___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_White_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Word);
  Py_VISIT(traverse_module_state->__pyx_n_u_Word);
  Py_VISIT(traverse_module_state->__pyx_n_s_WordEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_WordEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_WordEnd___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_WordEnd_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_WordRegex);
  Py_VISIT(traverse_module_state->__pyx_n_s_WordRegex_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_WordStart);
  Py_VISIT(traverse_module_state->__pyx_n_u_WordStart);
  Py_VISIT(traverse_module_state->__pyx_n_s_WordStart___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_WordStart_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Word___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_Word___init___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Word___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_Word___str___locals_charsAsStr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Word_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Wrapper_for_parse_actions_to_ens);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Y_m_d);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Y_m_dT_H_M_S_f);
  Py_VISIT(traverse_module_state->__pyx_kp_u_ZERO_WIDTH_SPACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZeroOrMore);
  Py_VISIT(traverse_module_state->__pyx_n_u_ZeroOrMore);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZeroOrMore___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZeroOrMore___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZeroOrMore_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_kp_u__10);
  Py_VISIT(traverse_module_state->__pyx_kp_u__100);
  Py_VISIT(traverse_module_state->__pyx_kp_u__102);
  Py_VISIT(traverse_module_state->__pyx_kp_u__104);
  Py_VISIT(traverse_module_state->__pyx_kp_u__105);
  Py_VISIT(traverse_module_state->__pyx_kp_u__107);
  Py_VISIT(traverse_module_state->__pyx_kp_u__108);
  Py_VISIT(traverse_module_state->__pyx_kp_u__11);
  Py_VISIT(traverse_module_state->__pyx_kp_u__110);
  Py_VISIT(traverse_module_state->__pyx_kp_u__111);
  Py_VISIT(traverse_module_state->__pyx_kp_u__112);
  Py_VISIT(traverse_module_state->__pyx_kp_u__113);
  Py_VISIT(traverse_module_state->__pyx_kp_u__114);
  Py_VISIT(traverse_module_state->__pyx_kp_u__115);
  Py_VISIT(traverse_module_state->__pyx_kp_u__116);
  Py_VISIT(traverse_module_state->__pyx_kp_u__117);
  Py_VISIT(traverse_module_state->__pyx_kp_u__118);
  Py_VISIT(traverse_module_state->__pyx_kp_u__119);
  Py_VISIT(traverse_module_state->__pyx_kp_u__12);
  Py_VISIT(traverse_module_state->__pyx_kp_u__122);
  Py_VISIT(traverse_module_state->__pyx_kp_u__13);
  Py_VISIT(traverse_module_state->__pyx_kp_u__136);
  Py_VISIT(traverse_module_state->__pyx_kp_u__14);
  Py_VISIT(traverse_module_state->__pyx_kp_u__144);
  Py_VISIT(traverse_module_state->__pyx_kp_u__145);
  Py_VISIT(traverse_module_state->__pyx_kp_u__147);
  Py_VISIT(traverse_module_state->__pyx_kp_u__148);
  Py_VISIT(traverse_module_state->__pyx_n_s__15);
  Py_VISIT(traverse_module_state->__pyx_kp_u__15);
  Py_VISIT(traverse_module_state->__pyx_kp_u__150);
  Py_VISIT(traverse_module_state->__pyx_kp_u__16);
  Py_VISIT(traverse_module_state->__pyx_kp_u__166);
  Py_VISIT(traverse_module_state->__pyx_kp_u__17);
  Py_VISIT(traverse_module_state->__pyx_kp_u__19);
  Py_VISIT(traverse_module_state->__pyx_kp_u__2);
  Py_VISIT(traverse_module_state->__pyx_kp_u__22);
  Py_VISIT(traverse_module_state->__pyx_kp_u__25);
  Py_VISIT(traverse_module_state->__pyx_kp_u__26);
  Py_VISIT(traverse_module_state->__pyx_kp_u__27);
  Py_VISIT(traverse_module_state->__pyx_kp_u__28);
  Py_VISIT(traverse_module_state->__pyx_kp_u__29);
  Py_VISIT(traverse_module_state->__pyx_kp_u__3);
  Py_VISIT(traverse_module_state->__pyx_kp_u__30);
  Py_VISIT(traverse_module_state->__pyx_kp_u__31);
  Py_VISIT(traverse_module_state->__pyx_kp_u__339);
  Py_VISIT(traverse_module_state->__pyx_kp_u__34);
  Py_VISIT(traverse_module_state->__pyx_kp_u__35);
  Py_VISIT(traverse_module_state->__pyx_kp_u__4);
  Py_VISIT(traverse_module_state->__pyx_kp_u__461);
  Py_VISIT(traverse_module_state->__pyx_kp_u__5);
  Py_VISIT(traverse_module_state->__pyx_kp_u__511);
  Py_VISIT(traverse_module_state->__pyx_kp_u__512);
  Py_VISIT(traverse_module_state->__pyx_kp_u__513);
  Py_VISIT(traverse_module_state->__pyx_kp_u__514);
  Py_VISIT(traverse_module_state->__pyx_kp_u__515);
  Py_VISIT(traverse_module_state->__pyx_kp_u__516);
  Py_VISIT(traverse_module_state->__pyx_kp_u__517);
  Py_VISIT(traverse_module_state->__pyx_kp_u__518);
  Py_VISIT(traverse_module_state->__pyx_kp_u__519);
  Py_VISIT(traverse_module_state->__pyx_kp_u__520);
  Py_VISIT(traverse_module_state->__pyx_kp_u__521);
  Py_VISIT(traverse_module_state->__pyx_kp_u__522);
  Py_VISIT(traverse_module_state->__pyx_kp_u__523);
  Py_VISIT(traverse_module_state->__pyx_kp_u__524);
  Py_VISIT(traverse_module_state->__pyx_kp_u__525);
  Py_VISIT(traverse_module_state->__pyx_kp_u__526);
  Py_VISIT(traverse_module_state->__pyx_kp_u__527);
  Py_VISIT(traverse_module_state->__pyx_kp_u__528);
  Py_VISIT(traverse_module_state->__pyx_kp_u__6);
  Py_VISIT(traverse_module_state->__pyx_n_s__621);
  Py_VISIT(traverse_module_state->__pyx_n_u__621);
  Py_VISIT(traverse_module_state->__pyx_kp_u__65);
  Py_VISIT(traverse_module_state->__pyx_kp_u__66);
  Py_VISIT(traverse_module_state->__pyx_kp_u__67);
  Py_VISIT(traverse_module_state->__pyx_kp_u__7);
  Py_VISIT(traverse_module_state->__pyx_kp_u__718);
  Py_VISIT(traverse_module_state->__pyx_kp_u__721);
  Py_VISIT(traverse_module_state->__pyx_kp_u__755);
  Py_VISIT(traverse_module_state->__pyx_kp_u__768);
  Py_VISIT(traverse_module_state->__pyx_kp_u__770);
  Py_VISIT(traverse_module_state->__pyx_kp_u__771);
  Py_VISIT(traverse_module_state->__pyx_kp_u__774);
  Py_VISIT(traverse_module_state->__pyx_kp_u__776);
  Py_VISIT(traverse_module_state->__pyx_kp_u__780);
  Py_VISIT(traverse_module_state->__pyx_kp_u__786);
  Py_VISIT(traverse_module_state->__pyx_kp_u__789);
  Py_VISIT(traverse_module_state->__pyx_kp_u__79);
  Py_VISIT(traverse_module_state->__pyx_kp_u__795);
  Py_VISIT(traverse_module_state->__pyx_kp_u__80);
  Py_VISIT(traverse_module_state->__pyx_n_u__856);
  Py_VISIT(traverse_module_state->__pyx_n_u__857);
  Py_VISIT(traverse_module_state->__pyx_n_u__858);
  Py_VISIT(traverse_module_state->__pyx_n_u__859);
  Py_VISIT(traverse_module_state->__pyx_kp_u__860);
  Py_VISIT(traverse_module_state->__pyx_n_u__861);
  Py_VISIT(traverse_module_state->__pyx_n_u__862);
  Py_VISIT(traverse_module_state->__pyx_n_u__863);
  Py_VISIT(traverse_module_state->__pyx_n_u__864);
  Py_VISIT(traverse_module_state->__pyx_n_u__865);
  Py_VISIT(traverse_module_state->__pyx_n_u__866);
  Py_VISIT(traverse_module_state->__pyx_kp_u__867);
  Py_VISIT(traverse_module_state->__pyx_n_s__893);
  Py_VISIT(traverse_module_state->__pyx_kp_u__91);
  Py_VISIT(traverse_module_state->__pyx_kp_u__94);
  Py_VISIT(traverse_module_state->__pyx_kp_u__95);
  Py_VISIT(traverse_module_state->__pyx_kp_u__96);
  Py_VISIT(traverse_module_state->__pyx_kp_u__97);
  Py_VISIT(traverse_module_state->__pyx_kp_u__98);
  Py_VISIT(traverse_module_state->__pyx_kp_u__99);
  Py_VISIT(traverse_module_state->__pyx_n_s_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_adaptive_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_adaptive_usage);
  Py_VISIT(traverse_module_state->__pyx_n_s_adaptive_usage_check_rate);
  Py_VISIT(traverse_module_state->__pyx_n_s_add);
  Py_VISIT(traverse_module_state->__pyx_n_s_addCondition);
  Py_VISIT(traverse_module_state->__pyx_n_s_addParseAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_addoffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_adjacent);
  Py_VISIT(traverse_module_state->__pyx_n_s_all);
  Py_VISIT(traverse_module_state->__pyx_n_s_allResults);
  Py_VISIT(traverse_module_state->__pyx_n_s_all_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_all_names);
  Py_VISIT(traverse_module_state->__pyx_n_s_all_parse_elements);
  Py_VISIT(traverse_module_state->__pyx_n_s_allow_unused_expr_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_alphanums);
  Py_VISIT(traverse_module_state->__pyx_n_u_alphanums);
  Py_VISIT(traverse_module_state->__pyx_n_s_alphas);
  Py_VISIT(traverse_module_state->__pyx_n_u_alphas);
  Py_VISIT(traverse_module_state->__pyx_n_s_alphas8bit);
  Py_VISIT(traverse_module_state->__pyx_n_u_alphas8bit);
  Py_VISIT(traverse_module_state->__pyx_kp_u_amp_gt_lt_quot_apos);
  Py_VISIT(traverse_module_state->__pyx_n_s_aname);
  Py_VISIT(traverse_module_state->__pyx_n_s_anchor);
  Py_VISIT(traverse_module_state->__pyx_n_s_and);
  Py_VISIT(traverse_module_state->__pyx_n_s_any);
  Py_VISIT(traverse_module_state->__pyx_n_s_anyCloseTag);
  Py_VISIT(traverse_module_state->__pyx_n_u_anyCloseTag);
  Py_VISIT(traverse_module_state->__pyx_n_s_anyOpenTag);
  Py_VISIT(traverse_module_state->__pyx_n_u_anyOpenTag);
  Py_VISIT(traverse_module_state->__pyx_kp_u_any_tag);
  Py_VISIT(traverse_module_state->__pyx_n_s_append);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_n_u_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_arity);
  Py_VISIT(traverse_module_state->__pyx_n_s_arrayExpr);
  Py_VISIT(traverse_module_state->__pyx_n_u_arrayLen);
  Py_VISIT(traverse_module_state->__pyx_n_s_asDict);
  Py_VISIT(traverse_module_state->__pyx_n_s_asGroupList);
  Py_VISIT(traverse_module_state->__pyx_n_s_asKeyword);
  Py_VISIT(traverse_module_state->__pyx_n_s_asList);
  Py_VISIT(traverse_module_state->__pyx_n_s_asMatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_asString);
  Py_VISIT(traverse_module_state->__pyx_n_s_asStringList);
  Py_VISIT(traverse_module_state->__pyx_n_s_asXML);
  Py_VISIT(traverse_module_state->__pyx_kp_u_as_column_list_and_dotted_table);
  Py_VISIT(traverse_module_state->__pyx_n_s_ascii_lowercase);
  Py_VISIT(traverse_module_state->__pyx_n_s_ascii_uppercase);
  Py_VISIT(traverse_module_state->__pyx_n_s_assertEqual);
  Py_VISIT(traverse_module_state->__pyx_n_s_assertParseAndCheckDict);
  Py_VISIT(traverse_module_state->__pyx_n_s_assertParseAndCheckList);
  Py_VISIT(traverse_module_state->__pyx_n_s_assertParseResultsEquals);
  Py_VISIT(traverse_module_state->__pyx_n_s_assertRaises);
  Py_VISIT(traverse_module_state->__pyx_n_s_assertRaisesParseException);
  Py_VISIT(traverse_module_state->__pyx_n_s_assertRunTestResults);
  Py_VISIT(traverse_module_state->__pyx_n_s_assertTrue);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_kp_u_at_char);
  Py_VISIT(traverse_module_state->__pyx_kp_u_at_loc);
  Py_VISIT(traverse_module_state->__pyx_n_s_attrDict);
  Py_VISIT(traverse_module_state->__pyx_n_s_attrName);
  Py_VISIT(traverse_module_state->__pyx_n_s_attrValue);
  Py_VISIT(traverse_module_state->__pyx_kp_u_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_attrname);
  Py_VISIT(traverse_module_state->__pyx_n_s_attrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_author);
  Py_VISIT(traverse_module_state->__pyx_n_u_author);
  Py_VISIT(traverse_module_state->__pyx_kp_u_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_b_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_b_s_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_backup_stack);
  Py_VISIT(traverse_module_state->__pyx_n_s_baseExpr);
  Py_VISIT(traverse_module_state->__pyx_kp_s_base_exception_class_for_all_par);
  Py_VISIT(traverse_module_state->__pyx_n_s_basestring);
  Py_VISIT(traverse_module_state->__pyx_n_s_best_expr);
  Py_VISIT(traverse_module_state->__pyx_n_s_blockStatementExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_body);
  Py_VISIT(traverse_module_state->__pyx_n_u_body);
  Py_VISIT(traverse_module_state->__pyx_n_s_bodyChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_bodyCharsOrig);
  Py_VISIT(traverse_module_state->__pyx_n_s_bodychars);
  Py_VISIT(traverse_module_state->__pyx_n_s_bool);
  Py_VISIT(traverse_module_state->__pyx_n_s_breakFlag);
  Py_VISIT(traverse_module_state->__pyx_n_s_breaker);
  Py_VISIT(traverse_module_state->__pyx_n_s_bslash);
  Py_VISIT(traverse_module_state->__pyx_n_s_builtin);
  Py_VISIT(traverse_module_state->__pyx_n_s_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_cPyparsing);
  Py_VISIT(traverse_module_state->__pyx_kp_s_cPyparsing_pyx);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cPyparsing_pyx);
  Py_VISIT(traverse_module_state->__pyx_n_s_cStyleComment);
  Py_VISIT(traverse_module_state->__pyx_n_u_cStyleComment);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache);
  Py_VISIT(traverse_module_state->__pyx_n_u_cache);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache_furthest_loc);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache_size_limit);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache_successes);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache_usefullness_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_call);
  Py_VISIT(traverse_module_state->__pyx_n_s_callDuringTry);
  Py_VISIT(traverse_module_state->__pyx_n_u_callDuringTry);
  Py_VISIT(traverse_module_state->__pyx_n_s_callPreParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_callPreparse);
  Py_VISIT(traverse_module_state->__pyx_n_s_callable);
  Py_VISIT(traverse_module_state->__pyx_n_s_called);
  Py_VISIT(traverse_module_state->__pyx_n_s_callers);
  Py_VISIT(traverse_module_state->__pyx_n_s_canParseNext);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_construct_And_with_sequen);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_multiply_ParserElement_an);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_multiply_ParserElement_an_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_multiply_ParserElement_by);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_multiply_ParserElement_by_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_specify_a_minimum_length);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_specify_a_minimum_length_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_use_sub_with_Regex_asGrou);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_use_sub_with_a_callable_w);
  Py_VISIT(traverse_module_state->__pyx_n_s_caseless);
  Py_VISIT(traverse_module_state->__pyx_n_s_caselessmatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_cause);
  Py_VISIT(traverse_module_state->__pyx_n_s_cc);
  Py_VISIT(traverse_module_state->__pyx_n_s_charRange);
  Py_VISIT(traverse_module_state->__pyx_n_s_chars);
  Py_VISIT(traverse_module_state->__pyx_n_s_charsAsStr);
  Py_VISIT(traverse_module_state->__pyx_n_s_charset);
  Py_VISIT(traverse_module_state->__pyx_n_s_checkPeerIndent);
  Py_VISIT(traverse_module_state->__pyx_n_s_checkRecursion);
  Py_VISIT(traverse_module_state->__pyx_n_s_checkSubIndent);
  Py_VISIT(traverse_module_state->__pyx_n_s_checkUnindent);
  Py_VISIT(traverse_module_state->__pyx_n_s_check_ender);
  Py_VISIT(traverse_module_state->__pyx_n_s_chr);
  Py_VISIT(traverse_module_state->__pyx_n_s_class);
  Py_VISIT(traverse_module_state->__pyx_n_u_class);
  Py_VISIT(traverse_module_state->__pyx_n_u_class_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_classattr);
  Py_VISIT(traverse_module_state->__pyx_n_s_classname);
  Py_VISIT(traverse_module_state->__pyx_n_s_clear);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_closeTag);
  Py_VISIT(traverse_module_state->__pyx_n_s_closer);
  Py_VISIT(traverse_module_state->__pyx_n_s_cls);
  Py_VISIT(traverse_module_state->__pyx_n_s_co_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_col);
  Py_VISIT(traverse_module_state->__pyx_n_u_col);
  Py_VISIT(traverse_module_state->__pyx_kp_u_col_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_collectParseElements);
  Py_VISIT(traverse_module_state->__pyx_n_s_collect_all_And_tokens);
  Py_VISIT(traverse_module_state->__pyx_n_u_collect_all_And_tokens);
  Py_VISIT(traverse_module_state->__pyx_n_s_collections);
  Py_VISIT(traverse_module_state->__pyx_n_s_collections_abc);
  Py_VISIT(traverse_module_state->__pyx_n_s_colno);
  Py_VISIT(traverse_module_state->__pyx_n_s_column);
  Py_VISIT(traverse_module_state->__pyx_n_u_column);
  Py_VISIT(traverse_module_state->__pyx_n_s_columnName);
  Py_VISIT(traverse_module_state->__pyx_n_s_columnNameList);
  Py_VISIT(traverse_module_state->__pyx_n_s_columnSpec);
  Py_VISIT(traverse_module_state->__pyx_n_u_columns);
  Py_VISIT(traverse_module_state->__pyx_n_s_combine);
  Py_VISIT(traverse_module_state->__pyx_n_u_commaItem);
  Py_VISIT(traverse_module_state->__pyx_n_s_commaSeparatedList);
  Py_VISIT(traverse_module_state->__pyx_n_u_commaSeparatedList);
  Py_VISIT(traverse_module_state->__pyx_kp_u_comma_separated_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_comma_separated_list_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_command);
  Py_VISIT(traverse_module_state->__pyx_n_s_commasepitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_comment);
  Py_VISIT(traverse_module_state->__pyx_kp_u_comment_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_comments);
  Py_VISIT(traverse_module_state->__pyx_n_s_commonHTMLEntity);
  Py_VISIT(traverse_module_state->__pyx_n_u_commonHTMLEntity);
  Py_VISIT(traverse_module_state->__pyx_kp_u_common_HTML_entity);
  Py_VISIT(traverse_module_state->__pyx_n_s_common_prefix_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_common_suffix_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_commonprefix);
  Py_VISIT(traverse_module_state->__pyx_n_s_compat);
  Py_VISIT(traverse_module_state->__pyx_n_u_compat);
  Py_VISIT(traverse_module_state->__pyx_n_s_compile);
  Py_VISIT(traverse_module_state->__pyx_n_s_conditionAsParseAction);
  Py_VISIT(traverse_module_state->__pyx_n_u_conditionAsParseAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_conditionAsParseAction_locals_pa);
  Py_VISIT(traverse_module_state->__pyx_n_s_contains);
  Py_VISIT(traverse_module_state->__pyx_n_s_content);
  Py_VISIT(traverse_module_state->__pyx_n_s_context);
  Py_VISIT(traverse_module_state->__pyx_n_s_contextlib);
  Py_VISIT(traverse_module_state->__pyx_n_s_contextmanager);
  Py_VISIT(traverse_module_state->__pyx_n_s_convertToDate);
  Py_VISIT(traverse_module_state->__pyx_n_s_convertToDatetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_convertToFloat);
  Py_VISIT(traverse_module_state->__pyx_n_s_convertToInteger);
  Py_VISIT(traverse_module_state->__pyx_n_s_convertWhitespaceEscapes);
  Py_VISIT(traverse_module_state->__pyx_n_s_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_copyDefaultWhiteChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_copyTokenToRepeater);
  Py_VISIT(traverse_module_state->__pyx_n_s_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_countFieldParseAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_countedArray);
  Py_VISIT(traverse_module_state->__pyx_n_u_countedArray);
  Py_VISIT(traverse_module_state->__pyx_n_s_countedArray_locals_countFieldPa);
  Py_VISIT(traverse_module_state->__pyx_n_s_countedArray_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_cppStyleComment);
  Py_VISIT(traverse_module_state->__pyx_n_u_cppStyleComment);
  Py_VISIT(traverse_module_state->__pyx_n_s_cpy);
  Py_VISIT(traverse_module_state->__pyx_n_s_cur);
  Py_VISIT(traverse_module_state->__pyx_n_s_curCol);
  Py_VISIT(traverse_module_state->__pyx_n_s_cvt_fn);
  Py_VISIT(traverse_module_state->__pyx_n_s_d);
  Py_VISIT(traverse_module_state->__pyx_n_u_d);
  Py_VISIT(traverse_module_state->__pyx_kp_u_d_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_d_d_d);
  Py_VISIT(traverse_module_state->__pyx_kp_u_d_d_eE_d);
  Py_VISIT(traverse_module_state->__pyx_kp_u_d_eE_d_d_d_d_eE_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_dblQuotedString);
  Py_VISIT(traverse_module_state->__pyx_n_u_dblQuotedString);
  Py_VISIT(traverse_module_state->__pyx_n_s_dblSlashComment);
  Py_VISIT(traverse_module_state->__pyx_n_u_dblSlashComment);
  Py_VISIT(traverse_module_state->__pyx_n_s_debug);
  Py_VISIT(traverse_module_state->__pyx_n_s_debugActions);
  Py_VISIT(traverse_module_state->__pyx_n_s_debugging);
  Py_VISIT(traverse_module_state->__pyx_n_s_decode);
  Py_VISIT(traverse_module_state->__pyx_n_s_default);
  Py_VISIT(traverse_module_state->__pyx_n_u_default);
  Py_VISIT(traverse_module_state->__pyx_n_s_defaultExceptionDebugAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_defaultStartDebugAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_defaultSuccessDebugAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_defaultValue);
  Py_VISIT(traverse_module_state->__pyx_n_u_default_keyword_chars);
  Py_VISIT(traverse_module_state->__pyx_n_u_default_whitespace);
  Py_VISIT(traverse_module_state->__pyx_n_s_defaultdict);
  Py_VISIT(traverse_module_state->__pyx_n_s_defaultvalue);
  Py_VISIT(traverse_module_state->__pyx_n_s_delim);
  Py_VISIT(traverse_module_state->__pyx_n_s_delimitedList);
  Py_VISIT(traverse_module_state->__pyx_n_u_delimitedList);
  Py_VISIT(traverse_module_state->__pyx_n_s_delitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_depth);
  Py_VISIT(traverse_module_state->__pyx_n_s_depth_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_deque);
  Py_VISIT(traverse_module_state->__pyx_n_s_diag);
  Py_VISIT(traverse_module_state->__pyx_n_u_diag);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_dictOf);
  Py_VISIT(traverse_module_state->__pyx_n_u_dictOf);
  Py_VISIT(traverse_module_state->__pyx_n_s_dictvalue);
  Py_VISIT(traverse_module_state->__pyx_n_s_dir);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_n_s_dlName);
  Py_VISIT(traverse_module_state->__pyx_n_s_doActions);
  Py_VISIT(traverse_module_state->__pyx_n_s_doc);
  Py_VISIT(traverse_module_state->__pyx_n_s_doctag);
  Py_VISIT(traverse_module_state->__pyx_n_s_downcaseTokens);
  Py_VISIT(traverse_module_state->__pyx_n_u_downcaseTokens);
  Py_VISIT(traverse_module_state->__pyx_n_s_dummy);
  Py_VISIT(traverse_module_state->__pyx_n_s_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_e2);
  Py_VISIT(traverse_module_state->__pyx_n_s_elem);
  Py_VISIT(traverse_module_state->__pyx_n_s_empty);
  Py_VISIT(traverse_module_state->__pyx_n_u_empty);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_enableIncremental);
  Py_VISIT(traverse_module_state->__pyx_n_s_enablePackrat);
  Py_VISIT(traverse_module_state->__pyx_n_u_enable_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_enable_all_warnings);
  Py_VISIT(traverse_module_state->__pyx_n_s_enable_all_warnings_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_enable_debug_on_named_expression);
  Py_VISIT(traverse_module_state->__pyx_n_s_end);
  Py_VISIT(traverse_module_state->__pyx_n_u_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_endQuoteChar);
  Py_VISIT(traverse_module_state->__pyx_n_s_endQuoteCharLen);
  Py_VISIT(traverse_module_state->__pyx_kp_u_endQuoteChar_cannot_be_the_empty);
  Py_VISIT(traverse_module_state->__pyx_n_s_ender);
  Py_VISIT(traverse_module_state->__pyx_kp_u_ending_with);
  Py_VISIT(traverse_module_state->__pyx_n_s_endloc);
  Py_VISIT(traverse_module_state->__pyx_n_s_endlocMarker);
  Py_VISIT(traverse_module_state->__pyx_n_s_endswith);
  Py_VISIT(traverse_module_state->__pyx_n_s_enter);
  Py_VISIT(traverse_module_state->__pyx_kp_u_entering);
  Py_VISIT(traverse_module_state->__pyx_n_s_entity);
  Py_VISIT(traverse_module_state->__pyx_n_s_enumerate);
  Py_VISIT(traverse_module_state->__pyx_n_s_eq);
  Py_VISIT(traverse_module_state->__pyx_n_s_err);
  Py_VISIT(traverse_module_state->__pyx_n_s_errmsg);
  Py_VISIT(traverse_module_state->__pyx_n_s_error);
  Py_VISIT(traverse_module_state->__pyx_n_s_errorStop);
  Py_VISIT(traverse_module_state->__pyx_n_s_escChar);
  Py_VISIT(traverse_module_state->__pyx_n_s_escCharReplacePattern);
  Py_VISIT(traverse_module_state->__pyx_n_s_escQuote);
  Py_VISIT(traverse_module_state->__pyx_n_s_escape);
  Py_VISIT(traverse_module_state->__pyx_n_s_escapeRegexRangeChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_escapedHexChar);
  Py_VISIT(traverse_module_state->__pyx_n_s_escapedOctChar);
  Py_VISIT(traverse_module_state->__pyx_n_s_escapedPunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_exact);
  Py_VISIT(traverse_module_state->__pyx_n_s_exc);
  Py_VISIT(traverse_module_state->__pyx_n_s_exc_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_exc_type);
  Py_VISIT(traverse_module_state->__pyx_kp_u_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_exceptionAction);
  Py_VISIT(traverse_module_state->__pyx_kp_u_exception_raised_in_parse_action);
  Py_VISIT(traverse_module_state->__pyx_kp_s_exception_thrown_by_class_Parser);
  Py_VISIT(traverse_module_state->__pyx_n_s_excludeChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_exit);
  Py_VISIT(traverse_module_state->__pyx_n_s_expand);
  Py_VISIT(traverse_module_state->__pyx_n_s_expanded);
  Py_VISIT(traverse_module_state->__pyx_n_s_expandtabs);
  Py_VISIT(traverse_module_state->__pyx_n_s_expected);
  Py_VISIT(traverse_module_state->__pyx_n_s_expected_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_expected_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_expected_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_expected_parse_results);
  Py_VISIT(traverse_module_state->__pyx_n_s_explain);
  Py_VISIT(traverse_module_state->__pyx_n_s_expr);
  Py_VISIT(traverse_module_state->__pyx_n_s_expr1);
  Py_VISIT(traverse_module_state->__pyx_n_s_expr_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_expr_parse);
  Py_VISIT(traverse_module_state->__pyx_kp_u_expression);
  Py_VISIT(traverse_module_state->__pyx_n_s_exprs);
  Py_VISIT(traverse_module_state->__pyx_n_u_exprs);
  Py_VISIT(traverse_module_state->__pyx_n_s_exprsFound);
  Py_VISIT(traverse_module_state->__pyx_n_s_exprtokens);
  Py_VISIT(traverse_module_state->__pyx_n_s_extend);
  Py_VISIT(traverse_module_state->__pyx_n_s_extractText);
  Py_VISIT(traverse_module_state->__pyx_n_s_extract_stack);
  Py_VISIT(traverse_module_state->__pyx_n_s_extract_tb);
  Py_VISIT(traverse_module_state->__pyx_kp_u_f);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_locals);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_self);
  Py_VISIT(traverse_module_state->__pyx_n_s_failAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_failOn);
  Py_VISIT(traverse_module_state->__pyx_n_s_fail_msg);
  Py_VISIT(traverse_module_state->__pyx_n_s_failed);
  Py_VISIT(traverse_module_state->__pyx_kp_u_failed_runTests);
  Py_VISIT(traverse_module_state->__pyx_kp_u_failed_user_defined_condition);
  Py_VISIT(traverse_module_state->__pyx_n_s_failureTests);
  Py_VISIT(traverse_module_state->__pyx_n_s_fatal);
  Py_VISIT(traverse_module_state->__pyx_n_u_fatal);
  Py_VISIT(traverse_module_state->__pyx_n_s_ff);
  Py_VISIT(traverse_module_state->__pyx_kp_u_ffff);
  Py_VISIT(traverse_module_state->__pyx_n_s_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_file_contents);
  Py_VISIT(traverse_module_state->__pyx_n_s_file_or_filename);
  Py_VISIT(traverse_module_state->__pyx_n_s_filter);
  Py_VISIT(traverse_module_state->__pyx_n_s_filterfalse);
  Py_VISIT(traverse_module_state->__pyx_n_s_finalResults);
  Py_VISIT(traverse_module_state->__pyx_n_s_find);
  Py_VISIT(traverse_module_state->__pyx_n_s_firstMatchChar);
  Py_VISIT(traverse_module_state->__pyx_n_s_firstQuoteChar);
  Py_VISIT(traverse_module_state->__pyx_n_s_flag);
  Py_VISIT(traverse_module_state->__pyx_n_s_flags);
  Py_VISIT(traverse_module_state->__pyx_n_s_flatten);
  Py_VISIT(traverse_module_state->__pyx_n_s_fmt);
  Py_VISIT(traverse_module_state->__pyx_n_s_fn);
  Py_VISIT(traverse_module_state->__pyx_n_s_fname);
  Py_VISIT(traverse_module_state->__pyx_n_s_fns);
  Py_VISIT(traverse_module_state->__pyx_n_s_fnumber);
  Py_VISIT(traverse_module_state->__pyx_n_u_fnumber);
  Py_VISIT(traverse_module_state->__pyx_n_s_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_formatted);
  Py_VISIT(traverse_module_state->__pyx_n_s_foundArity);
  Py_VISIT(traverse_module_state->__pyx_kp_u_found_end_of_text);
  Py_VISIT(traverse_module_state->__pyx_kp_u_found_multiline_regex_during_inc);
  Py_VISIT(traverse_module_state->__pyx_kp_u_found_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_foundstr);
  Py_VISIT(traverse_module_state->__pyx_n_s_fraction);
  Py_VISIT(traverse_module_state->__pyx_n_u_fraction);
  Py_VISIT(traverse_module_state->__pyx_kp_u_fraction_or_mixed_integer_fracti);
  Py_VISIT(traverse_module_state->__pyx_n_s_frame_summary);
  Py_VISIT(traverse_module_state->__pyx_n_s_frames);
  Py_VISIT(traverse_module_state->__pyx_n_s_frm);
  Py_VISIT(traverse_module_state->__pyx_n_s_from);
  Py_VISIT(traverse_module_state->__pyx_n_s_fromToken);
  Py_VISIT(traverse_module_state->__pyx_n_u_from_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_from_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_from_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_from_symbols);
  Py_VISIT(traverse_module_state->__pyx_n_s_full);
  Py_VISIT(traverse_module_state->__pyx_n_s_fullDump);
  Py_VISIT(traverse_module_state->__pyx_kp_u_full_IPv6_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_full_ipv6_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_func);
  Py_VISIT(traverse_module_state->__pyx_n_s_func_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_functools);
  Py_VISIT(traverse_module_state->__pyx_n_s_furthest_locs);
  Py_VISIT(traverse_module_state->__pyx_kp_u_g_1);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_generatorType);
  Py_VISIT(traverse_module_state->__pyx_n_s_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_getName);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_chars_for_ranges);
  Py_VISIT(traverse_module_state->__pyx_n_s_getattr);
  Py_VISIT(traverse_module_state->__pyx_n_s_getinnerframes);
  Py_VISIT(traverse_module_state->__pyx_n_s_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_getnewargs);
  Py_VISIT(traverse_module_state->__pyx_n_s_getrecursionlimit);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_group);
  Py_VISIT(traverse_module_state->__pyx_n_s_groupdict);
  Py_VISIT(traverse_module_state->__pyx_n_s_groups);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gt_lt_amp_nbsp_quot_apos);
  Py_VISIT(traverse_module_state->__pyx_n_s_hasIgnoreExprs);
  Py_VISIT(traverse_module_state->__pyx_kp_u_has_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_hash);
  Py_VISIT(traverse_module_state->__pyx_n_s_haskeys);
  Py_VISIT(traverse_module_state->__pyx_kp_u_hex_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_hex_integer_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_hex_integer_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_hexnums);
  Py_VISIT(traverse_module_state->__pyx_n_u_hexnums);
  Py_VISIT(traverse_module_state->__pyx_n_s_hit);
  Py_VISIT(traverse_module_state->__pyx_n_s_htmlComment);
  Py_VISIT(traverse_module_state->__pyx_n_u_htmlComment);
  Py_VISIT(traverse_module_state->__pyx_n_s_htmlEntityMap);
  Py_VISIT(traverse_module_state->__pyx_n_s_html_stripper);
  Py_VISIT(traverse_module_state->__pyx_n_s_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_iadd);
  Py_VISIT(traverse_module_state->__pyx_n_s_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_ident);
  Py_VISIT(traverse_module_state->__pyx_n_s_identChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_identifier);
  Py_VISIT(traverse_module_state->__pyx_n_u_identifier);
  Py_VISIT(traverse_module_state->__pyx_kp_u_if_numterms_3_opExpr_must_be_a_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_ifilterfalse);
  Py_VISIT(traverse_module_state->__pyx_n_s_ignore);
  Py_VISIT(traverse_module_state->__pyx_n_s_ignoreExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_ignoreExprs);
  Py_VISIT(traverse_module_state->__pyx_n_s_ikey);
  Py_VISIT(traverse_module_state->__pyx_kp_u_illegal_nesting);
  Py_VISIT(traverse_module_state->__pyx_n_s_ilshift);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_inAccumNames);
  Py_VISIT(traverse_module_state->__pyx_n_u_include);
  Py_VISIT(traverse_module_state->__pyx_n_s_includeMatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_includeSeparators);
  Py_VISIT(traverse_module_state->__pyx_n_s_include_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_include_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_incrementalEnabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_incrementalWithResets);
  Py_VISIT(traverse_module_state->__pyx_n_s_incremental_parent_usefullness);
  Py_VISIT(traverse_module_state->__pyx_n_s_ind);
  Py_VISIT(traverse_module_state->__pyx_n_s_ind_or_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_indent);
  Py_VISIT(traverse_module_state->__pyx_n_s_indentStack);
  Py_VISIT(traverse_module_state->__pyx_n_s_indentedBlock);
  Py_VISIT(traverse_module_state->__pyx_n_u_indentedBlock);
  Py_VISIT(traverse_module_state->__pyx_n_s_indentedBlock_locals_checkPeerIn);
  Py_VISIT(traverse_module_state->__pyx_n_s_indentedBlock_locals_checkSubInd);
  Py_VISIT(traverse_module_state->__pyx_n_s_indentedBlock_locals_checkUninde);
  Py_VISIT(traverse_module_state->__pyx_n_s_indentedBlock_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_indentedBlock_locals_reset_stack);
  Py_VISIT(traverse_module_state->__pyx_kp_u_indented_block);
  Py_VISIT(traverse_module_state->__pyx_n_s_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_indices);
  Py_VISIT(traverse_module_state->__pyx_n_s_infixNotation);
  Py_VISIT(traverse_module_state->__pyx_n_u_infixNotation);
  Py_VISIT(traverse_module_state->__pyx_n_s_infixNotation_locals__FB);
  Py_VISIT(traverse_module_state->__pyx_n_s_infixNotation_locals__FB_parseIm);
  Py_VISIT(traverse_module_state->__pyx_n_s_init);
  Py_VISIT(traverse_module_state->__pyx_n_s_initChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_initCharsOrig);
  Py_VISIT(traverse_module_state->__pyx_n_s_initExprGroups);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_subclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_inlineLiteralsUsing);
  Py_VISIT(traverse_module_state->__pyx_n_s_insStr);
  Py_VISIT(traverse_module_state->__pyx_n_s_insert);
  Py_VISIT(traverse_module_state->__pyx_n_s_inspect);
  Py_VISIT(traverse_module_state->__pyx_n_s_inspect_tracebacks);
  Py_VISIT(traverse_module_state->__pyx_n_s_instring);
  Py_VISIT(traverse_module_state->__pyx_n_s_instring_prefixes_and_suffixes);
  Py_VISIT(traverse_module_state->__pyx_n_s_instring_slice);
  Py_VISIT(traverse_module_state->__pyx_n_s_instrlen);
  Py_VISIT(traverse_module_state->__pyx_n_s_intExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_integer);
  Py_VISIT(traverse_module_state->__pyx_n_u_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_intern);
  Py_VISIT(traverse_module_state->__pyx_n_u_intern);
  Py_VISIT(traverse_module_state->__pyx_kp_u_invalid_pattern_s_passed_to_Rege);
  Py_VISIT(traverse_module_state->__pyx_n_s_invert);
  Py_VISIT(traverse_module_state->__pyx_n_s_ior);
  Py_VISIT(traverse_module_state->__pyx_n_s_ipv4_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_ipv6_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_ipv6_part);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_instring);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_iterable);
  Py_VISIT(traverse_module_state->__pyx_n_s_isalpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_isdigit);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_isequal);
  Py_VISIT(traverse_module_state->__pyx_n_s_isinstance);
  Py_VISIT(traverse_module_state->__pyx_n_s_iso8601_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_iso8601_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_isspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_item_fn);
  Py_VISIT(traverse_module_state->__pyx_n_s_itemgetter);
  Py_VISIT(traverse_module_state->__pyx_n_s_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_itemseq);
  Py_VISIT(traverse_module_state->__pyx_n_s_iter);
  Py_VISIT(traverse_module_state->__pyx_n_s_iteritems);
  Py_VISIT(traverse_module_state->__pyx_n_s_iteritems_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_iterkeys);
  Py_VISIT(traverse_module_state->__pyx_n_u_iterkeys);
  Py_VISIT(traverse_module_state->__pyx_n_s_iterkeys_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_itertools);
  Py_VISIT(traverse_module_state->__pyx_n_s_itervalues);
  Py_VISIT(traverse_module_state->__pyx_n_s_itervalues_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ixor);
  Py_VISIT(traverse_module_state->__pyx_n_s_j);
  Py_VISIT(traverse_module_state->__pyx_n_s_javaStyleComment);
  Py_VISIT(traverse_module_state->__pyx_n_u_javaStyleComment);
  Py_VISIT(traverse_module_state->__pyx_n_s_joinString);
  Py_VISIT(traverse_module_state->__pyx_kp_s_just_like_class_ParseFatalExcept);
  Py_VISIT(traverse_module_state->__pyx_n_s_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_keepMatching);
  Py_VISIT(traverse_module_state->__pyx_n_s_keepTabs);
  Py_VISIT(traverse_module_state->__pyx_n_s_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_key_fifo);
  Py_VISIT(traverse_module_state->__pyx_n_u_key_fifo);
  Py_VISIT(traverse_module_state->__pyx_n_s_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_kwargs);
  Py_VISIT(traverse_module_state->__pyx_n_s_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_last);
  Py_VISIT(traverse_module_state->__pyx_n_s_lastCR);
  Py_VISIT(traverse_module_state->__pyx_n_s_lastE);
  Py_VISIT(traverse_module_state->__pyx_n_s_lastExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_last_expr);
  Py_VISIT(traverse_module_state->__pyx_n_s_lazyclassproperty);
  Py_VISIT(traverse_module_state->__pyx_n_s_lazyclassproperty___get);
  Py_VISIT(traverse_module_state->__pyx_n_s_lazyclassproperty___get___local);
  Py_VISIT(traverse_module_state->__pyx_n_s_lazyclassproperty___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_leaveWhitespace);
  Py_VISIT(traverse_module_state->__pyx_kp_u_leaving);
  Py_VISIT(traverse_module_state->__pyx_kp_u_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_len_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_len_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_limit);
  Py_VISIT(traverse_module_state->__pyx_n_s_line);
  Py_VISIT(traverse_module_state->__pyx_n_u_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_lineEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_lineEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_lineStart);
  Py_VISIT(traverse_module_state->__pyx_n_u_lineStart);
  Py_VISIT(traverse_module_state->__pyx_kp_u_line_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_line_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_column);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_lineno);
  Py_VISIT(traverse_module_state->__pyx_n_u_lineno);
  Py_VISIT(traverse_module_state->__pyx_kp_u_lineno_col_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_listAllMatches);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_str_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_literalStringClass);
  Py_VISIT(traverse_module_state->__pyx_n_u_literal_string_class);
  Py_VISIT(traverse_module_state->__pyx_n_s_loc);
  Py_VISIT(traverse_module_state->__pyx_n_u_loc);
  Py_VISIT(traverse_module_state->__pyx_n_s_loc1);
  Py_VISIT(traverse_module_state->__pyx_n_s_loc2);
  Py_VISIT(traverse_module_state->__pyx_n_s_locMarker);
  Py_VISIT(traverse_module_state->__pyx_n_s_loc_in_suffix);
  Py_VISIT(traverse_module_state->__pyx_n_s_locatedExpr);
  Py_VISIT(traverse_module_state->__pyx_n_u_locatedExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_locatedExpr_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_locator);
  Py_VISIT(traverse_module_state->__pyx_n_s_locn);
  Py_VISIT(traverse_module_state->__pyx_n_u_locn_end);
  Py_VISIT(traverse_module_state->__pyx_n_u_locn_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_longest);
  Py_VISIT(traverse_module_state->__pyx_n_s_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_lookup_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_lookup_bools);
  Py_VISIT(traverse_module_state->__pyx_n_s_lower);
  Py_VISIT(traverse_module_state->__pyx_n_s_lpar);
  Py_VISIT(traverse_module_state->__pyx_n_s_lshift);
  Py_VISIT(traverse_module_state->__pyx_n_s_lstrip);
  Py_VISIT(traverse_module_state->__pyx_n_s_mac_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_u_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_makeHTMLTags);
  Py_VISIT(traverse_module_state->__pyx_n_u_makeHTMLTags);
  Py_VISIT(traverse_module_state->__pyx_n_s_makeOptionalList);
  Py_VISIT(traverse_module_state->__pyx_n_s_makeTags);
  Py_VISIT(traverse_module_state->__pyx_n_s_makeTags_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_makeXMLTags);
  Py_VISIT(traverse_module_state->__pyx_n_u_makeXMLTags);
  Py_VISIT(traverse_module_state->__pyx_n_s_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_markInputline);
  Py_VISIT(traverse_module_state->__pyx_n_s_markerString);
  Py_VISIT(traverse_module_state->__pyx_n_s_masks);
  Py_VISIT(traverse_module_state->__pyx_n_s_mat);
  Py_VISIT(traverse_module_state->__pyx_n_s_match);
  Py_VISIT(traverse_module_state->__pyx_n_u_match);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchLen);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchOnlyAtCol);
  Py_VISIT(traverse_module_state->__pyx_n_u_matchOnlyAtCol);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchOnlyAtCol_locals_verifyCol);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchOrder);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchPreviousExpr);
  Py_VISIT(traverse_module_state->__pyx_n_u_matchPreviousExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchPreviousExpr_locals_copyTok);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchPreviousExpr_locals_copyTok_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchPreviousLiteral);
  Py_VISIT(traverse_module_state->__pyx_n_u_matchPreviousLiteral);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchPreviousLiteral_locals_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchPreviousLiteral_locals_copy_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchString);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchTokens);
  Py_VISIT(traverse_module_state->__pyx_n_s_matchWhite);
  Py_VISIT(traverse_module_state->__pyx_n_s_match_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_match_stringloc);
  Py_VISIT(traverse_module_state->__pyx_kp_u_matched_token_not_at_column_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_matches);
  Py_VISIT(traverse_module_state->__pyx_n_s_max);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxExcLoc);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxException);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxLen);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxMatches);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxMismatches);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxSpecified);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxargs);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxint);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxlen);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxloc);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxsize);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxsplit);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxunicode);
  Py_VISIT(traverse_module_state->__pyx_n_s_mayIndexError);
  Py_VISIT(traverse_module_state->__pyx_n_s_mayReturnEmpty);
  Py_VISIT(traverse_module_state->__pyx_n_s_merged);
  Py_VISIT(traverse_module_state->__pyx_n_s_message);
  Py_VISIT(traverse_module_state->__pyx_n_u_message);
  Py_VISIT(traverse_module_state->__pyx_n_s_metaclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_methodCall);
  Py_VISIT(traverse_module_state->__pyx_n_s_min);
  Py_VISIT(traverse_module_state->__pyx_n_s_minElements);
  Py_VISIT(traverse_module_state->__pyx_n_s_minLen);
  Py_VISIT(traverse_module_state->__pyx_kp_u_mismatches);
  Py_VISIT(traverse_module_state->__pyx_n_s_mismatches_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_mismatches_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_missing);
  Py_VISIT(traverse_module_state->__pyx_n_s_missing_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_mixed_IPv6_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_mixed_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_mixed_ipv6_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_modal);
  Py_VISIT(traverse_module_state->__pyx_n_s_modalResults);
  Py_VISIT(traverse_module_state->__pyx_n_s_module);
  Py_VISIT(traverse_module_state->__pyx_kp_u_module_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_mro);
  Py_VISIT(traverse_module_state->__pyx_n_s_mro_entries);
  Py_VISIT(traverse_module_state->__pyx_n_s_msg);
  Py_VISIT(traverse_module_state->__pyx_n_u_msg);
  Py_VISIT(traverse_module_state->__pyx_n_s_mul);
  Py_VISIT(traverse_module_state->__pyx_n_s_multiline);
  Py_VISIT(traverse_module_state->__pyx_n_s_multioptionals);
  Py_VISIT(traverse_module_state->__pyx_n_s_multirequired);
  Py_VISIT(traverse_module_state->__pyx_n_s_mustMatchTheseTokens);
  Py_VISIT(traverse_module_state->__pyx_kp_u_must_be);
  Py_VISIT(traverse_module_state->__pyx_n_s_must_skip);
  Py_VISIT(traverse_module_state->__pyx_n_s_mylen);
  Py_VISIT(traverse_module_state->__pyx_n_s_n);
  Py_VISIT(traverse_module_state->__pyx_kp_u_n_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_n_n);
  Py_VISIT(traverse_module_state->__pyx_kp_u_n_r);
  Py_VISIT(traverse_module_state->__pyx_kp_u_n_r_x_x_0_9a_fA_F);
  Py_VISIT(traverse_module_state->__pyx_kp_u_n_r_x_x_0_9a_fA_F_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_u_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_namedItems);
  Py_VISIT(traverse_module_state->__pyx_n_s_namedItemsOnly);
  Py_VISIT(traverse_module_state->__pyx_n_s_namespace);
  Py_VISIT(traverse_module_state->__pyx_kp_s_namespace_class_for_classes_use);
  Py_VISIT(traverse_module_state->__pyx_n_s_ne);
  Py_VISIT(traverse_module_state->__pyx_n_u_negate);
  Py_VISIT(traverse_module_state->__pyx_kp_u_nested);
  Py_VISIT(traverse_module_state->__pyx_n_s_nestedExpr);
  Py_VISIT(traverse_module_state->__pyx_n_u_nestedExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_nestedExpr_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_n_s_new_loc);
  Py_VISIT(traverse_module_state->__pyx_n_s_newloc);
  Py_VISIT(traverse_module_state->__pyx_n_s_newself);
  Py_VISIT(traverse_module_state->__pyx_n_s_nextCR);
  Py_VISIT(traverse_module_state->__pyx_n_s_nextLevelIndent);
  Py_VISIT(traverse_module_state->__pyx_n_s_nextLoc);
  Py_VISIT(traverse_module_state->__pyx_n_s_next_linebreak_loc);
  Py_VISIT(traverse_module_state->__pyx_n_s_nextloc);
  Py_VISIT(traverse_module_state->__pyx_n_s_nl);
  Py_VISIT(traverse_module_state->__pyx_kp_u_no_defined_alternatives_to_match);
  Py_VISIT(traverse_module_state->__pyx_kp_u_no_matching_attribute);
  Py_VISIT(traverse_module_state->__pyx_kp_u_no_validation_for_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonzero);
  Py_VISIT(traverse_module_state->__pyx_n_s_notChars);
  Py_VISIT(traverse_module_state->__pyx_kp_u_not_a_peer_entry);
  Py_VISIT(traverse_module_state->__pyx_kp_u_not_a_subentry);
  Py_VISIT(traverse_module_state->__pyx_kp_u_not_an_unindent);
  Py_VISIT(traverse_module_state->__pyx_n_s_not_ender);
  Py_VISIT(traverse_module_state->__pyx_n_s_not_in_cache);
  Py_VISIT(traverse_module_state->__pyx_kp_u_not_preceded_by);
  Py_VISIT(traverse_module_state->__pyx_n_s_notchars);
  Py_VISIT(traverse_module_state->__pyx_n_s_nullDebugAction);
  Py_VISIT(traverse_module_state->__pyx_n_u_nullDebugAction);
  Py_VISIT(traverse_module_state->__pyx_kp_u_null_string_passed_to_Keyword_us);
  Py_VISIT(traverse_module_state->__pyx_kp_u_null_string_passed_to_Literal_us);
  Py_VISIT(traverse_module_state->__pyx_kp_u_null_string_passed_to_Regex_use);
  Py_VISIT(traverse_module_state->__pyx_n_s_number);
  Py_VISIT(traverse_module_state->__pyx_n_s_nums);
  Py_VISIT(traverse_module_state->__pyx_n_u_nums);
  Py_VISIT(traverse_module_state->__pyx_n_s_o);
  Py_VISIT(traverse_module_state->__pyx_n_s_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_occurrences);
  Py_VISIT(traverse_module_state->__pyx_n_s_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_on);
  Py_VISIT(traverse_module_state->__pyx_n_s_oneOf);
  Py_VISIT(traverse_module_state->__pyx_n_u_oneOf);
  Py_VISIT(traverse_module_state->__pyx_n_s_oneOf_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_oneOf_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_kp_u_only_1_or_2_index_arguments_supp);
  Py_VISIT(traverse_module_state->__pyx_n_s_opAssoc);
  Py_VISIT(traverse_module_state->__pyx_n_u_opAssoc);
  Py_VISIT(traverse_module_state->__pyx_n_s_opExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_opExpr1);
  Py_VISIT(traverse_module_state->__pyx_n_s_opExpr2);
  Py_VISIT(traverse_module_state->__pyx_n_s_opList);
  Py_VISIT(traverse_module_state->__pyx_n_s_open);
  Py_VISIT(traverse_module_state->__pyx_n_s_openTag);
  Py_VISIT(traverse_module_state->__pyx_n_s_opener);
  Py_VISIT(traverse_module_state->__pyx_kp_u_opening_and_closing_arguments_mu);
  Py_VISIT(traverse_module_state->__pyx_kp_u_opening_and_closing_strings_cann);
  Py_VISIT(traverse_module_state->__pyx_n_s_operDef);
  Py_VISIT(traverse_module_state->__pyx_n_s_operator);
  Py_VISIT(traverse_module_state->__pyx_n_s_operatorPrecedence);
  Py_VISIT(traverse_module_state->__pyx_n_u_operatorPrecedence);
  Py_VISIT(traverse_module_state->__pyx_kp_u_operator_must_be_unary_1_binary);
  Py_VISIT(traverse_module_state->__pyx_kp_u_operator_must_indicate_right_or);
  Py_VISIT(traverse_module_state->__pyx_n_s_opt1);
  Py_VISIT(traverse_module_state->__pyx_n_s_opt1map);
  Py_VISIT(traverse_module_state->__pyx_n_s_opt2);
  Py_VISIT(traverse_module_state->__pyx_n_s_optElements);
  Py_VISIT(traverse_module_state->__pyx_n_s_optionals);
  Py_VISIT(traverse_module_state->__pyx_n_s_or);
  Py_VISIT(traverse_module_state->__pyx_n_s_ordereddict);
  Py_VISIT(traverse_module_state->__pyx_n_u_original);
  Py_VISIT(traverse_module_state->__pyx_n_s_originalParseMethod);
  Py_VISIT(traverse_module_state->__pyx_n_u_originalParseMethod);
  Py_VISIT(traverse_module_state->__pyx_n_s_originalTextFor);
  Py_VISIT(traverse_module_state->__pyx_n_u_originalTextFor);
  Py_VISIT(traverse_module_state->__pyx_n_s_originalTextFor_locals_extractTe);
  Py_VISIT(traverse_module_state->__pyx_n_s_originalTextFor_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_original_end);
  Py_VISIT(traverse_module_state->__pyx_n_u_original_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_original_start);
  Py_VISIT(traverse_module_state->__pyx_n_u_original_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_os_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_other);
  Py_VISIT(traverse_module_state->__pyx_n_s_other_instring);
  Py_VISIT(traverse_module_state->__pyx_n_s_otherdictitems);
  Py_VISIT(traverse_module_state->__pyx_n_s_otheritems);
  Py_VISIT(traverse_module_state->__pyx_n_s_out);
  Py_VISIT(traverse_module_state->__pyx_n_s_outer_parent_usefullness_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_overlap);
  Py_VISIT(traverse_module_state->__pyx_n_s_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_p1);
  Py_VISIT(traverse_module_state->__pyx_n_s_p2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pa);
  Py_VISIT(traverse_module_state->__pyx_n_s_paArgs);
  Py_VISIT(traverse_module_state->__pyx_n_s_pa_call_line_synth);
  Py_VISIT(traverse_module_state->__pyx_n_s_packratEnabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_packrat_cache);
  Py_VISIT(traverse_module_state->__pyx_n_s_packrat_cache_lock);
  Py_VISIT(traverse_module_state->__pyx_n_s_packrat_cache_stats);
  Py_VISIT(traverse_module_state->__pyx_n_s_packrat_context);
  Py_VISIT(traverse_module_state->__pyx_n_u_packrat_enabled);
  Py_VISIT(traverse_module_state->__pyx_n_u_packrat_parse);
  Py_VISIT(traverse_module_state->__pyx_n_s_par);
  Py_VISIT(traverse_module_state->__pyx_n_s_parse);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseAll);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseCache);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseElementClass);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseElementList);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseElementTrace);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseFile);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseFn);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_u_parseImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseImplAsGroupList);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseImplAsMatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseIncremental);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseMethod);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseNoCache);
  Py_VISIT(traverse_module_state->__pyx_n_u_parseNoCache);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseString);
  Py_VISIT(traverse_module_state->__pyx_n_s_parseWithTabs);
  Py_VISIT(traverse_module_state->__pyx_kp_u_parse_action);
  Py_VISIT(traverse_module_state->__pyx_n_s_parse_action_exc);
  Py_VISIT(traverse_module_state->__pyx_kp_u_parse_actions_must_be_callable);
  Py_VISIT(traverse_module_state->__pyx_n_s_parse_element_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_parserElement);
  Py_VISIT(traverse_module_state->__pyx_n_u_parserElement);
  Py_VISIT(traverse_module_state->__pyx_n_s_pattern);
  Py_VISIT(traverse_module_state->__pyx_n_u_pattern);
  Py_VISIT(traverse_module_state->__pyx_n_s_pbe);
  Py_VISIT(traverse_module_state->__pyx_n_s_pdb);
  Py_VISIT(traverse_module_state->__pyx_n_s_pe);
  Py_VISIT(traverse_module_state->__pyx_n_s_pop);
  Py_VISIT(traverse_module_state->__pyx_kp_u_pop_got_an_unexpected_keyword_ar);
  Py_VISIT(traverse_module_state->__pyx_n_s_popitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_popleft);
  Py_VISIT(traverse_module_state->__pyx_n_s_position);
  Py_VISIT(traverse_module_state->__pyx_n_s_postParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_pp_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_pprint);
  Py_VISIT(traverse_module_state->__pyx_n_s_preParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_prefix_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_prefix_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_prefixes_and_suffixes);
  Py_VISIT(traverse_module_state->__pyx_n_s_preloc);
  Py_VISIT(traverse_module_state->__pyx_n_s_prepare);
  Py_VISIT(traverse_module_state->__pyx_n_s_preparseFn);
  Py_VISIT(traverse_module_state->__pyx_kp_u_prev);
  Py_VISIT(traverse_module_state->__pyx_n_s_print);
  Py_VISIT(traverse_module_state->__pyx_n_s_printResults);
  Py_VISIT(traverse_module_state->__pyx_n_s_print_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_printable);
  Py_VISIT(traverse_module_state->__pyx_n_s_printables);
  Py_VISIT(traverse_module_state->__pyx_n_u_printables);
  Py_VISIT(traverse_module_state->__pyx_n_s_pstr);
  Py_VISIT(traverse_module_state->__pyx_n_u_pstr);
  Py_VISIT(traverse_module_state->__pyx_n_s_punc8bit);
  Py_VISIT(traverse_module_state->__pyx_n_u_punc8bit);
  Py_VISIT(traverse_module_state->__pyx_n_s_py_repr);
  Py_VISIT(traverse_module_state->__pyx_n_s_py_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_common);
  Py_VISIT(traverse_module_state->__pyx_n_u_pyparsing_common);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_common_convertToDate);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_common_convertToDate_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_common_convertToDateti);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_common_convertToDateti_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_common_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_common_lambda_locals_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_common_stripHTMLTags);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_TestParseResultsA_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_test_reset_pyparsing_c_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode);
  Py_VISIT(traverse_module_state->__pyx_n_u_pyparsing_unicode);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Arabic);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_CJK);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Chinese);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Cyrillic);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Devanagari);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Greek);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Hebrew);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Japanese);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Japanese_Hirag);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Japanese_Kanji);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Japanese_Katak);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Korean);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Latin1);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_LatinA);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_LatinB);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyparsing_unicode_Thai);
  Py_VISIT(traverse_module_state->__pyx_n_s_pythonStyleComment);
  Py_VISIT(traverse_module_state->__pyx_n_u_pythonStyleComment);
  Py_VISIT(traverse_module_state->__pyx_n_s_qualname);
  Py_VISIT(traverse_module_state->__pyx_n_s_quoteChar);
  Py_VISIT(traverse_module_state->__pyx_n_s_quoteCharLen);
  Py_VISIT(traverse_module_state->__pyx_kp_u_quoteChar_cannot_be_the_empty_st);
  Py_VISIT(traverse_module_state->__pyx_n_s_quotedString);
  Py_VISIT(traverse_module_state->__pyx_n_u_quotedString);
  Py_VISIT(traverse_module_state->__pyx_kp_u_quotedString_using_single_or_dou);
  Py_VISIT(traverse_module_state->__pyx_kp_u_quoted_string_starting_with);
  Py_VISIT(traverse_module_state->__pyx_n_u_r);
  Py_VISIT(traverse_module_state->__pyx_kp_u_r_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_r_object_is_not_iterable);
  Py_VISIT(traverse_module_state->__pyx_n_s_radd);
  Py_VISIT(traverse_module_state->__pyx_n_s_rand);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_ranges);
  Py_VISIT(traverse_module_state->__pyx_n_s_re);
  Py_VISIT(traverse_module_state->__pyx_n_u_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_reBracketExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_reString);
  Py_VISIT(traverse_module_state->__pyx_n_s_re_match);
  Py_VISIT(traverse_module_state->__pyx_n_s_read);
  Py_VISIT(traverse_module_state->__pyx_n_s_real);
  Py_VISIT(traverse_module_state->__pyx_kp_u_real_number);
  Py_VISIT(traverse_module_state->__pyx_kp_u_real_number_with_scientific_nota);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_ref);
  Py_VISIT(traverse_module_state->__pyx_n_s_register);
  Py_VISIT(traverse_module_state->__pyx_n_s_remove);
  Py_VISIT(traverse_module_state->__pyx_n_s_removeQuotes);
  Py_VISIT(traverse_module_state->__pyx_n_u_removeQuotes);
  Py_VISIT(traverse_module_state->__pyx_n_s_removed);
  Py_VISIT(traverse_module_state->__pyx_n_s_rep);
  Py_VISIT(traverse_module_state->__pyx_n_s_repl);
  Py_VISIT(traverse_module_state->__pyx_n_s_replStr);
  Py_VISIT(traverse_module_state->__pyx_n_s_replace);
  Py_VISIT(traverse_module_state->__pyx_n_s_replaceHTMLEntity);
  Py_VISIT(traverse_module_state->__pyx_n_u_replaceHTMLEntity);
  Py_VISIT(traverse_module_state->__pyx_n_s_replaceWith);
  Py_VISIT(traverse_module_state->__pyx_n_u_replaceWith);
  Py_VISIT(traverse_module_state->__pyx_n_s_replaceWith_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_repr);
  Py_VISIT(traverse_module_state->__pyx_n_s_repr_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_req);
  Py_VISIT(traverse_module_state->__pyx_n_s_required);
  Py_VISIT(traverse_module_state->__pyx_n_s_res);
  Py_VISIT(traverse_module_state->__pyx_n_s_resTag);
  Py_VISIT(traverse_module_state->__pyx_n_s_reset);
  Py_VISIT(traverse_module_state->__pyx_n_s_resetCache);
  Py_VISIT(traverse_module_state->__pyx_n_s_reset_pyparsing_context);
  Py_VISIT(traverse_module_state->__pyx_n_s_reset_stack);
  Py_VISIT(traverse_module_state->__pyx_n_s_resname);
  Py_VISIT(traverse_module_state->__pyx_n_s_restOfLine);
  Py_VISIT(traverse_module_state->__pyx_n_u_restOfLine);
  Py_VISIT(traverse_module_state->__pyx_kp_u_rest_of_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_restore);
  Py_VISIT(traverse_module_state->__pyx_n_s_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_resultlist);
  Py_VISIT(traverse_module_state->__pyx_n_s_results);
  Py_VISIT(traverse_module_state->__pyx_n_s_resultsName);
  Py_VISIT(traverse_module_state->__pyx_n_s_ret);
  Py_VISIT(traverse_module_state->__pyx_n_s_retTokens);
  Py_VISIT(traverse_module_state->__pyx_n_s_retToks);
  Py_VISIT(traverse_module_state->__pyx_kp_u_ret_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ret_toks);
  Py_VISIT(traverse_module_state->__pyx_n_s_retobj);
  Py_VISIT(traverse_module_state->__pyx_n_s_retreat);
  Py_VISIT(traverse_module_state->__pyx_n_s_returnString);
  Py_VISIT(traverse_module_state->__pyx_n_s_reverse);
  Py_VISIT(traverse_module_state->__pyx_n_s_reversed);
  Py_VISIT(traverse_module_state->__pyx_n_s_reversed_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_reversed_instring);
  Py_VISIT(traverse_module_state->__pyx_n_s_rfind);
  Py_VISIT(traverse_module_state->__pyx_n_s_rightLeftAssoc);
  Py_VISIT(traverse_module_state->__pyx_n_s_rmul);
  Py_VISIT(traverse_module_state->__pyx_n_s_rne);
  Py_VISIT(traverse_module_state->__pyx_n_s_ror);
  Py_VISIT(traverse_module_state->__pyx_n_s_rpar);
  Py_VISIT(traverse_module_state->__pyx_n_s_rpt);
  Py_VISIT(traverse_module_state->__pyx_n_s_rr);
  Py_VISIT(traverse_module_state->__pyx_n_s_rstrip);
  Py_VISIT(traverse_module_state->__pyx_n_s_rsub);
  Py_VISIT(traverse_module_state->__pyx_n_s_runTests);
  Py_VISIT(traverse_module_state->__pyx_n_s_run_test_results);
  Py_VISIT(traverse_module_state->__pyx_n_s_run_test_success);
  Py_VISIT(traverse_module_state->__pyx_n_s_run_tests_report);
  Py_VISIT(traverse_module_state->__pyx_n_s_rxor);
  Py_VISIT(traverse_module_state->__pyx_n_s_s);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_10);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_4);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_5);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_6);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_7);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_8);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_9);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_S);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_class);
  Py_VISIT(traverse_module_state->__pyx_n_s_s_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_s_pl_sl);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_s_term);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_term);
  Py_VISIT(traverse_module_state->__pyx_n_s_save);
  Py_VISIT(traverse_module_state->__pyx_n_s_saveAsList);
  Py_VISIT(traverse_module_state->__pyx_n_s_save_context);
  Py_VISIT(traverse_module_state->__pyx_n_s_savelist);
  Py_VISIT(traverse_module_state->__pyx_n_s_scanString);
  Py_VISIT(traverse_module_state->__pyx_n_s_sci_real);
  Py_VISIT(traverse_module_state->__pyx_n_s_se);
  Py_VISIT(traverse_module_state->__pyx_n_s_searchString);
  Py_VISIT(traverse_module_state->__pyx_kp_u_second_tuple_value_must_be_great);
  Py_VISIT(traverse_module_state->__pyx_n_s_seen);
  Py_VISIT(traverse_module_state->__pyx_n_u_select);
  Py_VISIT(traverse_module_state->__pyx_n_s_selectToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_n_u_self);
  Py_VISIT(traverse_module_state->__pyx_n_s_selfTag);
  Py_VISIT(traverse_module_state->__pyx_n_s_self_expr_parse);
  Py_VISIT(traverse_module_state->__pyx_n_s_self_failOn_canParseNext);
  Py_VISIT(traverse_module_state->__pyx_n_s_self_ignoreExpr_tryParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_self_skip_ignorables);
  Py_VISIT(traverse_module_state->__pyx_n_s_self_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_send);
  Py_VISIT(traverse_module_state->__pyx_n_s_sep);
  Py_VISIT(traverse_module_state->__pyx_n_s_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_setAdaptiveMode);
  Py_VISIT(traverse_module_state->__pyx_n_s_setBreak);
  Py_VISIT(traverse_module_state->__pyx_n_s_setDebug);
  Py_VISIT(traverse_module_state->__pyx_n_s_setDebugActions);
  Py_VISIT(traverse_module_state->__pyx_n_s_setDefaultKeywordChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_setDefaultWhitespaceChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_setFailAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_setName);
  Py_VISIT(traverse_module_state->__pyx_n_s_setOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_setParseAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_setResultsName);
  Py_VISIT(traverse_module_state->__pyx_n_s_setResultsName_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_setWhitespaceChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_trace);
  Py_VISIT(traverse_module_state->__pyx_n_s_setitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_sglQuotedString);
  Py_VISIT(traverse_module_state->__pyx_n_u_sglQuotedString);
  Py_VISIT(traverse_module_state->__pyx_kp_u_short_IPv6_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_short_ipv6_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_should_cache_incremental_succes);
  Py_VISIT(traverse_module_state->__pyx_n_s_show_skip);
  Py_VISIT(traverse_module_state->__pyx_kp_u_signed_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_signed_integer_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_simpleSQL);
  Py_VISIT(traverse_module_state->__pyx_n_s_singleArgBuiltins);
  Py_VISIT(traverse_module_state->__pyx_n_s_singleChar);
  Py_VISIT(traverse_module_state->__pyx_n_s_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_skipIgnorables);
  Py_VISIT(traverse_module_state->__pyx_n_s_skipWhitespace);
  Py_VISIT(traverse_module_state->__pyx_kp_u_skipped);
  Py_VISIT(traverse_module_state->__pyx_n_s_skipped_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_skipped_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_skipped_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_skipper);
  Py_VISIT(traverse_module_state->__pyx_n_s_skipresult);
  Py_VISIT(traverse_module_state->__pyx_n_s_skiptext);
  Py_VISIT(traverse_module_state->__pyx_n_s_skipto_arg);
  Py_VISIT(traverse_module_state->__pyx_n_s_slots);
  Py_VISIT(traverse_module_state->__pyx_n_s_smExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_sort);
  Py_VISIT(traverse_module_state->__pyx_n_s_sorted);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_split);
  Py_VISIT(traverse_module_state->__pyx_n_s_splitlines);
  Py_VISIT(traverse_module_state->__pyx_n_s_splits);
  Py_VISIT(traverse_module_state->__pyx_n_s_srange);
  Py_VISIT(traverse_module_state->__pyx_n_u_srange);
  Py_VISIT(traverse_module_state->__pyx_n_s_srange_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_srange_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_srange_locals_lambda_locals_gene);
  Py_VISIT(traverse_module_state->__pyx_n_s_src);
  Py_VISIT(traverse_module_state->__pyx_n_s_sre_constants);
  Py_VISIT(traverse_module_state->__pyx_n_s_stacklevel);
  Py_VISIT(traverse_module_state->__pyx_n_s_start);
  Py_VISIT(traverse_module_state->__pyx_n_u_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_startAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_startloc);
  Py_VISIT(traverse_module_state->__pyx_n_s_startswith);
  Py_VISIT(traverse_module_state->__pyx_n_s_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_staticmethod);
  Py_VISIT(traverse_module_state->__pyx_n_s_stderr);
  Py_VISIT(traverse_module_state->__pyx_n_s_stdout);
  Py_VISIT(traverse_module_state->__pyx_n_s_still_reset_cache);
  Py_VISIT(traverse_module_state->__pyx_n_s_stopOn);
  Py_VISIT(traverse_module_state->__pyx_n_s_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_strRepr);
  Py_VISIT(traverse_module_state->__pyx_n_s_str_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_streamline);
  Py_VISIT(traverse_module_state->__pyx_n_s_streamlined);
  Py_VISIT(traverse_module_state->__pyx_n_s_strg);
  Py_VISIT(traverse_module_state->__pyx_n_s_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_stringEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_stringEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_stringStart);
  Py_VISIT(traverse_module_state->__pyx_n_u_stringStart);
  Py_VISIT(traverse_module_state->__pyx_kp_u_string_enclosed_in_double_quotes);
  Py_VISIT(traverse_module_state->__pyx_kp_u_string_enclosed_in_single_quotes);
  Py_VISIT(traverse_module_state->__pyx_n_s_strip);
  Py_VISIT(traverse_module_state->__pyx_n_s_stripHTMLTags);
  Py_VISIT(traverse_module_state->__pyx_n_s_strptime);
  Py_VISIT(traverse_module_state->__pyx_n_s_strs);
  Py_VISIT(traverse_module_state->__pyx_n_s_sub);
  Py_VISIT(traverse_module_state->__pyx_n_s_subRecCheckList);
  Py_VISIT(traverse_module_state->__pyx_n_s_sub_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_success);
  Py_VISIT(traverse_module_state->__pyx_n_s_successAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_suffix_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_suffix_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_sum);
  Py_VISIT(traverse_module_state->__pyx_kp_u_sum_len_sorted_reversed_list_tup);
  Py_VISIT(traverse_module_state->__pyx_n_s_super);
  Py_VISIT(traverse_module_state->__pyx_n_s_suppress);
  Py_VISIT(traverse_module_state->__pyx_n_s_suppress_GT);
  Py_VISIT(traverse_module_state->__pyx_n_s_suppress_LT);
  Py_VISIT(traverse_module_state->__pyx_n_s_symbols);
  Py_VISIT(traverse_module_state->__pyx_n_s_sys);
  Py_VISIT(traverse_module_state->__pyx_n_s_system_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_t);
  Py_VISIT(traverse_module_state->__pyx_kp_u_t_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_tableName);
  Py_VISIT(traverse_module_state->__pyx_n_s_tableNameList);
  Py_VISIT(traverse_module_state->__pyx_n_u_tables);
  Py_VISIT(traverse_module_state->__pyx_n_s_tag);
  Py_VISIT(traverse_module_state->__pyx_n_u_tag);
  Py_VISIT(traverse_module_state->__pyx_n_s_tagAttrName);
  Py_VISIT(traverse_module_state->__pyx_n_s_tagAttrValue);
  Py_VISIT(traverse_module_state->__pyx_n_s_tagStr);
  Py_VISIT(traverse_module_state->__pyx_n_s_tag_body);
  Py_VISIT(traverse_module_state->__pyx_n_s_tb);
  Py_VISIT(traverse_module_state->__pyx_n_s_tb_next);
  Py_VISIT(traverse_module_state->__pyx_n_s_termName);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_testString);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_expr);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_tests);
  Py_VISIT(traverse_module_state->__pyx_n_s_tflat);
  Py_VISIT(traverse_module_state->__pyx_n_s_theseTokens);
  Py_VISIT(traverse_module_state->__pyx_n_s_thisExpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_thisFunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_thiscol);
  Py_VISIT(traverse_module_state->__pyx_n_s_thread);
  Py_VISIT(traverse_module_state->__pyx_n_s_threading);
  Py_VISIT(traverse_module_state->__pyx_n_s_throw);
  Py_VISIT(traverse_module_state->__pyx_n_s_throwException);
  Py_VISIT(traverse_module_state->__pyx_n_s_title);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmp);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmpExprs);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmpLoc);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmpOpt);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmpReqd);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmploc);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmptokens);
  Py_VISIT(traverse_module_state->__pyx_n_s_to);
  Py_VISIT(traverse_module_state->__pyx_n_s_toItem);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_symbols);
  Py_VISIT(traverse_module_state->__pyx_n_s_tok);
  Py_VISIT(traverse_module_state->__pyx_n_s_tokenMap);
  Py_VISIT(traverse_module_state->__pyx_n_u_tokenMap);
  Py_VISIT(traverse_module_state->__pyx_n_s_tokenMap_locals_pa);
  Py_VISIT(traverse_module_state->__pyx_n_s_tokenlist);
  Py_VISIT(traverse_module_state->__pyx_n_s_tokens);
  Py_VISIT(traverse_module_state->__pyx_n_s_tokensStart);
  Py_VISIT(traverse_module_state->__pyx_n_s_toklist);
  Py_VISIT(traverse_module_state->__pyx_n_s_tokn);
  Py_VISIT(traverse_module_state->__pyx_n_s_toks);
  Py_VISIT(traverse_module_state->__pyx_n_s_traceParseAction);
  Py_VISIT(traverse_module_state->__pyx_n_u_traceParseAction);
  Py_VISIT(traverse_module_state->__pyx_n_s_traceParseAction_locals_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_u_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_traceback_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_transformString);
  Py_VISIT(traverse_module_state->__pyx_n_s_trim_arity);
  Py_VISIT(traverse_module_state->__pyx_n_s_trim_arity_locals_extract_stack);
  Py_VISIT(traverse_module_state->__pyx_n_s_trim_arity_locals_extract_tb);
  Py_VISIT(traverse_module_state->__pyx_n_s_trim_arity_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_trim_arity_locals_wrapper);
  Py_VISIT(traverse_module_state->__pyx_n_s_trim_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_tryParse);
  Py_VISIT(traverse_module_state->__pyx_n_s_try_not_ender);
  Py_VISIT(traverse_module_state->__pyx_n_s_tup);
  Py_VISIT(traverse_module_state->__pyx_n_s_types);
  Py_VISIT(traverse_module_state->__pyx_n_u_u);
  Py_VISIT(traverse_module_state->__pyx_n_s_ungroup);
  Py_VISIT(traverse_module_state->__pyx_n_u_ungroup);
  Py_VISIT(traverse_module_state->__pyx_n_s_ungroup_locals_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_unichr);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicode);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicodeString);
  Py_VISIT(traverse_module_state->__pyx_n_u_unicodeString);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicode_set);
  Py_VISIT(traverse_module_state->__pyx_n_u_unicode_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicode_set__get_chars_for_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicode_set_alphanums);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicode_set_alphas);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicode_set_nums);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicode_set_printables);
  Py_VISIT(traverse_module_state->__pyx_kp_u_unicode_string_literal);
  Py_VISIT(traverse_module_state->__pyx_n_s_unquoteResults);
  Py_VISIT(traverse_module_state->__pyx_n_s_upcaseTokens);
  Py_VISIT(traverse_module_state->__pyx_n_u_upcaseTokens);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_update_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_update_furthest_loc_for_regex);
  Py_VISIT(traverse_module_state->__pyx_n_s_update_wrapper);
  Py_VISIT(traverse_module_state->__pyx_n_s_upper);
  Py_VISIT(traverse_module_state->__pyx_n_s_usage);
  Py_VISIT(traverse_module_state->__pyx_n_s_usage_weight);
  Py_VISIT(traverse_module_state->__pyx_n_s_useRegex);
  Py_VISIT(traverse_module_state->__pyx_kp_u_use_of_expression_without_follow);
  Py_VISIT(traverse_module_state->__pyx_kp_s_user_throwable_exception_thrown);
  Py_VISIT(traverse_module_state->__pyx_n_s_ustr);
  Py_VISIT(traverse_module_state->__pyx_n_u_utf8);
  Py_VISIT(traverse_module_state->__pyx_n_s_uuid);
  Py_VISIT(traverse_module_state->__pyx_n_s_v);
  Py_VISIT(traverse_module_state->__pyx_n_s_validate);
  Py_VISIT(traverse_module_state->__pyx_n_s_validateTrace);
  Py_VISIT(traverse_module_state->__pyx_n_s_value);
  Py_VISIT(traverse_module_state->__pyx_n_u_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_vars);
  Py_VISIT(traverse_module_state->__pyx_n_s_ve);
  Py_VISIT(traverse_module_state->__pyx_n_s_verbose);
  Py_VISIT(traverse_module_state->__pyx_n_s_verbose_stacktrace);
  Py_VISIT(traverse_module_state->__pyx_n_s_verifyCol);
  Py_VISIT(traverse_module_state->__pyx_n_s_version);
  Py_VISIT(traverse_module_state->__pyx_n_u_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_versionTime);
  Py_VISIT(traverse_module_state->__pyx_n_u_versionTime);
  Py_VISIT(traverse_module_state->__pyx_n_s_version_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_vlist);
  Py_VISIT(traverse_module_state->__pyx_n_s_vv);
  Py_VISIT(traverse_module_state->__pyx_n_s_warn);
  Py_VISIT(traverse_module_state->__pyx_n_u_warn_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_warn_multiple_tokens_in_named_al);
  Py_VISIT(traverse_module_state->__pyx_n_u_warn_multiple_tokens_in_named_al);
  Py_VISIT(traverse_module_state->__pyx_n_s_warn_name_set_on_empty_Forward);
  Py_VISIT(traverse_module_state->__pyx_n_u_warn_name_set_on_empty_Forward);
  Py_VISIT(traverse_module_state->__pyx_n_s_warn_on_incremental_multiline_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_warn_on_multiple_string_args_to);
  Py_VISIT(traverse_module_state->__pyx_n_s_warn_ungrouped_named_tokens_in_c);
  Py_VISIT(traverse_module_state->__pyx_n_u_warn_ungrouped_named_tokens_in_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_warnings);
  Py_VISIT(traverse_module_state->__pyx_n_s_weakref);
  Py_VISIT(traverse_module_state->__pyx_n_s_whiteChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_whiteStrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_whitespace);
  Py_VISIT(traverse_module_state->__pyx_n_s_withAttribute);
  Py_VISIT(traverse_module_state->__pyx_n_u_withAttribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_withClass);
  Py_VISIT(traverse_module_state->__pyx_n_u_withClass);
  Py_VISIT(traverse_module_state->__pyx_kp_u_with_up_to);
  Py_VISIT(traverse_module_state->__pyx_n_s_wkref);
  Py_VISIT(traverse_module_state->__pyx_n_s_wordChars);
  Py_VISIT(traverse_module_state->__pyx_n_s_wrapper);
  Py_VISIT(traverse_module_state->__pyx_n_u_wrapper);
  Py_VISIT(traverse_module_state->__pyx_n_s_wraps);
  Py_VISIT(traverse_module_state->__pyx_n_s_write);
  Py_VISIT(traverse_module_state->__pyx_n_s_ws);
  Py_VISIT(traverse_module_state->__pyx_n_s_ws_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_wschar);
  Py_VISIT(traverse_module_state->__pyx_n_s_wslit);
  Py_VISIT(traverse_module_state->__pyx_n_s_wt);
  Py_VISIT(traverse_module_state->__pyx_n_s_xml);
  Py_VISIT(traverse_module_state->__pyx_n_s_xmlBodyText);
  Py_VISIT(traverse_module_state->__pyx_n_s_xml_escape);
  Py_VISIT(traverse_module_state->__pyx_n_s_xml_escape_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_xor);
  Py_VISIT(traverse_module_state->__pyx_n_s_xrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_zip);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_2);
  Py_VISIT(traverse_module_state->__pyx_int_3);
  Py_VISIT(traverse_module_state->__pyx_int_4);
  Py_VISIT(traverse_module_state->__pyx_int_5);
  Py_VISIT(traverse_module_state->__pyx_int_6);
  Py_VISIT(traverse_module_state->__pyx_int_7);
  Py_VISIT(traverse_module_state->__pyx_int_8);
  Py_VISIT(traverse_module_state->__pyx_int_11);
  Py_VISIT(traverse_module_state->__pyx_int_16);
  Py_VISIT(traverse_module_state->__pyx_int_32);
  Py_VISIT(traverse_module_state->__pyx_int_92);
  Py_VISIT(traverse_module_state->__pyx_int_126);
  Py_VISIT(traverse_module_state->__pyx_int_128);
  Py_VISIT(traverse_module_state->__pyx_int_160);
  Py_VISIT(traverse_module_state->__pyx_int_255);
  Py_VISIT(traverse_module_state->__pyx_int_256);
  Py_VISIT(traverse_module_state->__pyx_int_383);
  Py_VISIT(traverse_module_state->__pyx_int_384);
  Py_VISIT(traverse_module_state->__pyx_int_591);
  Py_VISIT(traverse_module_state->__pyx_int_880);
  Py_VISIT(traverse_module_state->__pyx_int_1023);
  Py_VISIT(traverse_module_state->__pyx_int_1024);
  Py_VISIT(traverse_module_state->__pyx_int_1279);
  Py_VISIT(traverse_module_state->__pyx_int_1328);
  Py_VISIT(traverse_module_state->__pyx_int_1424);
  Py_VISIT(traverse_module_state->__pyx_int_1535);
  Py_VISIT(traverse_module_state->__pyx_int_1536);
  Py_VISIT(traverse_module_state->__pyx_int_1563);
  Py_VISIT(traverse_module_state->__pyx_int_1566);
  Py_VISIT(traverse_module_state->__pyx_int_1791);
  Py_VISIT(traverse_module_state->__pyx_int_1792);
  Py_VISIT(traverse_module_state->__pyx_int_1919);
  Py_VISIT(traverse_module_state->__pyx_int_2304);
  Py_VISIT(traverse_module_state->__pyx_int_2431);
  Py_VISIT(traverse_module_state->__pyx_int_3585);
  Py_VISIT(traverse_module_state->__pyx_int_3642);
  Py_VISIT(traverse_module_state->__pyx_int_3647);
  Py_VISIT(traverse_module_state->__pyx_int_3675);
  Py_VISIT(traverse_module_state->__pyx_int_4352);
  Py_VISIT(traverse_module_state->__pyx_int_4607);
  Py_VISIT(traverse_module_state->__pyx_int_7936);
  Py_VISIT(traverse_module_state->__pyx_int_7957);
  Py_VISIT(traverse_module_state->__pyx_int_7960);
  Py_VISIT(traverse_module_state->__pyx_int_7965);
  Py_VISIT(traverse_module_state->__pyx_int_7968);
  Py_VISIT(traverse_module_state->__pyx_int_8005);
  Py_VISIT(traverse_module_state->__pyx_int_8008);
  Py_VISIT(traverse_module_state->__pyx_int_8013);
  Py_VISIT(traverse_module_state->__pyx_int_8016);
  Py_VISIT(traverse_module_state->__pyx_int_8023);
  Py_VISIT(traverse_module_state->__pyx_int_8025);
  Py_VISIT(traverse_module_state->__pyx_int_8027);
  Py_VISIT(traverse_module_state->__pyx_int_8029);
  Py_VISIT(traverse_module_state->__pyx_int_8031);
  Py_VISIT(traverse_module_state->__pyx_int_8061);
  Py_VISIT(traverse_module_state->__pyx_int_8064);
  Py_VISIT(traverse_module_state->__pyx_int_8116);
  Py_VISIT(traverse_module_state->__pyx_int_8118);
  Py_VISIT(traverse_module_state->__pyx_int_8132);
  Py_VISIT(traverse_module_state->__pyx_int_8134);
  Py_VISIT(traverse_module_state->__pyx_int_8147);
  Py_VISIT(traverse_module_state->__pyx_int_8150);
  Py_VISIT(traverse_module_state->__pyx_int_8155);
  Py_VISIT(traverse_module_state->__pyx_int_8157);
  Py_VISIT(traverse_module_state->__pyx_int_8175);
  Py_VISIT(traverse_module_state->__pyx_int_8178);
  Py_VISIT(traverse_module_state->__pyx_int_8180);
  Py_VISIT(traverse_module_state->__pyx_int_8182);
  Py_VISIT(traverse_module_state->__pyx_int_8190);
  Py_VISIT(traverse_module_state->__pyx_int_12288);
  Py_VISIT(traverse_module_state->__pyx_int_12351);
  Py_VISIT(traverse_module_state->__pyx_int_12352);
  Py_VISIT(traverse_module_state->__pyx_int_12447);
  Py_VISIT(traverse_module_state->__pyx_int_12448);
  Py_VISIT(traverse_module_state->__pyx_int_12543);
  Py_VISIT(traverse_module_state->__pyx_int_12592);
  Py_VISIT(traverse_module_state->__pyx_int_12687);
  Py_VISIT(traverse_module_state->__pyx_int_19968);
  Py_VISIT(traverse_module_state->__pyx_int_40895);
  Py_VISIT(traverse_module_state->__pyx_int_40959);
  Py_VISIT(traverse_module_state->__pyx_int_43232);
  Py_VISIT(traverse_module_state->__pyx_int_43263);
  Py_VISIT(traverse_module_state->__pyx_int_43360);
  Py_VISIT(traverse_module_state->__pyx_int_43391);
  Py_VISIT(traverse_module_state->__pyx_int_44032);
  Py_VISIT(traverse_module_state->__pyx_int_55215);
  Py_VISIT(traverse_module_state->__pyx_int_55216);
  Py_VISIT(traverse_module_state->__pyx_int_55295);
  Py_VISIT(traverse_module_state->__pyx_int_neg_1);
  Py_VISIT(traverse_module_state->__pyx_slice_);
  Py_VISIT(traverse_module_state->__pyx_tuple__8);
  Py_VISIT(traverse_module_state->__pyx_slice__20);
  Py_VISIT(traverse_module_state->__pyx_slice__21);
  Py_VISIT(traverse_module_state->__pyx_slice__37);
  Py_VISIT(traverse_module_state->__pyx_slice__47);
  Py_VISIT(traverse_module_state->__pyx_slice__55);
  Py_VISIT(traverse_module_state->__pyx_slice__64);
  Py_VISIT(traverse_module_state->__pyx_slice__70);
  Py_VISIT(traverse_module_state->__pyx_slice__81);
  Py_VISIT(traverse_module_state->__pyx_tuple__18);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__32);
  Py_VISIT(traverse_module_state->__pyx_tuple__36);
  Py_VISIT(traverse_module_state->__pyx_tuple__38);
  Py_VISIT(traverse_module_state->__pyx_tuple__39);
  Py_VISIT(traverse_module_state->__pyx_tuple__41);
  Py_VISIT(traverse_module_state->__pyx_tuple__42);
  Py_VISIT(traverse_module_state->__pyx_tuple__44);
  Py_VISIT(traverse_module_state->__pyx_tuple__46);
  Py_VISIT(traverse_module_state->__pyx_tuple__48);
  Py_VISIT(traverse_module_state->__pyx_tuple__50);
  Py_VISIT(traverse_module_state->__pyx_tuple__51);
  Py_VISIT(traverse_module_state->__pyx_tuple__54);
  Py_VISIT(traverse_module_state->__pyx_tuple__56);
  Py_VISIT(traverse_module_state->__pyx_tuple__57);
  Py_VISIT(traverse_module_state->__pyx_tuple__58);
  Py_VISIT(traverse_module_state->__pyx_tuple__59);
  Py_VISIT(traverse_module_state->__pyx_tuple__60);
  Py_VISIT(traverse_module_state->__pyx_tuple__61);
  Py_VISIT(traverse_module_state->__pyx_tuple__62);
  Py_VISIT(traverse_module_state->__pyx_tuple__68);
  Py_VISIT(traverse_module_state->__pyx_tuple__69);
  Py_VISIT(traverse_module_state->__pyx_tuple__71);
  Py_VISIT(traverse_module_state->__pyx_tuple__73);
  Py_VISIT(traverse_module_state->__pyx_tuple__75);
  Py_VISIT(traverse_module_state->__pyx_tuple__76);
  Py_VISIT(traverse_module_state->__pyx_tuple__77);
  Py_VISIT(traverse_module_state->__pyx_tuple__78);
  Py_VISIT(traverse_module_state->__pyx_tuple__82);
  Py_VISIT(traverse_module_state->__pyx_tuple__84);
  Py_VISIT(traverse_module_state->__pyx_tuple__85);
  Py_VISIT(traverse_module_state->__pyx_tuple__86);
  Py_VISIT(traverse_module_state->__pyx_tuple__87);
  Py_VISIT(traverse_module_state->__pyx_tuple__88);
  Py_VISIT(traverse_module_state->__pyx_tuple__92);
  Py_VISIT(traverse_module_state->__pyx_tuple__93);
  Py_VISIT(traverse_module_state->__pyx_codeobj__9);
  Py_VISIT(traverse_module_state->__pyx_slice__141);
  Py_VISIT(traverse_module_state->__pyx_tuple__101);
  Py_VISIT(traverse_module_state->__pyx_tuple__103);
  Py_VISIT(traverse_module_state->__pyx_tuple__106);
  Py_VISIT(traverse_module_state->__pyx_tuple__109);
  Py_VISIT(traverse_module_state->__pyx_tuple__120);
  Py_VISIT(traverse_module_state->__pyx_tuple__123);
  Py_VISIT(traverse_module_state->__pyx_tuple__125);
  Py_VISIT(traverse_module_state->__pyx_tuple__127);
  Py_VISIT(traverse_module_state->__pyx_tuple__128);
  Py_VISIT(traverse_module_state->__pyx_tuple__130);
  Py_VISIT(traverse_module_state->__pyx_tuple__132);
  Py_VISIT(traverse_module_state->__pyx_tuple__133);
  Py_VISIT(traverse_module_state->__pyx_tuple__134);
  Py_VISIT(traverse_module_state->__pyx_tuple__135);
  Py_VISIT(traverse_module_state->__pyx_tuple__137);
  Py_VISIT(traverse_module_state->__pyx_tuple__139);
  Py_VISIT(traverse_module_state->__pyx_tuple__142);
  Py_VISIT(traverse_module_state->__pyx_tuple__146);
  Py_VISIT(traverse_module_state->__pyx_tuple__149);
  Py_VISIT(traverse_module_state->__pyx_tuple__151);
  Py_VISIT(traverse_module_state->__pyx_tuple__153);
  Py_VISIT(traverse_module_state->__pyx_tuple__155);
  Py_VISIT(traverse_module_state->__pyx_tuple__156);
  Py_VISIT(traverse_module_state->__pyx_tuple__157);
  Py_VISIT(traverse_module_state->__pyx_tuple__158);
  Py_VISIT(traverse_module_state->__pyx_tuple__159);
  Py_VISIT(traverse_module_state->__pyx_tuple__160);
  Py_VISIT(traverse_module_state->__pyx_tuple__162);
  Py_VISIT(traverse_module_state->__pyx_tuple__167);
  Py_VISIT(traverse_module_state->__pyx_tuple__171);
  Py_VISIT(traverse_module_state->__pyx_tuple__175);
  Py_VISIT(traverse_module_state->__pyx_tuple__177);
  Py_VISIT(traverse_module_state->__pyx_tuple__178);
  Py_VISIT(traverse_module_state->__pyx_tuple__180);
  Py_VISIT(traverse_module_state->__pyx_tuple__181);
  Py_VISIT(traverse_module_state->__pyx_tuple__183);
  Py_VISIT(traverse_module_state->__pyx_tuple__184);
  Py_VISIT(traverse_module_state->__pyx_tuple__185);
  Py_VISIT(traverse_module_state->__pyx_tuple__187);
  Py_VISIT(traverse_module_state->__pyx_tuple__188);
  Py_VISIT(traverse_module_state->__pyx_tuple__190);
  Py_VISIT(traverse_module_state->__pyx_tuple__192);
  Py_VISIT(traverse_module_state->__pyx_tuple__194);
  Py_VISIT(traverse_module_state->__pyx_tuple__196);
  Py_VISIT(traverse_module_state->__pyx_tuple__198);
  Py_VISIT(traverse_module_state->__pyx_tuple__200);
  Py_VISIT(traverse_module_state->__pyx_tuple__202);
  Py_VISIT(traverse_module_state->__pyx_tuple__203);
  Py_VISIT(traverse_module_state->__pyx_tuple__206);
  Py_VISIT(traverse_module_state->__pyx_tuple__207);
  Py_VISIT(traverse_module_state->__pyx_tuple__208);
  Py_VISIT(traverse_module_state->__pyx_tuple__210);
  Py_VISIT(traverse_module_state->__pyx_tuple__214);
  Py_VISIT(traverse_module_state->__pyx_tuple__215);
  Py_VISIT(traverse_module_state->__pyx_tuple__216);
  Py_VISIT(traverse_module_state->__pyx_tuple__218);
  Py_VISIT(traverse_module_state->__pyx_tuple__219);
  Py_VISIT(traverse_module_state->__pyx_tuple__221);
  Py_VISIT(traverse_module_state->__pyx_tuple__223);
  Py_VISIT(traverse_module_state->__pyx_tuple__225);
  Py_VISIT(traverse_module_state->__pyx_tuple__227);
  Py_VISIT(traverse_module_state->__pyx_tuple__234);
  Py_VISIT(traverse_module_state->__pyx_tuple__241);
  Py_VISIT(traverse_module_state->__pyx_tuple__243);
  Py_VISIT(traverse_module_state->__pyx_tuple__245);
  Py_VISIT(traverse_module_state->__pyx_tuple__247);
  Py_VISIT(traverse_module_state->__pyx_tuple__249);
  Py_VISIT(traverse_module_state->__pyx_tuple__252);
  Py_VISIT(traverse_module_state->__pyx_tuple__254);
  Py_VISIT(traverse_module_state->__pyx_tuple__256);
  Py_VISIT(traverse_module_state->__pyx_tuple__258);
  Py_VISIT(traverse_module_state->__pyx_tuple__262);
  Py_VISIT(traverse_module_state->__pyx_tuple__264);
  Py_VISIT(traverse_module_state->__pyx_tuple__265);
  Py_VISIT(traverse_module_state->__pyx_tuple__267);
  Py_VISIT(traverse_module_state->__pyx_tuple__269);
  Py_VISIT(traverse_module_state->__pyx_tuple__271);
  Py_VISIT(traverse_module_state->__pyx_tuple__273);
  Py_VISIT(traverse_module_state->__pyx_tuple__274);
  Py_VISIT(traverse_module_state->__pyx_tuple__276);
  Py_VISIT(traverse_module_state->__pyx_tuple__278);
  Py_VISIT(traverse_module_state->__pyx_tuple__280);
  Py_VISIT(traverse_module_state->__pyx_tuple__281);
  Py_VISIT(traverse_module_state->__pyx_tuple__284);
  Py_VISIT(traverse_module_state->__pyx_tuple__288);
  Py_VISIT(traverse_module_state->__pyx_tuple__290);
  Py_VISIT(traverse_module_state->__pyx_tuple__292);
  Py_VISIT(traverse_module_state->__pyx_tuple__294);
  Py_VISIT(traverse_module_state->__pyx_tuple__296);
  Py_VISIT(traverse_module_state->__pyx_tuple__298);
  Py_VISIT(traverse_module_state->__pyx_tuple__300);
  Py_VISIT(traverse_module_state->__pyx_tuple__302);
  Py_VISIT(traverse_module_state->__pyx_tuple__304);
  Py_VISIT(traverse_module_state->__pyx_tuple__306);
  Py_VISIT(traverse_module_state->__pyx_tuple__307);
  Py_VISIT(traverse_module_state->__pyx_tuple__308);
  Py_VISIT(traverse_module_state->__pyx_tuple__310);
  Py_VISIT(traverse_module_state->__pyx_tuple__312);
  Py_VISIT(traverse_module_state->__pyx_tuple__314);
  Py_VISIT(traverse_module_state->__pyx_tuple__319);
  Py_VISIT(traverse_module_state->__pyx_tuple__320);
  Py_VISIT(traverse_module_state->__pyx_tuple__321);
  Py_VISIT(traverse_module_state->__pyx_tuple__329);
  Py_VISIT(traverse_module_state->__pyx_tuple__330);
  Py_VISIT(traverse_module_state->__pyx_tuple__337);
  Py_VISIT(traverse_module_state->__pyx_tuple__338);
  Py_VISIT(traverse_module_state->__pyx_tuple__340);
  Py_VISIT(traverse_module_state->__pyx_tuple__342);
  Py_VISIT(traverse_module_state->__pyx_tuple__344);
  Py_VISIT(traverse_module_state->__pyx_tuple__347);
  Py_VISIT(traverse_module_state->__pyx_tuple__349);
  Py_VISIT(traverse_module_state->__pyx_tuple__350);
  Py_VISIT(traverse_module_state->__pyx_tuple__353);
  Py_VISIT(traverse_module_state->__pyx_tuple__355);
  Py_VISIT(traverse_module_state->__pyx_tuple__357);
  Py_VISIT(traverse_module_state->__pyx_tuple__359);
  Py_VISIT(traverse_module_state->__pyx_tuple__361);
  Py_VISIT(traverse_module_state->__pyx_tuple__363);
  Py_VISIT(traverse_module_state->__pyx_tuple__365);
  Py_VISIT(traverse_module_state->__pyx_tuple__367);
  Py_VISIT(traverse_module_state->__pyx_tuple__369);
  Py_VISIT(traverse_module_state->__pyx_tuple__372);
  Py_VISIT(traverse_module_state->__pyx_tuple__374);
  Py_VISIT(traverse_module_state->__pyx_tuple__376);
  Py_VISIT(traverse_module_state->__pyx_tuple__379);
  Py_VISIT(traverse_module_state->__pyx_tuple__381);
  Py_VISIT(traverse_module_state->__pyx_tuple__383);
  Py_VISIT(traverse_module_state->__pyx_tuple__386);
  Py_VISIT(traverse_module_state->__pyx_tuple__388);
  Py_VISIT(traverse_module_state->__pyx_tuple__389);
  Py_VISIT(traverse_module_state->__pyx_tuple__391);
  Py_VISIT(traverse_module_state->__pyx_tuple__392);
  Py_VISIT(traverse_module_state->__pyx_tuple__394);
  Py_VISIT(traverse_module_state->__pyx_tuple__395);
  Py_VISIT(traverse_module_state->__pyx_tuple__397);
  Py_VISIT(traverse_module_state->__pyx_tuple__399);
  Py_VISIT(traverse_module_state->__pyx_tuple__404);
  Py_VISIT(traverse_module_state->__pyx_tuple__415);
  Py_VISIT(traverse_module_state->__pyx_tuple__420);
  Py_VISIT(traverse_module_state->__pyx_tuple__424);
  Py_VISIT(traverse_module_state->__pyx_tuple__426);
  Py_VISIT(traverse_module_state->__pyx_tuple__432);
  Py_VISIT(traverse_module_state->__pyx_tuple__434);
  Py_VISIT(traverse_module_state->__pyx_tuple__441);
  Py_VISIT(traverse_module_state->__pyx_tuple__443);
  Py_VISIT(traverse_module_state->__pyx_tuple__445);
  Py_VISIT(traverse_module_state->__pyx_tuple__446);
  Py_VISIT(traverse_module_state->__pyx_tuple__448);
  Py_VISIT(traverse_module_state->__pyx_tuple__451);
  Py_VISIT(traverse_module_state->__pyx_tuple__457);
  Py_VISIT(traverse_module_state->__pyx_tuple__462);
  Py_VISIT(traverse_module_state->__pyx_tuple__465);
  Py_VISIT(traverse_module_state->__pyx_tuple__470);
  Py_VISIT(traverse_module_state->__pyx_tuple__472);
  Py_VISIT(traverse_module_state->__pyx_tuple__474);
  Py_VISIT(traverse_module_state->__pyx_tuple__476);
  Py_VISIT(traverse_module_state->__pyx_tuple__478);
  Py_VISIT(traverse_module_state->__pyx_tuple__479);
  Py_VISIT(traverse_module_state->__pyx_tuple__481);
  Py_VISIT(traverse_module_state->__pyx_tuple__483);
  Py_VISIT(traverse_module_state->__pyx_tuple__485);
  Py_VISIT(traverse_module_state->__pyx_tuple__487);
  Py_VISIT(traverse_module_state->__pyx_tuple__488);
  Py_VISIT(traverse_module_state->__pyx_tuple__490);
  Py_VISIT(traverse_module_state->__pyx_tuple__491);
  Py_VISIT(traverse_module_state->__pyx_tuple__493);
  Py_VISIT(traverse_module_state->__pyx_tuple__497);
  Py_VISIT(traverse_module_state->__pyx_tuple__499);
  Py_VISIT(traverse_module_state->__pyx_tuple__501);
  Py_VISIT(traverse_module_state->__pyx_tuple__502);
  Py_VISIT(traverse_module_state->__pyx_tuple__505);
  Py_VISIT(traverse_module_state->__pyx_tuple__507);
  Py_VISIT(traverse_module_state->__pyx_tuple__508);
  Py_VISIT(traverse_module_state->__pyx_tuple__529);
  Py_VISIT(traverse_module_state->__pyx_tuple__531);
  Py_VISIT(traverse_module_state->__pyx_tuple__532);
  Py_VISIT(traverse_module_state->__pyx_tuple__535);
  Py_VISIT(traverse_module_state->__pyx_tuple__537);
  Py_VISIT(traverse_module_state->__pyx_tuple__539);
  Py_VISIT(traverse_module_state->__pyx_tuple__549);
  Py_VISIT(traverse_module_state->__pyx_tuple__553);
  Py_VISIT(traverse_module_state->__pyx_tuple__555);
  Py_VISIT(traverse_module_state->__pyx_tuple__558);
  Py_VISIT(traverse_module_state->__pyx_tuple__560);
  Py_VISIT(traverse_module_state->__pyx_tuple__563);
  Py_VISIT(traverse_module_state->__pyx_tuple__565);
  Py_VISIT(traverse_module_state->__pyx_tuple__567);
  Py_VISIT(traverse_module_state->__pyx_tuple__569);
  Py_VISIT(traverse_module_state->__pyx_tuple__572);
  Py_VISIT(traverse_module_state->__pyx_tuple__574);
  Py_VISIT(traverse_module_state->__pyx_tuple__576);
  Py_VISIT(traverse_module_state->__pyx_tuple__579);
  Py_VISIT(traverse_module_state->__pyx_tuple__584);
  Py_VISIT(traverse_module_state->__pyx_tuple__589);
  Py_VISIT(traverse_module_state->__pyx_tuple__593);
  Py_VISIT(traverse_module_state->__pyx_tuple__595);
  Py_VISIT(traverse_module_state->__pyx_tuple__596);
  Py_VISIT(traverse_module_state->__pyx_tuple__604);
  Py_VISIT(traverse_module_state->__pyx_tuple__608);
  Py_VISIT(traverse_module_state->__pyx_tuple__614);
  Py_VISIT(traverse_module_state->__pyx_tuple__616);
  Py_VISIT(traverse_module_state->__pyx_tuple__619);
  Py_VISIT(traverse_module_state->__pyx_tuple__622);
  Py_VISIT(traverse_module_state->__pyx_tuple__624);
  Py_VISIT(traverse_module_state->__pyx_tuple__626);
  Py_VISIT(traverse_module_state->__pyx_tuple__628);
  Py_VISIT(traverse_module_state->__pyx_tuple__632);
  Py_VISIT(traverse_module_state->__pyx_tuple__634);
  Py_VISIT(traverse_module_state->__pyx_tuple__636);
  Py_VISIT(traverse_module_state->__pyx_tuple__640);
  Py_VISIT(traverse_module_state->__pyx_tuple__644);
  Py_VISIT(traverse_module_state->__pyx_tuple__645);
  Py_VISIT(traverse_module_state->__pyx_tuple__648);
  Py_VISIT(traverse_module_state->__pyx_tuple__650);
  Py_VISIT(traverse_module_state->__pyx_tuple__653);
  Py_VISIT(traverse_module_state->__pyx_tuple__655);
  Py_VISIT(traverse_module_state->__pyx_tuple__667);
  Py_VISIT(traverse_module_state->__pyx_tuple__669);
  Py_VISIT(traverse_module_state->__pyx_tuple__671);
  Py_VISIT(traverse_module_state->__pyx_tuple__676);
  Py_VISIT(traverse_module_state->__pyx_tuple__680);
  Py_VISIT(traverse_module_state->__pyx_tuple__681);
  Py_VISIT(traverse_module_state->__pyx_tuple__682);
  Py_VISIT(traverse_module_state->__pyx_tuple__684);
  Py_VISIT(traverse_module_state->__pyx_tuple__687);
  Py_VISIT(traverse_module_state->__pyx_tuple__689);
  Py_VISIT(traverse_module_state->__pyx_tuple__691);
  Py_VISIT(traverse_module_state->__pyx_tuple__692);
  Py_VISIT(traverse_module_state->__pyx_tuple__694);
  Py_VISIT(traverse_module_state->__pyx_tuple__696);
  Py_VISIT(traverse_module_state->__pyx_tuple__698);
  Py_VISIT(traverse_module_state->__pyx_tuple__700);
  Py_VISIT(traverse_module_state->__pyx_tuple__702);
  Py_VISIT(traverse_module_state->__pyx_tuple__704);
  Py_VISIT(traverse_module_state->__pyx_tuple__705);
  Py_VISIT(traverse_module_state->__pyx_tuple__707);
  Py_VISIT(traverse_module_state->__pyx_tuple__709);
  Py_VISIT(traverse_module_state->__pyx_tuple__711);
  Py_VISIT(traverse_module_state->__pyx_tuple__713);
  Py_VISIT(traverse_module_state->__pyx_tuple__714);
  Py_VISIT(traverse_module_state->__pyx_tuple__715);
  Py_VISIT(traverse_module_state->__pyx_tuple__716);
  Py_VISIT(traverse_module_state->__pyx_tuple__717);
  Py_VISIT(traverse_module_state->__pyx_tuple__719);
  Py_VISIT(traverse_module_state->__pyx_tuple__720);
  Py_VISIT(traverse_module_state->__pyx_tuple__722);
  Py_VISIT(traverse_module_state->__pyx_tuple__723);
  Py_VISIT(traverse_module_state->__pyx_tuple__724);
  Py_VISIT(traverse_module_state->__pyx_tuple__725);
  Py_VISIT(traverse_module_state->__pyx_tuple__726);
  Py_VISIT(traverse_module_state->__pyx_tuple__727);
  Py_VISIT(traverse_module_state->__pyx_tuple__728);
  Py_VISIT(traverse_module_state->__pyx_tuple__730);
  Py_VISIT(traverse_module_state->__pyx_tuple__732);
  Py_VISIT(traverse_module_state->__pyx_tuple__735);
  Py_VISIT(traverse_module_state->__pyx_tuple__737);
  Py_VISIT(traverse_module_state->__pyx_tuple__739);
  Py_VISIT(traverse_module_state->__pyx_tuple__740);
  Py_VISIT(traverse_module_state->__pyx_tuple__741);
  Py_VISIT(traverse_module_state->__pyx_tuple__744);
  Py_VISIT(traverse_module_state->__pyx_tuple__745);
  Py_VISIT(traverse_module_state->__pyx_tuple__746);
  Py_VISIT(traverse_module_state->__pyx_tuple__748);
  Py_VISIT(traverse_module_state->__pyx_tuple__750);
  Py_VISIT(traverse_module_state->__pyx_tuple__752);
  Py_VISIT(traverse_module_state->__pyx_tuple__753);
  Py_VISIT(traverse_module_state->__pyx_tuple__754);
  Py_VISIT(traverse_module_state->__pyx_tuple__756);
  Py_VISIT(traverse_module_state->__pyx_tuple__757);
  Py_VISIT(traverse_module_state->__pyx_tuple__758);
  Py_VISIT(traverse_module_state->__pyx_tuple__759);
  Py_VISIT(traverse_module_state->__pyx_tuple__760);
  Py_VISIT(traverse_module_state->__pyx_tuple__761);
  Py_VISIT(traverse_module_state->__pyx_tuple__762);
  Py_VISIT(traverse_module_state->__pyx_tuple__764);
  Py_VISIT(traverse_module_state->__pyx_tuple__766);
  Py_VISIT(traverse_module_state->__pyx_tuple__767);
  Py_VISIT(traverse_module_state->__pyx_tuple__769);
  Py_VISIT(traverse_module_state->__pyx_tuple__772);
  Py_VISIT(traverse_module_state->__pyx_tuple__775);
  Py_VISIT(traverse_module_state->__pyx_tuple__777);
  Py_VISIT(traverse_module_state->__pyx_tuple__778);
  Py_VISIT(traverse_module_state->__pyx_tuple__779);
  Py_VISIT(traverse_module_state->__pyx_tuple__781);
  Py_VISIT(traverse_module_state->__pyx_tuple__782);
  Py_VISIT(traverse_module_state->__pyx_tuple__783);
  Py_VISIT(traverse_module_state->__pyx_tuple__784);
  Py_VISIT(traverse_module_state->__pyx_tuple__785);
  Py_VISIT(traverse_module_state->__pyx_tuple__787);
  Py_VISIT(traverse_module_state->__pyx_tuple__788);
  Py_VISIT(traverse_module_state->__pyx_tuple__790);
  Py_VISIT(traverse_module_state->__pyx_tuple__791);
  Py_VISIT(traverse_module_state->__pyx_tuple__792);
  Py_VISIT(traverse_module_state->__pyx_tuple__793);
  Py_VISIT(traverse_module_state->__pyx_tuple__794);
  Py_VISIT(traverse_module_state->__pyx_tuple__796);
  Py_VISIT(traverse_module_state->__pyx_tuple__798);
  Py_VISIT(traverse_module_state->__pyx_tuple__800);
  Py_VISIT(traverse_module_state->__pyx_tuple__801);
  Py_VISIT(traverse_module_state->__pyx_tuple__803);
  Py_VISIT(traverse_module_state->__pyx_tuple__804);
  Py_VISIT(traverse_module_state->__pyx_tuple__806);
  Py_VISIT(traverse_module_state->__pyx_tuple__808);
  Py_VISIT(traverse_module_state->__pyx_tuple__809);
  Py_VISIT(traverse_module_state->__pyx_tuple__810);
  Py_VISIT(traverse_module_state->__pyx_tuple__816);
  Py_VISIT(traverse_module_state->__pyx_tuple__817);
  Py_VISIT(traverse_module_state->__pyx_tuple__818);
  Py_VISIT(traverse_module_state->__pyx_tuple__819);
  Py_VISIT(traverse_module_state->__pyx_tuple__820);
  Py_VISIT(traverse_module_state->__pyx_tuple__821);
  Py_VISIT(traverse_module_state->__pyx_tuple__822);
  Py_VISIT(traverse_module_state->__pyx_tuple__823);
  Py_VISIT(traverse_module_state->__pyx_tuple__824);
  Py_VISIT(traverse_module_state->__pyx_tuple__825);
  Py_VISIT(traverse_module_state->__pyx_tuple__826);
  Py_VISIT(traverse_module_state->__pyx_tuple__827);
  Py_VISIT(traverse_module_state->__pyx_tuple__828);
  Py_VISIT(traverse_module_state->__pyx_tuple__829);
  Py_VISIT(traverse_module_state->__pyx_tuple__830);
  Py_VISIT(traverse_module_state->__pyx_tuple__831);
  Py_VISIT(traverse_module_state->__pyx_tuple__832);
  Py_VISIT(traverse_module_state->__pyx_tuple__833);
  Py_VISIT(traverse_module_state->__pyx_tuple__834);
  Py_VISIT(traverse_module_state->__pyx_tuple__835);
  Py_VISIT(traverse_module_state->__pyx_tuple__836);
  Py_VISIT(traverse_module_state->__pyx_tuple__837);
  Py_VISIT(traverse_module_state->__pyx_tuple__838);
  Py_VISIT(traverse_module_state->__pyx_tuple__839);
  Py_VISIT(traverse_module_state->__pyx_tuple__840);
  Py_VISIT(traverse_module_state->__pyx_tuple__841);
  Py_VISIT(traverse_module_state->__pyx_tuple__842);
  Py_VISIT(traverse_module_state->__pyx_tuple__843);
  Py_VISIT(traverse_module_state->__pyx_tuple__844);
  Py_VISIT(traverse_module_state->__pyx_tuple__845);
  Py_VISIT(traverse_module_state->__pyx_tuple__846);
  Py_VISIT(traverse_module_state->__pyx_tuple__847);
  Py_VISIT(traverse_module_state->__pyx_tuple__848);
  Py_VISIT(traverse_module_state->__pyx_tuple__849);
  Py_VISIT(traverse_module_state->__pyx_tuple__850);
  Py_VISIT(traverse_module_state->__pyx_tuple__851);
  Py_VISIT(traverse_module_state->__pyx_tuple__852);
  Py_VISIT(traverse_module_state->__pyx_tuple__853);
  Py_VISIT(traverse_module_state->__pyx_tuple__854);
  Py_VISIT(traverse_module_state->__pyx_tuple__855);
  Py_VISIT(traverse_module_state->__pyx_tuple__870);
  Py_VISIT(traverse_module_state->__pyx_tuple__874);
  Py_VISIT(traverse_module_state->__pyx_tuple__876);
  Py_VISIT(traverse_module_state->__pyx_tuple__878);
  Py_VISIT(traverse_module_state->__pyx_tuple__879);
  Py_VISIT(traverse_module_state->__pyx_tuple__881);
  Py_VISIT(traverse_module_state->__pyx_tuple__883);
  Py_VISIT(traverse_module_state->__pyx_tuple__884);
  Py_VISIT(traverse_module_state->__pyx_tuple__885);
  Py_VISIT(traverse_module_state->__pyx_tuple__886);
  Py_VISIT(traverse_module_state->__pyx_tuple__887);
  Py_VISIT(traverse_module_state->__pyx_tuple__888);
  Py_VISIT(traverse_module_state->__pyx_tuple__889);
  Py_VISIT(traverse_module_state->__pyx_tuple__890);
  Py_VISIT(traverse_module_state->__pyx_tuple__891);
  Py_VISIT(traverse_module_state->__pyx_tuple__892);
  Py_VISIT(traverse_module_state->__pyx_codeobj__24);
  Py_VISIT(traverse_module_state->__pyx_codeobj__33);
  Py_VISIT(traverse_module_state->__pyx_codeobj__40);
  Py_VISIT(traverse_module_state->__pyx_codeobj__43);
  Py_VISIT(traverse_module_state->__pyx_codeobj__45);
  Py_VISIT(traverse_module_state->__pyx_codeobj__49);
  Py_VISIT(traverse_module_state->__pyx_codeobj__52);
  Py_VISIT(traverse_module_state->__pyx_codeobj__53);
  Py_VISIT(traverse_module_state->__pyx_codeobj__63);
  Py_VISIT(traverse_module_state->__pyx_codeobj__72);
  Py_VISIT(traverse_module_state->__pyx_codeobj__74);
  Py_VISIT(traverse_module_state->__pyx_codeobj__83);
  Py_VISIT(traverse_module_state->__pyx_codeobj__89);
  Py_VISIT(traverse_module_state->__pyx_codeobj__90);
  Py_VISIT(traverse_module_state->__pyx_codeobj__121);
  Py_VISIT(traverse_module_state->__pyx_codeobj__124);
  Py_VISIT(traverse_module_state->__pyx_codeobj__126);
  Py_VISIT(traverse_module_state->__pyx_codeobj__129);
  Py_VISIT(traverse_module_state->__pyx_codeobj__131);
  Py_VISIT(traverse_module_state->__pyx_codeobj__138);
  Py_VISIT(traverse_module_state->__pyx_codeobj__140);
  Py_VISIT(traverse_module_state->__pyx_codeobj__143);
  Py_VISIT(traverse_module_state->__pyx_codeobj__152);
  Py_VISIT(traverse_module_state->__pyx_codeobj__154);
  Py_VISIT(traverse_module_state->__pyx_codeobj__161);
  Py_VISIT(traverse_module_state->__pyx_codeobj__163);
  Py_VISIT(traverse_module_state->__pyx_codeobj__164);
  Py_VISIT(traverse_module_state->__pyx_codeobj__165);
  Py_VISIT(traverse_module_state->__pyx_codeobj__168);
  Py_VISIT(traverse_module_state->__pyx_codeobj__169);
  Py_VISIT(traverse_module_state->__pyx_codeobj__170);
  Py_VISIT(traverse_module_state->__pyx_codeobj__172);
  Py_VISIT(traverse_module_state->__pyx_codeobj__173);
  Py_VISIT(traverse_module_state->__pyx_codeobj__174);
  Py_VISIT(traverse_module_state->__pyx_codeobj__176);
  Py_VISIT(traverse_module_state->__pyx_codeobj__179);
  Py_VISIT(traverse_module_state->__pyx_codeobj__182);
  Py_VISIT(traverse_module_state->__pyx_codeobj__186);
  Py_VISIT(traverse_module_state->__pyx_codeobj__189);
  Py_VISIT(traverse_module_state->__pyx_codeobj__191);
  Py_VISIT(traverse_module_state->__pyx_codeobj__193);
  Py_VISIT(traverse_module_state->__pyx_codeobj__195);
  Py_VISIT(traverse_module_state->__pyx_codeobj__197);
  Py_VISIT(traverse_module_state->__pyx_codeobj__199);
  Py_VISIT(traverse_module_state->__pyx_codeobj__201);
  Py_VISIT(traverse_module_state->__pyx_codeobj__204);
  Py_VISIT(traverse_module_state->__pyx_codeobj__205);
  Py_VISIT(traverse_module_state->__pyx_codeobj__209);
  Py_VISIT(traverse_module_state->__pyx_codeobj__211);
  Py_VISIT(traverse_module_state->__pyx_codeobj__212);
  Py_VISIT(traverse_module_state->__pyx_codeobj__213);
  Py_VISIT(traverse_module_state->__pyx_codeobj__217);
  Py_VISIT(traverse_module_state->__pyx_codeobj__220);
  Py_VISIT(traverse_module_state->__pyx_codeobj__222);
  Py_VISIT(traverse_module_state->__pyx_codeobj__224);
  Py_VISIT(traverse_module_state->__pyx_codeobj__226);
  Py_VISIT(traverse_module_state->__pyx_codeobj__228);
  Py_VISIT(traverse_module_state->__pyx_codeobj__229);
  Py_VISIT(traverse_module_state->__pyx_codeobj__230);
  Py_VISIT(traverse_module_state->__pyx_codeobj__231);
  Py_VISIT(traverse_module_state->__pyx_codeobj__232);
  Py_VISIT(traverse_module_state->__pyx_codeobj__233);
  Py_VISIT(traverse_module_state->__pyx_codeobj__235);
  Py_VISIT(traverse_module_state->__pyx_codeobj__236);
  Py_VISIT(traverse_module_state->__pyx_codeobj__237);
  Py_VISIT(traverse_module_state->__pyx_codeobj__238);
  Py_VISIT(traverse_module_state->__pyx_codeobj__239);
  Py_VISIT(traverse_module_state->__pyx_codeobj__240);
  Py_VISIT(traverse_module_state->__pyx_codeobj__242);
  Py_VISIT(traverse_module_state->__pyx_codeobj__244);
  Py_VISIT(traverse_module_state->__pyx_codeobj__246);
  Py_VISIT(traverse_module_state->__pyx_codeobj__248);
  Py_VISIT(traverse_module_state->__pyx_codeobj__250);
  Py_VISIT(traverse_module_state->__pyx_codeobj__251);
  Py_VISIT(traverse_module_state->__pyx_codeobj__253);
  Py_VISIT(traverse_module_state->__pyx_codeobj__255);
  Py_VISIT(traverse_module_state->__pyx_codeobj__257);
  Py_VISIT(traverse_module_state->__pyx_codeobj__259);
  Py_VISIT(traverse_module_state->__pyx_codeobj__260);
  Py_VISIT(traverse_module_state->__pyx_codeobj__261);
  Py_VISIT(traverse_module_state->__pyx_codeobj__263);
  Py_VISIT(traverse_module_state->__pyx_codeobj__266);
  Py_VISIT(traverse_module_state->__pyx_codeobj__268);
  Py_VISIT(traverse_module_state->__pyx_codeobj__270);
  Py_VISIT(traverse_module_state->__pyx_codeobj__272);
  Py_VISIT(traverse_module_state->__pyx_codeobj__275);
  Py_VISIT(traverse_module_state->__pyx_codeobj__277);
  Py_VISIT(traverse_module_state->__pyx_codeobj__279);
  Py_VISIT(traverse_module_state->__pyx_codeobj__282);
  Py_VISIT(traverse_module_state->__pyx_codeobj__283);
  Py_VISIT(traverse_module_state->__pyx_codeobj__285);
  Py_VISIT(traverse_module_state->__pyx_codeobj__286);
  Py_VISIT(traverse_module_state->__pyx_codeobj__287);
  Py_VISIT(traverse_module_state->__pyx_codeobj__289);
  Py_VISIT(traverse_module_state->__pyx_codeobj__291);
  Py_VISIT(traverse_module_state->__pyx_codeobj__293);
  Py_VISIT(traverse_module_state->__pyx_codeobj__295);
  Py_VISIT(traverse_module_state->__pyx_codeobj__297);
  Py_VISIT(traverse_module_state->__pyx_codeobj__299);
  Py_VISIT(traverse_module_state->__pyx_codeobj__301);
  Py_VISIT(traverse_module_state->__pyx_codeobj__303);
  Py_VISIT(traverse_module_state->__pyx_codeobj__305);
  Py_VISIT(traverse_module_state->__pyx_codeobj__309);
  Py_VISIT(traverse_module_state->__pyx_codeobj__311);
  Py_VISIT(traverse_module_state->__pyx_codeobj__313);
  Py_VISIT(traverse_module_state->__pyx_codeobj__315);
  Py_VISIT(traverse_module_state->__pyx_codeobj__316);
  Py_VISIT(traverse_module_state->__pyx_codeobj__317);
  Py_VISIT(traverse_module_state->__pyx_codeobj__318);
  Py_VISIT(traverse_module_state->__pyx_codeobj__322);
  Py_VISIT(traverse_module_state->__pyx_codeobj__323);
  Py_VISIT(traverse_module_state->__pyx_codeobj__324);
  Py_VISIT(traverse_module_state->__pyx_codeobj__325);
  Py_VISIT(traverse_module_state->__pyx_codeobj__326);
  Py_VISIT(traverse_module_state->__pyx_codeobj__327);
  Py_VISIT(traverse_module_state->__pyx_codeobj__328);
  Py_VISIT(traverse_module_state->__pyx_codeobj__331);
  Py_VISIT(traverse_module_state->__pyx_codeobj__332);
  Py_VISIT(traverse_module_state->__pyx_codeobj__333);
  Py_VISIT(traverse_module_state->__pyx_codeobj__334);
  Py_VISIT(traverse_module_state->__pyx_codeobj__335);
  Py_VISIT(traverse_module_state->__pyx_codeobj__336);
  Py_VISIT(traverse_module_state->__pyx_codeobj__341);
  Py_VISIT(traverse_module_state->__pyx_codeobj__343);
  Py_VISIT(traverse_module_state->__pyx_codeobj__345);
  Py_VISIT(traverse_module_state->__pyx_codeobj__346);
  Py_VISIT(traverse_module_state->__pyx_codeobj__348);
  Py_VISIT(traverse_module_state->__pyx_codeobj__351);
  Py_VISIT(traverse_module_state->__pyx_codeobj__352);
  Py_VISIT(traverse_module_state->__pyx_codeobj__354);
  Py_VISIT(traverse_module_state->__pyx_codeobj__356);
  Py_VISIT(traverse_module_state->__pyx_codeobj__358);
  Py_VISIT(traverse_module_state->__pyx_codeobj__360);
  Py_VISIT(traverse_module_state->__pyx_codeobj__362);
  Py_VISIT(traverse_module_state->__pyx_codeobj__364);
  Py_VISIT(traverse_module_state->__pyx_codeobj__366);
  Py_VISIT(traverse_module_state->__pyx_codeobj__368);
  Py_VISIT(traverse_module_state->__pyx_codeobj__370);
  Py_VISIT(traverse_module_state->__pyx_codeobj__371);
  Py_VISIT(traverse_module_state->__pyx_codeobj__373);
  Py_VISIT(traverse_module_state->__pyx_codeobj__375);
  Py_VISIT(traverse_module_state->__pyx_codeobj__377);
  Py_VISIT(traverse_module_state->__pyx_codeobj__378);
  Py_VISIT(traverse_module_state->__pyx_codeobj__380);
  Py_VISIT(traverse_module_state->__pyx_codeobj__382);
  Py_VISIT(traverse_module_state->__pyx_codeobj__384);
  Py_VISIT(traverse_module_state->__pyx_codeobj__385);
  Py_VISIT(traverse_module_state->__pyx_codeobj__387);
  Py_VISIT(traverse_module_state->__pyx_codeobj__390);
  Py_VISIT(traverse_module_state->__pyx_codeobj__393);
  Py_VISIT(traverse_module_state->__pyx_codeobj__396);
  Py_VISIT(traverse_module_state->__pyx_codeobj__398);
  Py_VISIT(traverse_module_state->__pyx_codeobj__400);
  Py_VISIT(traverse_module_state->__pyx_codeobj__401);
  Py_VISIT(traverse_module_state->__pyx_codeobj__402);
  Py_VISIT(traverse_module_state->__pyx_codeobj__403);
  Py_VISIT(traverse_module_state->__pyx_codeobj__405);
  Py_VISIT(traverse_module_state->__pyx_codeobj__406);
  Py_VISIT(traverse_module_state->__pyx_codeobj__407);
  Py_VISIT(traverse_module_state->__pyx_codeobj__408);
  Py_VISIT(traverse_module_state->__pyx_codeobj__409);
  Py_VISIT(traverse_module_state->__pyx_codeobj__410);
  Py_VISIT(traverse_module_state->__pyx_codeobj__411);
  Py_VISIT(traverse_module_state->__pyx_codeobj__412);
  Py_VISIT(traverse_module_state->__pyx_codeobj__413);
  Py_VISIT(traverse_module_state->__pyx_codeobj__414);
  Py_VISIT(traverse_module_state->__pyx_codeobj__416);
  Py_VISIT(traverse_module_state->__pyx_codeobj__417);
  Py_VISIT(traverse_module_state->__pyx_codeobj__418);
  Py_VISIT(traverse_module_state->__pyx_codeobj__419);
  Py_VISIT(traverse_module_state->__pyx_codeobj__421);
  Py_VISIT(traverse_module_state->__pyx_codeobj__422);
  Py_VISIT(traverse_module_state->__pyx_codeobj__423);
  Py_VISIT(traverse_module_state->__pyx_codeobj__425);
  Py_VISIT(traverse_module_state->__pyx_codeobj__427);
  Py_VISIT(traverse_module_state->__pyx_codeobj__428);
  Py_VISIT(traverse_module_state->__pyx_codeobj__429);
  Py_VISIT(traverse_module_state->__pyx_codeobj__430);
  Py_VISIT(traverse_module_state->__pyx_codeobj__431);
  Py_VISIT(traverse_module_state->__pyx_codeobj__433);
  Py_VISIT(traverse_module_state->__pyx_codeobj__435);
  Py_VISIT(traverse_module_state->__pyx_codeobj__436);
  Py_VISIT(traverse_module_state->__pyx_codeobj__437);
  Py_VISIT(traverse_module_state->__pyx_codeobj__438);
  Py_VISIT(traverse_module_state->__pyx_codeobj__439);
  Py_VISIT(traverse_module_state->__pyx_codeobj__440);
  Py_VISIT(traverse_module_state->__pyx_codeobj__442);
  Py_VISIT(traverse_module_state->__pyx_codeobj__444);
  Py_VISIT(traverse_module_state->__pyx_codeobj__447);
  Py_VISIT(traverse_module_state->__pyx_codeobj__449);
  Py_VISIT(traverse_module_state->__pyx_codeobj__450);
  Py_VISIT(traverse_module_state->__pyx_codeobj__452);
  Py_VISIT(traverse_module_state->__pyx_codeobj__453);
  Py_VISIT(traverse_module_state->__pyx_codeobj__454);
  Py_VISIT(traverse_module_state->__pyx_codeobj__455);
  Py_VISIT(traverse_module_state->__pyx_codeobj__456);
  Py_VISIT(traverse_module_state->__pyx_codeobj__458);
  Py_VISIT(traverse_module_state->__pyx_codeobj__459);
  Py_VISIT(traverse_module_state->__pyx_codeobj__460);
  Py_VISIT(traverse_module_state->__pyx_codeobj__463);
  Py_VISIT(traverse_module_state->__pyx_codeobj__464);
  Py_VISIT(traverse_module_state->__pyx_codeobj__466);
  Py_VISIT(traverse_module_state->__pyx_codeobj__467);
  Py_VISIT(traverse_module_state->__pyx_codeobj__468);
  Py_VISIT(traverse_module_state->__pyx_codeobj__469);
  Py_VISIT(traverse_module_state->__pyx_codeobj__471);
  Py_VISIT(traverse_module_state->__pyx_codeobj__473);
  Py_VISIT(traverse_module_state->__pyx_codeobj__475);
  Py_VISIT(traverse_module_state->__pyx_codeobj__477);
  Py_VISIT(traverse_module_state->__pyx_codeobj__480);
  Py_VISIT(traverse_module_state->__pyx_codeobj__482);
  Py_VISIT(traverse_module_state->__pyx_codeobj__484);
  Py_VISIT(traverse_module_state->__pyx_codeobj__486);
  Py_VISIT(traverse_module_state->__pyx_codeobj__489);
  Py_VISIT(traverse_module_state->__pyx_codeobj__492);
  Py_VISIT(traverse_module_state->__pyx_codeobj__494);
  Py_VISIT(traverse_module_state->__pyx_codeobj__495);
  Py_VISIT(traverse_module_state->__pyx_codeobj__496);
  Py_VISIT(traverse_module_state->__pyx_codeobj__498);
  Py_VISIT(traverse_module_state->__pyx_codeobj__500);
  Py_VISIT(traverse_module_state->__pyx_codeobj__503);
  Py_VISIT(traverse_module_state->__pyx_codeobj__504);
  Py_VISIT(traverse_module_state->__pyx_codeobj__506);
  Py_VISIT(traverse_module_state->__pyx_codeobj__509);
  Py_VISIT(traverse_module_state->__pyx_codeobj__510);
  Py_VISIT(traverse_module_state->__pyx_codeobj__530);
  Py_VISIT(traverse_module_state->__pyx_codeobj__533);
  Py_VISIT(traverse_module_state->__pyx_codeobj__534);
  Py_VISIT(traverse_module_state->__pyx_codeobj__536);
  Py_VISIT(traverse_module_state->__pyx_codeobj__538);
  Py_VISIT(traverse_module_state->__pyx_codeobj__540);
  Py_VISIT(traverse_module_state->__pyx_codeobj__541);
  Py_VISIT(traverse_module_state->__pyx_codeobj__542);
  Py_VISIT(traverse_module_state->__pyx_codeobj__543);
  Py_VISIT(traverse_module_state->__pyx_codeobj__544);
  Py_VISIT(traverse_module_state->__pyx_codeobj__545);
  Py_VISIT(traverse_module_state->__pyx_codeobj__546);
  Py_VISIT(traverse_module_state->__pyx_codeobj__547);
  Py_VISIT(traverse_module_state->__pyx_codeobj__548);
  Py_VISIT(traverse_module_state->__pyx_codeobj__550);
  Py_VISIT(traverse_module_state->__pyx_codeobj__551);
  Py_VISIT(traverse_module_state->__pyx_codeobj__552);
  Py_VISIT(traverse_module_state->__pyx_codeobj__554);
  Py_VISIT(traverse_module_state->__pyx_codeobj__556);
  Py_VISIT(traverse_module_state->__pyx_codeobj__557);
  Py_VISIT(traverse_module_state->__pyx_codeobj__559);
  Py_VISIT(traverse_module_state->__pyx_codeobj__561);
  Py_VISIT(traverse_module_state->__pyx_codeobj__562);
  Py_VISIT(traverse_module_state->__pyx_codeobj__564);
  Py_VISIT(traverse_module_state->__pyx_codeobj__566);
  Py_VISIT(traverse_module_state->__pyx_codeobj__568);
  Py_VISIT(traverse_module_state->__pyx_codeobj__570);
  Py_VISIT(traverse_module_state->__pyx_codeobj__571);
  Py_VISIT(traverse_module_state->__pyx_codeobj__573);
  Py_VISIT(traverse_module_state->__pyx_codeobj__575);
  Py_VISIT(traverse_module_state->__pyx_codeobj__577);
  Py_VISIT(traverse_module_state->__pyx_codeobj__578);
  Py_VISIT(traverse_module_state->__pyx_codeobj__580);
  Py_VISIT(traverse_module_state->__pyx_codeobj__581);
  Py_VISIT(traverse_module_state->__pyx_codeobj__582);
  Py_VISIT(traverse_module_state->__pyx_codeobj__583);
  Py_VISIT(traverse_module_state->__pyx_codeobj__585);
  Py_VISIT(traverse_module_state->__pyx_codeobj__586);
  Py_VISIT(traverse_module_state->__pyx_codeobj__587);
  Py_VISIT(traverse_module_state->__pyx_codeobj__588);
  Py_VISIT(traverse_module_state->__pyx_codeobj__590);
  Py_VISIT(traverse_module_state->__pyx_codeobj__591);
  Py_VISIT(traverse_module_state->__pyx_codeobj__592);
  Py_VISIT(traverse_module_state->__pyx_codeobj__594);
  Py_VISIT(traverse_module_state->__pyx_codeobj__597);
  Py_VISIT(traverse_module_state->__pyx_codeobj__598);
  Py_VISIT(traverse_module_state->__pyx_codeobj__599);
  Py_VISIT(traverse_module_state->__pyx_codeobj__600);
  Py_VISIT(traverse_module_state->__pyx_codeobj__601);
  Py_VISIT(traverse_module_state->__pyx_codeobj__602);
  Py_VISIT(traverse_module_state->__pyx_codeobj__603);
  Py_VISIT(traverse_module_state->__pyx_codeobj__605);
  Py_VISIT(traverse_module_state->__pyx_codeobj__606);
  Py_VISIT(traverse_module_state->__pyx_codeobj__607);
  Py_VISIT(traverse_module_state->__pyx_codeobj__609);
  Py_VISIT(traverse_module_state->__pyx_codeobj__610);
  Py_VISIT(traverse_module_state->__pyx_codeobj__611);
  Py_VISIT(traverse_module_state->__pyx_codeobj__612);
  Py_VISIT(traverse_module_state->__pyx_codeobj__613);
  Py_VISIT(traverse_module_state->__pyx_codeobj__615);
  Py_VISIT(traverse_module_state->__pyx_codeobj__617);
  Py_VISIT(traverse_module_state->__pyx_codeobj__618);
  Py_VISIT(traverse_module_state->__pyx_codeobj__620);
  Py_VISIT(traverse_module_state->__pyx_codeobj__623);
  Py_VISIT(traverse_module_state->__pyx_codeobj__625);
  Py_VISIT(traverse_module_state->__pyx_codeobj__627);
  Py_VISIT(traverse_module_state->__pyx_codeobj__629);
  Py_VISIT(traverse_module_state->__pyx_codeobj__630);
  Py_VISIT(traverse_module_state->__pyx_codeobj__631);
  Py_VISIT(traverse_module_state->__pyx_codeobj__633);
  Py_VISIT(traverse_module_state->__pyx_codeobj__635);
  Py_VISIT(traverse_module_state->__pyx_codeobj__637);
  Py_VISIT(traverse_module_state->__pyx_codeobj__638);
  Py_VISIT(traverse_module_state->__pyx_codeobj__639);
  Py_VISIT(traverse_module_state->__pyx_codeobj__641);
  Py_VISIT(traverse_module_state->__pyx_codeobj__642);
  Py_VISIT(traverse_module_state->__pyx_codeobj__643);
  Py_VISIT(traverse_module_state->__pyx_codeobj__646);
  Py_VISIT(traverse_module_state->__pyx_codeobj__647);
  Py_VISIT(traverse_module_state->__pyx_codeobj__649);
  Py_VISIT(traverse_module_state->__pyx_codeobj__651);
  Py_VISIT(traverse_module_state->__pyx_codeobj__652);
  Py_VISIT(traverse_module_state->__pyx_codeobj__654);
  Py_VISIT(traverse_module_state->__pyx_codeobj__656);
  Py_VISIT(traverse_module_state->__pyx_codeobj__657);
  Py_VISIT(traverse_module_state->__pyx_codeobj__658);
  Py_VISIT(traverse_module_state->__pyx_codeobj__659);
  Py_VISIT(traverse_module_state->__pyx_codeobj__660);
  Py_VISIT(traverse_module_state->__pyx_codeobj__661);
  Py_VISIT(traverse_module_state->__pyx_codeobj__662);
  Py_VISIT(traverse_module_state->__pyx_codeobj__663);
  Py_VISIT(traverse_module_state->__pyx_codeobj__664);
  Py_VISIT(traverse_module_state->__pyx_codeobj__665);
  Py_VISIT(traverse_module_state->__pyx_codeobj__666);
  Py_VISIT(traverse_module_state->__pyx_codeobj__668);
  Py_VISIT(traverse_module_state->__pyx_codeobj__670);
  Py_VISIT(traverse_module_state->__pyx_codeobj__672);
  Py_VISIT(traverse_module_state->__pyx_codeobj__673);
  Py_VISIT(traverse_module_state->__pyx_codeobj__674);
  Py_VISIT(traverse_module_state->__pyx_codeobj__675);
  Py_VISIT(traverse_module_state->__pyx_codeobj__677);
  Py_VISIT(traverse_module_state->__pyx_codeobj__678);
  Py_VISIT(traverse_module_state->__pyx_codeobj__679);
  Py_VISIT(traverse_module_state->__pyx_codeobj__683);
  Py_VISIT(traverse_module_state->__pyx_codeobj__685);
  Py_VISIT(traverse_module_state->__pyx_codeobj__686);
  Py_VISIT(traverse_module_state->__pyx_codeobj__688);
  Py_VISIT(traverse_module_state->__pyx_codeobj__690);
  Py_VISIT(traverse_module_state->__pyx_codeobj__693);
  Py_VISIT(traverse_module_state->__pyx_codeobj__695);
  Py_VISIT(traverse_module_state->__pyx_codeobj__697);
  Py_VISIT(traverse_module_state->__pyx_codeobj__699);
  Py_VISIT(traverse_module_state->__pyx_codeobj__701);
  Py_VISIT(traverse_module_state->__pyx_codeobj__703);
  Py_VISIT(traverse_module_state->__pyx_codeobj__706);
  Py_VISIT(traverse_module_state->__pyx_codeobj__708);
  Py_VISIT(traverse_module_state->__pyx_codeobj__710);
  Py_VISIT(traverse_module_state->__pyx_codeobj__712);
  Py_VISIT(traverse_module_state->__pyx_codeobj__729);
  Py_VISIT(traverse_module_state->__pyx_codeobj__731);
  Py_VISIT(traverse_module_state->__pyx_codeobj__733);
  Py_VISIT(traverse_module_state->__pyx_codeobj__734);
  Py_VISIT(traverse_module_state->__pyx_codeobj__736);
  Py_VISIT(traverse_module_state->__pyx_codeobj__738);
  Py_VISIT(traverse_module_state->__pyx_codeobj__742);
  Py_VISIT(traverse_module_state->__pyx_codeobj__743);
  Py_VISIT(traverse_module_state->__pyx_codeobj__747);
  Py_VISIT(traverse_module_state->__pyx_codeobj__749);
  Py_VISIT(traverse_module_state->__pyx_codeobj__751);
  Py_VISIT(traverse_module_state->__pyx_codeobj__763);
  Py_VISIT(traverse_module_state->__pyx_codeobj__765);
  Py_VISIT(traverse_module_state->__pyx_codeobj__773);
  Py_VISIT(traverse_module_state->__pyx_codeobj__797);
  Py_VISIT(traverse_module_state->__pyx_codeobj__799);
  Py_VISIT(traverse_module_state->__pyx_codeobj__802);
  Py_VISIT(traverse_module_state->__pyx_codeobj__805);
  Py_VISIT(traverse_module_state->__pyx_codeobj__807);
  Py_VISIT(traverse_module_state->__pyx_codeobj__811);
  Py_VISIT(traverse_module_state->__pyx_codeobj__812);
  Py_VISIT(traverse_module_state->__pyx_codeobj__813);
  Py_VISIT(traverse_module_state->__pyx_codeobj__814);
  Py_VISIT(traverse_module_state->__pyx_codeobj__815);
  Py_VISIT(traverse_module_state->__pyx_codeobj__868);
  Py_VISIT(traverse_module_state->__pyx_codeobj__869);
  Py_VISIT(traverse_module_state->__pyx_codeobj__871);
  Py_VISIT(traverse_module_state->__pyx_codeobj__872);
  Py_VISIT(traverse_module_state->__pyx_codeobj__873);
  Py_VISIT(traverse_module_state->__pyx_codeobj__875);
  Py_VISIT(traverse_module_state->__pyx_codeobj__877);
  Py_VISIT(traverse_module_state->__pyx_codeobj__880);
  Py_VISIT(traverse_module_state->__pyx_codeobj__882);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_10cPyparsing___pyx_scope_struct__genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct__genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction
#define __pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues
#define __pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems
#define __pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_9___iadd__ __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_9___iadd__
#define __pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_11_asDict __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_11_asDict
#define __pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity
#define __pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak
#define __pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_19_scanString __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_19_scanString
#define __pyx_type_10cPyparsing___pyx_scope_struct_20_split __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_20_split
#define __pyx_type_10cPyparsing___pyx_scope_struct_21___mul__ __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_21___mul__
#define __pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_23___add__ __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_23___add__
#define __pyx_type_10cPyparsing___pyx_scope_struct_24___init__ __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_24___init__
#define __pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_27_sub __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_27_sub
#define __pyx_type_10cPyparsing___pyx_scope_struct_28___init__ __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_28___init__
#define __pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_30___init__ __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_30___init__
#define __pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_33___init__ __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_33___init__
#define __pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction
#define __pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray
#define __pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral
#define __pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater
#define __pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf
#define __pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_62_srange __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_62_srange
#define __pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol
#define __pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith
#define __pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap
#define __pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags
#define __pyx_type_10cPyparsing___pyx_scope_struct_69___call__ __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_69___call__
#define __pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock
#define __pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate
#define __pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime
#define __pyx_type_10cPyparsing___pyx_scope_struct_74___get__ __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_74___get__
#define __pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr
#define __pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException __pyx_mstate_global->__pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException
#endif
#define __pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__ __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_20_split __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_20_split
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__ __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__ __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__ __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__ __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__ __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__ __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__ __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__ __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr
#define __pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException __pyx_mstate_global->__pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException
#define __pyx_kp_u_0 __pyx_mstate_global->__pyx_kp_u_0
#define __pyx_kp_u_0123456789 __pyx_mstate_global->__pyx_kp_u_0123456789
#define __pyx_kp_u_0_0_7 __pyx_mstate_global->__pyx_kp_u_0_0_7
#define __pyx_kp_u_0_1 __pyx_mstate_global->__pyx_kp_u_0_1
#define __pyx_kp_u_0_1_2 __pyx_mstate_global->__pyx_kp_u_0_1_2
#define __pyx_kp_u_0_1_3 __pyx_mstate_global->__pyx_kp_u_0_1_3
#define __pyx_kp_u_0_2 __pyx_mstate_global->__pyx_kp_u_0_2
#define __pyx_kp_u_0_9a_fA_F_1_4 __pyx_mstate_global->__pyx_kp_u_0_9a_fA_F_1_4
#define __pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a __pyx_mstate_global->__pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a
#define __pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a __pyx_mstate_global->__pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a
#define __pyx_kp_u_0_failed_1_2 __pyx_mstate_global->__pyx_kp_u_0_failed_1_2
#define __pyx_kp_u_0_setting_results_name_0_r_on_1 __pyx_mstate_global->__pyx_kp_u_0_setting_results_name_0_r_on_1
#define __pyx_kp_u_0_setting_results_name_1_r_on_2 __pyx_mstate_global->__pyx_kp_u_0_setting_results_name_1_r_on_2
#define __pyx_kp_u_0_setting_results_name_1_r_on_2_2 __pyx_mstate_global->__pyx_kp_u_0_setting_results_name_1_r_on_2_2
#define __pyx_kp_u_0_xX_0_9a_fA_F __pyx_mstate_global->__pyx_kp_u_0_xX_0_9a_fA_F
#define __pyx_kp_u_0x __pyx_mstate_global->__pyx_kp_u_0x
#define __pyx_kp_u_0xa1_0xbf_0xd7_0xf7 __pyx_mstate_global->__pyx_kp_u_0xa1_0xbf_0xd7_0xf7
#define __pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff __pyx_mstate_global->__pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff
#define __pyx_kp_u_100_100_100_3_14159_6_02e23_1e __pyx_mstate_global->__pyx_kp_u_100_100_100_3_14159_6_02e23_1e
#define __pyx_kp_u_100_FF __pyx_mstate_global->__pyx_kp_u_100_FF
#define __pyx_kp_u_12345678_1234_5678_1234_5678123 __pyx_mstate_global->__pyx_kp_u_12345678_1234_5678_1234_5678123
#define __pyx_kp_u_24_Nov_2023_01_45_UTC __pyx_mstate_global->__pyx_kp_u_24_Nov_2023_01_45_UTC
#define __pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0 __pyx_mstate_global->__pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0
#define __pyx_kp_u_2_4_7_2_3_0 __pyx_mstate_global->__pyx_kp_u_2_4_7_2_3_0
#define __pyx_n_u_ABCDEFabcdef __pyx_mstate_global->__pyx_n_u_ABCDEFabcdef
#define __pyx_n_s_ANY_VALUE __pyx_mstate_global->__pyx_n_s_ANY_VALUE
#define __pyx_kp_u_A_cross_version_compatibility_c __pyx_mstate_global->__pyx_kp_u_A_cross_version_compatibility_c
#define __pyx_kp_s_A_mixin_class_to_add_parse_resu __pyx_mstate_global->__pyx_kp_s_A_mixin_class_to_add_parse_resu
#define __pyx_kp_s_A_namespace_class_for_defining __pyx_mstate_global->__pyx_kp_s_A_namespace_class_for_defining
#define __pyx_kp_s_A_set_of_Unicode_characters_for __pyx_mstate_global->__pyx_kp_s_A_set_of_Unicode_characters_for
#define __pyx_kp_s_A_short_cut_class_for_defining_W __pyx_mstate_global->__pyx_kp_s_A_short_cut_class_for_defining_W
#define __pyx_kp_s_A_token_that_will_never_match __pyx_mstate_global->__pyx_kp_s_A_token_that_will_never_match
#define __pyx_kp_s_A_variation_on_class_Literal_whi __pyx_mstate_global->__pyx_kp_s_A_variation_on_class_Literal_whi
#define __pyx_kp_s_Abstract_base_level_parser_eleme __pyx_mstate_global->__pyx_kp_s_Abstract_base_level_parser_eleme
#define __pyx_kp_s_Abstract_class_ParserElement_sub __pyx_mstate_global->__pyx_kp_s_Abstract_class_ParserElement_sub
#define __pyx_kp_s_Abstract_subclass_of_ParserEleme __pyx_mstate_global->__pyx_kp_s_Abstract_subclass_of_ParserEleme
#define __pyx_kp_s_Abstract_subclass_of_class_Pars __pyx_mstate_global->__pyx_kp_s_Abstract_subclass_of_class_Pars
#define __pyx_kp_s_Abstract_subclass_of_class_Parse __pyx_mstate_global->__pyx_kp_s_Abstract_subclass_of_class_Parse
#define __pyx_kp_s_An_empty_token_will_always_match __pyx_mstate_global->__pyx_kp_s_An_empty_token_will_always_match
#define __pyx_n_s_And __pyx_mstate_global->__pyx_n_s_And
#define __pyx_n_u_And __pyx_mstate_global->__pyx_n_u_And
#define __pyx_n_s_And__ErrorStop __pyx_mstate_global->__pyx_n_s_And__ErrorStop
#define __pyx_n_s_And__ErrorStop___init __pyx_mstate_global->__pyx_n_s_And__ErrorStop___init
#define __pyx_n_s_And___iadd __pyx_mstate_global->__pyx_n_s_And___iadd
#define __pyx_n_s_And___init __pyx_mstate_global->__pyx_n_s_And___init
#define __pyx_n_s_And___init___locals_genexpr __pyx_mstate_global->__pyx_n_s_And___init___locals_genexpr
#define __pyx_n_s_And___str __pyx_mstate_global->__pyx_n_s_And___str
#define __pyx_n_s_And___str___locals_genexpr __pyx_mstate_global->__pyx_n_s_And___str___locals_genexpr
#define __pyx_n_s_And_checkRecursion __pyx_mstate_global->__pyx_n_s_And_checkRecursion
#define __pyx_n_s_And_parseImpl __pyx_mstate_global->__pyx_n_s_And_parseImpl
#define __pyx_n_s_And_streamline __pyx_mstate_global->__pyx_n_s_And_streamline
#define __pyx_n_s_And_streamline_locals_genexpr __pyx_mstate_global->__pyx_n_s_And_streamline_locals_genexpr
#define __pyx_n_s_Arabic __pyx_mstate_global->__pyx_n_s_Arabic
#define __pyx_n_s_AttributeError __pyx_mstate_global->__pyx_n_s_AttributeError
#define __pyx_n_s_BOM __pyx_mstate_global->__pyx_n_s_BOM
#define __pyx_n_s_BaseWithAttribute __pyx_mstate_global->__pyx_n_s_BaseWithAttribute
#define __pyx_n_s_BaseWithAttribute___call __pyx_mstate_global->__pyx_n_s_BaseWithAttribute___call
#define __pyx_n_s_BaseWithAttribute___call___local __pyx_mstate_global->__pyx_n_s_BaseWithAttribute___call___local
#define __pyx_n_s_CJK __pyx_mstate_global->__pyx_n_s_CJK
#define __pyx_kp_u_CR __pyx_mstate_global->__pyx_kp_u_CR
#define __pyx_kp_u_C_style_comment __pyx_mstate_global->__pyx_kp_u_C_style_comment
#define __pyx_kp_u_C_style_comment_2 __pyx_mstate_global->__pyx_kp_u_C_style_comment_2
#define __pyx_kp_u_Cannot_combine_element_of_type_s __pyx_mstate_global->__pyx_kp_u_Cannot_combine_element_of_type_s
#define __pyx_n_s_CaselessKeyword __pyx_mstate_global->__pyx_n_s_CaselessKeyword
#define __pyx_n_u_CaselessKeyword __pyx_mstate_global->__pyx_n_u_CaselessKeyword
#define __pyx_n_s_CaselessKeyword___init __pyx_mstate_global->__pyx_n_s_CaselessKeyword___init
#define __pyx_n_s_CaselessLiteral __pyx_mstate_global->__pyx_n_s_CaselessLiteral
#define __pyx_n_u_CaselessLiteral __pyx_mstate_global->__pyx_n_u_CaselessLiteral
#define __pyx_n_s_CaselessLiteral___init __pyx_mstate_global->__pyx_n_s_CaselessLiteral___init
#define __pyx_n_s_CaselessLiteral_parseImpl __pyx_mstate_global->__pyx_n_s_CaselessLiteral_parseImpl
#define __pyx_kp_s_Caseless_version_of_class_Keywo __pyx_mstate_global->__pyx_kp_s_Caseless_version_of_class_Keywo
#define __pyx_n_s_Char __pyx_mstate_global->__pyx_n_s_Char
#define __pyx_n_u_Char __pyx_mstate_global->__pyx_n_u_Char
#define __pyx_n_s_Char___init __pyx_mstate_global->__pyx_n_s_Char___init
#define __pyx_n_s_CharsNotIn __pyx_mstate_global->__pyx_n_s_CharsNotIn
#define __pyx_n_u_CharsNotIn __pyx_mstate_global->__pyx_n_u_CharsNotIn
#define __pyx_n_s_CharsNotIn___init __pyx_mstate_global->__pyx_n_s_CharsNotIn___init
#define __pyx_n_s_CharsNotIn___str __pyx_mstate_global->__pyx_n_s_CharsNotIn___str
#define __pyx_n_s_CharsNotIn_parseImpl __pyx_mstate_global->__pyx_n_s_CharsNotIn_parseImpl
#define __pyx_n_s_Chinese __pyx_mstate_global->__pyx_n_s_Chinese
#define __pyx_n_s_CloseMatch __pyx_mstate_global->__pyx_n_s_CloseMatch
#define __pyx_n_u_CloseMatch __pyx_mstate_global->__pyx_n_u_CloseMatch
#define __pyx_n_s_CloseMatch___init __pyx_mstate_global->__pyx_n_s_CloseMatch___init
#define __pyx_n_s_CloseMatch_parseImpl __pyx_mstate_global->__pyx_n_s_CloseMatch_parseImpl
#define __pyx_n_s_Combine __pyx_mstate_global->__pyx_n_s_Combine
#define __pyx_n_u_Combine __pyx_mstate_global->__pyx_n_u_Combine
#define __pyx_n_s_Combine___init __pyx_mstate_global->__pyx_n_s_Combine___init
#define __pyx_n_s_Combine_ignore __pyx_mstate_global->__pyx_n_s_Combine_ignore
#define __pyx_n_s_Combine_postParse __pyx_mstate_global->__pyx_n_s_Combine_postParse
#define __pyx_kp_s_Context_manager_to_be_used_when __pyx_mstate_global->__pyx_kp_s_Context_manager_to_be_used_when
#define __pyx_kp_s_Converter_for_ignoring_the_resul __pyx_mstate_global->__pyx_kp_s_Converter_for_ignoring_the_resul
#define __pyx_kp_s_Converter_to_concatenate_all_mat __pyx_mstate_global->__pyx_kp_s_Converter_to_concatenate_all_mat
#define __pyx_kp_s_Converter_to_return_a_repetitive __pyx_mstate_global->__pyx_kp_s_Converter_to_return_a_repetitive
#define __pyx_kp_s_Converter_to_return_the_matched __pyx_mstate_global->__pyx_kp_s_Converter_to_return_the_matched
#define __pyx_n_s_Cyrillic __pyx_mstate_global->__pyx_n_s_Cyrillic
#define __pyx_n_s_DEFAULT_KEYWORD_CHARS __pyx_mstate_global->__pyx_n_s_DEFAULT_KEYWORD_CHARS
#define __pyx_n_s_DEFAULT_WHITE_CHARS __pyx_mstate_global->__pyx_n_s_DEFAULT_WHITE_CHARS
#define __pyx_n_s_DOTALL __pyx_mstate_global->__pyx_n_s_DOTALL
#define __pyx_n_s_Devanagari __pyx_mstate_global->__pyx_n_s_Devanagari
#define __pyx_kp_u_Diagnostic_configuration_all_de __pyx_mstate_global->__pyx_kp_u_Diagnostic_configuration_all_de
#define __pyx_n_s_Dict __pyx_mstate_global->__pyx_n_s_Dict
#define __pyx_n_u_Dict __pyx_mstate_global->__pyx_n_u_Dict
#define __pyx_n_s_Dict___init __pyx_mstate_global->__pyx_n_s_Dict___init
#define __pyx_n_s_Dict_postParse __pyx_mstate_global->__pyx_n_s_Dict_postParse
#define __pyx_kp_u_EM_QUAD __pyx_mstate_global->__pyx_kp_u_EM_QUAD
#define __pyx_kp_u_EM_SPACE __pyx_mstate_global->__pyx_kp_u_EM_SPACE
#define __pyx_kp_u_EN_QUAD __pyx_mstate_global->__pyx_kp_u_EN_QUAD
#define __pyx_kp_u_EN_SPACE __pyx_mstate_global->__pyx_kp_u_EN_SPACE
#define __pyx_n_s_Each __pyx_mstate_global->__pyx_n_s_Each
#define __pyx_n_u_Each __pyx_mstate_global->__pyx_n_u_Each
#define __pyx_n_s_Each___init __pyx_mstate_global->__pyx_n_s_Each___init
#define __pyx_n_s_Each___init___locals_genexpr __pyx_mstate_global->__pyx_n_s_Each___init___locals_genexpr
#define __pyx_n_s_Each___str __pyx_mstate_global->__pyx_n_s_Each___str
#define __pyx_n_s_Each___str___locals_genexpr __pyx_mstate_global->__pyx_n_s_Each___str___locals_genexpr
#define __pyx_n_s_Each_checkRecursion __pyx_mstate_global->__pyx_n_s_Each_checkRecursion
#define __pyx_n_s_Each_parseImpl __pyx_mstate_global->__pyx_n_s_Each_parseImpl
#define __pyx_n_s_Each_parseImpl_locals_genexpr __pyx_mstate_global->__pyx_n_s_Each_parseImpl_locals_genexpr
#define __pyx_n_s_Each_streamline __pyx_mstate_global->__pyx_n_s_Each_streamline
#define __pyx_n_s_Each_streamline_locals_genexpr __pyx_mstate_global->__pyx_n_s_Each_streamline_locals_genexpr
#define __pyx_n_s_Ellipsis __pyx_mstate_global->__pyx_n_s_Ellipsis
#define __pyx_n_s_Empty __pyx_mstate_global->__pyx_n_s_Empty
#define __pyx_n_u_Empty __pyx_mstate_global->__pyx_n_u_Empty
#define __pyx_n_s_Empty___init __pyx_mstate_global->__pyx_n_s_Empty___init
#define __pyx_n_s_ErrorStop __pyx_mstate_global->__pyx_n_s_ErrorStop
#define __pyx_kp_u_Evan_Hubinger_evanjhub_gmail_com __pyx_mstate_global->__pyx_kp_u_Evan_Hubinger_evanjhub_gmail_com
#define __pyx_kp_u_Exception_creating_Regex_for_one __pyx_mstate_global->__pyx_kp_u_Exception_creating_Regex_for_one
#define __pyx_kp_u_Exception_raised __pyx_mstate_global->__pyx_kp_u_Exception_raised
#define __pyx_kp_s_Exception_thrown_when_parse_exp __pyx_mstate_global->__pyx_kp_s_Exception_thrown_when_parse_exp
#define __pyx_kp_u_Expected __pyx_mstate_global->__pyx_kp_u_Expected
#define __pyx_kp_u_Expected_end_of_line __pyx_mstate_global->__pyx_kp_u_Expected_end_of_line
#define __pyx_kp_u_Expected_end_of_text __pyx_mstate_global->__pyx_kp_u_Expected_end_of_text
#define __pyx_kp_u_Expected_start_of_line __pyx_mstate_global->__pyx_kp_u_Expected_start_of_line
#define __pyx_kp_u_Expected_start_of_text __pyx_mstate_global->__pyx_kp_u_Expected_start_of_text
#define __pyx_n_s_FAIL __pyx_mstate_global->__pyx_n_s_FAIL
#define __pyx_kp_u_FAIL_2 __pyx_mstate_global->__pyx_kp_u_FAIL_2
#define __pyx_kp_u_FAIL_EXCEPTION __pyx_mstate_global->__pyx_kp_u_FAIL_EXCEPTION
#define __pyx_kp_u_FATAL __pyx_mstate_global->__pyx_kp_u_FATAL
#define __pyx_n_s_FB __pyx_mstate_global->__pyx_n_s_FB
#define __pyx_kp_u_FF __pyx_mstate_global->__pyx_kp_u_FF
#define __pyx_kp_u_FIGURE_SPACE __pyx_mstate_global->__pyx_kp_u_FIGURE_SPACE
#define __pyx_n_s_FILE_NAME __pyx_mstate_global->__pyx_n_s_FILE_NAME
#define __pyx_kp_u_FOUR_PER_EM_SPACE __pyx_mstate_global->__pyx_kp_u_FOUR_PER_EM_SPACE
#define __pyx_n_s_FifoCache __pyx_mstate_global->__pyx_n_s_FifoCache
#define __pyx_n_s_FifoCache___init __pyx_mstate_global->__pyx_n_s_FifoCache___init
#define __pyx_n_s_FifoCache___len __pyx_mstate_global->__pyx_n_s_FifoCache___len
#define __pyx_n_s_FifoCache___reduce __pyx_mstate_global->__pyx_n_s_FifoCache___reduce
#define __pyx_n_s_FifoCache_clear __pyx_mstate_global->__pyx_n_s_FifoCache_clear
#define __pyx_n_s_FifoCache_get __pyx_mstate_global->__pyx_n_s_FifoCache_get
#define __pyx_n_s_FifoCache_set __pyx_mstate_global->__pyx_n_s_FifoCache_set
#define __pyx_n_s_FifoCache_update __pyx_mstate_global->__pyx_n_s_FifoCache_update
#define __pyx_n_s_FollowedBy __pyx_mstate_global->__pyx_n_s_FollowedBy
#define __pyx_n_u_FollowedBy __pyx_mstate_global->__pyx_n_u_FollowedBy
#define __pyx_n_s_FollowedBy___init __pyx_mstate_global->__pyx_n_s_FollowedBy___init
#define __pyx_n_s_FollowedBy_parseImpl __pyx_mstate_global->__pyx_n_s_FollowedBy_parseImpl
#define __pyx_n_s_Forward __pyx_mstate_global->__pyx_n_s_Forward
#define __pyx_n_u_Forward __pyx_mstate_global->__pyx_n_u_Forward
#define __pyx_n_s_Forward___ilshift __pyx_mstate_global->__pyx_n_s_Forward___ilshift
#define __pyx_n_s_Forward___init __pyx_mstate_global->__pyx_n_s_Forward___init
#define __pyx_n_s_Forward___lshift __pyx_mstate_global->__pyx_n_s_Forward___lshift
#define __pyx_n_s_Forward___str __pyx_mstate_global->__pyx_n_s_Forward___str
#define __pyx_n_s_Forward__setResultsName __pyx_mstate_global->__pyx_n_s_Forward__setResultsName
#define __pyx_n_s_Forward_copy __pyx_mstate_global->__pyx_n_s_Forward_copy
#define __pyx_kp_s_Forward_declaration_of_an_expres __pyx_mstate_global->__pyx_kp_s_Forward_declaration_of_an_expres
#define __pyx_n_s_Forward_leaveWhitespace __pyx_mstate_global->__pyx_n_s_Forward_leaveWhitespace
#define __pyx_n_s_Forward_streamline __pyx_mstate_global->__pyx_n_s_Forward_streamline
#define __pyx_n_s_Forward_validate __pyx_mstate_global->__pyx_n_s_Forward_validate
#define __pyx_kp_u_Found_unwanted_token __pyx_mstate_global->__pyx_kp_u_Found_unwanted_token
#define __pyx_n_s_GoToColumn __pyx_mstate_global->__pyx_n_s_GoToColumn
#define __pyx_n_u_GoToColumn __pyx_mstate_global->__pyx_n_u_GoToColumn
#define __pyx_n_s_GoToColumn___init __pyx_mstate_global->__pyx_n_s_GoToColumn___init
#define __pyx_n_s_GoToColumn_parseImpl __pyx_mstate_global->__pyx_n_s_GoToColumn_parseImpl
#define __pyx_n_s_GoToColumn_preParse __pyx_mstate_global->__pyx_n_s_GoToColumn_preParse
#define __pyx_n_s_Greek __pyx_mstate_global->__pyx_n_s_Greek
#define __pyx_n_s_Group __pyx_mstate_global->__pyx_n_s_Group
#define __pyx_n_u_Group __pyx_mstate_global->__pyx_n_u_Group
#define __pyx_n_s_Group___init __pyx_mstate_global->__pyx_n_s_Group___init
#define __pyx_n_s_Group_postParse __pyx_mstate_global->__pyx_n_s_Group_postParse
#define __pyx_kp_u_HAIR_SPACE __pyx_mstate_global->__pyx_kp_u_HAIR_SPACE
#define __pyx_n_s_HIT __pyx_mstate_global->__pyx_n_s_HIT
#define __pyx_kp_u_HTML_comment __pyx_mstate_global->__pyx_kp_u_HTML_comment
#define __pyx_n_s_Hebrew __pyx_mstate_global->__pyx_n_s_Hebrew
#define __pyx_kp_s_Here_are_some_common_low_level_e __pyx_mstate_global->__pyx_kp_s_Here_are_some_common_low_level_e
#define __pyx_n_s_Hiragana __pyx_mstate_global->__pyx_n_s_Hiragana
#define __pyx_kp_u_IDEOGRAPHIC_SPACE __pyx_mstate_global->__pyx_kp_u_IDEOGRAPHIC_SPACE
#define __pyx_n_s_INDENT __pyx_mstate_global->__pyx_n_s_INDENT
#define __pyx_n_u_INDENT __pyx_mstate_global->__pyx_n_u_INDENT
#define __pyx_kp_u_IPv4_address __pyx_mstate_global->__pyx_kp_u_IPv4_address
#define __pyx_kp_u_IPv6_address __pyx_mstate_global->__pyx_kp_u_IPv6_address
#define __pyx_kp_u_ISO8601_date __pyx_mstate_global->__pyx_kp_u_ISO8601_date
#define __pyx_kp_u_ISO8601_datetime __pyx_mstate_global->__pyx_kp_u_ISO8601_datetime
#define __pyx_n_u_ITEM __pyx_mstate_global->__pyx_n_u_ITEM
#define __pyx_n_s_ImportError __pyx_mstate_global->__pyx_n_s_ImportError
#define __pyx_n_s_IndexError __pyx_mstate_global->__pyx_n_s_IndexError
#define __pyx_kp_u_Invalid_argument_to_oneOf_expect __pyx_mstate_global->__pyx_kp_u_Invalid_argument_to_oneOf_expect
#define __pyx_n_s_Iterable __pyx_mstate_global->__pyx_n_s_Iterable
#define __pyx_n_s_Japanese __pyx_mstate_global->__pyx_n_s_Japanese
#define __pyx_n_s_Kanji __pyx_mstate_global->__pyx_n_s_Kanji
#define __pyx_n_s_Katakana __pyx_mstate_global->__pyx_n_s_Katakana
#define __pyx_n_s_KeyError __pyx_mstate_global->__pyx_n_s_KeyError
#define __pyx_n_s_Keyword __pyx_mstate_global->__pyx_n_s_Keyword
#define __pyx_n_u_Keyword __pyx_mstate_global->__pyx_n_u_Keyword
#define __pyx_n_s_Keyword___init __pyx_mstate_global->__pyx_n_s_Keyword___init
#define __pyx_n_s_Keyword_copy __pyx_mstate_global->__pyx_n_s_Keyword_copy
#define __pyx_n_s_Keyword_parseImpl __pyx_mstate_global->__pyx_n_s_Keyword_parseImpl
#define __pyx_n_s_Keyword_setDefaultKeywordChars __pyx_mstate_global->__pyx_n_s_Keyword_setDefaultKeywordChars
#define __pyx_n_s_Korean __pyx_mstate_global->__pyx_n_s_Korean
#define __pyx_n_s_L __pyx_mstate_global->__pyx_n_s_L
#define __pyx_n_s_LEFT __pyx_mstate_global->__pyx_n_s_LEFT
#define __pyx_kp_u_LF __pyx_mstate_global->__pyx_kp_u_LF
#define __pyx_n_s_L_2 __pyx_mstate_global->__pyx_n_s_L_2
#define __pyx_n_s_Latin1 __pyx_mstate_global->__pyx_n_s_Latin1
#define __pyx_n_s_LatinA __pyx_mstate_global->__pyx_n_s_LatinA
#define __pyx_n_s_LatinB __pyx_mstate_global->__pyx_n_s_LatinB
#define __pyx_n_s_LineEnd __pyx_mstate_global->__pyx_n_s_LineEnd
#define __pyx_n_u_LineEnd __pyx_mstate_global->__pyx_n_u_LineEnd
#define __pyx_n_s_LineEnd___init __pyx_mstate_global->__pyx_n_s_LineEnd___init
#define __pyx_n_s_LineEnd_parseImpl __pyx_mstate_global->__pyx_n_s_LineEnd_parseImpl
#define __pyx_n_s_LineStart __pyx_mstate_global->__pyx_n_s_LineStart
#define __pyx_n_u_LineStart __pyx_mstate_global->__pyx_n_u_LineStart
#define __pyx_n_s_LineStart___init __pyx_mstate_global->__pyx_n_s_LineStart___init
#define __pyx_n_s_LineStart_parseImpl __pyx_mstate_global->__pyx_n_s_LineStart_parseImpl
#define __pyx_n_s_Literal __pyx_mstate_global->__pyx_n_s_Literal
#define __pyx_n_u_Literal __pyx_mstate_global->__pyx_n_u_Literal
#define __pyx_n_s_Literal___init __pyx_mstate_global->__pyx_n_s_Literal___init
#define __pyx_n_s_Literal_parseImpl __pyx_mstate_global->__pyx_n_s_Literal_parseImpl
#define __pyx_kp_s_Lookahead_matching_of_the_given __pyx_mstate_global->__pyx_kp_s_Lookahead_matching_of_the_given
#define __pyx_kp_s_Lookahead_to_disallow_matching_w __pyx_mstate_global->__pyx_kp_s_Lookahead_to_disallow_matching_w
#define __pyx_kp_s_Lookbehind_matching_of_the_given __pyx_mstate_global->__pyx_kp_s_Lookbehind_matching_of_the_given
#define __pyx_kp_u_MAC_address __pyx_mstate_global->__pyx_kp_u_MAC_address
#define __pyx_n_s_MATCH __pyx_mstate_global->__pyx_n_s_MATCH
#define __pyx_n_s_MAX_INT __pyx_mstate_global->__pyx_n_s_MAX_INT
#define __pyx_n_s_MISS __pyx_mstate_global->__pyx_n_s_MISS
#define __pyx_kp_u_MMSP __pyx_mstate_global->__pyx_kp_u_MMSP
#define __pyx_kp_u_MONGOLIAN_VOWEL_SEPARATOR __pyx_mstate_global->__pyx_kp_u_MONGOLIAN_VOWEL_SEPARATOR
#define __pyx_n_s_MULTILINE __pyx_mstate_global->__pyx_n_s_MULTILINE
#define __pyx_n_s_Mapping __pyx_mstate_global->__pyx_n_s_Mapping
#define __pyx_kp_u_Match __pyx_mstate_global->__pyx_kp_u_Match
#define __pyx_n_s_MatchFirst __pyx_mstate_global->__pyx_n_s_MatchFirst
#define __pyx_n_u_MatchFirst __pyx_mstate_global->__pyx_n_u_MatchFirst
#define __pyx_n_s_MatchFirst___init __pyx_mstate_global->__pyx_n_s_MatchFirst___init
#define __pyx_n_s_MatchFirst___init___locals_genex __pyx_mstate_global->__pyx_n_s_MatchFirst___init___locals_genex
#define __pyx_n_s_MatchFirst___ior __pyx_mstate_global->__pyx_n_s_MatchFirst___ior
#define __pyx_n_s_MatchFirst___str __pyx_mstate_global->__pyx_n_s_MatchFirst___str
#define __pyx_n_s_MatchFirst___str___locals_genexp __pyx_mstate_global->__pyx_n_s_MatchFirst___str___locals_genexp
#define __pyx_n_s_MatchFirst__setResultsName __pyx_mstate_global->__pyx_n_s_MatchFirst__setResultsName
#define __pyx_n_s_MatchFirst__setResultsName_local __pyx_mstate_global->__pyx_n_s_MatchFirst__setResultsName_local
#define __pyx_n_s_MatchFirst_checkRecursion __pyx_mstate_global->__pyx_n_s_MatchFirst_checkRecursion
#define __pyx_n_s_MatchFirst_parseImpl __pyx_mstate_global->__pyx_n_s_MatchFirst_parseImpl
#define __pyx_n_s_MatchFirst_setAdaptiveMode __pyx_mstate_global->__pyx_n_s_MatchFirst_setAdaptiveMode
#define __pyx_n_s_MatchFirst_streamline __pyx_mstate_global->__pyx_n_s_MatchFirst_streamline
#define __pyx_n_s_MatchFirst_streamline_locals_gen __pyx_mstate_global->__pyx_n_s_MatchFirst_streamline_locals_gen
#define __pyx_kp_u_Matched __pyx_mstate_global->__pyx_kp_u_Matched
#define __pyx_kp_s_Matches_if_current_position_is_a __pyx_mstate_global->__pyx_kp_s_Matches_if_current_position_is_a
#define __pyx_kp_s_Matches_if_current_position_is_a_2 __pyx_mstate_global->__pyx_kp_s_Matches_if_current_position_is_a_2
#define __pyx_kp_s_Matches_if_current_position_is_a_3 __pyx_mstate_global->__pyx_kp_s_Matches_if_current_position_is_a_3
#define __pyx_kp_s_Matches_if_current_position_is_a_4 __pyx_mstate_global->__pyx_kp_s_Matches_if_current_position_is_a_4
#define __pyx_kp_s_Matches_if_the_current_position __pyx_mstate_global->__pyx_kp_s_Matches_if_the_current_position
#define __pyx_kp_s_Matches_if_the_current_position_2 __pyx_mstate_global->__pyx_kp_s_Matches_if_the_current_position_2
#define __pyx_kp_u_Missing_one_or_more_required_ele __pyx_mstate_global->__pyx_kp_u_Missing_one_or_more_required_ele
#define __pyx_kp_u_More_than_one_string_argument_pa __pyx_mstate_global->__pyx_kp_u_More_than_one_string_argument_pa
#define __pyx_n_s_MultipleMatch __pyx_mstate_global->__pyx_n_s_MultipleMatch
#define __pyx_n_s_MultipleMatch___init __pyx_mstate_global->__pyx_n_s_MultipleMatch___init
#define __pyx_n_s_MultipleMatch__setResultsName __pyx_mstate_global->__pyx_n_s_MultipleMatch__setResultsName
#define __pyx_n_s_MultipleMatch_parseImpl __pyx_mstate_global->__pyx_n_s_MultipleMatch_parseImpl
#define __pyx_n_s_MultipleMatch_stopOn __pyx_mstate_global->__pyx_n_s_MultipleMatch_stopOn
#define __pyx_n_s_MutableMapping __pyx_mstate_global->__pyx_n_s_MutableMapping
#define __pyx_kp_u_NBSP __pyx_mstate_global->__pyx_kp_u_NBSP
#define __pyx_n_s_NL __pyx_mstate_global->__pyx_n_s_NL
#define __pyx_kp_u_NNBSP __pyx_mstate_global->__pyx_kp_u_NNBSP
#define __pyx_n_s_NameError __pyx_mstate_global->__pyx_n_s_NameError
#define __pyx_n_s_NoMatch __pyx_mstate_global->__pyx_n_s_NoMatch
#define __pyx_n_u_NoMatch __pyx_mstate_global->__pyx_n_u_NoMatch
#define __pyx_n_s_NoMatch___init __pyx_mstate_global->__pyx_n_s_NoMatch___init
#define __pyx_n_s_NoMatch_parseImpl __pyx_mstate_global->__pyx_n_s_NoMatch_parseImpl
#define __pyx_kp_u_No_match_found_for __pyx_mstate_global->__pyx_kp_u_No_match_found_for
#define __pyx_n_s_NotAny __pyx_mstate_global->__pyx_n_s_NotAny
#define __pyx_n_u_NotAny __pyx_mstate_global->__pyx_n_u_NotAny
#define __pyx_n_s_NotAny___init __pyx_mstate_global->__pyx_n_s_NotAny___init
#define __pyx_n_s_NotAny___str __pyx_mstate_global->__pyx_n_s_NotAny___str
#define __pyx_n_s_NotAny_parseImpl __pyx_mstate_global->__pyx_n_s_NotAny_parseImpl
#define __pyx_kp_u_Not_at_the_end_of_a_word __pyx_mstate_global->__pyx_kp_u_Not_at_the_end_of_a_word
#define __pyx_kp_u_Not_at_the_start_of_a_word __pyx_mstate_global->__pyx_kp_u_Not_at_the_start_of_a_word
#define __pyx_n_s_NullToken __pyx_mstate_global->__pyx_n_s_NullToken
#define __pyx_n_s_NullToken___bool __pyx_mstate_global->__pyx_n_s_NullToken___bool
#define __pyx_n_s_NullToken___str __pyx_mstate_global->__pyx_n_s_NullToken___str
#define __pyx_kp_u_OGHAM_SPACE_MARK __pyx_mstate_global->__pyx_kp_u_OGHAM_SPACE_MARK
#define __pyx_n_s_OneOrMore __pyx_mstate_global->__pyx_n_s_OneOrMore
#define __pyx_n_u_OneOrMore __pyx_mstate_global->__pyx_n_u_OneOrMore
#define __pyx_n_s_OneOrMore___str __pyx_mstate_global->__pyx_n_s_OneOrMore___str
#define __pyx_n_s_OnlyOnce __pyx_mstate_global->__pyx_n_s_OnlyOnce
#define __pyx_n_u_OnlyOnce __pyx_mstate_global->__pyx_n_u_OnlyOnce
#define __pyx_n_s_OnlyOnce___call __pyx_mstate_global->__pyx_n_s_OnlyOnce___call
#define __pyx_n_s_OnlyOnce___init __pyx_mstate_global->__pyx_n_s_OnlyOnce___init
#define __pyx_n_s_OnlyOnce_reset __pyx_mstate_global->__pyx_n_s_OnlyOnce_reset
#define __pyx_n_s_Optional __pyx_mstate_global->__pyx_n_s_Optional
#define __pyx_n_u_Optional __pyx_mstate_global->__pyx_n_u_Optional
#define __pyx_n_s_Optional___init __pyx_mstate_global->__pyx_n_s_Optional___init
#define __pyx_n_s_Optional___str __pyx_mstate_global->__pyx_n_s_Optional___str
#define __pyx_n_s_Optional__optionalNotMatched __pyx_mstate_global->__pyx_n_s_Optional__optionalNotMatched
#define __pyx_kp_s_Optional_matching_of_the_given_e __pyx_mstate_global->__pyx_kp_s_Optional_matching_of_the_given_e
#define __pyx_n_s_Optional_parseImpl __pyx_mstate_global->__pyx_n_s_Optional_parseImpl
#define __pyx_kp_s_Optional_repetition_of_zero_or_m __pyx_mstate_global->__pyx_kp_s_Optional_repetition_of_zero_or_m
#define __pyx_n_s_Or __pyx_mstate_global->__pyx_n_s_Or
#define __pyx_n_u_Or __pyx_mstate_global->__pyx_n_u_Or
#define __pyx_n_s_Or___init __pyx_mstate_global->__pyx_n_s_Or___init
#define __pyx_n_s_Or___init___locals_genexpr __pyx_mstate_global->__pyx_n_s_Or___init___locals_genexpr
#define __pyx_n_s_Or___ixor __pyx_mstate_global->__pyx_n_s_Or___ixor
#define __pyx_n_s_Or___str __pyx_mstate_global->__pyx_n_s_Or___str
#define __pyx_n_s_Or___str___locals_genexpr __pyx_mstate_global->__pyx_n_s_Or___str___locals_genexpr
#define __pyx_n_s_Or__setResultsName __pyx_mstate_global->__pyx_n_s_Or__setResultsName
#define __pyx_n_s_Or__setResultsName_locals_genexp __pyx_mstate_global->__pyx_n_s_Or__setResultsName_locals_genexp
#define __pyx_n_s_Or_checkRecursion __pyx_mstate_global->__pyx_n_s_Or_checkRecursion
#define __pyx_n_s_Or_parseImpl __pyx_mstate_global->__pyx_n_s_Or_parseImpl
#define __pyx_n_s_Or_streamline __pyx_mstate_global->__pyx_n_s_Or_streamline
#define __pyx_n_s_Or_streamline_locals_genexpr __pyx_mstate_global->__pyx_n_s_Or_streamline_locals_genexpr
#define __pyx_n_s_OrderedDict __pyx_mstate_global->__pyx_n_s_OrderedDict
#define __pyx_n_s_OrderedDict_2 __pyx_mstate_global->__pyx_n_s_OrderedDict_2
#define __pyx_n_s_PEER __pyx_mstate_global->__pyx_n_s_PEER
#define __pyx_kp_u_PUNCTUATION_SPACE __pyx_mstate_global->__pyx_kp_u_PUNCTUATION_SPACE
#define __pyx_n_s_PY_3 __pyx_mstate_global->__pyx_n_s_PY_3
#define __pyx_kp_u_P_entity __pyx_mstate_global->__pyx_kp_u_P_entity
#define __pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d __pyx_mstate_global->__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d
#define __pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2 __pyx_mstate_global->__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2
#define __pyx_n_s_ParseBaseException __pyx_mstate_global->__pyx_n_s_ParseBaseException
#define __pyx_n_u_ParseBaseException __pyx_mstate_global->__pyx_n_u_ParseBaseException
#define __pyx_n_s_ParseBaseException___dir __pyx_mstate_global->__pyx_n_s_ParseBaseException___dir
#define __pyx_n_s_ParseBaseException___getattr __pyx_mstate_global->__pyx_n_s_ParseBaseException___getattr
#define __pyx_n_s_ParseBaseException___init __pyx_mstate_global->__pyx_n_s_ParseBaseException___init
#define __pyx_n_s_ParseBaseException___repr __pyx_mstate_global->__pyx_n_s_ParseBaseException___repr
#define __pyx_n_s_ParseBaseException___str __pyx_mstate_global->__pyx_n_s_ParseBaseException___str
#define __pyx_n_s_ParseBaseException__from_excepti __pyx_mstate_global->__pyx_n_s_ParseBaseException__from_excepti
#define __pyx_n_s_ParseBaseException_markInputline __pyx_mstate_global->__pyx_n_s_ParseBaseException_markInputline
#define __pyx_n_s_ParseElementEnhance __pyx_mstate_global->__pyx_n_s_ParseElementEnhance
#define __pyx_n_u_ParseElementEnhance __pyx_mstate_global->__pyx_n_u_ParseElementEnhance
#define __pyx_n_s_ParseElementEnhance___init __pyx_mstate_global->__pyx_n_s_ParseElementEnhance___init
#define __pyx_n_s_ParseElementEnhance___str __pyx_mstate_global->__pyx_n_s_ParseElementEnhance___str
#define __pyx_n_s_ParseElementEnhance_checkRecursi __pyx_mstate_global->__pyx_n_s_ParseElementEnhance_checkRecursi
#define __pyx_n_s_ParseElementEnhance_ignore __pyx_mstate_global->__pyx_n_s_ParseElementEnhance_ignore
#define __pyx_n_s_ParseElementEnhance_leaveWhitesp __pyx_mstate_global->__pyx_n_s_ParseElementEnhance_leaveWhitesp
#define __pyx_n_s_ParseElementEnhance_parseImpl __pyx_mstate_global->__pyx_n_s_ParseElementEnhance_parseImpl
#define __pyx_n_s_ParseElementEnhance_streamline __pyx_mstate_global->__pyx_n_s_ParseElementEnhance_streamline
#define __pyx_n_s_ParseElementEnhance_validate __pyx_mstate_global->__pyx_n_s_ParseElementEnhance_validate
#define __pyx_n_s_ParseException __pyx_mstate_global->__pyx_n_s_ParseException
#define __pyx_n_u_ParseException __pyx_mstate_global->__pyx_n_u_ParseException
#define __pyx_n_s_ParseException_explain __pyx_mstate_global->__pyx_n_s_ParseException_explain
#define __pyx_n_s_ParseExpression __pyx_mstate_global->__pyx_n_s_ParseExpression
#define __pyx_n_u_ParseExpression __pyx_mstate_global->__pyx_n_u_ParseExpression
#define __pyx_n_s_ParseExpression___init __pyx_mstate_global->__pyx_n_s_ParseExpression___init
#define __pyx_n_s_ParseExpression___init___locals __pyx_mstate_global->__pyx_n_s_ParseExpression___init___locals
#define __pyx_n_s_ParseExpression___init___locals_2 __pyx_mstate_global->__pyx_n_s_ParseExpression___init___locals_2
#define __pyx_n_s_ParseExpression___str __pyx_mstate_global->__pyx_n_s_ParseExpression___str
#define __pyx_n_s_ParseExpression__setResultsName __pyx_mstate_global->__pyx_n_s_ParseExpression__setResultsName
#define __pyx_n_s_ParseExpression_append __pyx_mstate_global->__pyx_n_s_ParseExpression_append
#define __pyx_n_s_ParseExpression_copy __pyx_mstate_global->__pyx_n_s_ParseExpression_copy
#define __pyx_n_s_ParseExpression_ignore __pyx_mstate_global->__pyx_n_s_ParseExpression_ignore
#define __pyx_n_s_ParseExpression_leaveWhitespace __pyx_mstate_global->__pyx_n_s_ParseExpression_leaveWhitespace
#define __pyx_n_s_ParseExpression_streamline __pyx_mstate_global->__pyx_n_s_ParseExpression_streamline
#define __pyx_n_s_ParseExpression_validate __pyx_mstate_global->__pyx_n_s_ParseExpression_validate
#define __pyx_n_s_ParseFatalException __pyx_mstate_global->__pyx_n_s_ParseFatalException
#define __pyx_n_u_ParseFatalException __pyx_mstate_global->__pyx_n_u_ParseFatalException
#define __pyx_n_s_ParseResults __pyx_mstate_global->__pyx_n_s_ParseResults
#define __pyx_n_u_ParseResults __pyx_mstate_global->__pyx_n_u_ParseResults
#define __pyx_n_s_ParseResultsWithOffset __pyx_mstate_global->__pyx_n_s_ParseResultsWithOffset
#define __pyx_n_s_ParseResultsWithOffset___getite __pyx_mstate_global->__pyx_n_s_ParseResultsWithOffset___getite
#define __pyx_n_s_ParseResultsWithOffset___init __pyx_mstate_global->__pyx_n_s_ParseResultsWithOffset___init
#define __pyx_n_s_ParseResultsWithOffset___repr __pyx_mstate_global->__pyx_n_s_ParseResultsWithOffset___repr
#define __pyx_n_s_ParseResultsWithOffset_setOffse __pyx_mstate_global->__pyx_n_s_ParseResultsWithOffset_setOffse
#define __pyx_n_s_ParseResults___add __pyx_mstate_global->__pyx_n_s_ParseResults___add
#define __pyx_n_s_ParseResults___bool __pyx_mstate_global->__pyx_n_s_ParseResults___bool
#define __pyx_n_s_ParseResults___contains __pyx_mstate_global->__pyx_n_s_ParseResults___contains
#define __pyx_n_s_ParseResults___delitem __pyx_mstate_global->__pyx_n_s_ParseResults___delitem
#define __pyx_n_s_ParseResults___dir __pyx_mstate_global->__pyx_n_s_ParseResults___dir
#define __pyx_n_s_ParseResults___getattr __pyx_mstate_global->__pyx_n_s_ParseResults___getattr
#define __pyx_n_s_ParseResults___getitem __pyx_mstate_global->__pyx_n_s_ParseResults___getitem
#define __pyx_n_s_ParseResults___getnewargs __pyx_mstate_global->__pyx_n_s_ParseResults___getnewargs
#define __pyx_n_s_ParseResults___getstate __pyx_mstate_global->__pyx_n_s_ParseResults___getstate
#define __pyx_n_s_ParseResults___iadd __pyx_mstate_global->__pyx_n_s_ParseResults___iadd
#define __pyx_n_s_ParseResults___iadd___locals_lam __pyx_mstate_global->__pyx_n_s_ParseResults___iadd___locals_lam
#define __pyx_n_s_ParseResults___init __pyx_mstate_global->__pyx_n_s_ParseResults___init
#define __pyx_n_s_ParseResults___iter __pyx_mstate_global->__pyx_n_s_ParseResults___iter
#define __pyx_n_s_ParseResults___len __pyx_mstate_global->__pyx_n_s_ParseResults___len
#define __pyx_n_s_ParseResults___lookup __pyx_mstate_global->__pyx_n_s_ParseResults___lookup
#define __pyx_n_s_ParseResults___new __pyx_mstate_global->__pyx_n_s_ParseResults___new
#define __pyx_n_s_ParseResults___radd __pyx_mstate_global->__pyx_n_s_ParseResults___radd
#define __pyx_n_s_ParseResults___repr __pyx_mstate_global->__pyx_n_s_ParseResults___repr
#define __pyx_n_s_ParseResults___reversed __pyx_mstate_global->__pyx_n_s_ParseResults___reversed
#define __pyx_n_s_ParseResults___setitem __pyx_mstate_global->__pyx_n_s_ParseResults___setitem
#define __pyx_n_s_ParseResults___setstate __pyx_mstate_global->__pyx_n_s_ParseResults___setstate
#define __pyx_n_s_ParseResults___str __pyx_mstate_global->__pyx_n_s_ParseResults___str
#define __pyx_n_s_ParseResults___str___locals_gene __pyx_mstate_global->__pyx_n_s_ParseResults___str___locals_gene
#define __pyx_n_s_ParseResults__accumNames __pyx_mstate_global->__pyx_n_s_ParseResults__accumNames
#define __pyx_n_s_ParseResults__asList __pyx_mstate_global->__pyx_n_s_ParseResults__asList
#define __pyx_n_s_ParseResults__asStringList __pyx_mstate_global->__pyx_n_s_ParseResults__asStringList
#define __pyx_n_s_ParseResults__doinit __pyx_mstate_global->__pyx_n_s_ParseResults__doinit
#define __pyx_n_s_ParseResults__iteritems __pyx_mstate_global->__pyx_n_s_ParseResults__iteritems
#define __pyx_n_s_ParseResults__iteritems_locals_g __pyx_mstate_global->__pyx_n_s_ParseResults__iteritems_locals_g
#define __pyx_n_s_ParseResults__iterkeys __pyx_mstate_global->__pyx_n_s_ParseResults__iterkeys
#define __pyx_n_s_ParseResults__itervalues __pyx_mstate_global->__pyx_n_s_ParseResults__itervalues
#define __pyx_n_s_ParseResults__itervalues_locals __pyx_mstate_global->__pyx_n_s_ParseResults__itervalues_locals
#define __pyx_n_s_ParseResults__lookup __pyx_mstate_global->__pyx_n_s_ParseResults__lookup
#define __pyx_n_s_ParseResults__modal __pyx_mstate_global->__pyx_n_s_ParseResults__modal
#define __pyx_n_s_ParseResults__name __pyx_mstate_global->__pyx_n_s_ParseResults__name
#define __pyx_n_s_ParseResults__parent __pyx_mstate_global->__pyx_n_s_ParseResults__parent
#define __pyx_n_s_ParseResults__tokdict __pyx_mstate_global->__pyx_n_s_ParseResults__tokdict
#define __pyx_n_s_ParseResults__toklist __pyx_mstate_global->__pyx_n_s_ParseResults__toklist
#define __pyx_n_s_ParseResults_append __pyx_mstate_global->__pyx_n_s_ParseResults_append
#define __pyx_n_s_ParseResults_asDict __pyx_mstate_global->__pyx_n_s_ParseResults_asDict
#define __pyx_n_s_ParseResults_asDict_locals_genex __pyx_mstate_global->__pyx_n_s_ParseResults_asDict_locals_genex
#define __pyx_n_s_ParseResults_asDict_locals_toIte __pyx_mstate_global->__pyx_n_s_ParseResults_asDict_locals_toIte
#define __pyx_n_s_ParseResults_asList __pyx_mstate_global->__pyx_n_s_ParseResults_asList
#define __pyx_n_s_ParseResults_asXML __pyx_mstate_global->__pyx_n_s_ParseResults_asXML
#define __pyx_n_s_ParseResults_asXML_locals_genexp __pyx_mstate_global->__pyx_n_s_ParseResults_asXML_locals_genexp
#define __pyx_n_s_ParseResults_clear __pyx_mstate_global->__pyx_n_s_ParseResults_clear
#define __pyx_n_s_ParseResults_copy __pyx_mstate_global->__pyx_n_s_ParseResults_copy
#define __pyx_n_s_ParseResults_dump __pyx_mstate_global->__pyx_n_s_ParseResults_dump
#define __pyx_n_s_ParseResults_dump_locals_genexpr __pyx_mstate_global->__pyx_n_s_ParseResults_dump_locals_genexpr
#define __pyx_n_s_ParseResults_extend __pyx_mstate_global->__pyx_n_s_ParseResults_extend
#define __pyx_n_s_ParseResults_from_dict __pyx_mstate_global->__pyx_n_s_ParseResults_from_dict
#define __pyx_n_s_ParseResults_from_dict_locals_is __pyx_mstate_global->__pyx_n_s_ParseResults_from_dict_locals_is
#define __pyx_n_s_ParseResults_get __pyx_mstate_global->__pyx_n_s_ParseResults_get
#define __pyx_n_s_ParseResults_getName __pyx_mstate_global->__pyx_n_s_ParseResults_getName
#define __pyx_n_s_ParseResults_haskeys __pyx_mstate_global->__pyx_n_s_ParseResults_haskeys
#define __pyx_n_s_ParseResults_insert __pyx_mstate_global->__pyx_n_s_ParseResults_insert
#define __pyx_n_s_ParseResults_items __pyx_mstate_global->__pyx_n_s_ParseResults_items
#define __pyx_n_s_ParseResults_keys __pyx_mstate_global->__pyx_n_s_ParseResults_keys
#define __pyx_n_s_ParseResults_pop __pyx_mstate_global->__pyx_n_s_ParseResults_pop
#define __pyx_n_s_ParseResults_pprint __pyx_mstate_global->__pyx_n_s_ParseResults_pprint
#define __pyx_n_s_ParseResults_values __pyx_mstate_global->__pyx_n_s_ParseResults_values
#define __pyx_n_s_ParseSyntaxException __pyx_mstate_global->__pyx_n_s_ParseSyntaxException
#define __pyx_n_u_ParseSyntaxException __pyx_mstate_global->__pyx_n_u_ParseSyntaxException
#define __pyx_n_s_ParserElement __pyx_mstate_global->__pyx_n_s_ParserElement
#define __pyx_n_u_ParserElement __pyx_mstate_global->__pyx_n_u_ParserElement
#define __pyx_n_s_ParserElement___add __pyx_mstate_global->__pyx_n_s_ParserElement___add
#define __pyx_n_s_ParserElement___and __pyx_mstate_global->__pyx_n_s_ParserElement___and
#define __pyx_n_s_ParserElement___call __pyx_mstate_global->__pyx_n_s_ParserElement___call
#define __pyx_n_s_ParserElement___eq __pyx_mstate_global->__pyx_n_s_ParserElement___eq
#define __pyx_n_s_ParserElement___getitem __pyx_mstate_global->__pyx_n_s_ParserElement___getitem
#define __pyx_n_s_ParserElement___hash __pyx_mstate_global->__pyx_n_s_ParserElement___hash
#define __pyx_n_s_ParserElement___init __pyx_mstate_global->__pyx_n_s_ParserElement___init
#define __pyx_n_s_ParserElement___invert __pyx_mstate_global->__pyx_n_s_ParserElement___invert
#define __pyx_n_s_ParserElement___iter __pyx_mstate_global->__pyx_n_s_ParserElement___iter
#define __pyx_n_s_ParserElement___mul __pyx_mstate_global->__pyx_n_s_ParserElement___mul
#define __pyx_n_s_ParserElement___mul___locals_gen __pyx_mstate_global->__pyx_n_s_ParserElement___mul___locals_gen
#define __pyx_n_s_ParserElement___mul___locals_mak __pyx_mstate_global->__pyx_n_s_ParserElement___mul___locals_mak
#define __pyx_n_s_ParserElement___ne __pyx_mstate_global->__pyx_n_s_ParserElement___ne
#define __pyx_n_s_ParserElement___or __pyx_mstate_global->__pyx_n_s_ParserElement___or
#define __pyx_n_s_ParserElement___radd __pyx_mstate_global->__pyx_n_s_ParserElement___radd
#define __pyx_n_s_ParserElement___rand __pyx_mstate_global->__pyx_n_s_ParserElement___rand
#define __pyx_n_s_ParserElement___repr __pyx_mstate_global->__pyx_n_s_ParserElement___repr
#define __pyx_n_s_ParserElement___req __pyx_mstate_global->__pyx_n_s_ParserElement___req
#define __pyx_n_s_ParserElement___rmul __pyx_mstate_global->__pyx_n_s_ParserElement___rmul
#define __pyx_n_s_ParserElement___rne __pyx_mstate_global->__pyx_n_s_ParserElement___rne
#define __pyx_n_s_ParserElement___ror __pyx_mstate_global->__pyx_n_s_ParserElement___ror
#define __pyx_n_s_ParserElement___rsub __pyx_mstate_global->__pyx_n_s_ParserElement___rsub
#define __pyx_n_s_ParserElement___rxor __pyx_mstate_global->__pyx_n_s_ParserElement___rxor
#define __pyx_n_s_ParserElement___str __pyx_mstate_global->__pyx_n_s_ParserElement___str
#define __pyx_n_s_ParserElement___sub __pyx_mstate_global->__pyx_n_s_ParserElement___sub
#define __pyx_n_s_ParserElement___xor __pyx_mstate_global->__pyx_n_s_ParserElement___xor
#define __pyx_n_s_ParserElement__parseCache __pyx_mstate_global->__pyx_n_s_ParserElement__parseCache
#define __pyx_n_s_ParserElement__parseIncremental __pyx_mstate_global->__pyx_n_s_ParserElement__parseIncremental
#define __pyx_n_s_ParserElement__parseIncremental_2 __pyx_mstate_global->__pyx_n_s_ParserElement__parseIncremental_2
#define __pyx_n_s_ParserElement__parseNoCache __pyx_mstate_global->__pyx_n_s_ParserElement__parseNoCache
#define __pyx_n_s_ParserElement__setResultsName __pyx_mstate_global->__pyx_n_s_ParserElement__setResultsName
#define __pyx_n_s_ParserElement__skipIgnorables __pyx_mstate_global->__pyx_n_s_ParserElement__skipIgnorables
#define __pyx_n_s_ParserElement__trim_traceback __pyx_mstate_global->__pyx_n_s_ParserElement__trim_traceback
#define __pyx_n_s_ParserElement__update_furthest_l __pyx_mstate_global->__pyx_n_s_ParserElement__update_furthest_l
#define __pyx_n_s_ParserElement_addCondition __pyx_mstate_global->__pyx_n_s_ParserElement_addCondition
#define __pyx_n_s_ParserElement_addParseAction __pyx_mstate_global->__pyx_n_s_ParserElement_addParseAction
#define __pyx_n_s_ParserElement_canParseNext __pyx_mstate_global->__pyx_n_s_ParserElement_canParseNext
#define __pyx_n_s_ParserElement_checkRecursion __pyx_mstate_global->__pyx_n_s_ParserElement_checkRecursion
#define __pyx_n_s_ParserElement_collectParseElemen __pyx_mstate_global->__pyx_n_s_ParserElement_collectParseElemen
#define __pyx_n_s_ParserElement_copy __pyx_mstate_global->__pyx_n_s_ParserElement_copy
#define __pyx_n_s_ParserElement_enableIncremental __pyx_mstate_global->__pyx_n_s_ParserElement_enableIncremental
#define __pyx_n_s_ParserElement_enablePackrat __pyx_mstate_global->__pyx_n_s_ParserElement_enablePackrat
#define __pyx_n_s_ParserElement_ignore __pyx_mstate_global->__pyx_n_s_ParserElement_ignore
#define __pyx_n_s_ParserElement_inlineLiteralsUsin __pyx_mstate_global->__pyx_n_s_ParserElement_inlineLiteralsUsin
#define __pyx_n_s_ParserElement_leaveWhitespace __pyx_mstate_global->__pyx_n_s_ParserElement_leaveWhitespace
#define __pyx_n_s_ParserElement_matches __pyx_mstate_global->__pyx_n_s_ParserElement_matches
#define __pyx_n_s_ParserElement_parseFile __pyx_mstate_global->__pyx_n_s_ParserElement_parseFile
#define __pyx_n_s_ParserElement_parseImpl __pyx_mstate_global->__pyx_n_s_ParserElement_parseImpl
#define __pyx_n_s_ParserElement_parseString __pyx_mstate_global->__pyx_n_s_ParserElement_parseString
#define __pyx_n_s_ParserElement_parseWithTabs __pyx_mstate_global->__pyx_n_s_ParserElement_parseWithTabs
#define __pyx_n_s_ParserElement_postParse __pyx_mstate_global->__pyx_n_s_ParserElement_postParse
#define __pyx_n_s_ParserElement_preParse __pyx_mstate_global->__pyx_n_s_ParserElement_preParse
#define __pyx_n_s_ParserElement_resetCache __pyx_mstate_global->__pyx_n_s_ParserElement_resetCache
#define __pyx_n_s_ParserElement_runTests __pyx_mstate_global->__pyx_n_s_ParserElement_runTests
#define __pyx_n_s_ParserElement_scanString __pyx_mstate_global->__pyx_n_s_ParserElement_scanString
#define __pyx_n_s_ParserElement_searchString __pyx_mstate_global->__pyx_n_s_ParserElement_searchString
#define __pyx_n_s_ParserElement_setBreak __pyx_mstate_global->__pyx_n_s_ParserElement_setBreak
#define __pyx_n_s_ParserElement_setBreak_locals_br __pyx_mstate_global->__pyx_n_s_ParserElement_setBreak_locals_br
#define __pyx_n_s_ParserElement_setDebug __pyx_mstate_global->__pyx_n_s_ParserElement_setDebug
#define __pyx_n_s_ParserElement_setDebugActions __pyx_mstate_global->__pyx_n_s_ParserElement_setDebugActions
#define __pyx_n_s_ParserElement_setDefaultWhitespa __pyx_mstate_global->__pyx_n_s_ParserElement_setDefaultWhitespa
#define __pyx_n_s_ParserElement_setFailAction __pyx_mstate_global->__pyx_n_s_ParserElement_setFailAction
#define __pyx_n_s_ParserElement_setName __pyx_mstate_global->__pyx_n_s_ParserElement_setName
#define __pyx_n_s_ParserElement_setParseAction __pyx_mstate_global->__pyx_n_s_ParserElement_setParseAction
#define __pyx_n_s_ParserElement_setParseAction_loc __pyx_mstate_global->__pyx_n_s_ParserElement_setParseAction_loc
#define __pyx_n_s_ParserElement_setResultsName __pyx_mstate_global->__pyx_n_s_ParserElement_setResultsName
#define __pyx_n_s_ParserElement_setWhitespaceChars __pyx_mstate_global->__pyx_n_s_ParserElement_setWhitespaceChars
#define __pyx_n_s_ParserElement_split __pyx_mstate_global->__pyx_n_s_ParserElement_split
#define __pyx_n_s_ParserElement_streamline __pyx_mstate_global->__pyx_n_s_ParserElement_streamline
#define __pyx_n_s_ParserElement_suppress __pyx_mstate_global->__pyx_n_s_ParserElement_suppress
#define __pyx_n_s_ParserElement_transformString __pyx_mstate_global->__pyx_n_s_ParserElement_transformString
#define __pyx_n_s_ParserElement_tryParse __pyx_mstate_global->__pyx_n_s_ParserElement_tryParse
#define __pyx_n_s_ParserElement_validate __pyx_mstate_global->__pyx_n_s_ParserElement_validate
#define __pyx_n_s_PendingSkip __pyx_mstate_global->__pyx_n_s_PendingSkip
#define __pyx_n_s_PendingSkip___add __pyx_mstate_global->__pyx_n_s_PendingSkip___add
#define __pyx_n_s_PendingSkip___add___locals_must __pyx_mstate_global->__pyx_n_s_PendingSkip___add___locals_must
#define __pyx_n_s_PendingSkip___add___locals_show __pyx_mstate_global->__pyx_n_s_PendingSkip___add___locals_show
#define __pyx_n_s_PendingSkip___init __pyx_mstate_global->__pyx_n_s_PendingSkip___init
#define __pyx_n_s_PendingSkip___repr __pyx_mstate_global->__pyx_n_s_PendingSkip___repr
#define __pyx_n_s_PendingSkip_parseImpl __pyx_mstate_global->__pyx_n_s_PendingSkip_parseImpl
#define __pyx_n_s_PositionToken __pyx_mstate_global->__pyx_n_s_PositionToken
#define __pyx_n_s_PositionToken___init __pyx_mstate_global->__pyx_n_s_PositionToken___init
#define __pyx_n_s_PrecededBy __pyx_mstate_global->__pyx_n_s_PrecededBy
#define __pyx_n_u_PrecededBy __pyx_mstate_global->__pyx_n_u_PrecededBy
#define __pyx_n_s_PrecededBy___init __pyx_mstate_global->__pyx_n_s_PrecededBy___init
#define __pyx_n_s_PrecededBy___init___locals_lambd __pyx_mstate_global->__pyx_n_s_PrecededBy___init___locals_lambd
#define __pyx_n_s_PrecededBy_parseImpl __pyx_mstate_global->__pyx_n_s_PrecededBy_parseImpl
#define __pyx_kp_u_Python_style_comment __pyx_mstate_global->__pyx_kp_u_Python_style_comment
#define __pyx_n_s_QuotedString __pyx_mstate_global->__pyx_n_s_QuotedString
#define __pyx_n_u_QuotedString __pyx_mstate_global->__pyx_n_u_QuotedString
#define __pyx_n_s_QuotedString___init __pyx_mstate_global->__pyx_n_s_QuotedString___init
#define __pyx_n_s_QuotedString___init___locals_gen __pyx_mstate_global->__pyx_n_s_QuotedString___init___locals_gen
#define __pyx_n_s_QuotedString___str __pyx_mstate_global->__pyx_n_s_QuotedString___str
#define __pyx_n_s_QuotedString_parseImpl __pyx_mstate_global->__pyx_n_s_QuotedString_parseImpl
#define __pyx_n_s_RIGHT __pyx_mstate_global->__pyx_n_s_RIGHT
#define __pyx_n_s_RLock __pyx_mstate_global->__pyx_n_s_RLock
#define __pyx_kp_u_Re_s __pyx_mstate_global->__pyx_kp_u_Re_s
#define __pyx_n_s_RecursiveGrammarException __pyx_mstate_global->__pyx_n_s_RecursiveGrammarException
#define __pyx_n_u_RecursiveGrammarException __pyx_mstate_global->__pyx_n_u_RecursiveGrammarException
#define __pyx_n_s_RecursiveGrammarException___init __pyx_mstate_global->__pyx_n_s_RecursiveGrammarException___init
#define __pyx_n_s_RecursiveGrammarException___str __pyx_mstate_global->__pyx_n_s_RecursiveGrammarException___str
#define __pyx_kp_u_RecursiveGrammarException_s __pyx_mstate_global->__pyx_kp_u_RecursiveGrammarException_s
#define __pyx_n_s_Regex __pyx_mstate_global->__pyx_n_s_Regex
#define __pyx_n_u_Regex __pyx_mstate_global->__pyx_n_u_Regex
#define __pyx_n_s_Regex___init __pyx_mstate_global->__pyx_n_s_Regex___init
#define __pyx_n_s_Regex___str __pyx_mstate_global->__pyx_n_s_Regex___str
#define __pyx_kp_u_Regex_may_only_be_constructed_wi __pyx_mstate_global->__pyx_kp_u_Regex_may_only_be_constructed_wi
#define __pyx_n_s_Regex_parseImpl __pyx_mstate_global->__pyx_n_s_Regex_parseImpl
#define __pyx_n_s_Regex_parseImplAsGroupList __pyx_mstate_global->__pyx_n_s_Regex_parseImplAsGroupList
#define __pyx_n_s_Regex_parseImplAsMatch __pyx_mstate_global->__pyx_n_s_Regex_parseImplAsMatch
#define __pyx_n_s_Regex_sub __pyx_mstate_global->__pyx_n_s_Regex_sub
#define __pyx_n_s_Regex_sub_locals_pa __pyx_mstate_global->__pyx_n_s_Regex_sub_locals_pa
#define __pyx_kp_s_Repetition_of_one_or_more_of_the __pyx_mstate_global->__pyx_kp_s_Repetition_of_one_or_more_of_the
#define __pyx_kp_s_Requires_all_given_class_ParseE __pyx_mstate_global->__pyx_kp_s_Requires_all_given_class_ParseE
#define __pyx_kp_s_Requires_all_given_class_ParseEx __pyx_mstate_global->__pyx_kp_s_Requires_all_given_class_ParseEx
#define __pyx_kp_s_Requires_that_at_least_one_class __pyx_mstate_global->__pyx_kp_s_Requires_that_at_least_one_class
#define __pyx_kp_s_Requires_that_at_least_one_class_2 __pyx_mstate_global->__pyx_kp_s_Requires_that_at_least_one_class_2
#define __pyx_kp_u_SIX_PER_EM_SPACE __pyx_mstate_global->__pyx_kp_u_SIX_PER_EM_SPACE
#define __pyx_kp_u_SP __pyx_mstate_global->__pyx_kp_u_SP
#define __pyx_n_s_SimpleNamespace __pyx_mstate_global->__pyx_n_s_SimpleNamespace
#define __pyx_n_s_SingleCharLiteral __pyx_mstate_global->__pyx_n_s_SingleCharLiteral
#define __pyx_n_s_SingleCharLiteral_parseImpl __pyx_mstate_global->__pyx_n_s_SingleCharLiteral_parseImpl
#define __pyx_n_s_SkipTo __pyx_mstate_global->__pyx_n_s_SkipTo
#define __pyx_n_u_SkipTo __pyx_mstate_global->__pyx_n_u_SkipTo
#define __pyx_n_s_SkipTo___init __pyx_mstate_global->__pyx_n_s_SkipTo___init
#define __pyx_n_s_SkipTo_parseImpl __pyx_mstate_global->__pyx_n_s_SkipTo_parseImpl
#define __pyx_kp_s_Special_matching_class_for_match __pyx_mstate_global->__pyx_kp_s_Special_matching_class_for_match
#define __pyx_n_s_StringEnd __pyx_mstate_global->__pyx_n_s_StringEnd
#define __pyx_n_u_StringEnd __pyx_mstate_global->__pyx_n_u_StringEnd
#define __pyx_n_s_StringEnd___init __pyx_mstate_global->__pyx_n_s_StringEnd___init
#define __pyx_n_s_StringEnd_parseImpl __pyx_mstate_global->__pyx_n_s_StringEnd_parseImpl
#define __pyx_n_s_StringStart __pyx_mstate_global->__pyx_n_s_StringStart
#define __pyx_n_u_StringStart __pyx_mstate_global->__pyx_n_u_StringStart
#define __pyx_n_s_StringStart___init __pyx_mstate_global->__pyx_n_s_StringStart___init
#define __pyx_n_s_StringStart_parseImpl __pyx_mstate_global->__pyx_n_s_StringStart_parseImpl
#define __pyx_kp_s_Structured_parse_results_to_prov __pyx_mstate_global->__pyx_kp_s_Structured_parse_results_to_prov
#define __pyx_n_s_Suppress __pyx_mstate_global->__pyx_n_s_Suppress
#define __pyx_n_u_Suppress __pyx_mstate_global->__pyx_n_u_Suppress
#define __pyx_n_s_Suppress_postParse __pyx_mstate_global->__pyx_n_s_Suppress_postParse
#define __pyx_n_s_Suppress_suppress __pyx_mstate_global->__pyx_n_s_Suppress_suppress
#define __pyx_n_s_SyntaxError __pyx_mstate_global->__pyx_n_s_SyntaxError
#define __pyx_n_s_SyntaxWarning __pyx_mstate_global->__pyx_n_s_SyntaxWarning
#define __pyx_kp_u_TAB __pyx_mstate_global->__pyx_kp_u_TAB
#define __pyx_kp_u_THIN_SPACE __pyx_mstate_global->__pyx_kp_u_THIN_SPACE
#define __pyx_kp_u_THREE_PER_EM_SPACE __pyx_mstate_global->__pyx_kp_u_THREE_PER_EM_SPACE
#define __pyx_n_s_TRY __pyx_mstate_global->__pyx_n_s_TRY
#define __pyx_n_s_TestParseResultsAsserts __pyx_mstate_global->__pyx_n_s_TestParseResultsAsserts
#define __pyx_kp_u_Text_not_in_expected_column __pyx_mstate_global->__pyx_kp_u_Text_not_in_expected_column
#define __pyx_n_s_Thai __pyx_mstate_global->__pyx_n_s_Thai
#define __pyx_n_s_Token __pyx_mstate_global->__pyx_n_s_Token
#define __pyx_n_u_Token __pyx_mstate_global->__pyx_n_u_Token
#define __pyx_n_s_TokenConverter __pyx_mstate_global->__pyx_n_s_TokenConverter
#define __pyx_n_u_TokenConverter __pyx_mstate_global->__pyx_n_u_TokenConverter
#define __pyx_n_s_TokenConverter___init __pyx_mstate_global->__pyx_n_s_TokenConverter___init
#define __pyx_n_s_Token___init __pyx_mstate_global->__pyx_n_s_Token___init
#define __pyx_kp_s_Token_for_matching_strings_that __pyx_mstate_global->__pyx_kp_s_Token_for_matching_strings_that
#define __pyx_kp_s_Token_for_matching_strings_that_2 __pyx_mstate_global->__pyx_kp_s_Token_for_matching_strings_that_2
#define __pyx_kp_s_Token_for_matching_words_compose __pyx_mstate_global->__pyx_kp_s_Token_for_matching_words_compose
#define __pyx_kp_s_Token_for_matching_words_compose_2 __pyx_mstate_global->__pyx_kp_s_Token_for_matching_words_compose_2
#define __pyx_kp_s_Token_for_skipping_over_all_unde __pyx_mstate_global->__pyx_kp_s_Token_for_skipping_over_all_unde
#define __pyx_kp_s_Token_to_advance_to_a_specific_c __pyx_mstate_global->__pyx_kp_s_Token_to_advance_to_a_specific_c
#define __pyx_kp_s_Token_to_exactly_match_a_specifi __pyx_mstate_global->__pyx_kp_s_Token_to_exactly_match_a_specifi
#define __pyx_kp_s_Token_to_exactly_match_a_specifi_2 __pyx_mstate_global->__pyx_kp_s_Token_to_exactly_match_a_specifi_2
#define __pyx_kp_s_Token_to_match_a_specified_strin __pyx_mstate_global->__pyx_kp_s_Token_to_match_a_specified_strin
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_n_s_UNDENT __pyx_mstate_global->__pyx_n_s_UNDENT
#define __pyx_n_u_UNINDENT __pyx_mstate_global->__pyx_n_u_UNINDENT
#define __pyx_n_s_UUID __pyx_mstate_global->__pyx_n_s_UUID
#define __pyx_n_u_UUID __pyx_mstate_global->__pyx_n_u_UUID
#define __pyx_n_s_UnboundedCache __pyx_mstate_global->__pyx_n_s_UnboundedCache
#define __pyx_n_s_UnboundedCache___init __pyx_mstate_global->__pyx_n_s_UnboundedCache___init
#define __pyx_n_s_UnboundedCache___len __pyx_mstate_global->__pyx_n_s_UnboundedCache___len
#define __pyx_n_s_UnboundedCache___reduce __pyx_mstate_global->__pyx_n_s_UnboundedCache___reduce
#define __pyx_n_s_UnboundedCache_clear __pyx_mstate_global->__pyx_n_s_UnboundedCache_clear
#define __pyx_n_s_UnboundedCache_get __pyx_mstate_global->__pyx_n_s_UnboundedCache_get
#define __pyx_n_s_UnboundedCache_set __pyx_mstate_global->__pyx_n_s_UnboundedCache_set
#define __pyx_n_s_UnboundedCache_update __pyx_mstate_global->__pyx_n_s_UnboundedCache_update
#define __pyx_kp_s_Unicode_set_for_Arabic_Unicode_C __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Arabic_Unicode_C
#define __pyx_kp_s_Unicode_set_for_Chinese_Unicode __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Chinese_Unicode
#define __pyx_kp_s_Unicode_set_for_Cyrillic_Unicode __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Cyrillic_Unicode
#define __pyx_kp_s_Unicode_set_for_Devanagari_Unico __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Devanagari_Unico
#define __pyx_kp_s_Unicode_set_for_Greek_Unicode_Ch __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Greek_Unicode_Ch
#define __pyx_kp_s_Unicode_set_for_Hebrew_Unicode_C __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Hebrew_Unicode_C
#define __pyx_kp_s_Unicode_set_for_Hiragana_Unicode __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Hiragana_Unicode
#define __pyx_kp_s_Unicode_set_for_Japanese_Unicode __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Japanese_Unicode
#define __pyx_kp_s_Unicode_set_for_Kanji_Unicode_Ch __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Kanji_Unicode_Ch
#define __pyx_kp_s_Unicode_set_for_Katakana_Unicode __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Katakana_Unicode
#define __pyx_kp_s_Unicode_set_for_Korean_Unicode_C __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Korean_Unicode_C
#define __pyx_kp_s_Unicode_set_for_Latin_1_Unicode __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Latin_1_Unicode
#define __pyx_kp_s_Unicode_set_for_Latin_A_Unicode __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Latin_A_Unicode
#define __pyx_kp_s_Unicode_set_for_Latin_B_Unicode __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Latin_B_Unicode
#define __pyx_kp_s_Unicode_set_for_Thai_Unicode_Cha __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_Thai_Unicode_Cha
#define __pyx_kp_s_Unicode_set_for_combined_Chinese __pyx_mstate_global->__pyx_kp_s_Unicode_set_for_combined_Chinese
#define __pyx_kp_u_Unmatchable_token __pyx_mstate_global->__pyx_kp_u_Unmatchable_token
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_kp_u_W __pyx_mstate_global->__pyx_kp_u_W
#define __pyx_n_s_WRAP_CALL_LINE_NUM __pyx_mstate_global->__pyx_n_s_WRAP_CALL_LINE_NUM
#define __pyx_kp_u_W_s __pyx_mstate_global->__pyx_kp_u_W_s
#define __pyx_kp_u_W_s_2 __pyx_mstate_global->__pyx_kp_u_W_s_2
#define __pyx_kp_u_W_s_3 __pyx_mstate_global->__pyx_kp_u_W_s_3
#define __pyx_n_s_White __pyx_mstate_global->__pyx_n_s_White
#define __pyx_n_u_White __pyx_mstate_global->__pyx_n_u_White
#define __pyx_n_s_White___init __pyx_mstate_global->__pyx_n_s_White___init
#define __pyx_n_s_White___init___locals_genexpr __pyx_mstate_global->__pyx_n_s_White___init___locals_genexpr
#define __pyx_n_s_White_parseImpl __pyx_mstate_global->__pyx_n_s_White_parseImpl
#define __pyx_n_s_Word __pyx_mstate_global->__pyx_n_s_Word
#define __pyx_n_u_Word __pyx_mstate_global->__pyx_n_u_Word
#define __pyx_n_s_WordEnd __pyx_mstate_global->__pyx_n_s_WordEnd
#define __pyx_n_u_WordEnd __pyx_mstate_global->__pyx_n_u_WordEnd
#define __pyx_n_s_WordEnd___init __pyx_mstate_global->__pyx_n_s_WordEnd___init
#define __pyx_n_s_WordEnd_parseImpl __pyx_mstate_global->__pyx_n_s_WordEnd_parseImpl
#define __pyx_n_s_WordRegex __pyx_mstate_global->__pyx_n_s_WordRegex
#define __pyx_n_s_WordRegex_parseImpl __pyx_mstate_global->__pyx_n_s_WordRegex_parseImpl
#define __pyx_n_s_WordStart __pyx_mstate_global->__pyx_n_s_WordStart
#define __pyx_n_u_WordStart __pyx_mstate_global->__pyx_n_u_WordStart
#define __pyx_n_s_WordStart___init __pyx_mstate_global->__pyx_n_s_WordStart___init
#define __pyx_n_s_WordStart_parseImpl __pyx_mstate_global->__pyx_n_s_WordStart_parseImpl
#define __pyx_n_s_Word___init __pyx_mstate_global->__pyx_n_s_Word___init
#define __pyx_n_s_Word___init___locals_genexpr __pyx_mstate_global->__pyx_n_s_Word___init___locals_genexpr
#define __pyx_n_s_Word___str __pyx_mstate_global->__pyx_n_s_Word___str
#define __pyx_n_s_Word___str___locals_charsAsStr __pyx_mstate_global->__pyx_n_s_Word___str___locals_charsAsStr
#define __pyx_n_s_Word_parseImpl __pyx_mstate_global->__pyx_n_s_Word_parseImpl
#define __pyx_kp_s_Wrapper_for_parse_actions_to_ens __pyx_mstate_global->__pyx_kp_s_Wrapper_for_parse_actions_to_ens
#define __pyx_kp_u_Y_m_d __pyx_mstate_global->__pyx_kp_u_Y_m_d
#define __pyx_kp_u_Y_m_dT_H_M_S_f __pyx_mstate_global->__pyx_kp_u_Y_m_dT_H_M_S_f
#define __pyx_kp_u_ZERO_WIDTH_SPACE __pyx_mstate_global->__pyx_kp_u_ZERO_WIDTH_SPACE
#define __pyx_n_s_ZeroOrMore __pyx_mstate_global->__pyx_n_s_ZeroOrMore
#define __pyx_n_u_ZeroOrMore __pyx_mstate_global->__pyx_n_u_ZeroOrMore
#define __pyx_n_s_ZeroOrMore___init __pyx_mstate_global->__pyx_n_s_ZeroOrMore___init
#define __pyx_n_s_ZeroOrMore___str __pyx_mstate_global->__pyx_n_s_ZeroOrMore___str
#define __pyx_n_s_ZeroOrMore_parseImpl __pyx_mstate_global->__pyx_n_s_ZeroOrMore_parseImpl
#define __pyx_kp_u__10 __pyx_mstate_global->__pyx_kp_u__10
#define __pyx_kp_u__100 __pyx_mstate_global->__pyx_kp_u__100
#define __pyx_kp_u__102 __pyx_mstate_global->__pyx_kp_u__102
#define __pyx_kp_u__104 __pyx_mstate_global->__pyx_kp_u__104
#define __pyx_kp_u__105 __pyx_mstate_global->__pyx_kp_u__105
#define __pyx_kp_u__107 __pyx_mstate_global->__pyx_kp_u__107
#define __pyx_kp_u__108 __pyx_mstate_global->__pyx_kp_u__108
#define __pyx_kp_u__11 __pyx_mstate_global->__pyx_kp_u__11
#define __pyx_kp_u__110 __pyx_mstate_global->__pyx_kp_u__110
#define __pyx_kp_u__111 __pyx_mstate_global->__pyx_kp_u__111
#define __pyx_kp_u__112 __pyx_mstate_global->__pyx_kp_u__112
#define __pyx_kp_u__113 __pyx_mstate_global->__pyx_kp_u__113
#define __pyx_kp_u__114 __pyx_mstate_global->__pyx_kp_u__114
#define __pyx_kp_u__115 __pyx_mstate_global->__pyx_kp_u__115
#define __pyx_kp_u__116 __pyx_mstate_global->__pyx_kp_u__116
#define __pyx_kp_u__117 __pyx_mstate_global->__pyx_kp_u__117
#define __pyx_kp_u__118 __pyx_mstate_global->__pyx_kp_u__118
#define __pyx_kp_u__119 __pyx_mstate_global->__pyx_kp_u__119
#define __pyx_kp_u__12 __pyx_mstate_global->__pyx_kp_u__12
#define __pyx_kp_u__122 __pyx_mstate_global->__pyx_kp_u__122
#define __pyx_kp_u__13 __pyx_mstate_global->__pyx_kp_u__13
#define __pyx_kp_u__136 __pyx_mstate_global->__pyx_kp_u__136
#define __pyx_kp_u__14 __pyx_mstate_global->__pyx_kp_u__14
#define __pyx_kp_u__144 __pyx_mstate_global->__pyx_kp_u__144
#define __pyx_kp_u__145 __pyx_mstate_global->__pyx_kp_u__145
#define __pyx_kp_u__147 __pyx_mstate_global->__pyx_kp_u__147
#define __pyx_kp_u__148 __pyx_mstate_global->__pyx_kp_u__148
#define __pyx_n_s__15 __pyx_mstate_global->__pyx_n_s__15
#define __pyx_kp_u__15 __pyx_mstate_global->__pyx_kp_u__15
#define __pyx_kp_u__150 __pyx_mstate_global->__pyx_kp_u__150
#define __pyx_kp_u__16 __pyx_mstate_global->__pyx_kp_u__16
#define __pyx_kp_u__166 __pyx_mstate_global->__pyx_kp_u__166
#define __pyx_kp_u__17 __pyx_mstate_global->__pyx_kp_u__17
#define __pyx_kp_u__19 __pyx_mstate_global->__pyx_kp_u__19
#define __pyx_kp_u__2 __pyx_mstate_global->__pyx_kp_u__2
#define __pyx_kp_u__22 __pyx_mstate_global->__pyx_kp_u__22
#define __pyx_kp_u__25 __pyx_mstate_global->__pyx_kp_u__25
#define __pyx_kp_u__26 __pyx_mstate_global->__pyx_kp_u__26
#define __pyx_kp_u__27 __pyx_mstate_global->__pyx_kp_u__27
#define __pyx_kp_u__28 __pyx_mstate_global->__pyx_kp_u__28
#define __pyx_kp_u__29 __pyx_mstate_global->__pyx_kp_u__29
#define __pyx_kp_u__3 __pyx_mstate_global->__pyx_kp_u__3
#define __pyx_kp_u__30 __pyx_mstate_global->__pyx_kp_u__30
#define __pyx_kp_u__31 __pyx_mstate_global->__pyx_kp_u__31
#define __pyx_kp_u__339 __pyx_mstate_global->__pyx_kp_u__339
#define __pyx_kp_u__34 __pyx_mstate_global->__pyx_kp_u__34
#define __pyx_kp_u__35 __pyx_mstate_global->__pyx_kp_u__35
#define __pyx_kp_u__4 __pyx_mstate_global->__pyx_kp_u__4
#define __pyx_kp_u__461 __pyx_mstate_global->__pyx_kp_u__461
#define __pyx_kp_u__5 __pyx_mstate_global->__pyx_kp_u__5
#define __pyx_kp_u__511 __pyx_mstate_global->__pyx_kp_u__511
#define __pyx_kp_u__512 __pyx_mstate_global->__pyx_kp_u__512
#define __pyx_kp_u__513 __pyx_mstate_global->__pyx_kp_u__513
#define __pyx_kp_u__514 __pyx_mstate_global->__pyx_kp_u__514
#define __pyx_kp_u__515 __pyx_mstate_global->__pyx_kp_u__515
#define __pyx_kp_u__516 __pyx_mstate_global->__pyx_kp_u__516
#define __pyx_kp_u__517 __pyx_mstate_global->__pyx_kp_u__517
#define __pyx_kp_u__518 __pyx_mstate_global->__pyx_kp_u__518
#define __pyx_kp_u__519 __pyx_mstate_global->__pyx_kp_u__519
#define __pyx_kp_u__520 __pyx_mstate_global->__pyx_kp_u__520
#define __pyx_kp_u__521 __pyx_mstate_global->__pyx_kp_u__521
#define __pyx_kp_u__522 __pyx_mstate_global->__pyx_kp_u__522
#define __pyx_kp_u__523 __pyx_mstate_global->__pyx_kp_u__523
#define __pyx_kp_u__524 __pyx_mstate_global->__pyx_kp_u__524
#define __pyx_kp_u__525 __pyx_mstate_global->__pyx_kp_u__525
#define __pyx_kp_u__526 __pyx_mstate_global->__pyx_kp_u__526
#define __pyx_kp_u__527 __pyx_mstate_global->__pyx_kp_u__527
#define __pyx_kp_u__528 __pyx_mstate_global->__pyx_kp_u__528
#define __pyx_kp_u__6 __pyx_mstate_global->__pyx_kp_u__6
#define __pyx_n_s__621 __pyx_mstate_global->__pyx_n_s__621
#define __pyx_n_u__621 __pyx_mstate_global->__pyx_n_u__621
#define __pyx_kp_u__65 __pyx_mstate_global->__pyx_kp_u__65
#define __pyx_kp_u__66 __pyx_mstate_global->__pyx_kp_u__66
#define __pyx_kp_u__67 __pyx_mstate_global->__pyx_kp_u__67
#define __pyx_kp_u__7 __pyx_mstate_global->__pyx_kp_u__7
#define __pyx_kp_u__718 __pyx_mstate_global->__pyx_kp_u__718
#define __pyx_kp_u__721 __pyx_mstate_global->__pyx_kp_u__721
#define __pyx_kp_u__755 __pyx_mstate_global->__pyx_kp_u__755
#define __pyx_kp_u__768 __pyx_mstate_global->__pyx_kp_u__768
#define __pyx_kp_u__770 __pyx_mstate_global->__pyx_kp_u__770
#define __pyx_kp_u__771 __pyx_mstate_global->__pyx_kp_u__771
#define __pyx_kp_u__774 __pyx_mstate_global->__pyx_kp_u__774
#define __pyx_kp_u__776 __pyx_mstate_global->__pyx_kp_u__776
#define __pyx_kp_u__780 __pyx_mstate_global->__pyx_kp_u__780
#define __pyx_kp_u__786 __pyx_mstate_global->__pyx_kp_u__786
#define __pyx_kp_u__789 __pyx_mstate_global->__pyx_kp_u__789
#define __pyx_kp_u__79 __pyx_mstate_global->__pyx_kp_u__79
#define __pyx_kp_u__795 __pyx_mstate_global->__pyx_kp_u__795
#define __pyx_kp_u__80 __pyx_mstate_global->__pyx_kp_u__80
#define __pyx_n_u__856 __pyx_mstate_global->__pyx_n_u__856
#define __pyx_n_u__857 __pyx_mstate_global->__pyx_n_u__857
#define __pyx_n_u__858 __pyx_mstate_global->__pyx_n_u__858
#define __pyx_n_u__859 __pyx_mstate_global->__pyx_n_u__859
#define __pyx_kp_u__860 __pyx_mstate_global->__pyx_kp_u__860
#define __pyx_n_u__861 __pyx_mstate_global->__pyx_n_u__861
#define __pyx_n_u__862 __pyx_mstate_global->__pyx_n_u__862
#define __pyx_n_u__863 __pyx_mstate_global->__pyx_n_u__863
#define __pyx_n_u__864 __pyx_mstate_global->__pyx_n_u__864
#define __pyx_n_u__865 __pyx_mstate_global->__pyx_n_u__865
#define __pyx_n_u__866 __pyx_mstate_global->__pyx_n_u__866
#define __pyx_kp_u__867 __pyx_mstate_global->__pyx_kp_u__867
#define __pyx_n_s__893 __pyx_mstate_global->__pyx_n_s__893
#define __pyx_kp_u__91 __pyx_mstate_global->__pyx_kp_u__91
#define __pyx_kp_u__94 __pyx_mstate_global->__pyx_kp_u__94
#define __pyx_kp_u__95 __pyx_mstate_global->__pyx_kp_u__95
#define __pyx_kp_u__96 __pyx_mstate_global->__pyx_kp_u__96
#define __pyx_kp_u__97 __pyx_mstate_global->__pyx_kp_u__97
#define __pyx_kp_u__98 __pyx_mstate_global->__pyx_kp_u__98
#define __pyx_kp_u__99 __pyx_mstate_global->__pyx_kp_u__99
#define __pyx_n_s_a __pyx_mstate_global->__pyx_n_s_a
#define __pyx_n_s_adaptive_mode __pyx_mstate_global->__pyx_n_s_adaptive_mode
#define __pyx_n_s_adaptive_usage __pyx_mstate_global->__pyx_n_s_adaptive_usage
#define __pyx_n_s_adaptive_usage_check_rate __pyx_mstate_global->__pyx_n_s_adaptive_usage_check_rate
#define __pyx_n_s_add __pyx_mstate_global->__pyx_n_s_add
#define __pyx_n_s_addCondition __pyx_mstate_global->__pyx_n_s_addCondition
#define __pyx_n_s_addParseAction __pyx_mstate_global->__pyx_n_s_addParseAction
#define __pyx_n_s_addoffset __pyx_mstate_global->__pyx_n_s_addoffset
#define __pyx_n_s_adjacent __pyx_mstate_global->__pyx_n_s_adjacent
#define __pyx_n_s_all __pyx_mstate_global->__pyx_n_s_all
#define __pyx_n_s_allResults __pyx_mstate_global->__pyx_n_s_allResults
#define __pyx_n_s_all_2 __pyx_mstate_global->__pyx_n_s_all_2
#define __pyx_n_s_all_names __pyx_mstate_global->__pyx_n_s_all_names
#define __pyx_n_s_all_parse_elements __pyx_mstate_global->__pyx_n_s_all_parse_elements
#define __pyx_n_s_allow_unused_expr_order __pyx_mstate_global->__pyx_n_s_allow_unused_expr_order
#define __pyx_n_s_alphanums __pyx_mstate_global->__pyx_n_s_alphanums
#define __pyx_n_u_alphanums __pyx_mstate_global->__pyx_n_u_alphanums
#define __pyx_n_s_alphas __pyx_mstate_global->__pyx_n_s_alphas
#define __pyx_n_u_alphas __pyx_mstate_global->__pyx_n_u_alphas
#define __pyx_n_s_alphas8bit __pyx_mstate_global->__pyx_n_s_alphas8bit
#define __pyx_n_u_alphas8bit __pyx_mstate_global->__pyx_n_u_alphas8bit
#define __pyx_kp_u_amp_gt_lt_quot_apos __pyx_mstate_global->__pyx_kp_u_amp_gt_lt_quot_apos
#define __pyx_n_s_aname __pyx_mstate_global->__pyx_n_s_aname
#define __pyx_n_s_anchor __pyx_mstate_global->__pyx_n_s_anchor
#define __pyx_n_s_and __pyx_mstate_global->__pyx_n_s_and
#define __pyx_n_s_any __pyx_mstate_global->__pyx_n_s_any
#define __pyx_n_s_anyCloseTag __pyx_mstate_global->__pyx_n_s_anyCloseTag
#define __pyx_n_u_anyCloseTag __pyx_mstate_global->__pyx_n_u_anyCloseTag
#define __pyx_n_s_anyOpenTag __pyx_mstate_global->__pyx_n_s_anyOpenTag
#define __pyx_n_u_anyOpenTag __pyx_mstate_global->__pyx_n_u_anyOpenTag
#define __pyx_kp_u_any_tag __pyx_mstate_global->__pyx_kp_u_any_tag
#define __pyx_n_s_append __pyx_mstate_global->__pyx_n_s_append
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_n_u_args __pyx_mstate_global->__pyx_n_u_args
#define __pyx_n_s_arity __pyx_mstate_global->__pyx_n_s_arity
#define __pyx_n_s_arrayExpr __pyx_mstate_global->__pyx_n_s_arrayExpr
#define __pyx_n_u_arrayLen __pyx_mstate_global->__pyx_n_u_arrayLen
#define __pyx_n_s_asDict __pyx_mstate_global->__pyx_n_s_asDict
#define __pyx_n_s_asGroupList __pyx_mstate_global->__pyx_n_s_asGroupList
#define __pyx_n_s_asKeyword __pyx_mstate_global->__pyx_n_s_asKeyword
#define __pyx_n_s_asList __pyx_mstate_global->__pyx_n_s_asList
#define __pyx_n_s_asMatch __pyx_mstate_global->__pyx_n_s_asMatch
#define __pyx_n_s_asString __pyx_mstate_global->__pyx_n_s_asString
#define __pyx_n_s_asStringList __pyx_mstate_global->__pyx_n_s_asStringList
#define __pyx_n_s_asXML __pyx_mstate_global->__pyx_n_s_asXML
#define __pyx_kp_u_as_column_list_and_dotted_table __pyx_mstate_global->__pyx_kp_u_as_column_list_and_dotted_table
#define __pyx_n_s_ascii_lowercase __pyx_mstate_global->__pyx_n_s_ascii_lowercase
#define __pyx_n_s_ascii_uppercase __pyx_mstate_global->__pyx_n_s_ascii_uppercase
#define __pyx_n_s_assertEqual __pyx_mstate_global->__pyx_n_s_assertEqual
#define __pyx_n_s_assertParseAndCheckDict __pyx_mstate_global->__pyx_n_s_assertParseAndCheckDict
#define __pyx_n_s_assertParseAndCheckList __pyx_mstate_global->__pyx_n_s_assertParseAndCheckList
#define __pyx_n_s_assertParseResultsEquals __pyx_mstate_global->__pyx_n_s_assertParseResultsEquals
#define __pyx_n_s_assertRaises __pyx_mstate_global->__pyx_n_s_assertRaises
#define __pyx_n_s_assertRaisesParseException __pyx_mstate_global->__pyx_n_s_assertRaisesParseException
#define __pyx_n_s_assertRunTestResults __pyx_mstate_global->__pyx_n_s_assertRunTestResults
#define __pyx_n_s_assertTrue __pyx_mstate_global->__pyx_n_s_assertTrue
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_kp_u_at_char __pyx_mstate_global->__pyx_kp_u_at_char
#define __pyx_kp_u_at_loc __pyx_mstate_global->__pyx_kp_u_at_loc
#define __pyx_n_s_attrDict __pyx_mstate_global->__pyx_n_s_attrDict
#define __pyx_n_s_attrName __pyx_mstate_global->__pyx_n_s_attrName
#define __pyx_n_s_attrValue __pyx_mstate_global->__pyx_n_s_attrValue
#define __pyx_kp_u_attribute __pyx_mstate_global->__pyx_kp_u_attribute
#define __pyx_n_s_attrname __pyx_mstate_global->__pyx_n_s_attrname
#define __pyx_n_s_attrs __pyx_mstate_global->__pyx_n_s_attrs
#define __pyx_n_s_author __pyx_mstate_global->__pyx_n_s_author
#define __pyx_n_u_author __pyx_mstate_global->__pyx_n_u_author
#define __pyx_kp_u_b __pyx_mstate_global->__pyx_kp_u_b
#define __pyx_n_s_b_2 __pyx_mstate_global->__pyx_n_s_b_2
#define __pyx_kp_u_b_s_b __pyx_mstate_global->__pyx_kp_u_b_s_b
#define __pyx_n_s_backup_stack __pyx_mstate_global->__pyx_n_s_backup_stack
#define __pyx_n_s_baseExpr __pyx_mstate_global->__pyx_n_s_baseExpr
#define __pyx_kp_s_base_exception_class_for_all_par __pyx_mstate_global->__pyx_kp_s_base_exception_class_for_all_par
#define __pyx_n_s_basestring __pyx_mstate_global->__pyx_n_s_basestring
#define __pyx_n_s_best_expr __pyx_mstate_global->__pyx_n_s_best_expr
#define __pyx_n_s_blockStatementExpr __pyx_mstate_global->__pyx_n_s_blockStatementExpr
#define __pyx_n_s_body __pyx_mstate_global->__pyx_n_s_body
#define __pyx_n_u_body __pyx_mstate_global->__pyx_n_u_body
#define __pyx_n_s_bodyChars __pyx_mstate_global->__pyx_n_s_bodyChars
#define __pyx_n_s_bodyCharsOrig __pyx_mstate_global->__pyx_n_s_bodyCharsOrig
#define __pyx_n_s_bodychars __pyx_mstate_global->__pyx_n_s_bodychars
#define __pyx_n_s_bool __pyx_mstate_global->__pyx_n_s_bool
#define __pyx_n_s_breakFlag __pyx_mstate_global->__pyx_n_s_breakFlag
#define __pyx_n_s_breaker __pyx_mstate_global->__pyx_n_s_breaker
#define __pyx_n_s_bslash __pyx_mstate_global->__pyx_n_s_bslash
#define __pyx_n_s_builtin __pyx_mstate_global->__pyx_n_s_builtin
#define __pyx_n_s_c __pyx_mstate_global->__pyx_n_s_c
#define __pyx_n_s_cPyparsing __pyx_mstate_global->__pyx_n_s_cPyparsing
#define __pyx_kp_s_cPyparsing_pyx __pyx_mstate_global->__pyx_kp_s_cPyparsing_pyx
#define __pyx_kp_u_cPyparsing_pyx __pyx_mstate_global->__pyx_kp_u_cPyparsing_pyx
#define __pyx_n_s_cStyleComment __pyx_mstate_global->__pyx_n_s_cStyleComment
#define __pyx_n_u_cStyleComment __pyx_mstate_global->__pyx_n_u_cStyleComment
#define __pyx_n_s_cache __pyx_mstate_global->__pyx_n_s_cache
#define __pyx_n_u_cache __pyx_mstate_global->__pyx_n_u_cache
#define __pyx_n_s_cache_furthest_loc __pyx_mstate_global->__pyx_n_s_cache_furthest_loc
#define __pyx_n_s_cache_item __pyx_mstate_global->__pyx_n_s_cache_item
#define __pyx_n_s_cache_result __pyx_mstate_global->__pyx_n_s_cache_result
#define __pyx_n_s_cache_size_limit __pyx_mstate_global->__pyx_n_s_cache_size_limit
#define __pyx_n_s_cache_successes __pyx_mstate_global->__pyx_n_s_cache_successes
#define __pyx_n_s_cache_usefullness_obj __pyx_mstate_global->__pyx_n_s_cache_usefullness_obj
#define __pyx_n_s_call __pyx_mstate_global->__pyx_n_s_call
#define __pyx_n_s_callDuringTry __pyx_mstate_global->__pyx_n_s_callDuringTry
#define __pyx_n_u_callDuringTry __pyx_mstate_global->__pyx_n_u_callDuringTry
#define __pyx_n_s_callPreParse __pyx_mstate_global->__pyx_n_s_callPreParse
#define __pyx_n_s_callPreparse __pyx_mstate_global->__pyx_n_s_callPreparse
#define __pyx_n_s_callable __pyx_mstate_global->__pyx_n_s_callable
#define __pyx_n_s_called __pyx_mstate_global->__pyx_n_s_called
#define __pyx_n_s_callers __pyx_mstate_global->__pyx_n_s_callers
#define __pyx_n_s_canParseNext __pyx_mstate_global->__pyx_n_s_canParseNext
#define __pyx_kp_u_cannot_construct_And_with_sequen __pyx_mstate_global->__pyx_kp_u_cannot_construct_And_with_sequen
#define __pyx_kp_u_cannot_multiply_ParserElement_an __pyx_mstate_global->__pyx_kp_u_cannot_multiply_ParserElement_an
#define __pyx_kp_u_cannot_multiply_ParserElement_an_2 __pyx_mstate_global->__pyx_kp_u_cannot_multiply_ParserElement_an_2
#define __pyx_kp_u_cannot_multiply_ParserElement_by __pyx_mstate_global->__pyx_kp_u_cannot_multiply_ParserElement_by
#define __pyx_kp_u_cannot_multiply_ParserElement_by_2 __pyx_mstate_global->__pyx_kp_u_cannot_multiply_ParserElement_by_2
#define __pyx_kp_u_cannot_specify_a_minimum_length __pyx_mstate_global->__pyx_kp_u_cannot_specify_a_minimum_length
#define __pyx_kp_u_cannot_specify_a_minimum_length_2 __pyx_mstate_global->__pyx_kp_u_cannot_specify_a_minimum_length_2
#define __pyx_kp_u_cannot_use_sub_with_Regex_asGrou __pyx_mstate_global->__pyx_kp_u_cannot_use_sub_with_Regex_asGrou
#define __pyx_kp_u_cannot_use_sub_with_a_callable_w __pyx_mstate_global->__pyx_kp_u_cannot_use_sub_with_a_callable_w
#define __pyx_n_s_caseless __pyx_mstate_global->__pyx_n_s_caseless
#define __pyx_n_s_caselessmatch __pyx_mstate_global->__pyx_n_s_caselessmatch
#define __pyx_n_s_cause __pyx_mstate_global->__pyx_n_s_cause
#define __pyx_n_s_cc __pyx_mstate_global->__pyx_n_s_cc
#define __pyx_n_s_charRange __pyx_mstate_global->__pyx_n_s_charRange
#define __pyx_n_s_chars __pyx_mstate_global->__pyx_n_s_chars
#define __pyx_n_s_charsAsStr __pyx_mstate_global->__pyx_n_s_charsAsStr
#define __pyx_n_s_charset __pyx_mstate_global->__pyx_n_s_charset
#define __pyx_n_s_checkPeerIndent __pyx_mstate_global->__pyx_n_s_checkPeerIndent
#define __pyx_n_s_checkRecursion __pyx_mstate_global->__pyx_n_s_checkRecursion
#define __pyx_n_s_checkSubIndent __pyx_mstate_global->__pyx_n_s_checkSubIndent
#define __pyx_n_s_checkUnindent __pyx_mstate_global->__pyx_n_s_checkUnindent
#define __pyx_n_s_check_ender __pyx_mstate_global->__pyx_n_s_check_ender
#define __pyx_n_s_chr __pyx_mstate_global->__pyx_n_s_chr
#define __pyx_n_s_class __pyx_mstate_global->__pyx_n_s_class
#define __pyx_n_u_class __pyx_mstate_global->__pyx_n_u_class
#define __pyx_n_u_class_2 __pyx_mstate_global->__pyx_n_u_class_2
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_classattr __pyx_mstate_global->__pyx_n_s_classattr
#define __pyx_n_s_classname __pyx_mstate_global->__pyx_n_s_classname
#define __pyx_n_s_clear __pyx_mstate_global->__pyx_n_s_clear
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_close __pyx_mstate_global->__pyx_n_s_close
#define __pyx_n_s_closeTag __pyx_mstate_global->__pyx_n_s_closeTag
#define __pyx_n_s_closer __pyx_mstate_global->__pyx_n_s_closer
#define __pyx_n_s_cls __pyx_mstate_global->__pyx_n_s_cls
#define __pyx_n_s_co_name __pyx_mstate_global->__pyx_n_s_co_name
#define __pyx_n_s_code __pyx_mstate_global->__pyx_n_s_code
#define __pyx_n_s_col __pyx_mstate_global->__pyx_n_s_col
#define __pyx_n_u_col __pyx_mstate_global->__pyx_n_u_col
#define __pyx_kp_u_col_2 __pyx_mstate_global->__pyx_kp_u_col_2
#define __pyx_n_s_collectParseElements __pyx_mstate_global->__pyx_n_s_collectParseElements
#define __pyx_n_s_collect_all_And_tokens __pyx_mstate_global->__pyx_n_s_collect_all_And_tokens
#define __pyx_n_u_collect_all_And_tokens __pyx_mstate_global->__pyx_n_u_collect_all_And_tokens
#define __pyx_n_s_collections __pyx_mstate_global->__pyx_n_s_collections
#define __pyx_n_s_collections_abc __pyx_mstate_global->__pyx_n_s_collections_abc
#define __pyx_n_s_colno __pyx_mstate_global->__pyx_n_s_colno
#define __pyx_n_s_column __pyx_mstate_global->__pyx_n_s_column
#define __pyx_n_u_column __pyx_mstate_global->__pyx_n_u_column
#define __pyx_n_s_columnName __pyx_mstate_global->__pyx_n_s_columnName
#define __pyx_n_s_columnNameList __pyx_mstate_global->__pyx_n_s_columnNameList
#define __pyx_n_s_columnSpec __pyx_mstate_global->__pyx_n_s_columnSpec
#define __pyx_n_u_columns __pyx_mstate_global->__pyx_n_u_columns
#define __pyx_n_s_combine __pyx_mstate_global->__pyx_n_s_combine
#define __pyx_n_u_commaItem __pyx_mstate_global->__pyx_n_u_commaItem
#define __pyx_n_s_commaSeparatedList __pyx_mstate_global->__pyx_n_s_commaSeparatedList
#define __pyx_n_u_commaSeparatedList __pyx_mstate_global->__pyx_n_u_commaSeparatedList
#define __pyx_kp_u_comma_separated_list __pyx_mstate_global->__pyx_kp_u_comma_separated_list
#define __pyx_n_s_comma_separated_list_2 __pyx_mstate_global->__pyx_n_s_comma_separated_list_2
#define __pyx_n_u_command __pyx_mstate_global->__pyx_n_u_command
#define __pyx_n_s_commasepitem __pyx_mstate_global->__pyx_n_s_commasepitem
#define __pyx_n_s_comment __pyx_mstate_global->__pyx_n_s_comment
#define __pyx_kp_u_comment_2 __pyx_mstate_global->__pyx_kp_u_comment_2
#define __pyx_n_s_comments __pyx_mstate_global->__pyx_n_s_comments
#define __pyx_n_s_commonHTMLEntity __pyx_mstate_global->__pyx_n_s_commonHTMLEntity
#define __pyx_n_u_commonHTMLEntity __pyx_mstate_global->__pyx_n_u_commonHTMLEntity
#define __pyx_kp_u_common_HTML_entity __pyx_mstate_global->__pyx_kp_u_common_HTML_entity
#define __pyx_n_s_common_prefix_len __pyx_mstate_global->__pyx_n_s_common_prefix_len
#define __pyx_n_s_common_suffix_len __pyx_mstate_global->__pyx_n_s_common_suffix_len
#define __pyx_n_s_commonprefix __pyx_mstate_global->__pyx_n_s_commonprefix
#define __pyx_n_s_compat __pyx_mstate_global->__pyx_n_s_compat
#define __pyx_n_u_compat __pyx_mstate_global->__pyx_n_u_compat
#define __pyx_n_s_compile __pyx_mstate_global->__pyx_n_s_compile
#define __pyx_n_s_conditionAsParseAction __pyx_mstate_global->__pyx_n_s_conditionAsParseAction
#define __pyx_n_u_conditionAsParseAction __pyx_mstate_global->__pyx_n_u_conditionAsParseAction
#define __pyx_n_s_conditionAsParseAction_locals_pa __pyx_mstate_global->__pyx_n_s_conditionAsParseAction_locals_pa
#define __pyx_n_s_contains __pyx_mstate_global->__pyx_n_s_contains
#define __pyx_n_s_content __pyx_mstate_global->__pyx_n_s_content
#define __pyx_n_s_context __pyx_mstate_global->__pyx_n_s_context
#define __pyx_n_s_contextlib __pyx_mstate_global->__pyx_n_s_contextlib
#define __pyx_n_s_contextmanager __pyx_mstate_global->__pyx_n_s_contextmanager
#define __pyx_n_s_convertToDate __pyx_mstate_global->__pyx_n_s_convertToDate
#define __pyx_n_s_convertToDatetime __pyx_mstate_global->__pyx_n_s_convertToDatetime
#define __pyx_n_s_convertToFloat __pyx_mstate_global->__pyx_n_s_convertToFloat
#define __pyx_n_s_convertToInteger __pyx_mstate_global->__pyx_n_s_convertToInteger
#define __pyx_n_s_convertWhitespaceEscapes __pyx_mstate_global->__pyx_n_s_convertWhitespaceEscapes
#define __pyx_n_s_copy __pyx_mstate_global->__pyx_n_s_copy
#define __pyx_n_s_copyDefaultWhiteChars __pyx_mstate_global->__pyx_n_s_copyDefaultWhiteChars
#define __pyx_n_s_copyTokenToRepeater __pyx_mstate_global->__pyx_n_s_copyTokenToRepeater
#define __pyx_n_s_count __pyx_mstate_global->__pyx_n_s_count
#define __pyx_n_s_countFieldParseAction __pyx_mstate_global->__pyx_n_s_countFieldParseAction
#define __pyx_n_s_countedArray __pyx_mstate_global->__pyx_n_s_countedArray
#define __pyx_n_u_countedArray __pyx_mstate_global->__pyx_n_u_countedArray
#define __pyx_n_s_countedArray_locals_countFieldPa __pyx_mstate_global->__pyx_n_s_countedArray_locals_countFieldPa
#define __pyx_n_s_countedArray_locals_lambda __pyx_mstate_global->__pyx_n_s_countedArray_locals_lambda
#define __pyx_n_s_cppStyleComment __pyx_mstate_global->__pyx_n_s_cppStyleComment
#define __pyx_n_u_cppStyleComment __pyx_mstate_global->__pyx_n_u_cppStyleComment
#define __pyx_n_s_cpy __pyx_mstate_global->__pyx_n_s_cpy
#define __pyx_n_s_cur __pyx_mstate_global->__pyx_n_s_cur
#define __pyx_n_s_curCol __pyx_mstate_global->__pyx_n_s_curCol
#define __pyx_n_s_cvt_fn __pyx_mstate_global->__pyx_n_s_cvt_fn
#define __pyx_n_s_d __pyx_mstate_global->__pyx_n_s_d
#define __pyx_n_u_d __pyx_mstate_global->__pyx_n_u_d
#define __pyx_kp_u_d_2 __pyx_mstate_global->__pyx_kp_u_d_2
#define __pyx_kp_u_d_d_d __pyx_mstate_global->__pyx_kp_u_d_d_d
#define __pyx_kp_u_d_d_eE_d __pyx_mstate_global->__pyx_kp_u_d_d_eE_d
#define __pyx_kp_u_d_eE_d_d_d_d_eE_d __pyx_mstate_global->__pyx_kp_u_d_eE_d_d_d_d_eE_d
#define __pyx_n_s_data __pyx_mstate_global->__pyx_n_s_data
#define __pyx_n_s_date __pyx_mstate_global->__pyx_n_s_date
#define __pyx_n_s_datetime __pyx_mstate_global->__pyx_n_s_datetime
#define __pyx_n_s_dblQuotedString __pyx_mstate_global->__pyx_n_s_dblQuotedString
#define __pyx_n_u_dblQuotedString __pyx_mstate_global->__pyx_n_u_dblQuotedString
#define __pyx_n_s_dblSlashComment __pyx_mstate_global->__pyx_n_s_dblSlashComment
#define __pyx_n_u_dblSlashComment __pyx_mstate_global->__pyx_n_u_dblSlashComment
#define __pyx_n_s_debug __pyx_mstate_global->__pyx_n_s_debug
#define __pyx_n_s_debugActions __pyx_mstate_global->__pyx_n_s_debugActions
#define __pyx_n_s_debugging __pyx_mstate_global->__pyx_n_s_debugging
#define __pyx_n_s_decode __pyx_mstate_global->__pyx_n_s_decode
#define __pyx_n_s_default __pyx_mstate_global->__pyx_n_s_default
#define __pyx_n_u_default __pyx_mstate_global->__pyx_n_u_default
#define __pyx_n_s_defaultExceptionDebugAction __pyx_mstate_global->__pyx_n_s_defaultExceptionDebugAction
#define __pyx_n_s_defaultStartDebugAction __pyx_mstate_global->__pyx_n_s_defaultStartDebugAction
#define __pyx_n_s_defaultSuccessDebugAction __pyx_mstate_global->__pyx_n_s_defaultSuccessDebugAction
#define __pyx_n_s_defaultValue __pyx_mstate_global->__pyx_n_s_defaultValue
#define __pyx_n_u_default_keyword_chars __pyx_mstate_global->__pyx_n_u_default_keyword_chars
#define __pyx_n_u_default_whitespace __pyx_mstate_global->__pyx_n_u_default_whitespace
#define __pyx_n_s_defaultdict __pyx_mstate_global->__pyx_n_s_defaultdict
#define __pyx_n_s_defaultvalue __pyx_mstate_global->__pyx_n_s_defaultvalue
#define __pyx_n_s_delim __pyx_mstate_global->__pyx_n_s_delim
#define __pyx_n_s_delimitedList __pyx_mstate_global->__pyx_n_s_delimitedList
#define __pyx_n_u_delimitedList __pyx_mstate_global->__pyx_n_u_delimitedList
#define __pyx_n_s_delitem __pyx_mstate_global->__pyx_n_s_delitem
#define __pyx_n_s_depth __pyx_mstate_global->__pyx_n_s_depth
#define __pyx_n_s_depth_2 __pyx_mstate_global->__pyx_n_s_depth_2
#define __pyx_n_s_deque __pyx_mstate_global->__pyx_n_s_deque
#define __pyx_n_s_diag __pyx_mstate_global->__pyx_n_s_diag
#define __pyx_n_u_diag __pyx_mstate_global->__pyx_n_u_diag
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_n_s_dictOf __pyx_mstate_global->__pyx_n_s_dictOf
#define __pyx_n_u_dictOf __pyx_mstate_global->__pyx_n_u_dictOf
#define __pyx_n_s_dictvalue __pyx_mstate_global->__pyx_n_s_dictvalue
#define __pyx_n_s_dir __pyx_mstate_global->__pyx_n_s_dir
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_n_s_dlName __pyx_mstate_global->__pyx_n_s_dlName
#define __pyx_n_s_doActions __pyx_mstate_global->__pyx_n_s_doActions
#define __pyx_n_s_doc __pyx_mstate_global->__pyx_n_s_doc
#define __pyx_n_s_doctag __pyx_mstate_global->__pyx_n_s_doctag
#define __pyx_n_s_downcaseTokens __pyx_mstate_global->__pyx_n_s_downcaseTokens
#define __pyx_n_u_downcaseTokens __pyx_mstate_global->__pyx_n_u_downcaseTokens
#define __pyx_n_s_dummy __pyx_mstate_global->__pyx_n_s_dummy
#define __pyx_n_s_dump __pyx_mstate_global->__pyx_n_s_dump
#define __pyx_n_s_e __pyx_mstate_global->__pyx_n_s_e
#define __pyx_n_s_e2 __pyx_mstate_global->__pyx_n_s_e2
#define __pyx_n_s_elem __pyx_mstate_global->__pyx_n_s_elem
#define __pyx_n_s_empty __pyx_mstate_global->__pyx_n_s_empty
#define __pyx_n_u_empty __pyx_mstate_global->__pyx_n_u_empty
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_enableIncremental __pyx_mstate_global->__pyx_n_s_enableIncremental
#define __pyx_n_s_enablePackrat __pyx_mstate_global->__pyx_n_s_enablePackrat
#define __pyx_n_u_enable_2 __pyx_mstate_global->__pyx_n_u_enable_2
#define __pyx_n_s_enable_all_warnings __pyx_mstate_global->__pyx_n_s_enable_all_warnings
#define __pyx_n_s_enable_all_warnings_2 __pyx_mstate_global->__pyx_n_s_enable_all_warnings_2
#define __pyx_n_s_enable_debug_on_named_expression __pyx_mstate_global->__pyx_n_s_enable_debug_on_named_expression
#define __pyx_n_s_end __pyx_mstate_global->__pyx_n_s_end
#define __pyx_n_u_end __pyx_mstate_global->__pyx_n_u_end
#define __pyx_n_s_endQuoteChar __pyx_mstate_global->__pyx_n_s_endQuoteChar
#define __pyx_n_s_endQuoteCharLen __pyx_mstate_global->__pyx_n_s_endQuoteCharLen
#define __pyx_kp_u_endQuoteChar_cannot_be_the_empty __pyx_mstate_global->__pyx_kp_u_endQuoteChar_cannot_be_the_empty
#define __pyx_n_s_ender __pyx_mstate_global->__pyx_n_s_ender
#define __pyx_kp_u_ending_with __pyx_mstate_global->__pyx_kp_u_ending_with
#define __pyx_n_s_endloc __pyx_mstate_global->__pyx_n_s_endloc
#define __pyx_n_s_endlocMarker __pyx_mstate_global->__pyx_n_s_endlocMarker
#define __pyx_n_s_endswith __pyx_mstate_global->__pyx_n_s_endswith
#define __pyx_n_s_enter __pyx_mstate_global->__pyx_n_s_enter
#define __pyx_kp_u_entering __pyx_mstate_global->__pyx_kp_u_entering
#define __pyx_n_s_entity __pyx_mstate_global->__pyx_n_s_entity
#define __pyx_n_s_enumerate __pyx_mstate_global->__pyx_n_s_enumerate
#define __pyx_n_s_eq __pyx_mstate_global->__pyx_n_s_eq
#define __pyx_n_s_err __pyx_mstate_global->__pyx_n_s_err
#define __pyx_n_s_errmsg __pyx_mstate_global->__pyx_n_s_errmsg
#define __pyx_n_s_error __pyx_mstate_global->__pyx_n_s_error
#define __pyx_n_s_errorStop __pyx_mstate_global->__pyx_n_s_errorStop
#define __pyx_n_s_escChar __pyx_mstate_global->__pyx_n_s_escChar
#define __pyx_n_s_escCharReplacePattern __pyx_mstate_global->__pyx_n_s_escCharReplacePattern
#define __pyx_n_s_escQuote __pyx_mstate_global->__pyx_n_s_escQuote
#define __pyx_n_s_escape __pyx_mstate_global->__pyx_n_s_escape
#define __pyx_n_s_escapeRegexRangeChars __pyx_mstate_global->__pyx_n_s_escapeRegexRangeChars
#define __pyx_n_s_escapedHexChar __pyx_mstate_global->__pyx_n_s_escapedHexChar
#define __pyx_n_s_escapedOctChar __pyx_mstate_global->__pyx_n_s_escapedOctChar
#define __pyx_n_s_escapedPunc __pyx_mstate_global->__pyx_n_s_escapedPunc
#define __pyx_n_s_exact __pyx_mstate_global->__pyx_n_s_exact
#define __pyx_n_s_exc __pyx_mstate_global->__pyx_n_s_exc
#define __pyx_n_s_exc_info __pyx_mstate_global->__pyx_n_s_exc_info
#define __pyx_n_s_exc_type __pyx_mstate_global->__pyx_n_s_exc_type
#define __pyx_kp_u_exception __pyx_mstate_global->__pyx_kp_u_exception
#define __pyx_n_s_exceptionAction __pyx_mstate_global->__pyx_n_s_exceptionAction
#define __pyx_kp_u_exception_raised_in_parse_action __pyx_mstate_global->__pyx_kp_u_exception_raised_in_parse_action
#define __pyx_kp_s_exception_thrown_by_class_Parser __pyx_mstate_global->__pyx_kp_s_exception_thrown_by_class_Parser
#define __pyx_n_s_excludeChars __pyx_mstate_global->__pyx_n_s_excludeChars
#define __pyx_n_s_exit __pyx_mstate_global->__pyx_n_s_exit
#define __pyx_n_s_expand __pyx_mstate_global->__pyx_n_s_expand
#define __pyx_n_s_expanded __pyx_mstate_global->__pyx_n_s_expanded
#define __pyx_n_s_expandtabs __pyx_mstate_global->__pyx_n_s_expandtabs
#define __pyx_n_s_expected __pyx_mstate_global->__pyx_n_s_expected
#define __pyx_n_s_expected_dict __pyx_mstate_global->__pyx_n_s_expected_dict
#define __pyx_n_s_expected_exception __pyx_mstate_global->__pyx_n_s_expected_exception
#define __pyx_n_s_expected_list __pyx_mstate_global->__pyx_n_s_expected_list
#define __pyx_n_s_expected_parse_results __pyx_mstate_global->__pyx_n_s_expected_parse_results
#define __pyx_n_s_explain __pyx_mstate_global->__pyx_n_s_explain
#define __pyx_n_s_expr __pyx_mstate_global->__pyx_n_s_expr
#define __pyx_n_s_expr1 __pyx_mstate_global->__pyx_n_s_expr1
#define __pyx_n_s_expr_order __pyx_mstate_global->__pyx_n_s_expr_order
#define __pyx_n_s_expr_parse __pyx_mstate_global->__pyx_n_s_expr_parse
#define __pyx_kp_u_expression __pyx_mstate_global->__pyx_kp_u_expression
#define __pyx_n_s_exprs __pyx_mstate_global->__pyx_n_s_exprs
#define __pyx_n_u_exprs __pyx_mstate_global->__pyx_n_u_exprs
#define __pyx_n_s_exprsFound __pyx_mstate_global->__pyx_n_s_exprsFound
#define __pyx_n_s_exprtokens __pyx_mstate_global->__pyx_n_s_exprtokens
#define __pyx_n_s_extend __pyx_mstate_global->__pyx_n_s_extend
#define __pyx_n_s_extractText __pyx_mstate_global->__pyx_n_s_extractText
#define __pyx_n_s_extract_stack __pyx_mstate_global->__pyx_n_s_extract_stack
#define __pyx_n_s_extract_tb __pyx_mstate_global->__pyx_n_s_extract_tb
#define __pyx_kp_u_f __pyx_mstate_global->__pyx_kp_u_f
#define __pyx_n_s_f_2 __pyx_mstate_global->__pyx_n_s_f_2
#define __pyx_n_s_f_code __pyx_mstate_global->__pyx_n_s_f_code
#define __pyx_n_s_f_locals __pyx_mstate_global->__pyx_n_s_f_locals
#define __pyx_n_s_f_self __pyx_mstate_global->__pyx_n_s_f_self
#define __pyx_n_s_failAction __pyx_mstate_global->__pyx_n_s_failAction
#define __pyx_n_s_failOn __pyx_mstate_global->__pyx_n_s_failOn
#define __pyx_n_s_fail_msg __pyx_mstate_global->__pyx_n_s_fail_msg
#define __pyx_n_s_failed __pyx_mstate_global->__pyx_n_s_failed
#define __pyx_kp_u_failed_runTests __pyx_mstate_global->__pyx_kp_u_failed_runTests
#define __pyx_kp_u_failed_user_defined_condition __pyx_mstate_global->__pyx_kp_u_failed_user_defined_condition
#define __pyx_n_s_failureTests __pyx_mstate_global->__pyx_n_s_failureTests
#define __pyx_n_s_fatal __pyx_mstate_global->__pyx_n_s_fatal
#define __pyx_n_u_fatal __pyx_mstate_global->__pyx_n_u_fatal
#define __pyx_n_s_ff __pyx_mstate_global->__pyx_n_s_ff
#define __pyx_kp_u_ffff __pyx_mstate_global->__pyx_kp_u_ffff
#define __pyx_n_s_file __pyx_mstate_global->__pyx_n_s_file
#define __pyx_n_s_file_contents __pyx_mstate_global->__pyx_n_s_file_contents
#define __pyx_n_s_file_or_filename __pyx_mstate_global->__pyx_n_s_file_or_filename
#define __pyx_n_s_filter __pyx_mstate_global->__pyx_n_s_filter
#define __pyx_n_s_filterfalse __pyx_mstate_global->__pyx_n_s_filterfalse
#define __pyx_n_s_finalResults __pyx_mstate_global->__pyx_n_s_finalResults
#define __pyx_n_s_find __pyx_mstate_global->__pyx_n_s_find
#define __pyx_n_s_firstMatchChar __pyx_mstate_global->__pyx_n_s_firstMatchChar
#define __pyx_n_s_firstQuoteChar __pyx_mstate_global->__pyx_n_s_firstQuoteChar
#define __pyx_n_s_flag __pyx_mstate_global->__pyx_n_s_flag
#define __pyx_n_s_flags __pyx_mstate_global->__pyx_n_s_flags
#define __pyx_n_s_flatten __pyx_mstate_global->__pyx_n_s_flatten
#define __pyx_n_s_fmt __pyx_mstate_global->__pyx_n_s_fmt
#define __pyx_n_s_fn __pyx_mstate_global->__pyx_n_s_fn
#define __pyx_n_s_fname __pyx_mstate_global->__pyx_n_s_fname
#define __pyx_n_s_fns __pyx_mstate_global->__pyx_n_s_fns
#define __pyx_n_s_fnumber __pyx_mstate_global->__pyx_n_s_fnumber
#define __pyx_n_u_fnumber __pyx_mstate_global->__pyx_n_u_fnumber
#define __pyx_n_s_format __pyx_mstate_global->__pyx_n_s_format
#define __pyx_n_s_formatted __pyx_mstate_global->__pyx_n_s_formatted
#define __pyx_n_s_foundArity __pyx_mstate_global->__pyx_n_s_foundArity
#define __pyx_kp_u_found_end_of_text __pyx_mstate_global->__pyx_kp_u_found_end_of_text
#define __pyx_kp_u_found_multiline_regex_during_inc __pyx_mstate_global->__pyx_kp_u_found_multiline_regex_during_inc
#define __pyx_kp_u_found_r __pyx_mstate_global->__pyx_kp_u_found_r
#define __pyx_n_s_foundstr __pyx_mstate_global->__pyx_n_s_foundstr
#define __pyx_n_s_fraction __pyx_mstate_global->__pyx_n_s_fraction
#define __pyx_n_u_fraction __pyx_mstate_global->__pyx_n_u_fraction
#define __pyx_kp_u_fraction_or_mixed_integer_fracti __pyx_mstate_global->__pyx_kp_u_fraction_or_mixed_integer_fracti
#define __pyx_n_s_frame_summary __pyx_mstate_global->__pyx_n_s_frame_summary
#define __pyx_n_s_frames __pyx_mstate_global->__pyx_n_s_frames
#define __pyx_n_s_frm __pyx_mstate_global->__pyx_n_s_frm
#define __pyx_n_s_from __pyx_mstate_global->__pyx_n_s_from
#define __pyx_n_s_fromToken __pyx_mstate_global->__pyx_n_s_fromToken
#define __pyx_n_u_from_2 __pyx_mstate_global->__pyx_n_u_from_2
#define __pyx_n_s_from_dict __pyx_mstate_global->__pyx_n_s_from_dict
#define __pyx_n_s_from_exception __pyx_mstate_global->__pyx_n_s_from_exception
#define __pyx_n_s_from_symbols __pyx_mstate_global->__pyx_n_s_from_symbols
#define __pyx_n_s_full __pyx_mstate_global->__pyx_n_s_full
#define __pyx_n_s_fullDump __pyx_mstate_global->__pyx_n_s_fullDump
#define __pyx_kp_u_full_IPv6_address __pyx_mstate_global->__pyx_kp_u_full_IPv6_address
#define __pyx_n_s_full_ipv6_address __pyx_mstate_global->__pyx_n_s_full_ipv6_address
#define __pyx_n_s_func __pyx_mstate_global->__pyx_n_s_func
#define __pyx_n_s_func_name __pyx_mstate_global->__pyx_n_s_func_name
#define __pyx_n_s_functools __pyx_mstate_global->__pyx_n_s_functools
#define __pyx_n_s_furthest_locs __pyx_mstate_global->__pyx_n_s_furthest_locs
#define __pyx_kp_u_g_1 __pyx_mstate_global->__pyx_kp_u_g_1
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_generatorType __pyx_mstate_global->__pyx_n_s_generatorType
#define __pyx_n_s_genexpr __pyx_mstate_global->__pyx_n_s_genexpr
#define __pyx_n_s_get __pyx_mstate_global->__pyx_n_s_get
#define __pyx_n_s_getName __pyx_mstate_global->__pyx_n_s_getName
#define __pyx_n_s_get_2 __pyx_mstate_global->__pyx_n_s_get_2
#define __pyx_n_s_get_chars_for_ranges __pyx_mstate_global->__pyx_n_s_get_chars_for_ranges
#define __pyx_n_s_getattr __pyx_mstate_global->__pyx_n_s_getattr
#define __pyx_n_s_getinnerframes __pyx_mstate_global->__pyx_n_s_getinnerframes
#define __pyx_n_s_getitem __pyx_mstate_global->__pyx_n_s_getitem
#define __pyx_n_s_getnewargs __pyx_mstate_global->__pyx_n_s_getnewargs
#define __pyx_n_s_getrecursionlimit __pyx_mstate_global->__pyx_n_s_getrecursionlimit
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_n_s_group __pyx_mstate_global->__pyx_n_s_group
#define __pyx_n_s_groupdict __pyx_mstate_global->__pyx_n_s_groupdict
#define __pyx_n_s_groups __pyx_mstate_global->__pyx_n_s_groups
#define __pyx_kp_u_gt_lt_amp_nbsp_quot_apos __pyx_mstate_global->__pyx_kp_u_gt_lt_amp_nbsp_quot_apos
#define __pyx_n_s_hasIgnoreExprs __pyx_mstate_global->__pyx_n_s_hasIgnoreExprs
#define __pyx_kp_u_has_value __pyx_mstate_global->__pyx_kp_u_has_value
#define __pyx_n_s_hash __pyx_mstate_global->__pyx_n_s_hash
#define __pyx_n_s_haskeys __pyx_mstate_global->__pyx_n_s_haskeys
#define __pyx_kp_u_hex_integer __pyx_mstate_global->__pyx_kp_u_hex_integer
#define __pyx_n_s_hex_integer_2 __pyx_mstate_global->__pyx_n_s_hex_integer_2
#define __pyx_n_u_hex_integer_2 __pyx_mstate_global->__pyx_n_u_hex_integer_2
#define __pyx_n_s_hexnums __pyx_mstate_global->__pyx_n_s_hexnums
#define __pyx_n_u_hexnums __pyx_mstate_global->__pyx_n_u_hexnums
#define __pyx_n_s_hit __pyx_mstate_global->__pyx_n_s_hit
#define __pyx_n_s_htmlComment __pyx_mstate_global->__pyx_n_s_htmlComment
#define __pyx_n_u_htmlComment __pyx_mstate_global->__pyx_n_u_htmlComment
#define __pyx_n_s_htmlEntityMap __pyx_mstate_global->__pyx_n_s_htmlEntityMap
#define __pyx_n_s_html_stripper __pyx_mstate_global->__pyx_n_s_html_stripper
#define __pyx_n_s_i __pyx_mstate_global->__pyx_n_s_i
#define __pyx_n_s_iadd __pyx_mstate_global->__pyx_n_s_iadd
#define __pyx_n_s_id __pyx_mstate_global->__pyx_n_s_id
#define __pyx_n_s_ident __pyx_mstate_global->__pyx_n_s_ident
#define __pyx_n_s_identChars __pyx_mstate_global->__pyx_n_s_identChars
#define __pyx_n_s_identifier __pyx_mstate_global->__pyx_n_s_identifier
#define __pyx_n_u_identifier __pyx_mstate_global->__pyx_n_u_identifier
#define __pyx_kp_u_if_numterms_3_opExpr_must_be_a_t __pyx_mstate_global->__pyx_kp_u_if_numterms_3_opExpr_must_be_a_t
#define __pyx_n_s_ifilterfalse __pyx_mstate_global->__pyx_n_s_ifilterfalse
#define __pyx_n_s_ignore __pyx_mstate_global->__pyx_n_s_ignore
#define __pyx_n_s_ignoreExpr __pyx_mstate_global->__pyx_n_s_ignoreExpr
#define __pyx_n_s_ignoreExprs __pyx_mstate_global->__pyx_n_s_ignoreExprs
#define __pyx_n_s_ikey __pyx_mstate_global->__pyx_n_s_ikey
#define __pyx_kp_u_illegal_nesting __pyx_mstate_global->__pyx_kp_u_illegal_nesting
#define __pyx_n_s_ilshift __pyx_mstate_global->__pyx_n_s_ilshift
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_inAccumNames __pyx_mstate_global->__pyx_n_s_inAccumNames
#define __pyx_n_u_include __pyx_mstate_global->__pyx_n_u_include
#define __pyx_n_s_includeMatch __pyx_mstate_global->__pyx_n_s_includeMatch
#define __pyx_n_s_includeSeparators __pyx_mstate_global->__pyx_n_s_includeSeparators
#define __pyx_n_s_include_2 __pyx_mstate_global->__pyx_n_s_include_2
#define __pyx_n_s_include_list __pyx_mstate_global->__pyx_n_s_include_list
#define __pyx_n_s_incrementalEnabled __pyx_mstate_global->__pyx_n_s_incrementalEnabled
#define __pyx_n_s_incrementalWithResets __pyx_mstate_global->__pyx_n_s_incrementalWithResets
#define __pyx_n_s_incremental_parent_usefullness __pyx_mstate_global->__pyx_n_s_incremental_parent_usefullness
#define __pyx_n_s_ind __pyx_mstate_global->__pyx_n_s_ind
#define __pyx_n_s_ind_or_e __pyx_mstate_global->__pyx_n_s_ind_or_e
#define __pyx_n_s_indent __pyx_mstate_global->__pyx_n_s_indent
#define __pyx_n_s_indentStack __pyx_mstate_global->__pyx_n_s_indentStack
#define __pyx_n_s_indentedBlock __pyx_mstate_global->__pyx_n_s_indentedBlock
#define __pyx_n_u_indentedBlock __pyx_mstate_global->__pyx_n_u_indentedBlock
#define __pyx_n_s_indentedBlock_locals_checkPeerIn __pyx_mstate_global->__pyx_n_s_indentedBlock_locals_checkPeerIn
#define __pyx_n_s_indentedBlock_locals_checkSubInd __pyx_mstate_global->__pyx_n_s_indentedBlock_locals_checkSubInd
#define __pyx_n_s_indentedBlock_locals_checkUninde __pyx_mstate_global->__pyx_n_s_indentedBlock_locals_checkUninde
#define __pyx_n_s_indentedBlock_locals_lambda __pyx_mstate_global->__pyx_n_s_indentedBlock_locals_lambda
#define __pyx_n_s_indentedBlock_locals_reset_stack __pyx_mstate_global->__pyx_n_s_indentedBlock_locals_reset_stack
#define __pyx_kp_u_indented_block __pyx_mstate_global->__pyx_kp_u_indented_block
#define __pyx_n_s_index __pyx_mstate_global->__pyx_n_s_index
#define __pyx_n_s_indices __pyx_mstate_global->__pyx_n_s_indices
#define __pyx_n_s_infixNotation __pyx_mstate_global->__pyx_n_s_infixNotation
#define __pyx_n_u_infixNotation __pyx_mstate_global->__pyx_n_u_infixNotation
#define __pyx_n_s_infixNotation_locals__FB __pyx_mstate_global->__pyx_n_s_infixNotation_locals__FB
#define __pyx_n_s_infixNotation_locals__FB_parseIm __pyx_mstate_global->__pyx_n_s_infixNotation_locals__FB_parseIm
#define __pyx_n_s_init __pyx_mstate_global->__pyx_n_s_init
#define __pyx_n_s_initChars __pyx_mstate_global->__pyx_n_s_initChars
#define __pyx_n_s_initCharsOrig __pyx_mstate_global->__pyx_n_s_initCharsOrig
#define __pyx_n_s_initExprGroups __pyx_mstate_global->__pyx_n_s_initExprGroups
#define __pyx_n_s_init_subclass __pyx_mstate_global->__pyx_n_s_init_subclass
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_inlineLiteralsUsing __pyx_mstate_global->__pyx_n_s_inlineLiteralsUsing
#define __pyx_n_s_insStr __pyx_mstate_global->__pyx_n_s_insStr
#define __pyx_n_s_insert __pyx_mstate_global->__pyx_n_s_insert
#define __pyx_n_s_inspect __pyx_mstate_global->__pyx_n_s_inspect
#define __pyx_n_s_inspect_tracebacks __pyx_mstate_global->__pyx_n_s_inspect_tracebacks
#define __pyx_n_s_instring __pyx_mstate_global->__pyx_n_s_instring
#define __pyx_n_s_instring_prefixes_and_suffixes __pyx_mstate_global->__pyx_n_s_instring_prefixes_and_suffixes
#define __pyx_n_s_instring_slice __pyx_mstate_global->__pyx_n_s_instring_slice
#define __pyx_n_s_instrlen __pyx_mstate_global->__pyx_n_s_instrlen
#define __pyx_n_s_intExpr __pyx_mstate_global->__pyx_n_s_intExpr
#define __pyx_n_s_integer __pyx_mstate_global->__pyx_n_s_integer
#define __pyx_n_u_integer __pyx_mstate_global->__pyx_n_u_integer
#define __pyx_n_s_intern __pyx_mstate_global->__pyx_n_s_intern
#define __pyx_n_u_intern __pyx_mstate_global->__pyx_n_u_intern
#define __pyx_kp_u_invalid_pattern_s_passed_to_Rege __pyx_mstate_global->__pyx_kp_u_invalid_pattern_s_passed_to_Rege
#define __pyx_n_s_invert __pyx_mstate_global->__pyx_n_s_invert
#define __pyx_n_s_ior __pyx_mstate_global->__pyx_n_s_ior
#define __pyx_n_s_ipv4_address __pyx_mstate_global->__pyx_n_s_ipv4_address
#define __pyx_n_s_ipv6_address __pyx_mstate_global->__pyx_n_s_ipv6_address
#define __pyx_n_s_ipv6_part __pyx_mstate_global->__pyx_n_s_ipv6_part
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_n_s_is_instring __pyx_mstate_global->__pyx_n_s_is_instring
#define __pyx_n_s_is_iterable __pyx_mstate_global->__pyx_n_s_is_iterable
#define __pyx_n_s_isalpha __pyx_mstate_global->__pyx_n_s_isalpha
#define __pyx_n_s_isdigit __pyx_mstate_global->__pyx_n_s_isdigit
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_isequal __pyx_mstate_global->__pyx_n_s_isequal
#define __pyx_n_s_isinstance __pyx_mstate_global->__pyx_n_s_isinstance
#define __pyx_n_s_iso8601_date __pyx_mstate_global->__pyx_n_s_iso8601_date
#define __pyx_n_s_iso8601_datetime __pyx_mstate_global->__pyx_n_s_iso8601_datetime
#define __pyx_n_s_isspace __pyx_mstate_global->__pyx_n_s_isspace
#define __pyx_n_s_item __pyx_mstate_global->__pyx_n_s_item
#define __pyx_n_s_item_fn __pyx_mstate_global->__pyx_n_s_item_fn
#define __pyx_n_s_itemgetter __pyx_mstate_global->__pyx_n_s_itemgetter
#define __pyx_n_s_items __pyx_mstate_global->__pyx_n_s_items
#define __pyx_n_s_itemseq __pyx_mstate_global->__pyx_n_s_itemseq
#define __pyx_n_s_iter __pyx_mstate_global->__pyx_n_s_iter
#define __pyx_n_s_iteritems __pyx_mstate_global->__pyx_n_s_iteritems
#define __pyx_n_s_iteritems_2 __pyx_mstate_global->__pyx_n_s_iteritems_2
#define __pyx_n_s_iterkeys __pyx_mstate_global->__pyx_n_s_iterkeys
#define __pyx_n_u_iterkeys __pyx_mstate_global->__pyx_n_u_iterkeys
#define __pyx_n_s_iterkeys_2 __pyx_mstate_global->__pyx_n_s_iterkeys_2
#define __pyx_n_s_itertools __pyx_mstate_global->__pyx_n_s_itertools
#define __pyx_n_s_itervalues __pyx_mstate_global->__pyx_n_s_itervalues
#define __pyx_n_s_itervalues_2 __pyx_mstate_global->__pyx_n_s_itervalues_2
#define __pyx_n_s_ixor __pyx_mstate_global->__pyx_n_s_ixor
#define __pyx_n_s_j __pyx_mstate_global->__pyx_n_s_j
#define __pyx_n_s_javaStyleComment __pyx_mstate_global->__pyx_n_s_javaStyleComment
#define __pyx_n_u_javaStyleComment __pyx_mstate_global->__pyx_n_u_javaStyleComment
#define __pyx_n_s_joinString __pyx_mstate_global->__pyx_n_s_joinString
#define __pyx_kp_s_just_like_class_ParseFatalExcept __pyx_mstate_global->__pyx_kp_s_just_like_class_ParseFatalExcept
#define __pyx_n_s_k __pyx_mstate_global->__pyx_n_s_k
#define __pyx_n_s_keepMatching __pyx_mstate_global->__pyx_n_s_keepMatching
#define __pyx_n_s_keepTabs __pyx_mstate_global->__pyx_n_s_keepTabs
#define __pyx_n_s_key __pyx_mstate_global->__pyx_n_s_key
#define __pyx_n_s_key_fifo __pyx_mstate_global->__pyx_n_s_key_fifo
#define __pyx_n_u_key_fifo __pyx_mstate_global->__pyx_n_u_key_fifo
#define __pyx_n_s_keys __pyx_mstate_global->__pyx_n_s_keys
#define __pyx_n_s_kwargs __pyx_mstate_global->__pyx_n_s_kwargs
#define __pyx_n_s_l __pyx_mstate_global->__pyx_n_s_l
#define __pyx_n_s_lambda __pyx_mstate_global->__pyx_n_s_lambda
#define __pyx_n_s_last __pyx_mstate_global->__pyx_n_s_last
#define __pyx_n_s_lastCR __pyx_mstate_global->__pyx_n_s_lastCR
#define __pyx_n_s_lastE __pyx_mstate_global->__pyx_n_s_lastE
#define __pyx_n_s_lastExpr __pyx_mstate_global->__pyx_n_s_lastExpr
#define __pyx_n_s_last_expr __pyx_mstate_global->__pyx_n_s_last_expr
#define __pyx_n_s_lazyclassproperty __pyx_mstate_global->__pyx_n_s_lazyclassproperty
#define __pyx_n_s_lazyclassproperty___get __pyx_mstate_global->__pyx_n_s_lazyclassproperty___get
#define __pyx_n_s_lazyclassproperty___get___local __pyx_mstate_global->__pyx_n_s_lazyclassproperty___get___local
#define __pyx_n_s_lazyclassproperty___init __pyx_mstate_global->__pyx_n_s_lazyclassproperty___init
#define __pyx_n_s_leaveWhitespace __pyx_mstate_global->__pyx_n_s_leaveWhitespace
#define __pyx_kp_u_leaving __pyx_mstate_global->__pyx_kp_u_leaving
#define __pyx_kp_u_len __pyx_mstate_global->__pyx_kp_u_len
#define __pyx_n_s_len_2 __pyx_mstate_global->__pyx_n_s_len_2
#define __pyx_n_s_len_3 __pyx_mstate_global->__pyx_n_s_len_3
#define __pyx_n_s_limit __pyx_mstate_global->__pyx_n_s_limit
#define __pyx_n_s_line __pyx_mstate_global->__pyx_n_s_line
#define __pyx_n_u_line __pyx_mstate_global->__pyx_n_u_line
#define __pyx_n_s_lineEnd __pyx_mstate_global->__pyx_n_s_lineEnd
#define __pyx_n_u_lineEnd __pyx_mstate_global->__pyx_n_u_lineEnd
#define __pyx_n_s_lineStart __pyx_mstate_global->__pyx_n_s_lineStart
#define __pyx_n_u_lineStart __pyx_mstate_global->__pyx_n_u_lineStart
#define __pyx_kp_u_line_2 __pyx_mstate_global->__pyx_kp_u_line_2
#define __pyx_kp_u_line_3 __pyx_mstate_global->__pyx_kp_u_line_3
#define __pyx_n_s_line_column __pyx_mstate_global->__pyx_n_s_line_column
#define __pyx_n_s_line_str __pyx_mstate_global->__pyx_n_s_line_str
#define __pyx_n_s_lineno __pyx_mstate_global->__pyx_n_s_lineno
#define __pyx_n_u_lineno __pyx_mstate_global->__pyx_n_u_lineno
#define __pyx_kp_u_lineno_col_line __pyx_mstate_global->__pyx_kp_u_lineno_col_line
#define __pyx_n_s_listAllMatches __pyx_mstate_global->__pyx_n_s_listAllMatches
#define __pyx_n_s_list_str __pyx_mstate_global->__pyx_n_s_list_str
#define __pyx_n_s_list_str_locals_genexpr __pyx_mstate_global->__pyx_n_s_list_str_locals_genexpr
#define __pyx_n_s_literalStringClass __pyx_mstate_global->__pyx_n_s_literalStringClass
#define __pyx_n_u_literal_string_class __pyx_mstate_global->__pyx_n_u_literal_string_class
#define __pyx_n_s_loc __pyx_mstate_global->__pyx_n_s_loc
#define __pyx_n_u_loc __pyx_mstate_global->__pyx_n_u_loc
#define __pyx_n_s_loc1 __pyx_mstate_global->__pyx_n_s_loc1
#define __pyx_n_s_loc2 __pyx_mstate_global->__pyx_n_s_loc2
#define __pyx_n_s_locMarker __pyx_mstate_global->__pyx_n_s_locMarker
#define __pyx_n_s_loc_in_suffix __pyx_mstate_global->__pyx_n_s_loc_in_suffix
#define __pyx_n_s_locatedExpr __pyx_mstate_global->__pyx_n_s_locatedExpr
#define __pyx_n_u_locatedExpr __pyx_mstate_global->__pyx_n_u_locatedExpr
#define __pyx_n_s_locatedExpr_locals_lambda __pyx_mstate_global->__pyx_n_s_locatedExpr_locals_lambda
#define __pyx_n_s_locator __pyx_mstate_global->__pyx_n_s_locator
#define __pyx_n_s_locn __pyx_mstate_global->__pyx_n_s_locn
#define __pyx_n_u_locn_end __pyx_mstate_global->__pyx_n_u_locn_end
#define __pyx_n_u_locn_start __pyx_mstate_global->__pyx_n_u_locn_start
#define __pyx_n_s_longest __pyx_mstate_global->__pyx_n_s_longest
#define __pyx_n_s_lookup __pyx_mstate_global->__pyx_n_s_lookup
#define __pyx_n_s_lookup_2 __pyx_mstate_global->__pyx_n_s_lookup_2
#define __pyx_n_s_lookup_bools __pyx_mstate_global->__pyx_n_s_lookup_bools
#define __pyx_n_s_lower __pyx_mstate_global->__pyx_n_s_lower
#define __pyx_n_s_lpar __pyx_mstate_global->__pyx_n_s_lpar
#define __pyx_n_s_lshift __pyx_mstate_global->__pyx_n_s_lshift
#define __pyx_n_s_lstrip __pyx_mstate_global->__pyx_n_s_lstrip
#define __pyx_n_s_mac_address __pyx_mstate_global->__pyx_n_s_mac_address
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_u_main __pyx_mstate_global->__pyx_n_u_main
#define __pyx_n_s_makeHTMLTags __pyx_mstate_global->__pyx_n_s_makeHTMLTags
#define __pyx_n_u_makeHTMLTags __pyx_mstate_global->__pyx_n_u_makeHTMLTags
#define __pyx_n_s_makeOptionalList __pyx_mstate_global->__pyx_n_s_makeOptionalList
#define __pyx_n_s_makeTags __pyx_mstate_global->__pyx_n_s_makeTags
#define __pyx_n_s_makeTags_locals_lambda __pyx_mstate_global->__pyx_n_s_makeTags_locals_lambda
#define __pyx_n_s_makeXMLTags __pyx_mstate_global->__pyx_n_s_makeXMLTags
#define __pyx_n_u_makeXMLTags __pyx_mstate_global->__pyx_n_u_makeXMLTags
#define __pyx_n_s_map __pyx_mstate_global->__pyx_n_s_map
#define __pyx_n_s_markInputline __pyx_mstate_global->__pyx_n_s_markInputline
#define __pyx_n_s_markerString __pyx_mstate_global->__pyx_n_s_markerString
#define __pyx_n_s_masks __pyx_mstate_global->__pyx_n_s_masks
#define __pyx_n_s_mat __pyx_mstate_global->__pyx_n_s_mat
#define __pyx_n_s_match __pyx_mstate_global->__pyx_n_s_match
#define __pyx_n_u_match __pyx_mstate_global->__pyx_n_u_match
#define __pyx_n_s_matchExpr __pyx_mstate_global->__pyx_n_s_matchExpr
#define __pyx_n_s_matchLen __pyx_mstate_global->__pyx_n_s_matchLen
#define __pyx_n_s_matchOnlyAtCol __pyx_mstate_global->__pyx_n_s_matchOnlyAtCol
#define __pyx_n_u_matchOnlyAtCol __pyx_mstate_global->__pyx_n_u_matchOnlyAtCol
#define __pyx_n_s_matchOnlyAtCol_locals_verifyCol __pyx_mstate_global->__pyx_n_s_matchOnlyAtCol_locals_verifyCol
#define __pyx_n_s_matchOrder __pyx_mstate_global->__pyx_n_s_matchOrder
#define __pyx_n_s_matchPreviousExpr __pyx_mstate_global->__pyx_n_s_matchPreviousExpr
#define __pyx_n_u_matchPreviousExpr __pyx_mstate_global->__pyx_n_u_matchPreviousExpr
#define __pyx_n_s_matchPreviousExpr_locals_copyTok __pyx_mstate_global->__pyx_n_s_matchPreviousExpr_locals_copyTok
#define __pyx_n_s_matchPreviousExpr_locals_copyTok_2 __pyx_mstate_global->__pyx_n_s_matchPreviousExpr_locals_copyTok_2
#define __pyx_n_s_matchPreviousLiteral __pyx_mstate_global->__pyx_n_s_matchPreviousLiteral
#define __pyx_n_u_matchPreviousLiteral __pyx_mstate_global->__pyx_n_u_matchPreviousLiteral
#define __pyx_n_s_matchPreviousLiteral_locals_copy __pyx_mstate_global->__pyx_n_s_matchPreviousLiteral_locals_copy
#define __pyx_n_s_matchPreviousLiteral_locals_copy_2 __pyx_mstate_global->__pyx_n_s_matchPreviousLiteral_locals_copy_2
#define __pyx_n_s_matchString __pyx_mstate_global->__pyx_n_s_matchString
#define __pyx_n_s_matchTokens __pyx_mstate_global->__pyx_n_s_matchTokens
#define __pyx_n_s_matchWhite __pyx_mstate_global->__pyx_n_s_matchWhite
#define __pyx_n_s_match_string __pyx_mstate_global->__pyx_n_s_match_string
#define __pyx_n_s_match_stringloc __pyx_mstate_global->__pyx_n_s_match_stringloc
#define __pyx_kp_u_matched_token_not_at_column_d __pyx_mstate_global->__pyx_kp_u_matched_token_not_at_column_d
#define __pyx_n_s_matches __pyx_mstate_global->__pyx_n_s_matches
#define __pyx_n_s_max __pyx_mstate_global->__pyx_n_s_max
#define __pyx_n_s_maxExcLoc __pyx_mstate_global->__pyx_n_s_maxExcLoc
#define __pyx_n_s_maxException __pyx_mstate_global->__pyx_n_s_maxException
#define __pyx_n_s_maxLen __pyx_mstate_global->__pyx_n_s_maxLen
#define __pyx_n_s_maxMatches __pyx_mstate_global->__pyx_n_s_maxMatches
#define __pyx_n_s_maxMismatches __pyx_mstate_global->__pyx_n_s_maxMismatches
#define __pyx_n_s_maxSpecified __pyx_mstate_global->__pyx_n_s_maxSpecified
#define __pyx_n_s_maxargs __pyx_mstate_global->__pyx_n_s_maxargs
#define __pyx_n_s_maxint __pyx_mstate_global->__pyx_n_s_maxint
#define __pyx_n_s_maxlen __pyx_mstate_global->__pyx_n_s_maxlen
#define __pyx_n_s_maxloc __pyx_mstate_global->__pyx_n_s_maxloc
#define __pyx_n_s_maxsize __pyx_mstate_global->__pyx_n_s_maxsize
#define __pyx_n_s_maxsplit __pyx_mstate_global->__pyx_n_s_maxsplit
#define __pyx_n_s_maxunicode __pyx_mstate_global->__pyx_n_s_maxunicode
#define __pyx_n_s_mayIndexError __pyx_mstate_global->__pyx_n_s_mayIndexError
#define __pyx_n_s_mayReturnEmpty __pyx_mstate_global->__pyx_n_s_mayReturnEmpty
#define __pyx_n_s_merged __pyx_mstate_global->__pyx_n_s_merged
#define __pyx_n_s_message __pyx_mstate_global->__pyx_n_s_message
#define __pyx_n_u_message __pyx_mstate_global->__pyx_n_u_message
#define __pyx_n_s_metaclass __pyx_mstate_global->__pyx_n_s_metaclass
#define __pyx_n_s_methodCall __pyx_mstate_global->__pyx_n_s_methodCall
#define __pyx_n_s_min __pyx_mstate_global->__pyx_n_s_min
#define __pyx_n_s_minElements __pyx_mstate_global->__pyx_n_s_minElements
#define __pyx_n_s_minLen __pyx_mstate_global->__pyx_n_s_minLen
#define __pyx_kp_u_mismatches __pyx_mstate_global->__pyx_kp_u_mismatches
#define __pyx_n_s_mismatches_2 __pyx_mstate_global->__pyx_n_s_mismatches_2
#define __pyx_n_u_mismatches_2 __pyx_mstate_global->__pyx_n_u_mismatches_2
#define __pyx_kp_u_missing __pyx_mstate_global->__pyx_kp_u_missing
#define __pyx_n_s_missing_2 __pyx_mstate_global->__pyx_n_s_missing_2
#define __pyx_kp_u_mixed_IPv6_address __pyx_mstate_global->__pyx_kp_u_mixed_IPv6_address
#define __pyx_n_s_mixed_integer __pyx_mstate_global->__pyx_n_s_mixed_integer
#define __pyx_n_s_mixed_ipv6_address __pyx_mstate_global->__pyx_n_s_mixed_ipv6_address
#define __pyx_n_s_modal __pyx_mstate_global->__pyx_n_s_modal
#define __pyx_n_s_modalResults __pyx_mstate_global->__pyx_n_s_modalResults
#define __pyx_n_s_module __pyx_mstate_global->__pyx_n_s_module
#define __pyx_kp_u_module_2 __pyx_mstate_global->__pyx_kp_u_module_2
#define __pyx_n_s_mro __pyx_mstate_global->__pyx_n_s_mro
#define __pyx_n_s_mro_entries __pyx_mstate_global->__pyx_n_s_mro_entries
#define __pyx_n_s_msg __pyx_mstate_global->__pyx_n_s_msg
#define __pyx_n_u_msg __pyx_mstate_global->__pyx_n_u_msg
#define __pyx_n_s_mul __pyx_mstate_global->__pyx_n_s_mul
#define __pyx_n_s_multiline __pyx_mstate_global->__pyx_n_s_multiline
#define __pyx_n_s_multioptionals __pyx_mstate_global->__pyx_n_s_multioptionals
#define __pyx_n_s_multirequired __pyx_mstate_global->__pyx_n_s_multirequired
#define __pyx_n_s_mustMatchTheseTokens __pyx_mstate_global->__pyx_n_s_mustMatchTheseTokens
#define __pyx_kp_u_must_be __pyx_mstate_global->__pyx_kp_u_must_be
#define __pyx_n_s_must_skip __pyx_mstate_global->__pyx_n_s_must_skip
#define __pyx_n_s_mylen __pyx_mstate_global->__pyx_n_s_mylen
#define __pyx_n_s_n __pyx_mstate_global->__pyx_n_s_n
#define __pyx_kp_u_n_2 __pyx_mstate_global->__pyx_kp_u_n_2
#define __pyx_kp_u_n_n __pyx_mstate_global->__pyx_kp_u_n_n
#define __pyx_kp_u_n_r __pyx_mstate_global->__pyx_kp_u_n_r
#define __pyx_kp_u_n_r_x_x_0_9a_fA_F __pyx_mstate_global->__pyx_kp_u_n_r_x_x_0_9a_fA_F
#define __pyx_kp_u_n_r_x_x_0_9a_fA_F_2 __pyx_mstate_global->__pyx_kp_u_n_r_x_x_0_9a_fA_F_2
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_u_name __pyx_mstate_global->__pyx_n_u_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_u_name_2 __pyx_mstate_global->__pyx_n_u_name_2
#define __pyx_n_s_namedItems __pyx_mstate_global->__pyx_n_s_namedItems
#define __pyx_n_s_namedItemsOnly __pyx_mstate_global->__pyx_n_s_namedItemsOnly
#define __pyx_n_s_namespace __pyx_mstate_global->__pyx_n_s_namespace
#define __pyx_kp_s_namespace_class_for_classes_use __pyx_mstate_global->__pyx_kp_s_namespace_class_for_classes_use
#define __pyx_n_s_ne __pyx_mstate_global->__pyx_n_s_ne
#define __pyx_n_u_negate __pyx_mstate_global->__pyx_n_u_negate
#define __pyx_kp_u_nested __pyx_mstate_global->__pyx_kp_u_nested
#define __pyx_n_s_nestedExpr __pyx_mstate_global->__pyx_n_s_nestedExpr
#define __pyx_n_u_nestedExpr __pyx_mstate_global->__pyx_n_u_nestedExpr
#define __pyx_n_s_nestedExpr_locals_lambda __pyx_mstate_global->__pyx_n_s_nestedExpr_locals_lambda
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_n_s_new_loc __pyx_mstate_global->__pyx_n_s_new_loc
#define __pyx_n_s_newloc __pyx_mstate_global->__pyx_n_s_newloc
#define __pyx_n_s_newself __pyx_mstate_global->__pyx_n_s_newself
#define __pyx_n_s_nextCR __pyx_mstate_global->__pyx_n_s_nextCR
#define __pyx_n_s_nextLevelIndent __pyx_mstate_global->__pyx_n_s_nextLevelIndent
#define __pyx_n_s_nextLoc __pyx_mstate_global->__pyx_n_s_nextLoc
#define __pyx_n_s_next_linebreak_loc __pyx_mstate_global->__pyx_n_s_next_linebreak_loc
#define __pyx_n_s_nextloc __pyx_mstate_global->__pyx_n_s_nextloc
#define __pyx_n_s_nl __pyx_mstate_global->__pyx_n_s_nl
#define __pyx_kp_u_no_defined_alternatives_to_match __pyx_mstate_global->__pyx_kp_u_no_defined_alternatives_to_match
#define __pyx_kp_u_no_matching_attribute __pyx_mstate_global->__pyx_kp_u_no_matching_attribute
#define __pyx_kp_u_no_validation_for_r __pyx_mstate_global->__pyx_kp_u_no_validation_for_r
#define __pyx_n_s_nonzero __pyx_mstate_global->__pyx_n_s_nonzero
#define __pyx_n_s_notChars __pyx_mstate_global->__pyx_n_s_notChars
#define __pyx_kp_u_not_a_peer_entry __pyx_mstate_global->__pyx_kp_u_not_a_peer_entry
#define __pyx_kp_u_not_a_subentry __pyx_mstate_global->__pyx_kp_u_not_a_subentry
#define __pyx_kp_u_not_an_unindent __pyx_mstate_global->__pyx_kp_u_not_an_unindent
#define __pyx_n_s_not_ender __pyx_mstate_global->__pyx_n_s_not_ender
#define __pyx_n_s_not_in_cache __pyx_mstate_global->__pyx_n_s_not_in_cache
#define __pyx_kp_u_not_preceded_by __pyx_mstate_global->__pyx_kp_u_not_preceded_by
#define __pyx_n_s_notchars __pyx_mstate_global->__pyx_n_s_notchars
#define __pyx_n_s_nullDebugAction __pyx_mstate_global->__pyx_n_s_nullDebugAction
#define __pyx_n_u_nullDebugAction __pyx_mstate_global->__pyx_n_u_nullDebugAction
#define __pyx_kp_u_null_string_passed_to_Keyword_us __pyx_mstate_global->__pyx_kp_u_null_string_passed_to_Keyword_us
#define __pyx_kp_u_null_string_passed_to_Literal_us __pyx_mstate_global->__pyx_kp_u_null_string_passed_to_Literal_us
#define __pyx_kp_u_null_string_passed_to_Regex_use __pyx_mstate_global->__pyx_kp_u_null_string_passed_to_Regex_use
#define __pyx_n_s_number __pyx_mstate_global->__pyx_n_s_number
#define __pyx_n_s_nums __pyx_mstate_global->__pyx_n_s_nums
#define __pyx_n_u_nums __pyx_mstate_global->__pyx_n_u_nums
#define __pyx_n_s_o __pyx_mstate_global->__pyx_n_s_o
#define __pyx_n_s_obj __pyx_mstate_global->__pyx_n_s_obj
#define __pyx_n_s_object __pyx_mstate_global->__pyx_n_s_object
#define __pyx_n_s_occurrences __pyx_mstate_global->__pyx_n_s_occurrences
#define __pyx_n_s_offset __pyx_mstate_global->__pyx_n_s_offset
#define __pyx_n_s_on __pyx_mstate_global->__pyx_n_s_on
#define __pyx_n_s_oneOf __pyx_mstate_global->__pyx_n_s_oneOf
#define __pyx_n_u_oneOf __pyx_mstate_global->__pyx_n_u_oneOf
#define __pyx_n_s_oneOf_locals_genexpr __pyx_mstate_global->__pyx_n_s_oneOf_locals_genexpr
#define __pyx_n_s_oneOf_locals_lambda __pyx_mstate_global->__pyx_n_s_oneOf_locals_lambda
#define __pyx_kp_u_only_1_or_2_index_arguments_supp __pyx_mstate_global->__pyx_kp_u_only_1_or_2_index_arguments_supp
#define __pyx_n_s_opAssoc __pyx_mstate_global->__pyx_n_s_opAssoc
#define __pyx_n_u_opAssoc __pyx_mstate_global->__pyx_n_u_opAssoc
#define __pyx_n_s_opExpr __pyx_mstate_global->__pyx_n_s_opExpr
#define __pyx_n_s_opExpr1 __pyx_mstate_global->__pyx_n_s_opExpr1
#define __pyx_n_s_opExpr2 __pyx_mstate_global->__pyx_n_s_opExpr2
#define __pyx_n_s_opList __pyx_mstate_global->__pyx_n_s_opList
#define __pyx_n_s_open __pyx_mstate_global->__pyx_n_s_open
#define __pyx_n_s_openTag __pyx_mstate_global->__pyx_n_s_openTag
#define __pyx_n_s_opener __pyx_mstate_global->__pyx_n_s_opener
#define __pyx_kp_u_opening_and_closing_arguments_mu __pyx_mstate_global->__pyx_kp_u_opening_and_closing_arguments_mu
#define __pyx_kp_u_opening_and_closing_strings_cann __pyx_mstate_global->__pyx_kp_u_opening_and_closing_strings_cann
#define __pyx_n_s_operDef __pyx_mstate_global->__pyx_n_s_operDef
#define __pyx_n_s_operator __pyx_mstate_global->__pyx_n_s_operator
#define __pyx_n_s_operatorPrecedence __pyx_mstate_global->__pyx_n_s_operatorPrecedence
#define __pyx_n_u_operatorPrecedence __pyx_mstate_global->__pyx_n_u_operatorPrecedence
#define __pyx_kp_u_operator_must_be_unary_1_binary __pyx_mstate_global->__pyx_kp_u_operator_must_be_unary_1_binary
#define __pyx_kp_u_operator_must_indicate_right_or __pyx_mstate_global->__pyx_kp_u_operator_must_indicate_right_or
#define __pyx_n_s_opt1 __pyx_mstate_global->__pyx_n_s_opt1
#define __pyx_n_s_opt1map __pyx_mstate_global->__pyx_n_s_opt1map
#define __pyx_n_s_opt2 __pyx_mstate_global->__pyx_n_s_opt2
#define __pyx_n_s_optElements __pyx_mstate_global->__pyx_n_s_optElements
#define __pyx_n_s_optionals __pyx_mstate_global->__pyx_n_s_optionals
#define __pyx_n_s_or __pyx_mstate_global->__pyx_n_s_or
#define __pyx_n_s_ordereddict __pyx_mstate_global->__pyx_n_s_ordereddict
#define __pyx_n_u_original __pyx_mstate_global->__pyx_n_u_original
#define __pyx_n_s_originalParseMethod __pyx_mstate_global->__pyx_n_s_originalParseMethod
#define __pyx_n_u_originalParseMethod __pyx_mstate_global->__pyx_n_u_originalParseMethod
#define __pyx_n_s_originalTextFor __pyx_mstate_global->__pyx_n_s_originalTextFor
#define __pyx_n_u_originalTextFor __pyx_mstate_global->__pyx_n_u_originalTextFor
#define __pyx_n_s_originalTextFor_locals_extractTe __pyx_mstate_global->__pyx_n_s_originalTextFor_locals_extractTe
#define __pyx_n_s_originalTextFor_locals_lambda __pyx_mstate_global->__pyx_n_s_originalTextFor_locals_lambda
#define __pyx_n_s_original_end __pyx_mstate_global->__pyx_n_s_original_end
#define __pyx_n_u_original_end __pyx_mstate_global->__pyx_n_u_original_end
#define __pyx_n_s_original_start __pyx_mstate_global->__pyx_n_s_original_start
#define __pyx_n_u_original_start __pyx_mstate_global->__pyx_n_u_original_start
#define __pyx_n_s_os_path __pyx_mstate_global->__pyx_n_s_os_path
#define __pyx_n_s_other __pyx_mstate_global->__pyx_n_s_other
#define __pyx_n_s_other_instring __pyx_mstate_global->__pyx_n_s_other_instring
#define __pyx_n_s_otherdictitems __pyx_mstate_global->__pyx_n_s_otherdictitems
#define __pyx_n_s_otheritems __pyx_mstate_global->__pyx_n_s_otheritems
#define __pyx_n_s_out __pyx_mstate_global->__pyx_n_s_out
#define __pyx_n_s_outer_parent_usefullness_obj __pyx_mstate_global->__pyx_n_s_outer_parent_usefullness_obj
#define __pyx_n_s_overlap __pyx_mstate_global->__pyx_n_s_overlap
#define __pyx_n_s_p __pyx_mstate_global->__pyx_n_s_p
#define __pyx_n_s_p1 __pyx_mstate_global->__pyx_n_s_p1
#define __pyx_n_s_p2 __pyx_mstate_global->__pyx_n_s_p2
#define __pyx_n_s_pa __pyx_mstate_global->__pyx_n_s_pa
#define __pyx_n_s_paArgs __pyx_mstate_global->__pyx_n_s_paArgs
#define __pyx_n_s_pa_call_line_synth __pyx_mstate_global->__pyx_n_s_pa_call_line_synth
#define __pyx_n_s_packratEnabled __pyx_mstate_global->__pyx_n_s_packratEnabled
#define __pyx_n_s_packrat_cache __pyx_mstate_global->__pyx_n_s_packrat_cache
#define __pyx_n_s_packrat_cache_lock __pyx_mstate_global->__pyx_n_s_packrat_cache_lock
#define __pyx_n_s_packrat_cache_stats __pyx_mstate_global->__pyx_n_s_packrat_cache_stats
#define __pyx_n_s_packrat_context __pyx_mstate_global->__pyx_n_s_packrat_context
#define __pyx_n_u_packrat_enabled __pyx_mstate_global->__pyx_n_u_packrat_enabled
#define __pyx_n_u_packrat_parse __pyx_mstate_global->__pyx_n_u_packrat_parse
#define __pyx_n_s_par __pyx_mstate_global->__pyx_n_s_par
#define __pyx_n_s_parse __pyx_mstate_global->__pyx_n_s_parse
#define __pyx_n_s_parseAction __pyx_mstate_global->__pyx_n_s_parseAction
#define __pyx_n_s_parseAll __pyx_mstate_global->__pyx_n_s_parseAll
#define __pyx_n_s_parseCache __pyx_mstate_global->__pyx_n_s_parseCache
#define __pyx_n_s_parseElementClass __pyx_mstate_global->__pyx_n_s_parseElementClass
#define __pyx_n_s_parseElementList __pyx_mstate_global->__pyx_n_s_parseElementList
#define __pyx_n_s_parseElementTrace __pyx_mstate_global->__pyx_n_s_parseElementTrace
#define __pyx_n_s_parseFile __pyx_mstate_global->__pyx_n_s_parseFile
#define __pyx_n_s_parseFn __pyx_mstate_global->__pyx_n_s_parseFn
#define __pyx_n_s_parseImpl __pyx_mstate_global->__pyx_n_s_parseImpl
#define __pyx_n_u_parseImpl __pyx_mstate_global->__pyx_n_u_parseImpl
#define __pyx_n_s_parseImplAsGroupList __pyx_mstate_global->__pyx_n_s_parseImplAsGroupList
#define __pyx_n_s_parseImplAsMatch __pyx_mstate_global->__pyx_n_s_parseImplAsMatch
#define __pyx_n_s_parseIncremental __pyx_mstate_global->__pyx_n_s_parseIncremental
#define __pyx_n_s_parseMethod __pyx_mstate_global->__pyx_n_s_parseMethod
#define __pyx_n_s_parseNoCache __pyx_mstate_global->__pyx_n_s_parseNoCache
#define __pyx_n_u_parseNoCache __pyx_mstate_global->__pyx_n_u_parseNoCache
#define __pyx_n_s_parseString __pyx_mstate_global->__pyx_n_s_parseString
#define __pyx_n_s_parseWithTabs __pyx_mstate_global->__pyx_n_s_parseWithTabs
#define __pyx_kp_u_parse_action __pyx_mstate_global->__pyx_kp_u_parse_action
#define __pyx_n_s_parse_action_exc __pyx_mstate_global->__pyx_n_s_parse_action_exc
#define __pyx_kp_u_parse_actions_must_be_callable __pyx_mstate_global->__pyx_kp_u_parse_actions_must_be_callable
#define __pyx_n_s_parse_element_index __pyx_mstate_global->__pyx_n_s_parse_element_index
#define __pyx_n_s_parserElement __pyx_mstate_global->__pyx_n_s_parserElement
#define __pyx_n_u_parserElement __pyx_mstate_global->__pyx_n_u_parserElement
#define __pyx_n_s_pattern __pyx_mstate_global->__pyx_n_s_pattern
#define __pyx_n_u_pattern __pyx_mstate_global->__pyx_n_u_pattern
#define __pyx_n_s_pbe __pyx_mstate_global->__pyx_n_s_pbe
#define __pyx_n_s_pdb __pyx_mstate_global->__pyx_n_s_pdb
#define __pyx_n_s_pe __pyx_mstate_global->__pyx_n_s_pe
#define __pyx_n_s_pop __pyx_mstate_global->__pyx_n_s_pop
#define __pyx_kp_u_pop_got_an_unexpected_keyword_ar __pyx_mstate_global->__pyx_kp_u_pop_got_an_unexpected_keyword_ar
#define __pyx_n_s_popitem __pyx_mstate_global->__pyx_n_s_popitem
#define __pyx_n_s_popleft __pyx_mstate_global->__pyx_n_s_popleft
#define __pyx_n_s_position __pyx_mstate_global->__pyx_n_s_position
#define __pyx_n_s_postParse __pyx_mstate_global->__pyx_n_s_postParse
#define __pyx_n_s_pp_value __pyx_mstate_global->__pyx_n_s_pp_value
#define __pyx_n_s_pprint __pyx_mstate_global->__pyx_n_s_pprint
#define __pyx_n_s_preParse __pyx_mstate_global->__pyx_n_s_preParse
#define __pyx_n_s_prefix_len __pyx_mstate_global->__pyx_n_s_prefix_len
#define __pyx_n_s_prefix_lookup __pyx_mstate_global->__pyx_n_s_prefix_lookup
#define __pyx_n_s_prefixes_and_suffixes __pyx_mstate_global->__pyx_n_s_prefixes_and_suffixes
#define __pyx_n_s_preloc __pyx_mstate_global->__pyx_n_s_preloc
#define __pyx_n_s_prepare __pyx_mstate_global->__pyx_n_s_prepare
#define __pyx_n_s_preparseFn __pyx_mstate_global->__pyx_n_s_preparseFn
#define __pyx_kp_u_prev __pyx_mstate_global->__pyx_kp_u_prev
#define __pyx_n_s_print __pyx_mstate_global->__pyx_n_s_print
#define __pyx_n_s_printResults __pyx_mstate_global->__pyx_n_s_printResults
#define __pyx_n_s_print_2 __pyx_mstate_global->__pyx_n_s_print_2
#define __pyx_n_s_printable __pyx_mstate_global->__pyx_n_s_printable
#define __pyx_n_s_printables __pyx_mstate_global->__pyx_n_s_printables
#define __pyx_n_u_printables __pyx_mstate_global->__pyx_n_u_printables
#define __pyx_n_s_pstr __pyx_mstate_global->__pyx_n_s_pstr
#define __pyx_n_u_pstr __pyx_mstate_global->__pyx_n_u_pstr
#define __pyx_n_s_punc8bit __pyx_mstate_global->__pyx_n_s_punc8bit
#define __pyx_n_u_punc8bit __pyx_mstate_global->__pyx_n_u_punc8bit
#define __pyx_n_s_py_repr __pyx_mstate_global->__pyx_n_s_py_repr
#define __pyx_n_s_py_str __pyx_mstate_global->__pyx_n_s_py_str
#define __pyx_n_s_pyparsing_common __pyx_mstate_global->__pyx_n_s_pyparsing_common
#define __pyx_n_u_pyparsing_common __pyx_mstate_global->__pyx_n_u_pyparsing_common
#define __pyx_n_s_pyparsing_common_convertToDate __pyx_mstate_global->__pyx_n_s_pyparsing_common_convertToDate
#define __pyx_n_s_pyparsing_common_convertToDate_l __pyx_mstate_global->__pyx_n_s_pyparsing_common_convertToDate_l
#define __pyx_n_s_pyparsing_common_convertToDateti __pyx_mstate_global->__pyx_n_s_pyparsing_common_convertToDateti
#define __pyx_n_s_pyparsing_common_convertToDateti_2 __pyx_mstate_global->__pyx_n_s_pyparsing_common_convertToDateti_2
#define __pyx_n_s_pyparsing_common_lambda __pyx_mstate_global->__pyx_n_s_pyparsing_common_lambda
#define __pyx_n_s_pyparsing_common_lambda_locals_g __pyx_mstate_global->__pyx_n_s_pyparsing_common_lambda_locals_g
#define __pyx_n_s_pyparsing_common_stripHTMLTags __pyx_mstate_global->__pyx_n_s_pyparsing_common_stripHTMLTags
#define __pyx_n_s_pyparsing_test __pyx_mstate_global->__pyx_n_s_pyparsing_test
#define __pyx_n_s_pyparsing_test_TestParseResultsA __pyx_mstate_global->__pyx_n_s_pyparsing_test_TestParseResultsA
#define __pyx_n_s_pyparsing_test_TestParseResultsA_2 __pyx_mstate_global->__pyx_n_s_pyparsing_test_TestParseResultsA_2
#define __pyx_n_s_pyparsing_test_TestParseResultsA_3 __pyx_mstate_global->__pyx_n_s_pyparsing_test_TestParseResultsA_3
#define __pyx_n_s_pyparsing_test_TestParseResultsA_4 __pyx_mstate_global->__pyx_n_s_pyparsing_test_TestParseResultsA_4
#define __pyx_n_s_pyparsing_test_TestParseResultsA_5 __pyx_mstate_global->__pyx_n_s_pyparsing_test_TestParseResultsA_5
#define __pyx_n_s_pyparsing_test_TestParseResultsA_6 __pyx_mstate_global->__pyx_n_s_pyparsing_test_TestParseResultsA_6
#define __pyx_n_s_pyparsing_test_TestParseResultsA_7 __pyx_mstate_global->__pyx_n_s_pyparsing_test_TestParseResultsA_7
#define __pyx_n_s_pyparsing_test_reset_pyparsing_c __pyx_mstate_global->__pyx_n_s_pyparsing_test_reset_pyparsing_c
#define __pyx_n_s_pyparsing_test_reset_pyparsing_c_2 __pyx_mstate_global->__pyx_n_s_pyparsing_test_reset_pyparsing_c_2
#define __pyx_n_s_pyparsing_test_reset_pyparsing_c_3 __pyx_mstate_global->__pyx_n_s_pyparsing_test_reset_pyparsing_c_3
#define __pyx_n_s_pyparsing_test_reset_pyparsing_c_4 __pyx_mstate_global->__pyx_n_s_pyparsing_test_reset_pyparsing_c_4
#define __pyx_n_s_pyparsing_test_reset_pyparsing_c_5 __pyx_mstate_global->__pyx_n_s_pyparsing_test_reset_pyparsing_c_5
#define __pyx_n_s_pyparsing_test_reset_pyparsing_c_6 __pyx_mstate_global->__pyx_n_s_pyparsing_test_reset_pyparsing_c_6
#define __pyx_n_s_pyparsing_unicode __pyx_mstate_global->__pyx_n_s_pyparsing_unicode
#define __pyx_n_u_pyparsing_unicode __pyx_mstate_global->__pyx_n_u_pyparsing_unicode
#define __pyx_n_s_pyparsing_unicode_Arabic __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Arabic
#define __pyx_n_s_pyparsing_unicode_CJK __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_CJK
#define __pyx_n_s_pyparsing_unicode_Chinese __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Chinese
#define __pyx_n_s_pyparsing_unicode_Cyrillic __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Cyrillic
#define __pyx_n_s_pyparsing_unicode_Devanagari __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Devanagari
#define __pyx_n_s_pyparsing_unicode_Greek __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Greek
#define __pyx_n_s_pyparsing_unicode_Hebrew __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Hebrew
#define __pyx_n_s_pyparsing_unicode_Japanese __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Japanese
#define __pyx_n_s_pyparsing_unicode_Japanese_Hirag __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Japanese_Hirag
#define __pyx_n_s_pyparsing_unicode_Japanese_Kanji __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Japanese_Kanji
#define __pyx_n_s_pyparsing_unicode_Japanese_Katak __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Japanese_Katak
#define __pyx_n_s_pyparsing_unicode_Korean __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Korean
#define __pyx_n_s_pyparsing_unicode_Latin1 __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Latin1
#define __pyx_n_s_pyparsing_unicode_LatinA __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_LatinA
#define __pyx_n_s_pyparsing_unicode_LatinB __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_LatinB
#define __pyx_n_s_pyparsing_unicode_Thai __pyx_mstate_global->__pyx_n_s_pyparsing_unicode_Thai
#define __pyx_n_s_pythonStyleComment __pyx_mstate_global->__pyx_n_s_pythonStyleComment
#define __pyx_n_u_pythonStyleComment __pyx_mstate_global->__pyx_n_u_pythonStyleComment
#define __pyx_n_s_qualname __pyx_mstate_global->__pyx_n_s_qualname
#define __pyx_n_s_quoteChar __pyx_mstate_global->__pyx_n_s_quoteChar
#define __pyx_n_s_quoteCharLen __pyx_mstate_global->__pyx_n_s_quoteCharLen
#define __pyx_kp_u_quoteChar_cannot_be_the_empty_st __pyx_mstate_global->__pyx_kp_u_quoteChar_cannot_be_the_empty_st
#define __pyx_n_s_quotedString __pyx_mstate_global->__pyx_n_s_quotedString
#define __pyx_n_u_quotedString __pyx_mstate_global->__pyx_n_u_quotedString
#define __pyx_kp_u_quotedString_using_single_or_dou __pyx_mstate_global->__pyx_kp_u_quotedString_using_single_or_dou
#define __pyx_kp_u_quoted_string_starting_with __pyx_mstate_global->__pyx_kp_u_quoted_string_starting_with
#define __pyx_n_u_r __pyx_mstate_global->__pyx_n_u_r
#define __pyx_kp_u_r_2 __pyx_mstate_global->__pyx_kp_u_r_2
#define __pyx_kp_u_r_object_is_not_iterable __pyx_mstate_global->__pyx_kp_u_r_object_is_not_iterable
#define __pyx_n_s_radd __pyx_mstate_global->__pyx_n_s_radd
#define __pyx_n_s_rand __pyx_mstate_global->__pyx_n_s_rand
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_ranges __pyx_mstate_global->__pyx_n_s_ranges
#define __pyx_n_s_re __pyx_mstate_global->__pyx_n_s_re
#define __pyx_n_u_re __pyx_mstate_global->__pyx_n_u_re
#define __pyx_n_s_reBracketExpr __pyx_mstate_global->__pyx_n_s_reBracketExpr
#define __pyx_n_s_reString __pyx_mstate_global->__pyx_n_s_reString
#define __pyx_n_s_re_match __pyx_mstate_global->__pyx_n_s_re_match
#define __pyx_n_s_read __pyx_mstate_global->__pyx_n_s_read
#define __pyx_n_s_real __pyx_mstate_global->__pyx_n_s_real
#define __pyx_kp_u_real_number __pyx_mstate_global->__pyx_kp_u_real_number
#define __pyx_kp_u_real_number_with_scientific_nota __pyx_mstate_global->__pyx_kp_u_real_number_with_scientific_nota
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_ref __pyx_mstate_global->__pyx_n_s_ref
#define __pyx_n_s_register __pyx_mstate_global->__pyx_n_s_register
#define __pyx_n_s_remove __pyx_mstate_global->__pyx_n_s_remove
#define __pyx_n_s_removeQuotes __pyx_mstate_global->__pyx_n_s_removeQuotes
#define __pyx_n_u_removeQuotes __pyx_mstate_global->__pyx_n_u_removeQuotes
#define __pyx_n_s_removed __pyx_mstate_global->__pyx_n_s_removed
#define __pyx_n_s_rep __pyx_mstate_global->__pyx_n_s_rep
#define __pyx_n_s_repl __pyx_mstate_global->__pyx_n_s_repl
#define __pyx_n_s_replStr __pyx_mstate_global->__pyx_n_s_replStr
#define __pyx_n_s_replace __pyx_mstate_global->__pyx_n_s_replace
#define __pyx_n_s_replaceHTMLEntity __pyx_mstate_global->__pyx_n_s_replaceHTMLEntity
#define __pyx_n_u_replaceHTMLEntity __pyx_mstate_global->__pyx_n_u_replaceHTMLEntity
#define __pyx_n_s_replaceWith __pyx_mstate_global->__pyx_n_s_replaceWith
#define __pyx_n_u_replaceWith __pyx_mstate_global->__pyx_n_u_replaceWith
#define __pyx_n_s_replaceWith_locals_lambda __pyx_mstate_global->__pyx_n_s_replaceWith_locals_lambda
#define __pyx_n_s_repr __pyx_mstate_global->__pyx_n_s_repr
#define __pyx_n_s_repr_2 __pyx_mstate_global->__pyx_n_s_repr_2
#define __pyx_n_s_req __pyx_mstate_global->__pyx_n_s_req
#define __pyx_n_s_required __pyx_mstate_global->__pyx_n_s_required
#define __pyx_n_s_res __pyx_mstate_global->__pyx_n_s_res
#define __pyx_n_s_resTag __pyx_mstate_global->__pyx_n_s_resTag
#define __pyx_n_s_reset __pyx_mstate_global->__pyx_n_s_reset
#define __pyx_n_s_resetCache __pyx_mstate_global->__pyx_n_s_resetCache
#define __pyx_n_s_reset_pyparsing_context __pyx_mstate_global->__pyx_n_s_reset_pyparsing_context
#define __pyx_n_s_reset_stack __pyx_mstate_global->__pyx_n_s_reset_stack
#define __pyx_n_s_resname __pyx_mstate_global->__pyx_n_s_resname
#define __pyx_n_s_restOfLine __pyx_mstate_global->__pyx_n_s_restOfLine
#define __pyx_n_u_restOfLine __pyx_mstate_global->__pyx_n_u_restOfLine
#define __pyx_kp_u_rest_of_line __pyx_mstate_global->__pyx_kp_u_rest_of_line
#define __pyx_n_s_restore __pyx_mstate_global->__pyx_n_s_restore
#define __pyx_n_s_result __pyx_mstate_global->__pyx_n_s_result
#define __pyx_n_s_resultlist __pyx_mstate_global->__pyx_n_s_resultlist
#define __pyx_n_s_results __pyx_mstate_global->__pyx_n_s_results
#define __pyx_n_s_resultsName __pyx_mstate_global->__pyx_n_s_resultsName
#define __pyx_n_s_ret __pyx_mstate_global->__pyx_n_s_ret
#define __pyx_n_s_retTokens __pyx_mstate_global->__pyx_n_s_retTokens
#define __pyx_n_s_retToks __pyx_mstate_global->__pyx_n_s_retToks
#define __pyx_kp_u_ret_2 __pyx_mstate_global->__pyx_kp_u_ret_2
#define __pyx_n_s_ret_toks __pyx_mstate_global->__pyx_n_s_ret_toks
#define __pyx_n_s_retobj __pyx_mstate_global->__pyx_n_s_retobj
#define __pyx_n_s_retreat __pyx_mstate_global->__pyx_n_s_retreat
#define __pyx_n_s_returnString __pyx_mstate_global->__pyx_n_s_returnString
#define __pyx_n_s_reverse __pyx_mstate_global->__pyx_n_s_reverse
#define __pyx_n_s_reversed __pyx_mstate_global->__pyx_n_s_reversed
#define __pyx_n_s_reversed_2 __pyx_mstate_global->__pyx_n_s_reversed_2
#define __pyx_n_s_reversed_instring __pyx_mstate_global->__pyx_n_s_reversed_instring
#define __pyx_n_s_rfind __pyx_mstate_global->__pyx_n_s_rfind
#define __pyx_n_s_rightLeftAssoc __pyx_mstate_global->__pyx_n_s_rightLeftAssoc
#define __pyx_n_s_rmul __pyx_mstate_global->__pyx_n_s_rmul
#define __pyx_n_s_rne __pyx_mstate_global->__pyx_n_s_rne
#define __pyx_n_s_ror __pyx_mstate_global->__pyx_n_s_ror
#define __pyx_n_s_rpar __pyx_mstate_global->__pyx_n_s_rpar
#define __pyx_n_s_rpt __pyx_mstate_global->__pyx_n_s_rpt
#define __pyx_n_s_rr __pyx_mstate_global->__pyx_n_s_rr
#define __pyx_n_s_rstrip __pyx_mstate_global->__pyx_n_s_rstrip
#define __pyx_n_s_rsub __pyx_mstate_global->__pyx_n_s_rsub
#define __pyx_n_s_runTests __pyx_mstate_global->__pyx_n_s_runTests
#define __pyx_n_s_run_test_results __pyx_mstate_global->__pyx_n_s_run_test_results
#define __pyx_n_s_run_test_success __pyx_mstate_global->__pyx_n_s_run_test_success
#define __pyx_n_s_run_tests_report __pyx_mstate_global->__pyx_n_s_run_tests_report
#define __pyx_n_s_rxor __pyx_mstate_global->__pyx_n_s_rxor
#define __pyx_n_s_s __pyx_mstate_global->__pyx_n_s_s
#define __pyx_kp_u_s_10 __pyx_mstate_global->__pyx_kp_u_s_10
#define __pyx_kp_u_s_2 __pyx_mstate_global->__pyx_kp_u_s_2
#define __pyx_kp_u_s_3 __pyx_mstate_global->__pyx_kp_u_s_3
#define __pyx_kp_u_s_4 __pyx_mstate_global->__pyx_kp_u_s_4
#define __pyx_kp_u_s_5 __pyx_mstate_global->__pyx_kp_u_s_5
#define __pyx_kp_u_s_6 __pyx_mstate_global->__pyx_kp_u_s_6
#define __pyx_kp_u_s_7 __pyx_mstate_global->__pyx_kp_u_s_7
#define __pyx_kp_u_s_8 __pyx_mstate_global->__pyx_kp_u_s_8
#define __pyx_kp_u_s_9 __pyx_mstate_global->__pyx_kp_u_s_9
#define __pyx_kp_u_s_S __pyx_mstate_global->__pyx_kp_u_s_S
#define __pyx_kp_u_s_class __pyx_mstate_global->__pyx_kp_u_s_class
#define __pyx_n_s_s_m __pyx_mstate_global->__pyx_n_s_s_m
#define __pyx_n_s_s_pl_sl __pyx_mstate_global->__pyx_n_s_s_pl_sl
#define __pyx_kp_u_s_s_term __pyx_mstate_global->__pyx_kp_u_s_s_term
#define __pyx_kp_u_s_term __pyx_mstate_global->__pyx_kp_u_s_term
#define __pyx_n_s_save __pyx_mstate_global->__pyx_n_s_save
#define __pyx_n_s_saveAsList __pyx_mstate_global->__pyx_n_s_saveAsList
#define __pyx_n_s_save_context __pyx_mstate_global->__pyx_n_s_save_context
#define __pyx_n_s_savelist __pyx_mstate_global->__pyx_n_s_savelist
#define __pyx_n_s_scanString __pyx_mstate_global->__pyx_n_s_scanString
#define __pyx_n_s_sci_real __pyx_mstate_global->__pyx_n_s_sci_real
#define __pyx_n_s_se __pyx_mstate_global->__pyx_n_s_se
#define __pyx_n_s_searchString __pyx_mstate_global->__pyx_n_s_searchString
#define __pyx_kp_u_second_tuple_value_must_be_great __pyx_mstate_global->__pyx_kp_u_second_tuple_value_must_be_great
#define __pyx_n_s_seen __pyx_mstate_global->__pyx_n_s_seen
#define __pyx_n_u_select __pyx_mstate_global->__pyx_n_u_select
#define __pyx_n_s_selectToken __pyx_mstate_global->__pyx_n_s_selectToken
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_n_u_self __pyx_mstate_global->__pyx_n_u_self
#define __pyx_n_s_selfTag __pyx_mstate_global->__pyx_n_s_selfTag
#define __pyx_n_s_self_expr_parse __pyx_mstate_global->__pyx_n_s_self_expr_parse
#define __pyx_n_s_self_failOn_canParseNext __pyx_mstate_global->__pyx_n_s_self_failOn_canParseNext
#define __pyx_n_s_self_ignoreExpr_tryParse __pyx_mstate_global->__pyx_n_s_self_ignoreExpr_tryParse
#define __pyx_n_s_self_skip_ignorables __pyx_mstate_global->__pyx_n_s_self_skip_ignorables
#define __pyx_n_s_self_type __pyx_mstate_global->__pyx_n_s_self_type
#define __pyx_n_s_send __pyx_mstate_global->__pyx_n_s_send
#define __pyx_n_s_sep __pyx_mstate_global->__pyx_n_s_sep
#define __pyx_n_s_set __pyx_mstate_global->__pyx_n_s_set
#define __pyx_n_s_setAdaptiveMode __pyx_mstate_global->__pyx_n_s_setAdaptiveMode
#define __pyx_n_s_setBreak __pyx_mstate_global->__pyx_n_s_setBreak
#define __pyx_n_s_setDebug __pyx_mstate_global->__pyx_n_s_setDebug
#define __pyx_n_s_setDebugActions __pyx_mstate_global->__pyx_n_s_setDebugActions
#define __pyx_n_s_setDefaultKeywordChars __pyx_mstate_global->__pyx_n_s_setDefaultKeywordChars
#define __pyx_n_s_setDefaultWhitespaceChars __pyx_mstate_global->__pyx_n_s_setDefaultWhitespaceChars
#define __pyx_n_s_setFailAction __pyx_mstate_global->__pyx_n_s_setFailAction
#define __pyx_n_s_setName __pyx_mstate_global->__pyx_n_s_setName
#define __pyx_n_s_setOffset __pyx_mstate_global->__pyx_n_s_setOffset
#define __pyx_n_s_setParseAction __pyx_mstate_global->__pyx_n_s_setParseAction
#define __pyx_n_s_setResultsName __pyx_mstate_global->__pyx_n_s_setResultsName
#define __pyx_n_s_setResultsName_2 __pyx_mstate_global->__pyx_n_s_setResultsName_2
#define __pyx_n_s_setWhitespaceChars __pyx_mstate_global->__pyx_n_s_setWhitespaceChars
#define __pyx_n_s_set_name __pyx_mstate_global->__pyx_n_s_set_name
#define __pyx_n_s_set_trace __pyx_mstate_global->__pyx_n_s_set_trace
#define __pyx_n_s_setitem __pyx_mstate_global->__pyx_n_s_setitem
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_sglQuotedString __pyx_mstate_global->__pyx_n_s_sglQuotedString
#define __pyx_n_u_sglQuotedString __pyx_mstate_global->__pyx_n_u_sglQuotedString
#define __pyx_kp_u_short_IPv6_address __pyx_mstate_global->__pyx_kp_u_short_IPv6_address
#define __pyx_n_s_short_ipv6_address __pyx_mstate_global->__pyx_n_s_short_ipv6_address
#define __pyx_n_s_should_cache_incremental_succes __pyx_mstate_global->__pyx_n_s_should_cache_incremental_succes
#define __pyx_n_s_show_skip __pyx_mstate_global->__pyx_n_s_show_skip
#define __pyx_kp_u_signed_integer __pyx_mstate_global->__pyx_kp_u_signed_integer
#define __pyx_n_s_signed_integer_2 __pyx_mstate_global->__pyx_n_s_signed_integer_2
#define __pyx_n_s_simpleSQL __pyx_mstate_global->__pyx_n_s_simpleSQL
#define __pyx_n_s_singleArgBuiltins __pyx_mstate_global->__pyx_n_s_singleArgBuiltins
#define __pyx_n_s_singleChar __pyx_mstate_global->__pyx_n_s_singleChar
#define __pyx_n_s_size __pyx_mstate_global->__pyx_n_s_size
#define __pyx_n_s_skipIgnorables __pyx_mstate_global->__pyx_n_s_skipIgnorables
#define __pyx_n_s_skipWhitespace __pyx_mstate_global->__pyx_n_s_skipWhitespace
#define __pyx_kp_u_skipped __pyx_mstate_global->__pyx_kp_u_skipped
#define __pyx_n_s_skipped_2 __pyx_mstate_global->__pyx_n_s_skipped_2
#define __pyx_n_u_skipped_2 __pyx_mstate_global->__pyx_n_u_skipped_2
#define __pyx_n_s_skipped_3 __pyx_mstate_global->__pyx_n_s_skipped_3
#define __pyx_n_s_skipper __pyx_mstate_global->__pyx_n_s_skipper
#define __pyx_n_s_skipresult __pyx_mstate_global->__pyx_n_s_skipresult
#define __pyx_n_s_skiptext __pyx_mstate_global->__pyx_n_s_skiptext
#define __pyx_n_s_skipto_arg __pyx_mstate_global->__pyx_n_s_skipto_arg
#define __pyx_n_s_slots __pyx_mstate_global->__pyx_n_s_slots
#define __pyx_n_s_smExpr __pyx_mstate_global->__pyx_n_s_smExpr
#define __pyx_n_s_sort __pyx_mstate_global->__pyx_n_s_sort
#define __pyx_n_s_sorted __pyx_mstate_global->__pyx_n_s_sorted
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_split __pyx_mstate_global->__pyx_n_s_split
#define __pyx_n_s_splitlines __pyx_mstate_global->__pyx_n_s_splitlines
#define __pyx_n_s_splits __pyx_mstate_global->__pyx_n_s_splits
#define __pyx_n_s_srange __pyx_mstate_global->__pyx_n_s_srange
#define __pyx_n_u_srange __pyx_mstate_global->__pyx_n_u_srange
#define __pyx_n_s_srange_locals_genexpr __pyx_mstate_global->__pyx_n_s_srange_locals_genexpr
#define __pyx_n_s_srange_locals_lambda __pyx_mstate_global->__pyx_n_s_srange_locals_lambda
#define __pyx_n_s_srange_locals_lambda_locals_gene __pyx_mstate_global->__pyx_n_s_srange_locals_lambda_locals_gene
#define __pyx_n_s_src __pyx_mstate_global->__pyx_n_s_src
#define __pyx_n_s_sre_constants __pyx_mstate_global->__pyx_n_s_sre_constants
#define __pyx_n_s_stacklevel __pyx_mstate_global->__pyx_n_s_stacklevel
#define __pyx_n_s_start __pyx_mstate_global->__pyx_n_s_start
#define __pyx_n_u_start __pyx_mstate_global->__pyx_n_u_start
#define __pyx_n_s_startAction __pyx_mstate_global->__pyx_n_s_startAction
#define __pyx_n_s_startloc __pyx_mstate_global->__pyx_n_s_startloc
#define __pyx_n_s_startswith __pyx_mstate_global->__pyx_n_s_startswith
#define __pyx_n_s_state __pyx_mstate_global->__pyx_n_s_state
#define __pyx_n_s_staticmethod __pyx_mstate_global->__pyx_n_s_staticmethod
#define __pyx_n_s_stderr __pyx_mstate_global->__pyx_n_s_stderr
#define __pyx_n_s_stdout __pyx_mstate_global->__pyx_n_s_stdout
#define __pyx_n_s_still_reset_cache __pyx_mstate_global->__pyx_n_s_still_reset_cache
#define __pyx_n_s_stopOn __pyx_mstate_global->__pyx_n_s_stopOn
#define __pyx_n_s_str __pyx_mstate_global->__pyx_n_s_str
#define __pyx_n_s_strRepr __pyx_mstate_global->__pyx_n_s_strRepr
#define __pyx_n_s_str_2 __pyx_mstate_global->__pyx_n_s_str_2
#define __pyx_n_s_streamline __pyx_mstate_global->__pyx_n_s_streamline
#define __pyx_n_s_streamlined __pyx_mstate_global->__pyx_n_s_streamlined
#define __pyx_n_s_strg __pyx_mstate_global->__pyx_n_s_strg
#define __pyx_n_s_string __pyx_mstate_global->__pyx_n_s_string
#define __pyx_n_s_stringEnd __pyx_mstate_global->__pyx_n_s_stringEnd
#define __pyx_n_u_stringEnd __pyx_mstate_global->__pyx_n_u_stringEnd
#define __pyx_n_s_stringStart __pyx_mstate_global->__pyx_n_s_stringStart
#define __pyx_n_u_stringStart __pyx_mstate_global->__pyx_n_u_stringStart
#define __pyx_kp_u_string_enclosed_in_double_quotes __pyx_mstate_global->__pyx_kp_u_string_enclosed_in_double_quotes
#define __pyx_kp_u_string_enclosed_in_single_quotes __pyx_mstate_global->__pyx_kp_u_string_enclosed_in_single_quotes
#define __pyx_n_s_strip __pyx_mstate_global->__pyx_n_s_strip
#define __pyx_n_s_stripHTMLTags __pyx_mstate_global->__pyx_n_s_stripHTMLTags
#define __pyx_n_s_strptime __pyx_mstate_global->__pyx_n_s_strptime
#define __pyx_n_s_strs __pyx_mstate_global->__pyx_n_s_strs
#define __pyx_n_s_sub __pyx_mstate_global->__pyx_n_s_sub
#define __pyx_n_s_subRecCheckList __pyx_mstate_global->__pyx_n_s_subRecCheckList
#define __pyx_n_s_sub_2 __pyx_mstate_global->__pyx_n_s_sub_2
#define __pyx_n_s_success __pyx_mstate_global->__pyx_n_s_success
#define __pyx_n_s_successAction __pyx_mstate_global->__pyx_n_s_successAction
#define __pyx_n_s_suffix_len __pyx_mstate_global->__pyx_n_s_suffix_len
#define __pyx_n_s_suffix_lookup __pyx_mstate_global->__pyx_n_s_suffix_lookup
#define __pyx_n_s_sum __pyx_mstate_global->__pyx_n_s_sum
#define __pyx_kp_u_sum_len_sorted_reversed_list_tup __pyx_mstate_global->__pyx_kp_u_sum_len_sorted_reversed_list_tup
#define __pyx_n_s_super __pyx_mstate_global->__pyx_n_s_super
#define __pyx_n_s_suppress __pyx_mstate_global->__pyx_n_s_suppress
#define __pyx_n_s_suppress_GT __pyx_mstate_global->__pyx_n_s_suppress_GT
#define __pyx_n_s_suppress_LT __pyx_mstate_global->__pyx_n_s_suppress_LT
#define __pyx_n_s_symbols __pyx_mstate_global->__pyx_n_s_symbols
#define __pyx_n_s_sys __pyx_mstate_global->__pyx_n_s_sys
#define __pyx_n_s_system_version __pyx_mstate_global->__pyx_n_s_system_version
#define __pyx_n_s_t __pyx_mstate_global->__pyx_n_s_t
#define __pyx_kp_u_t_2 __pyx_mstate_global->__pyx_kp_u_t_2
#define __pyx_n_s_tableName __pyx_mstate_global->__pyx_n_s_tableName
#define __pyx_n_s_tableNameList __pyx_mstate_global->__pyx_n_s_tableNameList
#define __pyx_n_u_tables __pyx_mstate_global->__pyx_n_u_tables
#define __pyx_n_s_tag __pyx_mstate_global->__pyx_n_s_tag
#define __pyx_n_u_tag __pyx_mstate_global->__pyx_n_u_tag
#define __pyx_n_s_tagAttrName __pyx_mstate_global->__pyx_n_s_tagAttrName
#define __pyx_n_s_tagAttrValue __pyx_mstate_global->__pyx_n_s_tagAttrValue
#define __pyx_n_s_tagStr __pyx_mstate_global->__pyx_n_s_tagStr
#define __pyx_n_s_tag_body __pyx_mstate_global->__pyx_n_s_tag_body
#define __pyx_n_s_tb __pyx_mstate_global->__pyx_n_s_tb
#define __pyx_n_s_tb_next __pyx_mstate_global->__pyx_n_s_tb_next
#define __pyx_n_s_termName __pyx_mstate_global->__pyx_n_s_termName
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_testString __pyx_mstate_global->__pyx_n_s_testString
#define __pyx_n_s_test_expr __pyx_mstate_global->__pyx_n_s_test_expr
#define __pyx_n_s_test_string __pyx_mstate_global->__pyx_n_s_test_string
#define __pyx_n_s_tests __pyx_mstate_global->__pyx_n_s_tests
#define __pyx_n_s_tflat __pyx_mstate_global->__pyx_n_s_tflat
#define __pyx_n_s_theseTokens __pyx_mstate_global->__pyx_n_s_theseTokens
#define __pyx_n_s_thisExpr __pyx_mstate_global->__pyx_n_s_thisExpr
#define __pyx_n_s_thisFunc __pyx_mstate_global->__pyx_n_s_thisFunc
#define __pyx_n_s_thiscol __pyx_mstate_global->__pyx_n_s_thiscol
#define __pyx_n_s_thread __pyx_mstate_global->__pyx_n_s_thread
#define __pyx_n_s_threading __pyx_mstate_global->__pyx_n_s_threading
#define __pyx_n_s_throw __pyx_mstate_global->__pyx_n_s_throw
#define __pyx_n_s_throwException __pyx_mstate_global->__pyx_n_s_throwException
#define __pyx_n_s_title __pyx_mstate_global->__pyx_n_s_title
#define __pyx_n_s_tmp __pyx_mstate_global->__pyx_n_s_tmp
#define __pyx_n_s_tmpExprs __pyx_mstate_global->__pyx_n_s_tmpExprs
#define __pyx_n_s_tmpLoc __pyx_mstate_global->__pyx_n_s_tmpLoc
#define __pyx_n_s_tmpOpt __pyx_mstate_global->__pyx_n_s_tmpOpt
#define __pyx_n_s_tmpReqd __pyx_mstate_global->__pyx_n_s_tmpReqd
#define __pyx_n_s_tmploc __pyx_mstate_global->__pyx_n_s_tmploc
#define __pyx_n_s_tmptokens __pyx_mstate_global->__pyx_n_s_tmptokens
#define __pyx_n_s_to __pyx_mstate_global->__pyx_n_s_to
#define __pyx_n_s_toItem __pyx_mstate_global->__pyx_n_s_toItem
#define __pyx_n_s_to_symbols __pyx_mstate_global->__pyx_n_s_to_symbols
#define __pyx_n_s_tok __pyx_mstate_global->__pyx_n_s_tok
#define __pyx_n_s_tokenMap __pyx_mstate_global->__pyx_n_s_tokenMap
#define __pyx_n_u_tokenMap __pyx_mstate_global->__pyx_n_u_tokenMap
#define __pyx_n_s_tokenMap_locals_pa __pyx_mstate_global->__pyx_n_s_tokenMap_locals_pa
#define __pyx_n_s_tokenlist __pyx_mstate_global->__pyx_n_s_tokenlist
#define __pyx_n_s_tokens __pyx_mstate_global->__pyx_n_s_tokens
#define __pyx_n_s_tokensStart __pyx_mstate_global->__pyx_n_s_tokensStart
#define __pyx_n_s_toklist __pyx_mstate_global->__pyx_n_s_toklist
#define __pyx_n_s_tokn __pyx_mstate_global->__pyx_n_s_tokn
#define __pyx_n_s_toks __pyx_mstate_global->__pyx_n_s_toks
#define __pyx_n_s_traceParseAction __pyx_mstate_global->__pyx_n_s_traceParseAction
#define __pyx_n_u_traceParseAction __pyx_mstate_global->__pyx_n_u_traceParseAction
#define __pyx_n_s_traceParseAction_locals_z __pyx_mstate_global->__pyx_n_s_traceParseAction_locals_z
#define __pyx_n_s_traceback __pyx_mstate_global->__pyx_n_s_traceback
#define __pyx_n_u_traceback __pyx_mstate_global->__pyx_n_u_traceback
#define __pyx_n_s_traceback_2 __pyx_mstate_global->__pyx_n_s_traceback_2
#define __pyx_n_s_transformString __pyx_mstate_global->__pyx_n_s_transformString
#define __pyx_n_s_trim_arity __pyx_mstate_global->__pyx_n_s_trim_arity
#define __pyx_n_s_trim_arity_locals_extract_stack __pyx_mstate_global->__pyx_n_s_trim_arity_locals_extract_stack
#define __pyx_n_s_trim_arity_locals_extract_tb __pyx_mstate_global->__pyx_n_s_trim_arity_locals_extract_tb
#define __pyx_n_s_trim_arity_locals_lambda __pyx_mstate_global->__pyx_n_s_trim_arity_locals_lambda
#define __pyx_n_s_trim_arity_locals_wrapper __pyx_mstate_global->__pyx_n_s_trim_arity_locals_wrapper
#define __pyx_n_s_trim_traceback __pyx_mstate_global->__pyx_n_s_trim_traceback
#define __pyx_n_s_tryParse __pyx_mstate_global->__pyx_n_s_tryParse
#define __pyx_n_s_try_not_ender __pyx_mstate_global->__pyx_n_s_try_not_ender
#define __pyx_n_s_tup __pyx_mstate_global->__pyx_n_s_tup
#define __pyx_n_s_types __pyx_mstate_global->__pyx_n_s_types
#define __pyx_n_u_u __pyx_mstate_global->__pyx_n_u_u
#define __pyx_n_s_ungroup __pyx_mstate_global->__pyx_n_s_ungroup
#define __pyx_n_u_ungroup __pyx_mstate_global->__pyx_n_u_ungroup
#define __pyx_n_s_ungroup_locals_lambda __pyx_mstate_global->__pyx_n_s_ungroup_locals_lambda
#define __pyx_n_s_unichr __pyx_mstate_global->__pyx_n_s_unichr
#define __pyx_n_s_unicode __pyx_mstate_global->__pyx_n_s_unicode
#define __pyx_n_s_unicodeString __pyx_mstate_global->__pyx_n_s_unicodeString
#define __pyx_n_u_unicodeString __pyx_mstate_global->__pyx_n_u_unicodeString
#define __pyx_n_s_unicode_set __pyx_mstate_global->__pyx_n_s_unicode_set
#define __pyx_n_u_unicode_set __pyx_mstate_global->__pyx_n_u_unicode_set
#define __pyx_n_s_unicode_set__get_chars_for_range __pyx_mstate_global->__pyx_n_s_unicode_set__get_chars_for_range
#define __pyx_n_s_unicode_set_alphanums __pyx_mstate_global->__pyx_n_s_unicode_set_alphanums
#define __pyx_n_s_unicode_set_alphas __pyx_mstate_global->__pyx_n_s_unicode_set_alphas
#define __pyx_n_s_unicode_set_nums __pyx_mstate_global->__pyx_n_s_unicode_set_nums
#define __pyx_n_s_unicode_set_printables __pyx_mstate_global->__pyx_n_s_unicode_set_printables
#define __pyx_kp_u_unicode_string_literal __pyx_mstate_global->__pyx_kp_u_unicode_string_literal
#define __pyx_n_s_unquoteResults __pyx_mstate_global->__pyx_n_s_unquoteResults
#define __pyx_n_s_upcaseTokens __pyx_mstate_global->__pyx_n_s_upcaseTokens
#define __pyx_n_u_upcaseTokens __pyx_mstate_global->__pyx_n_u_upcaseTokens
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_update_dict __pyx_mstate_global->__pyx_n_s_update_dict
#define __pyx_n_s_update_furthest_loc_for_regex __pyx_mstate_global->__pyx_n_s_update_furthest_loc_for_regex
#define __pyx_n_s_update_wrapper __pyx_mstate_global->__pyx_n_s_update_wrapper
#define __pyx_n_s_upper __pyx_mstate_global->__pyx_n_s_upper
#define __pyx_n_s_usage __pyx_mstate_global->__pyx_n_s_usage
#define __pyx_n_s_usage_weight __pyx_mstate_global->__pyx_n_s_usage_weight
#define __pyx_n_s_useRegex __pyx_mstate_global->__pyx_n_s_useRegex
#define __pyx_kp_u_use_of_expression_without_follow __pyx_mstate_global->__pyx_kp_u_use_of_expression_without_follow
#define __pyx_kp_s_user_throwable_exception_thrown __pyx_mstate_global->__pyx_kp_s_user_throwable_exception_thrown
#define __pyx_n_s_ustr __pyx_mstate_global->__pyx_n_s_ustr
#define __pyx_n_u_utf8 __pyx_mstate_global->__pyx_n_u_utf8
#define __pyx_n_s_uuid __pyx_mstate_global->__pyx_n_s_uuid
#define __pyx_n_s_v __pyx_mstate_global->__pyx_n_s_v
#define __pyx_n_s_validate __pyx_mstate_global->__pyx_n_s_validate
#define __pyx_n_s_validateTrace __pyx_mstate_global->__pyx_n_s_validateTrace
#define __pyx_n_s_value __pyx_mstate_global->__pyx_n_s_value
#define __pyx_n_u_value __pyx_mstate_global->__pyx_n_u_value
#define __pyx_n_s_values __pyx_mstate_global->__pyx_n_s_values
#define __pyx_n_s_vars __pyx_mstate_global->__pyx_n_s_vars
#define __pyx_n_s_ve __pyx_mstate_global->__pyx_n_s_ve
#define __pyx_n_s_verbose __pyx_mstate_global->__pyx_n_s_verbose
#define __pyx_n_s_verbose_stacktrace __pyx_mstate_global->__pyx_n_s_verbose_stacktrace
#define __pyx_n_s_verifyCol __pyx_mstate_global->__pyx_n_s_verifyCol
#define __pyx_n_s_version __pyx_mstate_global->__pyx_n_s_version
#define __pyx_n_u_version __pyx_mstate_global->__pyx_n_u_version
#define __pyx_n_s_versionTime __pyx_mstate_global->__pyx_n_s_versionTime
#define __pyx_n_u_versionTime __pyx_mstate_global->__pyx_n_u_versionTime
#define __pyx_n_s_version_info __pyx_mstate_global->__pyx_n_s_version_info
#define __pyx_n_s_vlist __pyx_mstate_global->__pyx_n_s_vlist
#define __pyx_n_s_vv __pyx_mstate_global->__pyx_n_s_vv
#define __pyx_n_s_warn __pyx_mstate_global->__pyx_n_s_warn
#define __pyx_n_u_warn_2 __pyx_mstate_global->__pyx_n_u_warn_2
#define __pyx_n_s_warn_multiple_tokens_in_named_al __pyx_mstate_global->__pyx_n_s_warn_multiple_tokens_in_named_al
#define __pyx_n_u_warn_multiple_tokens_in_named_al __pyx_mstate_global->__pyx_n_u_warn_multiple_tokens_in_named_al
#define __pyx_n_s_warn_name_set_on_empty_Forward __pyx_mstate_global->__pyx_n_s_warn_name_set_on_empty_Forward
#define __pyx_n_u_warn_name_set_on_empty_Forward __pyx_mstate_global->__pyx_n_u_warn_name_set_on_empty_Forward
#define __pyx_n_s_warn_on_incremental_multiline_re __pyx_mstate_global->__pyx_n_s_warn_on_incremental_multiline_re
#define __pyx_n_s_warn_on_multiple_string_args_to __pyx_mstate_global->__pyx_n_s_warn_on_multiple_string_args_to
#define __pyx_n_s_warn_ungrouped_named_tokens_in_c __pyx_mstate_global->__pyx_n_s_warn_ungrouped_named_tokens_in_c
#define __pyx_n_u_warn_ungrouped_named_tokens_in_c __pyx_mstate_global->__pyx_n_u_warn_ungrouped_named_tokens_in_c
#define __pyx_n_s_warnings __pyx_mstate_global->__pyx_n_s_warnings
#define __pyx_n_s_weakref __pyx_mstate_global->__pyx_n_s_weakref
#define __pyx_n_s_whiteChars __pyx_mstate_global->__pyx_n_s_whiteChars
#define __pyx_n_s_whiteStrs __pyx_mstate_global->__pyx_n_s_whiteStrs
#define __pyx_n_s_whitespace __pyx_mstate_global->__pyx_n_s_whitespace
#define __pyx_n_s_withAttribute __pyx_mstate_global->__pyx_n_s_withAttribute
#define __pyx_n_u_withAttribute __pyx_mstate_global->__pyx_n_u_withAttribute
#define __pyx_n_s_withClass __pyx_mstate_global->__pyx_n_s_withClass
#define __pyx_n_u_withClass __pyx_mstate_global->__pyx_n_u_withClass
#define __pyx_kp_u_with_up_to __pyx_mstate_global->__pyx_kp_u_with_up_to
#define __pyx_n_s_wkref __pyx_mstate_global->__pyx_n_s_wkref
#define __pyx_n_s_wordChars __pyx_mstate_global->__pyx_n_s_wordChars
#define __pyx_n_s_wrapper __pyx_mstate_global->__pyx_n_s_wrapper
#define __pyx_n_u_wrapper __pyx_mstate_global->__pyx_n_u_wrapper
#define __pyx_n_s_wraps __pyx_mstate_global->__pyx_n_s_wraps
#define __pyx_n_s_write __pyx_mstate_global->__pyx_n_s_write
#define __pyx_n_s_ws __pyx_mstate_global->__pyx_n_s_ws
#define __pyx_n_s_ws_map __pyx_mstate_global->__pyx_n_s_ws_map
#define __pyx_n_s_wschar __pyx_mstate_global->__pyx_n_s_wschar
#define __pyx_n_s_wslit __pyx_mstate_global->__pyx_n_s_wslit
#define __pyx_n_s_wt __pyx_mstate_global->__pyx_n_s_wt
#define __pyx_n_s_xml __pyx_mstate_global->__pyx_n_s_xml
#define __pyx_n_s_xmlBodyText __pyx_mstate_global->__pyx_n_s_xmlBodyText
#define __pyx_n_s_xml_escape __pyx_mstate_global->__pyx_n_s_xml_escape
#define __pyx_n_s_xml_escape_locals_genexpr __pyx_mstate_global->__pyx_n_s_xml_escape_locals_genexpr
#define __pyx_n_s_xor __pyx_mstate_global->__pyx_n_s_xor
#define __pyx_n_s_xrange __pyx_mstate_global->__pyx_n_s_xrange
#define __pyx_n_s_z __pyx_mstate_global->__pyx_n_s_z
#define __pyx_n_s_zip __pyx_mstate_global->__pyx_n_s_zip
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_2 __pyx_mstate_global->__pyx_int_2
#define __pyx_int_3 __pyx_mstate_global->__pyx_int_3
#define __pyx_int_4 __pyx_mstate_global->__pyx_int_4
#define __pyx_int_5 __pyx_mstate_global->__pyx_int_5
#define __pyx_int_6 __pyx_mstate_global->__pyx_int_6
#define __pyx_int_7 __pyx_mstate_global->__pyx_int_7
#define __pyx_int_8 __pyx_mstate_global->__pyx_int_8
#define __pyx_int_11 __pyx_mstate_global->__pyx_int_11
#define __pyx_int_16 __pyx_mstate_global->__pyx_int_16
#define __pyx_int_32 __pyx_mstate_global->__pyx_int_32
#define __pyx_int_92 __pyx_mstate_global->__pyx_int_92
#define __pyx_int_126 __pyx_mstate_global->__pyx_int_126
#define __pyx_int_128 __pyx_mstate_global->__pyx_int_128
#define __pyx_int_160 __pyx_mstate_global->__pyx_int_160
#define __pyx_int_255 __pyx_mstate_global->__pyx_int_255
#define __pyx_int_256 __pyx_mstate_global->__pyx_int_256
#define __pyx_int_383 __pyx_mstate_global->__pyx_int_383
#define __pyx_int_384 __pyx_mstate_global->__pyx_int_384
#define __pyx_int_591 __pyx_mstate_global->__pyx_int_591
#define __pyx_int_880 __pyx_mstate_global->__pyx_int_880
#define __pyx_int_1023 __pyx_mstate_global->__pyx_int_1023
#define __pyx_int_1024 __pyx_mstate_global->__pyx_int_1024
#define __pyx_int_1279 __pyx_mstate_global->__pyx_int_1279
#define __pyx_int_1328 __pyx_mstate_global->__pyx_int_1328
#define __pyx_int_1424 __pyx_mstate_global->__pyx_int_1424
#define __pyx_int_1535 __pyx_mstate_global->__pyx_int_1535
#define __pyx_int_1536 __pyx_mstate_global->__pyx_int_1536
#define __pyx_int_1563 __pyx_mstate_global->__pyx_int_1563
#define __pyx_int_1566 __pyx_mstate_global->__pyx_int_1566
#define __pyx_int_1791 __pyx_mstate_global->__pyx_int_1791
#define __pyx_int_1792 __pyx_mstate_global->__pyx_int_1792
#define __pyx_int_1919 __pyx_mstate_global->__pyx_int_1919
#define __pyx_int_2304 __pyx_mstate_global->__pyx_int_2304
#define __pyx_int_2431 __pyx_mstate_global->__pyx_int_2431
#define __pyx_int_3585 __pyx_mstate_global->__pyx_int_3585
#define __pyx_int_3642 __pyx_mstate_global->__pyx_int_3642
#define __pyx_int_3647 __pyx_mstate_global->__pyx_int_3647
#define __pyx_int_3675 __pyx_mstate_global->__pyx_int_3675
#define __pyx_int_4352 __pyx_mstate_global->__pyx_int_4352
#define __pyx_int_4607 __pyx_mstate_global->__pyx_int_4607
#define __pyx_int_7936 __pyx_mstate_global->__pyx_int_7936
#define __pyx_int_7957 __pyx_mstate_global->__pyx_int_7957
#define __pyx_int_7960 __pyx_mstate_global->__pyx_int_7960
#define __pyx_int_7965 __pyx_mstate_global->__pyx_int_7965
#define __pyx_int_7968 __pyx_mstate_global->__pyx_int_7968
#define __pyx_int_8005 __pyx_mstate_global->__pyx_int_8005
#define __pyx_int_8008 __pyx_mstate_global->__pyx_int_8008
#define __pyx_int_8013 __pyx_mstate_global->__pyx_int_8013
#define __pyx_int_8016 __pyx_mstate_global->__pyx_int_8016
#define __pyx_int_8023 __pyx_mstate_global->__pyx_int_8023
#define __pyx_int_8025 __pyx_mstate_global->__pyx_int_8025
#define __pyx_int_8027 __pyx_mstate_global->__pyx_int_8027
#define __pyx_int_8029 __pyx_mstate_global->__pyx_int_8029
#define __pyx_int_8031 __pyx_mstate_global->__pyx_int_8031
#define __pyx_int_8061 __pyx_mstate_global->__pyx_int_8061
#define __pyx_int_8064 __pyx_mstate_global->__pyx_int_8064
#define __pyx_int_8116 __pyx_mstate_global->__pyx_int_8116
#define __pyx_int_8118 __pyx_mstate_global->__pyx_int_8118
#define __pyx_int_8132 __pyx_mstate_global->__pyx_int_8132
#define __pyx_int_8134 __pyx_mstate_global->__pyx_int_8134
#define __pyx_int_8147 __pyx_mstate_global->__pyx_int_8147
#define __pyx_int_8150 __pyx_mstate_global->__pyx_int_8150
#define __pyx_int_8155 __pyx_mstate_global->__pyx_int_8155
#define __pyx_int_8157 __pyx_mstate_global->__pyx_int_8157
#define __pyx_int_8175 __pyx_mstate_global->__pyx_int_8175
#define __pyx_int_8178 __pyx_mstate_global->__pyx_int_8178
#define __pyx_int_8180 __pyx_mstate_global->__pyx_int_8180
#define __pyx_int_8182 __pyx_mstate_global->__pyx_int_8182
#define __pyx_int_8190 __pyx_mstate_global->__pyx_int_8190
#define __pyx_int_12288 __pyx_mstate_global->__pyx_int_12288
#define __pyx_int_12351 __pyx_mstate_global->__pyx_int_12351
#define __pyx_int_12352 __pyx_mstate_global->__pyx_int_12352
#define __pyx_int_12447 __pyx_mstate_global->__pyx_int_12447
#define __pyx_int_12448 __pyx_mstate_global->__pyx_int_12448
#define __pyx_int_12543 __pyx_mstate_global->__pyx_int_12543
#define __pyx_int_12592 __pyx_mstate_global->__pyx_int_12592
#define __pyx_int_12687 __pyx_mstate_global->__pyx_int_12687
#define __pyx_int_19968 __pyx_mstate_global->__pyx_int_19968
#define __pyx_int_40895 __pyx_mstate_global->__pyx_int_40895
#define __pyx_int_40959 __pyx_mstate_global->__pyx_int_40959
#define __pyx_int_43232 __pyx_mstate_global->__pyx_int_43232
#define __pyx_int_43263 __pyx_mstate_global->__pyx_int_43263
#define __pyx_int_43360 __pyx_mstate_global->__pyx_int_43360
#define __pyx_int_43391 __pyx_mstate_global->__pyx_int_43391
#define __pyx_int_44032 __pyx_mstate_global->__pyx_int_44032
#define __pyx_int_55215 __pyx_mstate_global->__pyx_int_55215
#define __pyx_int_55216 __pyx_mstate_global->__pyx_int_55216
#define __pyx_int_55295 __pyx_mstate_global->__pyx_int_55295
#define __pyx_int_neg_1 __pyx_mstate_global->__pyx_int_neg_1
#define __pyx_slice_ __pyx_mstate_global->__pyx_slice_
#define __pyx_tuple__8 __pyx_mstate_global->__pyx_tuple__8
#define __pyx_slice__20 __pyx_mstate_global->__pyx_slice__20
#define __pyx_slice__21 __pyx_mstate_global->__pyx_slice__21
#define __pyx_slice__37 __pyx_mstate_global->__pyx_slice__37
#define __pyx_slice__47 __pyx_mstate_global->__pyx_slice__47
#define __pyx_slice__55 __pyx_mstate_global->__pyx_slice__55
#define __pyx_slice__64 __pyx_mstate_global->__pyx_slice__64
#define __pyx_slice__70 __pyx_mstate_global->__pyx_slice__70
#define __pyx_slice__81 __pyx_mstate_global->__pyx_slice__81
#define __pyx_tuple__18 __pyx_mstate_global->__pyx_tuple__18
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__32 __pyx_mstate_global->__pyx_tuple__32
#define __pyx_tuple__36 __pyx_mstate_global->__pyx_tuple__36
#define __pyx_tuple__38 __pyx_mstate_global->__pyx_tuple__38
#define __pyx_tuple__39 __pyx_mstate_global->__pyx_tuple__39
#define __pyx_tuple__41 __pyx_mstate_global->__pyx_tuple__41
#define __pyx_tuple__42 __pyx_mstate_global->__pyx_tuple__42
#define __pyx_tuple__44 __pyx_mstate_global->__pyx_tuple__44
#define __pyx_tuple__46 __pyx_mstate_global->__pyx_tuple__46
#define __pyx_tuple__48 __pyx_mstate_global->__pyx_tuple__48
#define __pyx_tuple__50 __pyx_mstate_global->__pyx_tuple__50
#define __pyx_tuple__51 __pyx_mstate_global->__pyx_tuple__51
#define __pyx_tuple__54 __pyx_mstate_global->__pyx_tuple__54
#define __pyx_tuple__56 __pyx_mstate_global->__pyx_tuple__56
#define __pyx_tuple__57 __pyx_mstate_global->__pyx_tuple__57
#define __pyx_tuple__58 __pyx_mstate_global->__pyx_tuple__58
#define __pyx_tuple__59 __pyx_mstate_global->__pyx_tuple__59
#define __pyx_tuple__60 __pyx_mstate_global->__pyx_tuple__60
#define __pyx_tuple__61 __pyx_mstate_global->__pyx_tuple__61
#define __pyx_tuple__62 __pyx_mstate_global->__pyx_tuple__62
#define __pyx_tuple__68 __pyx_mstate_global->__pyx_tuple__68
#define __pyx_tuple__69 __pyx_mstate_global->__pyx_tuple__69
#define __pyx_tuple__71 __pyx_mstate_global->__pyx_tuple__71
#define __pyx_tuple__73 __pyx_mstate_global->__pyx_tuple__73
#define __pyx_tuple__75 __pyx_mstate_global->__pyx_tuple__75
#define __pyx_tuple__76 __pyx_mstate_global->__pyx_tuple__76
#define __pyx_tuple__77 __pyx_mstate_global->__pyx_tuple__77
#define __pyx_tuple__78 __pyx_mstate_global->__pyx_tuple__78
#define __pyx_tuple__82 __pyx_mstate_global->__pyx_tuple__82
#define __pyx_tuple__84 __pyx_mstate_global->__pyx_tuple__84
#define __pyx_tuple__85 __pyx_mstate_global->__pyx_tuple__85
#define __pyx_tuple__86 __pyx_mstate_global->__pyx_tuple__86
#define __pyx_tuple__87 __pyx_mstate_global->__pyx_tuple__87
#define __pyx_tuple__88 __pyx_mstate_global->__pyx_tuple__88
#define __pyx_tuple__92 __pyx_mstate_global->__pyx_tuple__92
#define __pyx_tuple__93 __pyx_mstate_global->__pyx_tuple__93
#define __pyx_codeobj__9 __pyx_mstate_global->__pyx_codeobj__9
#define __pyx_slice__141 __pyx_mstate_global->__pyx_slice__141
#define __pyx_tuple__101 __pyx_mstate_global->__pyx_tuple__101
#define __pyx_tuple__103 __pyx_mstate_global->__pyx_tuple__103
#define __pyx_tuple__106 __pyx_mstate_global->__pyx_tuple__106
#define __pyx_tuple__109 __pyx_mstate_global->__pyx_tuple__109
#define __pyx_tuple__120 __pyx_mstate_global->__pyx_tuple__120
#define __pyx_tuple__123 __pyx_mstate_global->__pyx_tuple__123
#define __pyx_tuple__125 __pyx_mstate_global->__pyx_tuple__125
#define __pyx_tuple__127 __pyx_mstate_global->__pyx_tuple__127
#define __pyx_tuple__128 __pyx_mstate_global->__pyx_tuple__128
#define __pyx_tuple__130 __pyx_mstate_global->__pyx_tuple__130
#define __pyx_tuple__132 __pyx_mstate_global->__pyx_tuple__132
#define __pyx_tuple__133 __pyx_mstate_global->__pyx_tuple__133
#define __pyx_tuple__134 __pyx_mstate_global->__pyx_tuple__134
#define __pyx_tuple__135 __pyx_mstate_global->__pyx_tuple__135
#define __pyx_tuple__137 __pyx_mstate_global->__pyx_tuple__137
#define __pyx_tuple__139 __pyx_mstate_global->__pyx_tuple__139
#define __pyx_tuple__142 __pyx_mstate_global->__pyx_tuple__142
#define __pyx_tuple__146 __pyx_mstate_global->__pyx_tuple__146
#define __pyx_tuple__149 __pyx_mstate_global->__pyx_tuple__149
#define __pyx_tuple__151 __pyx_mstate_global->__pyx_tuple__151
#define __pyx_tuple__153 __pyx_mstate_global->__pyx_tuple__153
#define __pyx_tuple__155 __pyx_mstate_global->__pyx_tuple__155
#define __pyx_tuple__156 __pyx_mstate_global->__pyx_tuple__156
#define __pyx_tuple__157 __pyx_mstate_global->__pyx_tuple__157
#define __pyx_tuple__158 __pyx_mstate_global->__pyx_tuple__158
#define __pyx_tuple__159 __pyx_mstate_global->__pyx_tuple__159
#define __pyx_tuple__160 __pyx_mstate_global->__pyx_tuple__160
#define __pyx_tuple__162 __pyx_mstate_global->__pyx_tuple__162
#define __pyx_tuple__167 __pyx_mstate_global->__pyx_tuple__167
#define __pyx_tuple__171 __pyx_mstate_global->__pyx_tuple__171
#define __pyx_tuple__175 __pyx_mstate_global->__pyx_tuple__175
#define __pyx_tuple__177 __pyx_mstate_global->__pyx_tuple__177
#define __pyx_tuple__178 __pyx_mstate_global->__pyx_tuple__178
#define __pyx_tuple__180 __pyx_mstate_global->__pyx_tuple__180
#define __pyx_tuple__181 __pyx_mstate_global->__pyx_tuple__181
#define __pyx_tuple__183 __pyx_mstate_global->__pyx_tuple__183
#define __pyx_tuple__184 __pyx_mstate_global->__pyx_tuple__184
#define __pyx_tuple__185 __pyx_mstate_global->__pyx_tuple__185
#define __pyx_tuple__187 __pyx_mstate_global->__pyx_tuple__187
#define __pyx_tuple__188 __pyx_mstate_global->__pyx_tuple__188
#define __pyx_tuple__190 __pyx_mstate_global->__pyx_tuple__190
#define __pyx_tuple__192 __pyx_mstate_global->__pyx_tuple__192
#define __pyx_tuple__194 __pyx_mstate_global->__pyx_tuple__194
#define __pyx_tuple__196 __pyx_mstate_global->__pyx_tuple__196
#define __pyx_tuple__198 __pyx_mstate_global->__pyx_tuple__198
#define __pyx_tuple__200 __pyx_mstate_global->__pyx_tuple__200
#define __pyx_tuple__202 __pyx_mstate_global->__pyx_tuple__202
#define __pyx_tuple__203 __pyx_mstate_global->__pyx_tuple__203
#define __pyx_tuple__206 __pyx_mstate_global->__pyx_tuple__206
#define __pyx_tuple__207 __pyx_mstate_global->__pyx_tuple__207
#define __pyx_tuple__208 __pyx_mstate_global->__pyx_tuple__208
#define __pyx_tuple__210 __pyx_mstate_global->__pyx_tuple__210
#define __pyx_tuple__214 __pyx_mstate_global->__pyx_tuple__214
#define __pyx_tuple__215 __pyx_mstate_global->__pyx_tuple__215
#define __pyx_tuple__216 __pyx_mstate_global->__pyx_tuple__216
#define __pyx_tuple__218 __pyx_mstate_global->__pyx_tuple__218
#define __pyx_tuple__219 __pyx_mstate_global->__pyx_tuple__219
#define __pyx_tuple__221 __pyx_mstate_global->__pyx_tuple__221
#define __pyx_tuple__223 __pyx_mstate_global->__pyx_tuple__223
#define __pyx_tuple__225 __pyx_mstate_global->__pyx_tuple__225
#define __pyx_tuple__227 __pyx_mstate_global->__pyx_tuple__227
#define __pyx_tuple__234 __pyx_mstate_global->__pyx_tuple__234
#define __pyx_tuple__241 __pyx_mstate_global->__pyx_tuple__241
#define __pyx_tuple__243 __pyx_mstate_global->__pyx_tuple__243
#define __pyx_tuple__245 __pyx_mstate_global->__pyx_tuple__245
#define __pyx_tuple__247 __pyx_mstate_global->__pyx_tuple__247
#define __pyx_tuple__249 __pyx_mstate_global->__pyx_tuple__249
#define __pyx_tuple__252 __pyx_mstate_global->__pyx_tuple__252
#define __pyx_tuple__254 __pyx_mstate_global->__pyx_tuple__254
#define __pyx_tuple__256 __pyx_mstate_global->__pyx_tuple__256
#define __pyx_tuple__258 __pyx_mstate_global->__pyx_tuple__258
#define __pyx_tuple__262 __pyx_mstate_global->__pyx_tuple__262
#define __pyx_tuple__264 __pyx_mstate_global->__pyx_tuple__264
#define __pyx_tuple__265 __pyx_mstate_global->__pyx_tuple__265
#define __pyx_tuple__267 __pyx_mstate_global->__pyx_tuple__267
#define __pyx_tuple__269 __pyx_mstate_global->__pyx_tuple__269
#define __pyx_tuple__271 __pyx_mstate_global->__pyx_tuple__271
#define __pyx_tuple__273 __pyx_mstate_global->__pyx_tuple__273
#define __pyx_tuple__274 __pyx_mstate_global->__pyx_tuple__274
#define __pyx_tuple__276 __pyx_mstate_global->__pyx_tuple__276
#define __pyx_tuple__278 __pyx_mstate_global->__pyx_tuple__278
#define __pyx_tuple__280 __pyx_mstate_global->__pyx_tuple__280
#define __pyx_tuple__281 __pyx_mstate_global->__pyx_tuple__281
#define __pyx_tuple__284 __pyx_mstate_global->__pyx_tuple__284
#define __pyx_tuple__288 __pyx_mstate_global->__pyx_tuple__288
#define __pyx_tuple__290 __pyx_mstate_global->__pyx_tuple__290
#define __pyx_tuple__292 __pyx_mstate_global->__pyx_tuple__292
#define __pyx_tuple__294 __pyx_mstate_global->__pyx_tuple__294
#define __pyx_tuple__296 __pyx_mstate_global->__pyx_tuple__296
#define __pyx_tuple__298 __pyx_mstate_global->__pyx_tuple__298
#define __pyx_tuple__300 __pyx_mstate_global->__pyx_tuple__300
#define __pyx_tuple__302 __pyx_mstate_global->__pyx_tuple__302
#define __pyx_tuple__304 __pyx_mstate_global->__pyx_tuple__304
#define __pyx_tuple__306 __pyx_mstate_global->__pyx_tuple__306
#define __pyx_tuple__307 __pyx_mstate_global->__pyx_tuple__307
#define __pyx_tuple__308 __pyx_mstate_global->__pyx_tuple__308
#define __pyx_tuple__310 __pyx_mstate_global->__pyx_tuple__310
#define __pyx_tuple__312 __pyx_mstate_global->__pyx_tuple__312
#define __pyx_tuple__314 __pyx_mstate_global->__pyx_tuple__314
#define __pyx_tuple__319 __pyx_mstate_global->__pyx_tuple__319
#define __pyx_tuple__320 __pyx_mstate_global->__pyx_tuple__320
#define __pyx_tuple__321 __pyx_mstate_global->__pyx_tuple__321
#define __pyx_tuple__329 __pyx_mstate_global->__pyx_tuple__329
#define __pyx_tuple__330 __pyx_mstate_global->__pyx_tuple__330
#define __pyx_tuple__337 __pyx_mstate_global->__pyx_tuple__337
#define __pyx_tuple__338 __pyx_mstate_global->__pyx_tuple__338
#define __pyx_tuple__340 __pyx_mstate_global->__pyx_tuple__340
#define __pyx_tuple__342 __pyx_mstate_global->__pyx_tuple__342
#define __pyx_tuple__344 __pyx_mstate_global->__pyx_tuple__344
#define __pyx_tuple__347 __pyx_mstate_global->__pyx_tuple__347
#define __pyx_tuple__349 __pyx_mstate_global->__pyx_tuple__349
#define __pyx_tuple__350 __pyx_mstate_global->__pyx_tuple__350
#define __pyx_tuple__353 __pyx_mstate_global->__pyx_tuple__353
#define __pyx_tuple__355 __pyx_mstate_global->__pyx_tuple__355
#define __pyx_tuple__357 __pyx_mstate_global->__pyx_tuple__357
#define __pyx_tuple__359 __pyx_mstate_global->__pyx_tuple__359
#define __pyx_tuple__361 __pyx_mstate_global->__pyx_tuple__361
#define __pyx_tuple__363 __pyx_mstate_global->__pyx_tuple__363
#define __pyx_tuple__365 __pyx_mstate_global->__pyx_tuple__365
#define __pyx_tuple__367 __pyx_mstate_global->__pyx_tuple__367
#define __pyx_tuple__369 __pyx_mstate_global->__pyx_tuple__369
#define __pyx_tuple__372 __pyx_mstate_global->__pyx_tuple__372
#define __pyx_tuple__374 __pyx_mstate_global->__pyx_tuple__374
#define __pyx_tuple__376 __pyx_mstate_global->__pyx_tuple__376
#define __pyx_tuple__379 __pyx_mstate_global->__pyx_tuple__379
#define __pyx_tuple__381 __pyx_mstate_global->__pyx_tuple__381
#define __pyx_tuple__383 __pyx_mstate_global->__pyx_tuple__383
#define __pyx_tuple__386 __pyx_mstate_global->__pyx_tuple__386
#define __pyx_tuple__388 __pyx_mstate_global->__pyx_tuple__388
#define __pyx_tuple__389 __pyx_mstate_global->__pyx_tuple__389
#define __pyx_tuple__391 __pyx_mstate_global->__pyx_tuple__391
#define __pyx_tuple__392 __pyx_mstate_global->__pyx_tuple__392
#define __pyx_tuple__394 __pyx_mstate_global->__pyx_tuple__394
#define __pyx_tuple__395 __pyx_mstate_global->__pyx_tuple__395
#define __pyx_tuple__397 __pyx_mstate_global->__pyx_tuple__397
#define __pyx_tuple__399 __pyx_mstate_global->__pyx_tuple__399
#define __pyx_tuple__404 __pyx_mstate_global->__pyx_tuple__404
#define __pyx_tuple__415 __pyx_mstate_global->__pyx_tuple__415
#define __pyx_tuple__420 __pyx_mstate_global->__pyx_tuple__420
#define __pyx_tuple__424 __pyx_mstate_global->__pyx_tuple__424
#define __pyx_tuple__426 __pyx_mstate_global->__pyx_tuple__426
#define __pyx_tuple__432 __pyx_mstate_global->__pyx_tuple__432
#define __pyx_tuple__434 __pyx_mstate_global->__pyx_tuple__434
#define __pyx_tuple__441 __pyx_mstate_global->__pyx_tuple__441
#define __pyx_tuple__443 __pyx_mstate_global->__pyx_tuple__443
#define __pyx_tuple__445 __pyx_mstate_global->__pyx_tuple__445
#define __pyx_tuple__446 __pyx_mstate_global->__pyx_tuple__446
#define __pyx_tuple__448 __pyx_mstate_global->__pyx_tuple__448
#define __pyx_tuple__451 __pyx_mstate_global->__pyx_tuple__451
#define __pyx_tuple__457 __pyx_mstate_global->__pyx_tuple__457
#define __pyx_tuple__462 __pyx_mstate_global->__pyx_tuple__462
#define __pyx_tuple__465 __pyx_mstate_global->__pyx_tuple__465
#define __pyx_tuple__470 __pyx_mstate_global->__pyx_tuple__470
#define __pyx_tuple__472 __pyx_mstate_global->__pyx_tuple__472
#define __pyx_tuple__474 __pyx_mstate_global->__pyx_tuple__474
#define __pyx_tuple__476 __pyx_mstate_global->__pyx_tuple__476
#define __pyx_tuple__478 __pyx_mstate_global->__pyx_tuple__478
#define __pyx_tuple__479 __pyx_mstate_global->__pyx_tuple__479
#define __pyx_tuple__481 __pyx_mstate_global->__pyx_tuple__481
#define __pyx_tuple__483 __pyx_mstate_global->__pyx_tuple__483
#define __pyx_tuple__485 __pyx_mstate_global->__pyx_tuple__485
#define __pyx_tuple__487 __pyx_mstate_global->__pyx_tuple__487
#define __pyx_tuple__488 __pyx_mstate_global->__pyx_tuple__488
#define __pyx_tuple__490 __pyx_mstate_global->__pyx_tuple__490
#define __pyx_tuple__491 __pyx_mstate_global->__pyx_tuple__491
#define __pyx_tuple__493 __pyx_mstate_global->__pyx_tuple__493
#define __pyx_tuple__497 __pyx_mstate_global->__pyx_tuple__497
#define __pyx_tuple__499 __pyx_mstate_global->__pyx_tuple__499
#define __pyx_tuple__501 __pyx_mstate_global->__pyx_tuple__501
#define __pyx_tuple__502 __pyx_mstate_global->__pyx_tuple__502
#define __pyx_tuple__505 __pyx_mstate_global->__pyx_tuple__505
#define __pyx_tuple__507 __pyx_mstate_global->__pyx_tuple__507
#define __pyx_tuple__508 __pyx_mstate_global->__pyx_tuple__508
#define __pyx_tuple__529 __pyx_mstate_global->__pyx_tuple__529
#define __pyx_tuple__531 __pyx_mstate_global->__pyx_tuple__531
#define __pyx_tuple__532 __pyx_mstate_global->__pyx_tuple__532
#define __pyx_tuple__535 __pyx_mstate_global->__pyx_tuple__535
#define __pyx_tuple__537 __pyx_mstate_global->__pyx_tuple__537
#define __pyx_tuple__539 __pyx_mstate_global->__pyx_tuple__539
#define __pyx_tuple__549 __pyx_mstate_global->__pyx_tuple__549
#define __pyx_tuple__553 __pyx_mstate_global->__pyx_tuple__553
#define __pyx_tuple__555 __pyx_mstate_global->__pyx_tuple__555
#define __pyx_tuple__558 __pyx_mstate_global->__pyx_tuple__558
#define __pyx_tuple__560 __pyx_mstate_global->__pyx_tuple__560
#define __pyx_tuple__563 __pyx_mstate_global->__pyx_tuple__563
#define __pyx_tuple__565 __pyx_mstate_global->__pyx_tuple__565
#define __pyx_tuple__567 __pyx_mstate_global->__pyx_tuple__567
#define __pyx_tuple__569 __pyx_mstate_global->__pyx_tuple__569
#define __pyx_tuple__572 __pyx_mstate_global->__pyx_tuple__572
#define __pyx_tuple__574 __pyx_mstate_global->__pyx_tuple__574
#define __pyx_tuple__576 __pyx_mstate_global->__pyx_tuple__576
#define __pyx_tuple__579 __pyx_mstate_global->__pyx_tuple__579
#define __pyx_tuple__584 __pyx_mstate_global->__pyx_tuple__584
#define __pyx_tuple__589 __pyx_mstate_global->__pyx_tuple__589
#define __pyx_tuple__593 __pyx_mstate_global->__pyx_tuple__593
#define __pyx_tuple__595 __pyx_mstate_global->__pyx_tuple__595
#define __pyx_tuple__596 __pyx_mstate_global->__pyx_tuple__596
#define __pyx_tuple__604 __pyx_mstate_global->__pyx_tuple__604
#define __pyx_tuple__608 __pyx_mstate_global->__pyx_tuple__608
#define __pyx_tuple__614 __pyx_mstate_global->__pyx_tuple__614
#define __pyx_tuple__616 __pyx_mstate_global->__pyx_tuple__616
#define __pyx_tuple__619 __pyx_mstate_global->__pyx_tuple__619
#define __pyx_tuple__622 __pyx_mstate_global->__pyx_tuple__622
#define __pyx_tuple__624 __pyx_mstate_global->__pyx_tuple__624
#define __pyx_tuple__626 __pyx_mstate_global->__pyx_tuple__626
#define __pyx_tuple__628 __pyx_mstate_global->__pyx_tuple__628
#define __pyx_tuple__632 __pyx_mstate_global->__pyx_tuple__632
#define __pyx_tuple__634 __pyx_mstate_global->__pyx_tuple__634
#define __pyx_tuple__636 __pyx_mstate_global->__pyx_tuple__636
#define __pyx_tuple__640 __pyx_mstate_global->__pyx_tuple__640
#define __pyx_tuple__644 __pyx_mstate_global->__pyx_tuple__644
#define __pyx_tuple__645 __pyx_mstate_global->__pyx_tuple__645
#define __pyx_tuple__648 __pyx_mstate_global->__pyx_tuple__648
#define __pyx_tuple__650 __pyx_mstate_global->__pyx_tuple__650
#define __pyx_tuple__653 __pyx_mstate_global->__pyx_tuple__653
#define __pyx_tuple__655 __pyx_mstate_global->__pyx_tuple__655
#define __pyx_tuple__667 __pyx_mstate_global->__pyx_tuple__667
#define __pyx_tuple__669 __pyx_mstate_global->__pyx_tuple__669
#define __pyx_tuple__671 __pyx_mstate_global->__pyx_tuple__671
#define __pyx_tuple__676 __pyx_mstate_global->__pyx_tuple__676
#define __pyx_tuple__680 __pyx_mstate_global->__pyx_tuple__680
#define __pyx_tuple__681 __pyx_mstate_global->__pyx_tuple__681
#define __pyx_tuple__682 __pyx_mstate_global->__pyx_tuple__682
#define __pyx_tuple__684 __pyx_mstate_global->__pyx_tuple__684
#define __pyx_tuple__687 __pyx_mstate_global->__pyx_tuple__687
#define __pyx_tuple__689 __pyx_mstate_global->__pyx_tuple__689
#define __pyx_tuple__691 __pyx_mstate_global->__pyx_tuple__691
#define __pyx_tuple__692 __pyx_mstate_global->__pyx_tuple__692
#define __pyx_tuple__694 __pyx_mstate_global->__pyx_tuple__694
#define __pyx_tuple__696 __pyx_mstate_global->__pyx_tuple__696
#define __pyx_tuple__698 __pyx_mstate_global->__pyx_tuple__698
#define __pyx_tuple__700 __pyx_mstate_global->__pyx_tuple__700
#define __pyx_tuple__702 __pyx_mstate_global->__pyx_tuple__702
#define __pyx_tuple__704 __pyx_mstate_global->__pyx_tuple__704
#define __pyx_tuple__705 __pyx_mstate_global->__pyx_tuple__705
#define __pyx_tuple__707 __pyx_mstate_global->__pyx_tuple__707
#define __pyx_tuple__709 __pyx_mstate_global->__pyx_tuple__709
#define __pyx_tuple__711 __pyx_mstate_global->__pyx_tuple__711
#define __pyx_tuple__713 __pyx_mstate_global->__pyx_tuple__713
#define __pyx_tuple__714 __pyx_mstate_global->__pyx_tuple__714
#define __pyx_tuple__715 __pyx_mstate_global->__pyx_tuple__715
#define __pyx_tuple__716 __pyx_mstate_global->__pyx_tuple__716
#define __pyx_tuple__717 __pyx_mstate_global->__pyx_tuple__717
#define __pyx_tuple__719 __pyx_mstate_global->__pyx_tuple__719
#define __pyx_tuple__720 __pyx_mstate_global->__pyx_tuple__720
#define __pyx_tuple__722 __pyx_mstate_global->__pyx_tuple__722
#define __pyx_tuple__723 __pyx_mstate_global->__pyx_tuple__723
#define __pyx_tuple__724 __pyx_mstate_global->__pyx_tuple__724
#define __pyx_tuple__725 __pyx_mstate_global->__pyx_tuple__725
#define __pyx_tuple__726 __pyx_mstate_global->__pyx_tuple__726
#define __pyx_tuple__727 __pyx_mstate_global->__pyx_tuple__727
#define __pyx_tuple__728 __pyx_mstate_global->__pyx_tuple__728
#define __pyx_tuple__730 __pyx_mstate_global->__pyx_tuple__730
#define __pyx_tuple__732 __pyx_mstate_global->__pyx_tuple__732
#define __pyx_tuple__735 __pyx_mstate_global->__pyx_tuple__735
#define __pyx_tuple__737 __pyx_mstate_global->__pyx_tuple__737
#define __pyx_tuple__739 __pyx_mstate_global->__pyx_tuple__739
#define __pyx_tuple__740 __pyx_mstate_global->__pyx_tuple__740
#define __pyx_tuple__741 __pyx_mstate_global->__pyx_tuple__741
#define __pyx_tuple__744 __pyx_mstate_global->__pyx_tuple__744
#define __pyx_tuple__745 __pyx_mstate_global->__pyx_tuple__745
#define __pyx_tuple__746 __pyx_mstate_global->__pyx_tuple__746
#define __pyx_tuple__748 __pyx_mstate_global->__pyx_tuple__748
#define __pyx_tuple__750 __pyx_mstate_global->__pyx_tuple__750
#define __pyx_tuple__752 __pyx_mstate_global->__pyx_tuple__752
#define __pyx_tuple__753 __pyx_mstate_global->__pyx_tuple__753
#define __pyx_tuple__754 __pyx_mstate_global->__pyx_tuple__754
#define __pyx_tuple__756 __pyx_mstate_global->__pyx_tuple__756
#define __pyx_tuple__757 __pyx_mstate_global->__pyx_tuple__757
#define __pyx_tuple__758 __pyx_mstate_global->__pyx_tuple__758
#define __pyx_tuple__759 __pyx_mstate_global->__pyx_tuple__759
#define __pyx_tuple__760 __pyx_mstate_global->__pyx_tuple__760
#define __pyx_tuple__761 __pyx_mstate_global->__pyx_tuple__761
#define __pyx_tuple__762 __pyx_mstate_global->__pyx_tuple__762
#define __pyx_tuple__764 __pyx_mstate_global->__pyx_tuple__764
#define __pyx_tuple__766 __pyx_mstate_global->__pyx_tuple__766
#define __pyx_tuple__767 __pyx_mstate_global->__pyx_tuple__767
#define __pyx_tuple__769 __pyx_mstate_global->__pyx_tuple__769
#define __pyx_tuple__772 __pyx_mstate_global->__pyx_tuple__772
#define __pyx_tuple__775 __pyx_mstate_global->__pyx_tuple__775
#define __pyx_tuple__777 __pyx_mstate_global->__pyx_tuple__777
#define __pyx_tuple__778 __pyx_mstate_global->__pyx_tuple__778
#define __pyx_tuple__779 __pyx_mstate_global->__pyx_tuple__779
#define __pyx_tuple__781 __pyx_mstate_global->__pyx_tuple__781
#define __pyx_tuple__782 __pyx_mstate_global->__pyx_tuple__782
#define __pyx_tuple__783 __pyx_mstate_global->__pyx_tuple__783
#define __pyx_tuple__784 __pyx_mstate_global->__pyx_tuple__784
#define __pyx_tuple__785 __pyx_mstate_global->__pyx_tuple__785
#define __pyx_tuple__787 __pyx_mstate_global->__pyx_tuple__787
#define __pyx_tuple__788 __pyx_mstate_global->__pyx_tuple__788
#define __pyx_tuple__790 __pyx_mstate_global->__pyx_tuple__790
#define __pyx_tuple__791 __pyx_mstate_global->__pyx_tuple__791
#define __pyx_tuple__792 __pyx_mstate_global->__pyx_tuple__792
#define __pyx_tuple__793 __pyx_mstate_global->__pyx_tuple__793
#define __pyx_tuple__794 __pyx_mstate_global->__pyx_tuple__794
#define __pyx_tuple__796 __pyx_mstate_global->__pyx_tuple__796
#define __pyx_tuple__798 __pyx_mstate_global->__pyx_tuple__798
#define __pyx_tuple__800 __pyx_mstate_global->__pyx_tuple__800
#define __pyx_tuple__801 __pyx_mstate_global->__pyx_tuple__801
#define __pyx_tuple__803 __pyx_mstate_global->__pyx_tuple__803
#define __pyx_tuple__804 __pyx_mstate_global->__pyx_tuple__804
#define __pyx_tuple__806 __pyx_mstate_global->__pyx_tuple__806
#define __pyx_tuple__808 __pyx_mstate_global->__pyx_tuple__808
#define __pyx_tuple__809 __pyx_mstate_global->__pyx_tuple__809
#define __pyx_tuple__810 __pyx_mstate_global->__pyx_tuple__810
#define __pyx_tuple__816 __pyx_mstate_global->__pyx_tuple__816
#define __pyx_tuple__817 __pyx_mstate_global->__pyx_tuple__817
#define __pyx_tuple__818 __pyx_mstate_global->__pyx_tuple__818
#define __pyx_tuple__819 __pyx_mstate_global->__pyx_tuple__819
#define __pyx_tuple__820 __pyx_mstate_global->__pyx_tuple__820
#define __pyx_tuple__821 __pyx_mstate_global->__pyx_tuple__821
#define __pyx_tuple__822 __pyx_mstate_global->__pyx_tuple__822
#define __pyx_tuple__823 __pyx_mstate_global->__pyx_tuple__823
#define __pyx_tuple__824 __pyx_mstate_global->__pyx_tuple__824
#define __pyx_tuple__825 __pyx_mstate_global->__pyx_tuple__825
#define __pyx_tuple__826 __pyx_mstate_global->__pyx_tuple__826
#define __pyx_tuple__827 __pyx_mstate_global->__pyx_tuple__827
#define __pyx_tuple__828 __pyx_mstate_global->__pyx_tuple__828
#define __pyx_tuple__829 __pyx_mstate_global->__pyx_tuple__829
#define __pyx_tuple__830 __pyx_mstate_global->__pyx_tuple__830
#define __pyx_tuple__831 __pyx_mstate_global->__pyx_tuple__831
#define __pyx_tuple__832 __pyx_mstate_global->__pyx_tuple__832
#define __pyx_tuple__833 __pyx_mstate_global->__pyx_tuple__833
#define __pyx_tuple__834 __pyx_mstate_global->__pyx_tuple__834
#define __pyx_tuple__835 __pyx_mstate_global->__pyx_tuple__835
#define __pyx_tuple__836 __pyx_mstate_global->__pyx_tuple__836
#define __pyx_tuple__837 __pyx_mstate_global->__pyx_tuple__837
#define __pyx_tuple__838 __pyx_mstate_global->__pyx_tuple__838
#define __pyx_tuple__839 __pyx_mstate_global->__pyx_tuple__839
#define __pyx_tuple__840 __pyx_mstate_global->__pyx_tuple__840
#define __pyx_tuple__841 __pyx_mstate_global->__pyx_tuple__841
#define __pyx_tuple__842 __pyx_mstate_global->__pyx_tuple__842
#define __pyx_tuple__843 __pyx_mstate_global->__pyx_tuple__843
#define __pyx_tuple__844 __pyx_mstate_global->__pyx_tuple__844
#define __pyx_tuple__845 __pyx_mstate_global->__pyx_tuple__845
#define __pyx_tuple__846 __pyx_mstate_global->__pyx_tuple__846
#define __pyx_tuple__847 __pyx_mstate_global->__pyx_tuple__847
#define __pyx_tuple__848 __pyx_mstate_global->__pyx_tuple__848
#define __pyx_tuple__849 __pyx_mstate_global->__pyx_tuple__849
#define __pyx_tuple__850 __pyx_mstate_global->__pyx_tuple__850
#define __pyx_tuple__851 __pyx_mstate_global->__pyx_tuple__851
#define __pyx_tuple__852 __pyx_mstate_global->__pyx_tuple__852
#define __pyx_tuple__853 __pyx_mstate_global->__pyx_tuple__853
#define __pyx_tuple__854 __pyx_mstate_global->__pyx_tuple__854
#define __pyx_tuple__855 __pyx_mstate_global->__pyx_tuple__855
#define __pyx_tuple__870 __pyx_mstate_global->__pyx_tuple__870
#define __pyx_tuple__874 __pyx_mstate_global->__pyx_tuple__874
#define __pyx_tuple__876 __pyx_mstate_global->__pyx_tuple__876
#define __pyx_tuple__878 __pyx_mstate_global->__pyx_tuple__878
#define __pyx_tuple__879 __pyx_mstate_global->__pyx_tuple__879
#define __pyx_tuple__881 __pyx_mstate_global->__pyx_tuple__881
#define __pyx_tuple__883 __pyx_mstate_global->__pyx_tuple__883
#define __pyx_tuple__884 __pyx_mstate_global->__pyx_tuple__884
#define __pyx_tuple__885 __pyx_mstate_global->__pyx_tuple__885
#define __pyx_tuple__886 __pyx_mstate_global->__pyx_tuple__886
#define __pyx_tuple__887 __pyx_mstate_global->__pyx_tuple__887
#define __pyx_tuple__888 __pyx_mstate_global->__pyx_tuple__888
#define __pyx_tuple__889 __pyx_mstate_global->__pyx_tuple__889
#define __pyx_tuple__890 __pyx_mstate_global->__pyx_tuple__890
#define __pyx_tuple__891 __pyx_mstate_global->__pyx_tuple__891
#define __pyx_tuple__892 __pyx_mstate_global->__pyx_tuple__892
#define __pyx_codeobj__24 __pyx_mstate_global->__pyx_codeobj__24
#define __pyx_codeobj__33 __pyx_mstate_global->__pyx_codeobj__33
#define __pyx_codeobj__40 __pyx_mstate_global->__pyx_codeobj__40
#define __pyx_codeobj__43 __pyx_mstate_global->__pyx_codeobj__43
#define __pyx_codeobj__45 __pyx_mstate_global->__pyx_codeobj__45
#define __pyx_codeobj__49 __pyx_mstate_global->__pyx_codeobj__49
#define __pyx_codeobj__52 __pyx_mstate_global->__pyx_codeobj__52
#define __pyx_codeobj__53 __pyx_mstate_global->__pyx_codeobj__53
#define __pyx_codeobj__63 __pyx_mstate_global->__pyx_codeobj__63
#define __pyx_codeobj__72 __pyx_mstate_global->__pyx_codeobj__72
#define __pyx_codeobj__74 __pyx_mstate_global->__pyx_codeobj__74
#define __pyx_codeobj__83 __pyx_mstate_global->__pyx_codeobj__83
#define __pyx_codeobj__89 __pyx_mstate_global->__pyx_codeobj__89
#define __pyx_codeobj__90 __pyx_mstate_global->__pyx_codeobj__90
#define __pyx_codeobj__121 __pyx_mstate_global->__pyx_codeobj__121
#define __pyx_codeobj__124 __pyx_mstate_global->__pyx_codeobj__124
#define __pyx_codeobj__126 __pyx_mstate_global->__pyx_codeobj__126
#define __pyx_codeobj__129 __pyx_mstate_global->__pyx_codeobj__129
#define __pyx_codeobj__131 __pyx_mstate_global->__pyx_codeobj__131
#define __pyx_codeobj__138 __pyx_mstate_global->__pyx_codeobj__138
#define __pyx_codeobj__140 __pyx_mstate_global->__pyx_codeobj__140
#define __pyx_codeobj__143 __pyx_mstate_global->__pyx_codeobj__143
#define __pyx_codeobj__152 __pyx_mstate_global->__pyx_codeobj__152
#define __pyx_codeobj__154 __pyx_mstate_global->__pyx_codeobj__154
#define __pyx_codeobj__161 __pyx_mstate_global->__pyx_codeobj__161
#define __pyx_codeobj__163 __pyx_mstate_global->__pyx_codeobj__163
#define __pyx_codeobj__164 __pyx_mstate_global->__pyx_codeobj__164
#define __pyx_codeobj__165 __pyx_mstate_global->__pyx_codeobj__165
#define __pyx_codeobj__168 __pyx_mstate_global->__pyx_codeobj__168
#define __pyx_codeobj__169 __pyx_mstate_global->__pyx_codeobj__169
#define __pyx_codeobj__170 __pyx_mstate_global->__pyx_codeobj__170
#define __pyx_codeobj__172 __pyx_mstate_global->__pyx_codeobj__172
#define __pyx_codeobj__173 __pyx_mstate_global->__pyx_codeobj__173
#define __pyx_codeobj__174 __pyx_mstate_global->__pyx_codeobj__174
#define __pyx_codeobj__176 __pyx_mstate_global->__pyx_codeobj__176
#define __pyx_codeobj__179 __pyx_mstate_global->__pyx_codeobj__179
#define __pyx_codeobj__182 __pyx_mstate_global->__pyx_codeobj__182
#define __pyx_codeobj__186 __pyx_mstate_global->__pyx_codeobj__186
#define __pyx_codeobj__189 __pyx_mstate_global->__pyx_codeobj__189
#define __pyx_codeobj__191 __pyx_mstate_global->__pyx_codeobj__191
#define __pyx_codeobj__193 __pyx_mstate_global->__pyx_codeobj__193
#define __pyx_codeobj__195 __pyx_mstate_global->__pyx_codeobj__195
#define __pyx_codeobj__197 __pyx_mstate_global->__pyx_codeobj__197
#define __pyx_codeobj__199 __pyx_mstate_global->__pyx_codeobj__199
#define __pyx_codeobj__201 __pyx_mstate_global->__pyx_codeobj__201
#define __pyx_codeobj__204 __pyx_mstate_global->__pyx_codeobj__204
#define __pyx_codeobj__205 __pyx_mstate_global->__pyx_codeobj__205
#define __pyx_codeobj__209 __pyx_mstate_global->__pyx_codeobj__209
#define __pyx_codeobj__211 __pyx_mstate_global->__pyx_codeobj__211
#define __pyx_codeobj__212 __pyx_mstate_global->__pyx_codeobj__212
#define __pyx_codeobj__213 __pyx_mstate_global->__pyx_codeobj__213
#define __pyx_codeobj__217 __pyx_mstate_global->__pyx_codeobj__217
#define __pyx_codeobj__220 __pyx_mstate_global->__pyx_codeobj__220
#define __pyx_codeobj__222 __pyx_mstate_global->__pyx_codeobj__222
#define __pyx_codeobj__224 __pyx_mstate_global->__pyx_codeobj__224
#define __pyx_codeobj__226 __pyx_mstate_global->__pyx_codeobj__226
#define __pyx_codeobj__228 __pyx_mstate_global->__pyx_codeobj__228
#define __pyx_codeobj__229 __pyx_mstate_global->__pyx_codeobj__229
#define __pyx_codeobj__230 __pyx_mstate_global->__pyx_codeobj__230
#define __pyx_codeobj__231 __pyx_mstate_global->__pyx_codeobj__231
#define __pyx_codeobj__232 __pyx_mstate_global->__pyx_codeobj__232
#define __pyx_codeobj__233 __pyx_mstate_global->__pyx_codeobj__233
#define __pyx_codeobj__235 __pyx_mstate_global->__pyx_codeobj__235
#define __pyx_codeobj__236 __pyx_mstate_global->__pyx_codeobj__236
#define __pyx_codeobj__237 __pyx_mstate_global->__pyx_codeobj__237
#define __pyx_codeobj__238 __pyx_mstate_global->__pyx_codeobj__238
#define __pyx_codeobj__239 __pyx_mstate_global->__pyx_codeobj__239
#define __pyx_codeobj__240 __pyx_mstate_global->__pyx_codeobj__240
#define __pyx_codeobj__242 __pyx_mstate_global->__pyx_codeobj__242
#define __pyx_codeobj__244 __pyx_mstate_global->__pyx_codeobj__244
#define __pyx_codeobj__246 __pyx_mstate_global->__pyx_codeobj__246
#define __pyx_codeobj__248 __pyx_mstate_global->__pyx_codeobj__248
#define __pyx_codeobj__250 __pyx_mstate_global->__pyx_codeobj__250
#define __pyx_codeobj__251 __pyx_mstate_global->__pyx_codeobj__251
#define __pyx_codeobj__253 __pyx_mstate_global->__pyx_codeobj__253
#define __pyx_codeobj__255 __pyx_mstate_global->__pyx_codeobj__255
#define __pyx_codeobj__257 __pyx_mstate_global->__pyx_codeobj__257
#define __pyx_codeobj__259 __pyx_mstate_global->__pyx_codeobj__259
#define __pyx_codeobj__260 __pyx_mstate_global->__pyx_codeobj__260
#define __pyx_codeobj__261 __pyx_mstate_global->__pyx_codeobj__261
#define __pyx_codeobj__263 __pyx_mstate_global->__pyx_codeobj__263
#define __pyx_codeobj__266 __pyx_mstate_global->__pyx_codeobj__266
#define __pyx_codeobj__268 __pyx_mstate_global->__pyx_codeobj__268
#define __pyx_codeobj__270 __pyx_mstate_global->__pyx_codeobj__270
#define __pyx_codeobj__272 __pyx_mstate_global->__pyx_codeobj__272
#define __pyx_codeobj__275 __pyx_mstate_global->__pyx_codeobj__275
#define __pyx_codeobj__277 __pyx_mstate_global->__pyx_codeobj__277
#define __pyx_codeobj__279 __pyx_mstate_global->__pyx_codeobj__279
#define __pyx_codeobj__282 __pyx_mstate_global->__pyx_codeobj__282
#define __pyx_codeobj__283 __pyx_mstate_global->__pyx_codeobj__283
#define __pyx_codeobj__285 __pyx_mstate_global->__pyx_codeobj__285
#define __pyx_codeobj__286 __pyx_mstate_global->__pyx_codeobj__286
#define __pyx_codeobj__287 __pyx_mstate_global->__pyx_codeobj__287
#define __pyx_codeobj__289 __pyx_mstate_global->__pyx_codeobj__289
#define __pyx_codeobj__291 __pyx_mstate_global->__pyx_codeobj__291
#define __pyx_codeobj__293 __pyx_mstate_global->__pyx_codeobj__293
#define __pyx_codeobj__295 __pyx_mstate_global->__pyx_codeobj__295
#define __pyx_codeobj__297 __pyx_mstate_global->__pyx_codeobj__297
#define __pyx_codeobj__299 __pyx_mstate_global->__pyx_codeobj__299
#define __pyx_codeobj__301 __pyx_mstate_global->__pyx_codeobj__301
#define __pyx_codeobj__303 __pyx_mstate_global->__pyx_codeobj__303
#define __pyx_codeobj__305 __pyx_mstate_global->__pyx_codeobj__305
#define __pyx_codeobj__309 __pyx_mstate_global->__pyx_codeobj__309
#define __pyx_codeobj__311 __pyx_mstate_global->__pyx_codeobj__311
#define __pyx_codeobj__313 __pyx_mstate_global->__pyx_codeobj__313
#define __pyx_codeobj__315 __pyx_mstate_global->__pyx_codeobj__315
#define __pyx_codeobj__316 __pyx_mstate_global->__pyx_codeobj__316
#define __pyx_codeobj__317 __pyx_mstate_global->__pyx_codeobj__317
#define __pyx_codeobj__318 __pyx_mstate_global->__pyx_codeobj__318
#define __pyx_codeobj__322 __pyx_mstate_global->__pyx_codeobj__322
#define __pyx_codeobj__323 __pyx_mstate_global->__pyx_codeobj__323
#define __pyx_codeobj__324 __pyx_mstate_global->__pyx_codeobj__324
#define __pyx_codeobj__325 __pyx_mstate_global->__pyx_codeobj__325
#define __pyx_codeobj__326 __pyx_mstate_global->__pyx_codeobj__326
#define __pyx_codeobj__327 __pyx_mstate_global->__pyx_codeobj__327
#define __pyx_codeobj__328 __pyx_mstate_global->__pyx_codeobj__328
#define __pyx_codeobj__331 __pyx_mstate_global->__pyx_codeobj__331
#define __pyx_codeobj__332 __pyx_mstate_global->__pyx_codeobj__332
#define __pyx_codeobj__333 __pyx_mstate_global->__pyx_codeobj__333
#define __pyx_codeobj__334 __pyx_mstate_global->__pyx_codeobj__334
#define __pyx_codeobj__335 __pyx_mstate_global->__pyx_codeobj__335
#define __pyx_codeobj__336 __pyx_mstate_global->__pyx_codeobj__336
#define __pyx_codeobj__341 __pyx_mstate_global->__pyx_codeobj__341
#define __pyx_codeobj__343 __pyx_mstate_global->__pyx_codeobj__343
#define __pyx_codeobj__345 __pyx_mstate_global->__pyx_codeobj__345
#define __pyx_codeobj__346 __pyx_mstate_global->__pyx_codeobj__346
#define __pyx_codeobj__348 __pyx_mstate_global->__pyx_codeobj__348
#define __pyx_codeobj__351 __pyx_mstate_global->__pyx_codeobj__351
#define __pyx_codeobj__352 __pyx_mstate_global->__pyx_codeobj__352
#define __pyx_codeobj__354 __pyx_mstate_global->__pyx_codeobj__354
#define __pyx_codeobj__356 __pyx_mstate_global->__pyx_codeobj__356
#define __pyx_codeobj__358 __pyx_mstate_global->__pyx_codeobj__358
#define __pyx_codeobj__360 __pyx_mstate_global->__pyx_codeobj__360
#define __pyx_codeobj__362 __pyx_mstate_global->__pyx_codeobj__362
#define __pyx_codeobj__364 __pyx_mstate_global->__pyx_codeobj__364
#define __pyx_codeobj__366 __pyx_mstate_global->__pyx_codeobj__366
#define __pyx_codeobj__368 __pyx_mstate_global->__pyx_codeobj__368
#define __pyx_codeobj__370 __pyx_mstate_global->__pyx_codeobj__370
#define __pyx_codeobj__371 __pyx_mstate_global->__pyx_codeobj__371
#define __pyx_codeobj__373 __pyx_mstate_global->__pyx_codeobj__373
#define __pyx_codeobj__375 __pyx_mstate_global->__pyx_codeobj__375
#define __pyx_codeobj__377 __pyx_mstate_global->__pyx_codeobj__377
#define __pyx_codeobj__378 __pyx_mstate_global->__pyx_codeobj__378
#define __pyx_codeobj__380 __pyx_mstate_global->__pyx_codeobj__380
#define __pyx_codeobj__382 __pyx_mstate_global->__pyx_codeobj__382
#define __pyx_codeobj__384 __pyx_mstate_global->__pyx_codeobj__384
#define __pyx_codeobj__385 __pyx_mstate_global->__pyx_codeobj__385
#define __pyx_codeobj__387 __pyx_mstate_global->__pyx_codeobj__387
#define __pyx_codeobj__390 __pyx_mstate_global->__pyx_codeobj__390
#define __pyx_codeobj__393 __pyx_mstate_global->__pyx_codeobj__393
#define __pyx_codeobj__396 __pyx_mstate_global->__pyx_codeobj__396
#define __pyx_codeobj__398 __pyx_mstate_global->__pyx_codeobj__398
#define __pyx_codeobj__400 __pyx_mstate_global->__pyx_codeobj__400
#define __pyx_codeobj__401 __pyx_mstate_global->__pyx_codeobj__401
#define __pyx_codeobj__402 __pyx_mstate_global->__pyx_codeobj__402
#define __pyx_codeobj__403 __pyx_mstate_global->__pyx_codeobj__403
#define __pyx_codeobj__405 __pyx_mstate_global->__pyx_codeobj__405
#define __pyx_codeobj__406 __pyx_mstate_global->__pyx_codeobj__406
#define __pyx_codeobj__407 __pyx_mstate_global->__pyx_codeobj__407
#define __pyx_codeobj__408 __pyx_mstate_global->__pyx_codeobj__408
#define __pyx_codeobj__409 __pyx_mstate_global->__pyx_codeobj__409
#define __pyx_codeobj__410 __pyx_mstate_global->__pyx_codeobj__410
#define __pyx_codeobj__411 __pyx_mstate_global->__pyx_codeobj__411
#define __pyx_codeobj__412 __pyx_mstate_global->__pyx_codeobj__412
#define __pyx_codeobj__413 __pyx_mstate_global->__pyx_codeobj__413
#define __pyx_codeobj__414 __pyx_mstate_global->__pyx_codeobj__414
#define __pyx_codeobj__416 __pyx_mstate_global->__pyx_codeobj__416
#define __pyx_codeobj__417 __pyx_mstate_global->__pyx_codeobj__417
#define __pyx_codeobj__418 __pyx_mstate_global->__pyx_codeobj__418
#define __pyx_codeobj__419 __pyx_mstate_global->__pyx_codeobj__419
#define __pyx_codeobj__421 __pyx_mstate_global->__pyx_codeobj__421
#define __pyx_codeobj__422 __pyx_mstate_global->__pyx_codeobj__422
#define __pyx_codeobj__423 __pyx_mstate_global->__pyx_codeobj__423
#define __pyx_codeobj__425 __pyx_mstate_global->__pyx_codeobj__425
#define __pyx_codeobj__427 __pyx_mstate_global->__pyx_codeobj__427
#define __pyx_codeobj__428 __pyx_mstate_global->__pyx_codeobj__428
#define __pyx_codeobj__429 __pyx_mstate_global->__pyx_codeobj__429
#define __pyx_codeobj__430 __pyx_mstate_global->__pyx_codeobj__430
#define __pyx_codeobj__431 __pyx_mstate_global->__pyx_codeobj__431
#define __pyx_codeobj__433 __pyx_mstate_global->__pyx_codeobj__433
#define __pyx_codeobj__435 __pyx_mstate_global->__pyx_codeobj__435
#define __pyx_codeobj__436 __pyx_mstate_global->__pyx_codeobj__436
#define __pyx_codeobj__437 __pyx_mstate_global->__pyx_codeobj__437
#define __pyx_codeobj__438 __pyx_mstate_global->__pyx_codeobj__438
#define __pyx_codeobj__439 __pyx_mstate_global->__pyx_codeobj__439
#define __pyx_codeobj__440 __pyx_mstate_global->__pyx_codeobj__440
#define __pyx_codeobj__442 __pyx_mstate_global->__pyx_codeobj__442
#define __pyx_codeobj__444 __pyx_mstate_global->__pyx_codeobj__444
#define __pyx_codeobj__447 __pyx_mstate_global->__pyx_codeobj__447
#define __pyx_codeobj__449 __pyx_mstate_global->__pyx_codeobj__449
#define __pyx_codeobj__450 __pyx_mstate_global->__pyx_codeobj__450
#define __pyx_codeobj__452 __pyx_mstate_global->__pyx_codeobj__452
#define __pyx_codeobj__453 __pyx_mstate_global->__pyx_codeobj__453
#define __pyx_codeobj__454 __pyx_mstate_global->__pyx_codeobj__454
#define __pyx_codeobj__455 __pyx_mstate_global->__pyx_codeobj__455
#define __pyx_codeobj__456 __pyx_mstate_global->__pyx_codeobj__456
#define __pyx_codeobj__458 __pyx_mstate_global->__pyx_codeobj__458
#define __pyx_codeobj__459 __pyx_mstate_global->__pyx_codeobj__459
#define __pyx_codeobj__460 __pyx_mstate_global->__pyx_codeobj__460
#define __pyx_codeobj__463 __pyx_mstate_global->__pyx_codeobj__463
#define __pyx_codeobj__464 __pyx_mstate_global->__pyx_codeobj__464
#define __pyx_codeobj__466 __pyx_mstate_global->__pyx_codeobj__466
#define __pyx_codeobj__467 __pyx_mstate_global->__pyx_codeobj__467
#define __pyx_codeobj__468 __pyx_mstate_global->__pyx_codeobj__468
#define __pyx_codeobj__469 __pyx_mstate_global->__pyx_codeobj__469
#define __pyx_codeobj__471 __pyx_mstate_global->__pyx_codeobj__471
#define __pyx_codeobj__473 __pyx_mstate_global->__pyx_codeobj__473
#define __pyx_codeobj__475 __pyx_mstate_global->__pyx_codeobj__475
#define __pyx_codeobj__477 __pyx_mstate_global->__pyx_codeobj__477
#define __pyx_codeobj__480 __pyx_mstate_global->__pyx_codeobj__480
#define __pyx_codeobj__482 __pyx_mstate_global->__pyx_codeobj__482
#define __pyx_codeobj__484 __pyx_mstate_global->__pyx_codeobj__484
#define __pyx_codeobj__486 __pyx_mstate_global->__pyx_codeobj__486
#define __pyx_codeobj__489 __pyx_mstate_global->__pyx_codeobj__489
#define __pyx_codeobj__492 __pyx_mstate_global->__pyx_codeobj__492
#define __pyx_codeobj__494 __pyx_mstate_global->__pyx_codeobj__494
#define __pyx_codeobj__495 __pyx_mstate_global->__pyx_codeobj__495
#define __pyx_codeobj__496 __pyx_mstate_global->__pyx_codeobj__496
#define __pyx_codeobj__498 __pyx_mstate_global->__pyx_codeobj__498
#define __pyx_codeobj__500 __pyx_mstate_global->__pyx_codeobj__500
#define __pyx_codeobj__503 __pyx_mstate_global->__pyx_codeobj__503
#define __pyx_codeobj__504 __pyx_mstate_global->__pyx_codeobj__504
#define __pyx_codeobj__506 __pyx_mstate_global->__pyx_codeobj__506
#define __pyx_codeobj__509 __pyx_mstate_global->__pyx_codeobj__509
#define __pyx_codeobj__510 __pyx_mstate_global->__pyx_codeobj__510
#define __pyx_codeobj__530 __pyx_mstate_global->__pyx_codeobj__530
#define __pyx_codeobj__533 __pyx_mstate_global->__pyx_codeobj__533
#define __pyx_codeobj__534 __pyx_mstate_global->__pyx_codeobj__534
#define __pyx_codeobj__536 __pyx_mstate_global->__pyx_codeobj__536
#define __pyx_codeobj__538 __pyx_mstate_global->__pyx_codeobj__538
#define __pyx_codeobj__540 __pyx_mstate_global->__pyx_codeobj__540
#define __pyx_codeobj__541 __pyx_mstate_global->__pyx_codeobj__541
#define __pyx_codeobj__542 __pyx_mstate_global->__pyx_codeobj__542
#define __pyx_codeobj__543 __pyx_mstate_global->__pyx_codeobj__543
#define __pyx_codeobj__544 __pyx_mstate_global->__pyx_codeobj__544
#define __pyx_codeobj__545 __pyx_mstate_global->__pyx_codeobj__545
#define __pyx_codeobj__546 __pyx_mstate_global->__pyx_codeobj__546
#define __pyx_codeobj__547 __pyx_mstate_global->__pyx_codeobj__547
#define __pyx_codeobj__548 __pyx_mstate_global->__pyx_codeobj__548
#define __pyx_codeobj__550 __pyx_mstate_global->__pyx_codeobj__550
#define __pyx_codeobj__551 __pyx_mstate_global->__pyx_codeobj__551
#define __pyx_codeobj__552 __pyx_mstate_global->__pyx_codeobj__552
#define __pyx_codeobj__554 __pyx_mstate_global->__pyx_codeobj__554
#define __pyx_codeobj__556 __pyx_mstate_global->__pyx_codeobj__556
#define __pyx_codeobj__557 __pyx_mstate_global->__pyx_codeobj__557
#define __pyx_codeobj__559 __pyx_mstate_global->__pyx_codeobj__559
#define __pyx_codeobj__561 __pyx_mstate_global->__pyx_codeobj__561
#define __pyx_codeobj__562 __pyx_mstate_global->__pyx_codeobj__562
#define __pyx_codeobj__564 __pyx_mstate_global->__pyx_codeobj__564
#define __pyx_codeobj__566 __pyx_mstate_global->__pyx_codeobj__566
#define __pyx_codeobj__568 __pyx_mstate_global->__pyx_codeobj__568
#define __pyx_codeobj__570 __pyx_mstate_global->__pyx_codeobj__570
#define __pyx_codeobj__571 __pyx_mstate_global->__pyx_codeobj__571
#define __pyx_codeobj__573 __pyx_mstate_global->__pyx_codeobj__573
#define __pyx_codeobj__575 __pyx_mstate_global->__pyx_codeobj__575
#define __pyx_codeobj__577 __pyx_mstate_global->__pyx_codeobj__577
#define __pyx_codeobj__578 __pyx_mstate_global->__pyx_codeobj__578
#define __pyx_codeobj__580 __pyx_mstate_global->__pyx_codeobj__580
#define __pyx_codeobj__581 __pyx_mstate_global->__pyx_codeobj__581
#define __pyx_codeobj__582 __pyx_mstate_global->__pyx_codeobj__582
#define __pyx_codeobj__583 __pyx_mstate_global->__pyx_codeobj__583
#define __pyx_codeobj__585 __pyx_mstate_global->__pyx_codeobj__585
#define __pyx_codeobj__586 __pyx_mstate_global->__pyx_codeobj__586
#define __pyx_codeobj__587 __pyx_mstate_global->__pyx_codeobj__587
#define __pyx_codeobj__588 __pyx_mstate_global->__pyx_codeobj__588
#define __pyx_codeobj__590 __pyx_mstate_global->__pyx_codeobj__590
#define __pyx_codeobj__591 __pyx_mstate_global->__pyx_codeobj__591
#define __pyx_codeobj__592 __pyx_mstate_global->__pyx_codeobj__592
#define __pyx_codeobj__594 __pyx_mstate_global->__pyx_codeobj__594
#define __pyx_codeobj__597 __pyx_mstate_global->__pyx_codeobj__597
#define __pyx_codeobj__598 __pyx_mstate_global->__pyx_codeobj__598
#define __pyx_codeobj__599 __pyx_mstate_global->__pyx_codeobj__599
#define __pyx_codeobj__600 __pyx_mstate_global->__pyx_codeobj__600
#define __pyx_codeobj__601 __pyx_mstate_global->__pyx_codeobj__601
#define __pyx_codeobj__602 __pyx_mstate_global->__pyx_codeobj__602
#define __pyx_codeobj__603 __pyx_mstate_global->__pyx_codeobj__603
#define __pyx_codeobj__605 __pyx_mstate_global->__pyx_codeobj__605
#define __pyx_codeobj__606 __pyx_mstate_global->__pyx_codeobj__606
#define __pyx_codeobj__607 __pyx_mstate_global->__pyx_codeobj__607
#define __pyx_codeobj__609 __pyx_mstate_global->__pyx_codeobj__609
#define __pyx_codeobj__610 __pyx_mstate_global->__pyx_codeobj__610
#define __pyx_codeobj__611 __pyx_mstate_global->__pyx_codeobj__611
#define __pyx_codeobj__612 __pyx_mstate_global->__pyx_codeobj__612
#define __pyx_codeobj__613 __pyx_mstate_global->__pyx_codeobj__613
#define __pyx_codeobj__615 __pyx_mstate_global->__pyx_codeobj__615
#define __pyx_codeobj__617 __pyx_mstate_global->__pyx_codeobj__617
#define __pyx_codeobj__618 __pyx_mstate_global->__pyx_codeobj__618
#define __pyx_codeobj__620 __pyx_mstate_global->__pyx_codeobj__620
#define __pyx_codeobj__623 __pyx_mstate_global->__pyx_codeobj__623
#define __pyx_codeobj__625 __pyx_mstate_global->__pyx_codeobj__625
#define __pyx_codeobj__627 __pyx_mstate_global->__pyx_codeobj__627
#define __pyx_codeobj__629 __pyx_mstate_global->__pyx_codeobj__629
#define __pyx_codeobj__630 __pyx_mstate_global->__pyx_codeobj__630
#define __pyx_codeobj__631 __pyx_mstate_global->__pyx_codeobj__631
#define __pyx_codeobj__633 __pyx_mstate_global->__pyx_codeobj__633
#define __pyx_codeobj__635 __pyx_mstate_global->__pyx_codeobj__635
#define __pyx_codeobj__637 __pyx_mstate_global->__pyx_codeobj__637
#define __pyx_codeobj__638 __pyx_mstate_global->__pyx_codeobj__638
#define __pyx_codeobj__639 __pyx_mstate_global->__pyx_codeobj__639
#define __pyx_codeobj__641 __pyx_mstate_global->__pyx_codeobj__641
#define __pyx_codeobj__642 __pyx_mstate_global->__pyx_codeobj__642
#define __pyx_codeobj__643 __pyx_mstate_global->__pyx_codeobj__643
#define __pyx_codeobj__646 __pyx_mstate_global->__pyx_codeobj__646
#define __pyx_codeobj__647 __pyx_mstate_global->__pyx_codeobj__647
#define __pyx_codeobj__649 __pyx_mstate_global->__pyx_codeobj__649
#define __pyx_codeobj__651 __pyx_mstate_global->__pyx_codeobj__651
#define __pyx_codeobj__652 __pyx_mstate_global->__pyx_codeobj__652
#define __pyx_codeobj__654 __pyx_mstate_global->__pyx_codeobj__654
#define __pyx_codeobj__656 __pyx_mstate_global->__pyx_codeobj__656
#define __pyx_codeobj__657 __pyx_mstate_global->__pyx_codeobj__657
#define __pyx_codeobj__658 __pyx_mstate_global->__pyx_codeobj__658
#define __pyx_codeobj__659 __pyx_mstate_global->__pyx_codeobj__659
#define __pyx_codeobj__660 __pyx_mstate_global->__pyx_codeobj__660
#define __pyx_codeobj__661 __pyx_mstate_global->__pyx_codeobj__661
#define __pyx_codeobj__662 __pyx_mstate_global->__pyx_codeobj__662
#define __pyx_codeobj__663 __pyx_mstate_global->__pyx_codeobj__663
#define __pyx_codeobj__664 __pyx_mstate_global->__pyx_codeobj__664
#define __pyx_codeobj__665 __pyx_mstate_global->__pyx_codeobj__665
#define __pyx_codeobj__666 __pyx_mstate_global->__pyx_codeobj__666
#define __pyx_codeobj__668 __pyx_mstate_global->__pyx_codeobj__668
#define __pyx_codeobj__670 __pyx_mstate_global->__pyx_codeobj__670
#define __pyx_codeobj__672 __pyx_mstate_global->__pyx_codeobj__672
#define __pyx_codeobj__673 __pyx_mstate_global->__pyx_codeobj__673
#define __pyx_codeobj__674 __pyx_mstate_global->__pyx_codeobj__674
#define __pyx_codeobj__675 __pyx_mstate_global->__pyx_codeobj__675
#define __pyx_codeobj__677 __pyx_mstate_global->__pyx_codeobj__677
#define __pyx_codeobj__678 __pyx_mstate_global->__pyx_codeobj__678
#define __pyx_codeobj__679 __pyx_mstate_global->__pyx_codeobj__679
#define __pyx_codeobj__683 __pyx_mstate_global->__pyx_codeobj__683
#define __pyx_codeobj__685 __pyx_mstate_global->__pyx_codeobj__685
#define __pyx_codeobj__686 __pyx_mstate_global->__pyx_codeobj__686
#define __pyx_codeobj__688 __pyx_mstate_global->__pyx_codeobj__688
#define __pyx_codeobj__690 __pyx_mstate_global->__pyx_codeobj__690
#define __pyx_codeobj__693 __pyx_mstate_global->__pyx_codeobj__693
#define __pyx_codeobj__695 __pyx_mstate_global->__pyx_codeobj__695
#define __pyx_codeobj__697 __pyx_mstate_global->__pyx_codeobj__697
#define __pyx_codeobj__699 __pyx_mstate_global->__pyx_codeobj__699
#define __pyx_codeobj__701 __pyx_mstate_global->__pyx_codeobj__701
#define __pyx_codeobj__703 __pyx_mstate_global->__pyx_codeobj__703
#define __pyx_codeobj__706 __pyx_mstate_global->__pyx_codeobj__706
#define __pyx_codeobj__708 __pyx_mstate_global->__pyx_codeobj__708
#define __pyx_codeobj__710 __pyx_mstate_global->__pyx_codeobj__710
#define __pyx_codeobj__712 __pyx_mstate_global->__pyx_codeobj__712
#define __pyx_codeobj__729 __pyx_mstate_global->__pyx_codeobj__729
#define __pyx_codeobj__731 __pyx_mstate_global->__pyx_codeobj__731
#define __pyx_codeobj__733 __pyx_mstate_global->__pyx_codeobj__733
#define __pyx_codeobj__734 __pyx_mstate_global->__pyx_codeobj__734
#define __pyx_codeobj__736 __pyx_mstate_global->__pyx_codeobj__736
#define __pyx_codeobj__738 __pyx_mstate_global->__pyx_codeobj__738
#define __pyx_codeobj__742 __pyx_mstate_global->__pyx_codeobj__742
#define __pyx_codeobj__743 __pyx_mstate_global->__pyx_codeobj__743
#define __pyx_codeobj__747 __pyx_mstate_global->__pyx_codeobj__747
#define __pyx_codeobj__749 __pyx_mstate_global->__pyx_codeobj__749
#define __pyx_codeobj__751 __pyx_mstate_global->__pyx_codeobj__751
#define __pyx_codeobj__763 __pyx_mstate_global->__pyx_codeobj__763
#define __pyx_codeobj__765 __pyx_mstate_global->__pyx_codeobj__765
#define __pyx_codeobj__773 __pyx_mstate_global->__pyx_codeobj__773
#define __pyx_codeobj__797 __pyx_mstate_global->__pyx_codeobj__797
#define __pyx_codeobj__799 __pyx_mstate_global->__pyx_codeobj__799
#define __pyx_codeobj__802 __pyx_mstate_global->__pyx_codeobj__802
#define __pyx_codeobj__805 __pyx_mstate_global->__pyx_codeobj__805
#define __pyx_codeobj__807 __pyx_mstate_global->__pyx_codeobj__807
#define __pyx_codeobj__811 __pyx_mstate_global->__pyx_codeobj__811
#define __pyx_codeobj__812 __pyx_mstate_global->__pyx_codeobj__812
#define __pyx_codeobj__813 __pyx_mstate_global->__pyx_codeobj__813
#define __pyx_codeobj__814 __pyx_mstate_global->__pyx_codeobj__814
#define __pyx_codeobj__815 __pyx_mstate_global->__pyx_codeobj__815
#define __pyx_codeobj__868 __pyx_mstate_global->__pyx_codeobj__868
#define __pyx_codeobj__869 __pyx_mstate_global->__pyx_codeobj__869
#define __pyx_codeobj__871 __pyx_mstate_global->__pyx_codeobj__871
#define __pyx_codeobj__872 __pyx_mstate_global->__pyx_codeobj__872
#define __pyx_codeobj__873 __pyx_mstate_global->__pyx_codeobj__873
#define __pyx_codeobj__875 __pyx_mstate_global->__pyx_codeobj__875
#define __pyx_codeobj__877 __pyx_mstate_global->__pyx_codeobj__877
#define __pyx_codeobj__880 __pyx_mstate_global->__pyx_codeobj__880
#define __pyx_codeobj__882 __pyx_mstate_global->__pyx_codeobj__882
/* #### Code section: module_code ### */
static PyObject *__pyx_gb_10cPyparsing_80generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":232
 *     return "[" + ", ".join(repr(x) for x in l) + "]"
 * 
 * _generatorType = type((y for y in range(1)))             # <<<<<<<<<<<<<<
 * 
 * def _xml_escape(data):
 */

static PyObject *__pyx_pf_10cPyparsing_78genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_1_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 232, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_80generator4, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 232, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_80generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 232, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 232, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 232, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 232, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 232, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 232, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 232, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 232, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 232, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 232, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 232, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_y);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_y, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_y);
    __pyx_r = __pyx_cur_scope->__pyx_v_y;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 232, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_83generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":249
 * alphanums = alphas + nums
 * _bslash = chr(92)
 * printables = "".join(c for c in string.printable if c not in string.whitespace)             # <<<<<<<<<<<<<<
 * 
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_81genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_3_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 249, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_83generator6, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 249, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_83generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 249, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 249, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 249, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 249, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 249, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 249, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 249, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 249, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 249, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 249, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_string); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_whitespace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_c, __pyx_t_5, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 249, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_6) {
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_c))) __PYX_ERR(0, 249, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6731
 * stringEnd   = StringEnd().setName("stringEnd")
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])             # <<<<<<<<<<<<<<
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_84lambda54(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_84lambda54 = {"lambda54", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_84lambda54, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_84lambda54(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda54 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6731, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6731, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda54", 1, 3, 3, 1); __PYX_ERR(0, 6731, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6731, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda54", 1, 3, 3, 2); __PYX_ERR(0, 6731, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda54") < 0)) __PYX_ERR(0, 6731, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda54", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6731, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.lambda54", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda54(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda54(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda54", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.lambda54", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6732
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))             # <<<<<<<<<<<<<<
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_85lambda55(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_85lambda55 = {"lambda55", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_85lambda55, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_85lambda55(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda55 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6732, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6732, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda55", 1, 3, 3, 1); __PYX_ERR(0, 6732, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6732, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda55", 1, 3, 3, 2); __PYX_ERR(0, 6732, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda55") < 0)) __PYX_ERR(0, 6732, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda55", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6732, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.lambda55", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda55(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda55(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda55", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unichr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_0x};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 6732, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_16);
  __Pyx_GIVEREF(__pyx_int_16);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_16)) __PYX_ERR(0, 6732, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)(&PyInt_Type)), __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.lambda55", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6733
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))             # <<<<<<<<<<<<<<
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_86lambda56(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_86lambda56 = {"lambda56", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_86lambda56, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_86lambda56(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda56 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6733, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6733, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda56", 1, 3, 3, 1); __PYX_ERR(0, 6733, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6733, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda56", 1, 3, 3, 2); __PYX_ERR(0, 6733, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda56") < 0)) __PYX_ERR(0, 6733, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda56", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6733, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.lambda56", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda56(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda56(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda56", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unichr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_3, 1, 0, NULL, NULL, &__pyx_slice_, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 6733, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_8);
  __Pyx_GIVEREF(__pyx_int_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_8)) __PYX_ERR(0, 6733, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)(&PyInt_Type)), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.lambda56", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6857
 *     return pa
 * 
 * upcaseTokens = tokenMap(lambda t: _ustr(t).upper())             # <<<<<<<<<<<<<<
 * """(Deprecated) Helper parse action to convert tokens to upper case.
 * Deprecated in favor of :class:`pyparsing_common.upcaseTokens`"""
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_87lambda61(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_87lambda61 = {"lambda61", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_87lambda61, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_87lambda61(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda61 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6857, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda61") < 0)) __PYX_ERR(0, 6857, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda61", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6857, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.lambda61", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda61(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda61(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda61", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_t};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.lambda61", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6861
 * Deprecated in favor of :class:`pyparsing_common.upcaseTokens`"""
 * 
 * downcaseTokens = tokenMap(lambda t: _ustr(t).lower())             # <<<<<<<<<<<<<<
 * """(Deprecated) Helper parse action to convert tokens to lower case.
 * Deprecated in favor of :class:`pyparsing_common.downcaseTokens`"""
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_88lambda62(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_88lambda62 = {"lambda62", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_88lambda62, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_88lambda62(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda62 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6861, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda62") < 0)) __PYX_ERR(0, 6861, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda62", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6861, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.lambda62", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda62(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda62(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda62", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_t};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_lower); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.lambda62", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":156
 * __diag__._all_names = [nm for nm in vars(__diag__) if nm.startswith("enable_") or nm.startswith("warn_")]
 * 
 * def _enable_all_warnings():             # <<<<<<<<<<<<<<
 *     __diag__.warn_multiple_tokens_in_named_alternation = True
 *     __diag__.warn_ungrouped_named_tokens_in_collection = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_1_enable_all_warnings(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing__enable_all_warnings, "_enable_all_warnings()");
static PyMethodDef __pyx_mdef_10cPyparsing_1_enable_all_warnings = {"_enable_all_warnings", (PyCFunction)__pyx_pw_10cPyparsing_1_enable_all_warnings, METH_NOARGS, __pyx_doc_10cPyparsing__enable_all_warnings};
static PyObject *__pyx_pw_10cPyparsing_1_enable_all_warnings(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_enable_all_warnings (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_10cPyparsing__enable_all_warnings(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing__enable_all_warnings(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_enable_all_warnings", 1);

  /* "cPyparsing.pyx":157
 * 
 * def _enable_all_warnings():
 *     __diag__.warn_multiple_tokens_in_named_alternation = True             # <<<<<<<<<<<<<<
 *     __diag__.warn_ungrouped_named_tokens_in_collection = True
 *     __diag__.warn_name_set_on_empty_Forward = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_warn_multiple_tokens_in_named_al, Py_True) < 0) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":158
 * def _enable_all_warnings():
 *     __diag__.warn_multiple_tokens_in_named_alternation = True
 *     __diag__.warn_ungrouped_named_tokens_in_collection = True             # <<<<<<<<<<<<<<
 *     __diag__.warn_name_set_on_empty_Forward = True
 *     __diag__.warn_on_multiple_string_args_to_oneof = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_warn_ungrouped_named_tokens_in_c, Py_True) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":159
 *     __diag__.warn_multiple_tokens_in_named_alternation = True
 *     __diag__.warn_ungrouped_named_tokens_in_collection = True
 *     __diag__.warn_name_set_on_empty_Forward = True             # <<<<<<<<<<<<<<
 *     __diag__.warn_on_multiple_string_args_to_oneof = True
 *     # [CPYPARSING] add warn_on_incremental_multiline_regex
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_warn_name_set_on_empty_Forward, Py_True) < 0) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":160
 *     __diag__.warn_ungrouped_named_tokens_in_collection = True
 *     __diag__.warn_name_set_on_empty_Forward = True
 *     __diag__.warn_on_multiple_string_args_to_oneof = True             # <<<<<<<<<<<<<<
 *     # [CPYPARSING] add warn_on_incremental_multiline_regex
 *     __diag__.warn_on_incremental_multiline_regex = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_warn_on_multiple_string_args_to, Py_True) < 0) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":162
 *     __diag__.warn_on_multiple_string_args_to_oneof = True
 *     # [CPYPARSING] add warn_on_incremental_multiline_regex
 *     __diag__.warn_on_incremental_multiline_regex = True             # <<<<<<<<<<<<<<
 * __diag__.enable_all_warnings = _enable_all_warnings
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_warn_on_incremental_multiline_re, Py_True) < 0) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":156
 * __diag__._all_names = [nm for nm in vars(__diag__) if nm.startswith("enable_") or nm.startswith("warn_")]
 * 
 * def _enable_all_warnings():             # <<<<<<<<<<<<<<
 *     __diag__.warn_multiple_tokens_in_named_alternation = True
 *     __diag__.warn_ungrouped_named_tokens_in_collection = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._enable_all_warnings", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":205
 * 
 *     # [CPYPARSING] repr logic
 *     def repr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, unicode):
 *             return py_repr(obj).lstrip("u")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3repr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_2repr, "repr(obj)");
static PyMethodDef __pyx_mdef_10cPyparsing_3repr = {"repr", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_3repr, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_2repr};
static PyObject *__pyx_pw_10cPyparsing_3repr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("repr (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 205, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "repr") < 0)) __PYX_ERR(0, 205, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_obj = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("repr", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 205, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.repr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2repr(__pyx_self, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_2repr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("repr", 1);

  /* "cPyparsing.pyx":206
 *     # [CPYPARSING] repr logic
 *     def repr(obj):
 *         if isinstance(obj, unicode):             # <<<<<<<<<<<<<<
 *             return py_repr(obj).lstrip("u")
 *         else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":207
 *     def repr(obj):
 *         if isinstance(obj, unicode):
 *             return py_repr(obj).lstrip("u")             # <<<<<<<<<<<<<<
 *         else:
 *             return py_repr(obj)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_py_repr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_obj};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_u};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":206
 *     # [CPYPARSING] repr logic
 *     def repr(obj):
 *         if isinstance(obj, unicode):             # <<<<<<<<<<<<<<
 *             return py_repr(obj).lstrip("u")
 *         else:
 */
  }

  /* "cPyparsing.pyx":209
 *             return py_repr(obj).lstrip("u")
 *         else:
 *             return py_repr(obj)             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] _ustr logic
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_py_repr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_obj};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":205
 * 
 *     # [CPYPARSING] repr logic
 *     def repr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, unicode):
 *             return py_repr(obj).lstrip("u")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.repr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":213
 *     # [CPYPARSING] _ustr logic
 *     str = unicode
 *     def _ustr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5_ustr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4_ustr, "_ustr(obj)");
static PyMethodDef __pyx_mdef_10cPyparsing_5_ustr = {"_ustr", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5_ustr, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4_ustr};
static PyObject *__pyx_pw_10cPyparsing_5_ustr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_ustr (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 213, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_ustr") < 0)) __PYX_ERR(0, 213, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_obj = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_ustr", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 213, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._ustr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4_ustr(__pyx_self, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4_ustr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_ustr", 0);
  __Pyx_INCREF(__pyx_v_obj);

  /* "cPyparsing.pyx":214
 *     str = unicode
 *     def _ustr(obj):
 *         if isinstance(obj, py_str):             # <<<<<<<<<<<<<<
 *             obj = obj.decode("utf8")
 *         return unicode(obj)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_py_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":215
 *     def _ustr(obj):
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")             # <<<<<<<<<<<<<<
 *         return unicode(obj)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_decode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_utf8};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":214
 *     str = unicode
 *     def _ustr(obj):
 *         if isinstance(obj, py_str):             # <<<<<<<<<<<<<<
 *             obj = obj.decode("utf8")
 *         return unicode(obj)
 */
  }

  /* "cPyparsing.pyx":216
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 *         return unicode(obj)             # <<<<<<<<<<<<<<
 * 
 *     # build list of single arg builtins, tolerant of Python version, that can be used as parse actions
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_obj};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":213
 *     # [CPYPARSING] _ustr logic
 *     str = unicode
 *     def _ustr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._ustr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":229
 * 
 * # [CPYPARSING] custom list_str
 * def list_str(l):             # <<<<<<<<<<<<<<
 *     return "[" + ", ".join(repr(x) for x in l) + "]"
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7list_str(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_6list_str, "list_str(l)");
static PyMethodDef __pyx_mdef_10cPyparsing_7list_str = {"list_str", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7list_str, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_6list_str};
static PyObject *__pyx_pw_10cPyparsing_7list_str(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_l = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("list_str (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_l,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 229, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "list_str") < 0)) __PYX_ERR(0, 229, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_l = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("list_str", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 229, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.list_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6list_str(__pyx_self, __pyx_v_l);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_8list_str_2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":230
 * # [CPYPARSING] custom list_str
 * def list_str(l):
 *     return "[" + ", ".join(repr(x) for x in l) + "]"             # <<<<<<<<<<<<<<
 * 
 * _generatorType = type((y for y in range(1)))
 */

static PyObject *__pyx_pf_10cPyparsing_8list_str_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct__genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 230, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_8list_str_2generator3, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_list_str_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 230, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.list_str.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_8list_str_2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 230, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 230, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 230, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 230, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 230, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 230, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 230, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 230, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 230, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 230, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_x);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_x, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_repr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_x};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 230, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":229
 * 
 * # [CPYPARSING] custom list_str
 * def list_str(l):             # <<<<<<<<<<<<<<
 *     return "[" + ", ".join(repr(x) for x in l) + "]"
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_6list_str(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_l) {
  PyObject *__pyx_gb_10cPyparsing_8list_str_2generator3 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list_str", 1);

  /* "cPyparsing.pyx":230
 * # [CPYPARSING] custom list_str
 * def list_str(l):
 *     return "[" + ", ".join(repr(x) for x in l) + "]"             # <<<<<<<<<<<<<<
 * 
 * _generatorType = type((y for y in range(1)))
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_pf_10cPyparsing_8list_str_genexpr(NULL, __pyx_v_l); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__2, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_2, __pyx_kp_u__4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":229
 * 
 * # [CPYPARSING] custom list_str
 * def list_str(l):             # <<<<<<<<<<<<<<
 *     return "[" + ", ".join(repr(x) for x in l) + "]"
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.list_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_8list_str_2generator3);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":234
 * _generatorType = type((y for y in range(1)))
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9_xml_escape(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_8_xml_escape, "_xml_escape(data)\nEscape &, <, >, \", ', etc. in a string of data.");
static PyMethodDef __pyx_mdef_10cPyparsing_9_xml_escape = {"_xml_escape", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9_xml_escape, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_8_xml_escape};
static PyObject *__pyx_pw_10cPyparsing_9_xml_escape(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_xml_escape (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 234, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_xml_escape") < 0)) __PYX_ERR(0, 234, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_data = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_xml_escape", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 234, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._xml_escape", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8_xml_escape(__pyx_self, __pyx_v_data);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_11_xml_escape_2generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":239
 *     # ampersand must be replaced first
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())             # <<<<<<<<<<<<<<
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)
 */

static PyObject *__pyx_pf_10cPyparsing_11_xml_escape_genexpr(CYTHON_UNUSED PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_2_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 239, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_11_xml_escape_2generator5, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_xml_escape_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing._xml_escape.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_11_xml_escape_2generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 239, __pyx_L1_error)
  __pyx_t_1 = PyUnicode_Split(__pyx_kp_u_amp_gt_lt_quot_apos, ((PyObject *)NULL), -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 239, __pyx_L1_error)
      #endif
      if (__pyx_t_3 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 239, __pyx_L1_error)
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_s);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_s, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_kp_u__5, __pyx_cur_scope->__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_1;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 239, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":234
 * _generatorType = type((y for y in range(1)))
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_8_xml_escape(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_v_from_symbols = NULL;
  PyObject *__pyx_v_to_symbols = NULL;
  PyObject *__pyx_v_from_ = NULL;
  PyObject *__pyx_v_to_ = NULL;
  PyObject *__pyx_gb_10cPyparsing_11_xml_escape_2generator5 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_xml_escape", 0);
  __Pyx_INCREF(__pyx_v_data);

  /* "cPyparsing.pyx":238
 * 
 *     # ampersand must be replaced first
 *     from_symbols = '&><"\''             # <<<<<<<<<<<<<<
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())
 *     for from_, to_ in zip(from_symbols, to_symbols):
 */
  __Pyx_INCREF(__pyx_kp_u__7);
  __pyx_v_from_symbols = __pyx_kp_u__7;

  /* "cPyparsing.pyx":239
 *     # ampersand must be replaced first
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())             # <<<<<<<<<<<<<<
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)
 */
  __pyx_t_1 = __pyx_pf_10cPyparsing_11_xml_escape_genexpr(NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_to_symbols = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":240
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())
 *     for from_, to_ in zip(from_symbols, to_symbols):             # <<<<<<<<<<<<<<
 *         data = data.replace(from_, to_)
 *     return data
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_from_symbols);
  __Pyx_GIVEREF(__pyx_v_from_symbols);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_from_symbols)) __PYX_ERR(0, 240, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_to_symbols);
  __Pyx_GIVEREF(__pyx_v_to_symbols);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_to_symbols)) __PYX_ERR(0, 240, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 240, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 240, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 240, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 240, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 240, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 240, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 240, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 240, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 240, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_from_, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_to_, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":241
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)             # <<<<<<<<<<<<<<
 *     return data
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_data, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_from_, __pyx_v_to_};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 2+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":240
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())
 *     for from_, to_ in zip(from_symbols, to_symbols):             # <<<<<<<<<<<<<<
 *         data = data.replace(from_, to_)
 *     return data
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":242
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)
 *     return data             # <<<<<<<<<<<<<<
 * 
 * alphas = string.ascii_uppercase + string.ascii_lowercase
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_data);
  __pyx_r = __pyx_v_data;
  goto __pyx_L0;

  /* "cPyparsing.pyx":234
 * _generatorType = type((y for y in range(1)))
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing._xml_escape", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_from_symbols);
  __Pyx_XDECREF(__pyx_v_to_symbols);
  __Pyx_XDECREF(__pyx_v_from_);
  __Pyx_XDECREF(__pyx_v_to_);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_11_xml_escape_2generator5);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":252
 * 
 * 
 * def conditionAsParseAction(fn, message=None, fatal=False):             # <<<<<<<<<<<<<<
 *     msg = message if message is not None else "failed user-defined condition"
 *     exc_type = ParseFatalException if fatal else ParseException
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11conditionAsParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10conditionAsParseAction, "conditionAsParseAction(fn, message=None, fatal=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_11conditionAsParseAction = {"conditionAsParseAction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11conditionAsParseAction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10conditionAsParseAction};
static PyObject *__pyx_pw_10cPyparsing_11conditionAsParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_fn = 0;
  PyObject *__pyx_v_message = 0;
  PyObject *__pyx_v_fatal = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("conditionAsParseAction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fn,&__pyx_n_s_message,&__pyx_n_s_fatal,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fn)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 252, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_message);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 252, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fatal);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 252, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "conditionAsParseAction") < 0)) __PYX_ERR(0, 252, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_fn = values[0];
    __pyx_v_message = values[1];
    __pyx_v_fatal = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("conditionAsParseAction", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 252, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.conditionAsParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10conditionAsParseAction(__pyx_self, __pyx_v_fn, __pyx_v_message, __pyx_v_fatal);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":257
 *     fn = _trim_arity(fn)
 * 
 *     @wraps(fn)             # <<<<<<<<<<<<<<
 *     def pa(s, l, t):
 *         if not bool(fn(s, l, t)):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_22conditionAsParseAction_1pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_22conditionAsParseAction_1pa = {"pa", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_22conditionAsParseAction_1pa, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_22conditionAsParseAction_1pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pa (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 257, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 257, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 1); __PYX_ERR(0, 257, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 257, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 2); __PYX_ERR(0, 257, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pa") < 0)) __PYX_ERR(0, 257, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 257, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.conditionAsParseAction.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_22conditionAsParseAction_pa(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_22conditionAsParseAction_pa(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pa", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":259
 *     @wraps(fn)
 *     def pa(s, l, t):
 *         if not bool(fn(s, l, t)):             # <<<<<<<<<<<<<<
 *             raise exc_type(s, l, msg)
 * 
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_fn)) { __Pyx_RaiseClosureNameError("fn"); __PYX_ERR(0, 259, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fn);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_fn; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_s, __pyx_v_l, __pyx_v_t};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!(!(!__pyx_t_5)));
  if (unlikely(__pyx_t_6)) {

    /* "cPyparsing.pyx":260
 *     def pa(s, l, t):
 *         if not bool(fn(s, l, t)):
 *             raise exc_type(s, l, msg)             # <<<<<<<<<<<<<<
 * 
 *     return pa
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_exc_type)) { __Pyx_RaiseClosureNameError("exc_type"); __PYX_ERR(0, 260, __pyx_L1_error) }
    if (unlikely(!__pyx_cur_scope->__pyx_v_msg)) { __Pyx_RaiseClosureNameError("msg"); __PYX_ERR(0, 260, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exc_type);
    __pyx_t_2 = __pyx_cur_scope->__pyx_v_exc_type; __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_s, __pyx_v_l, __pyx_cur_scope->__pyx_v_msg};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 260, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 260, __pyx_L1_error)

    /* "cPyparsing.pyx":259
 *     @wraps(fn)
 *     def pa(s, l, t):
 *         if not bool(fn(s, l, t)):             # <<<<<<<<<<<<<<
 *             raise exc_type(s, l, msg)
 * 
 */
  }

  /* "cPyparsing.pyx":257
 *     fn = _trim_arity(fn)
 * 
 *     @wraps(fn)             # <<<<<<<<<<<<<<
 *     def pa(s, l, t):
 *         if not bool(fn(s, l, t)):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.conditionAsParseAction.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":252
 * 
 * 
 * def conditionAsParseAction(fn, message=None, fatal=False):             # <<<<<<<<<<<<<<
 *     msg = message if message is not None else "failed user-defined condition"
 *     exc_type = ParseFatalException if fatal else ParseException
 */

static PyObject *__pyx_pf_10cPyparsing_10conditionAsParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fn, PyObject *__pyx_v_message, PyObject *__pyx_v_fatal) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *__pyx_cur_scope;
  PyObject *__pyx_v_pa = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("conditionAsParseAction", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction(__pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 252, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_fn = __pyx_v_fn;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fn);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fn);

  /* "cPyparsing.pyx":253
 * 
 * def conditionAsParseAction(fn, message=None, fatal=False):
 *     msg = message if message is not None else "failed user-defined condition"             # <<<<<<<<<<<<<<
 *     exc_type = ParseFatalException if fatal else ParseException
 *     fn = _trim_arity(fn)
 */
  __pyx_t_2 = (__pyx_v_message != Py_None);
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_v_message);
    __pyx_t_1 = __pyx_v_message;
  } else {
    __Pyx_INCREF(__pyx_kp_u_failed_user_defined_condition);
    __pyx_t_1 = __pyx_kp_u_failed_user_defined_condition;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_msg = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":254
 * def conditionAsParseAction(fn, message=None, fatal=False):
 *     msg = message if message is not None else "failed user-defined condition"
 *     exc_type = ParseFatalException if fatal else ParseException             # <<<<<<<<<<<<<<
 *     fn = _trim_arity(fn)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_fatal); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 254, __pyx_L1_error)
  if (__pyx_t_2) {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseFatalException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_exc_type = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":255
 *     msg = message if message is not None else "failed user-defined condition"
 *     exc_type = ParseFatalException if fatal else ParseException
 *     fn = _trim_arity(fn)             # <<<<<<<<<<<<<<
 * 
 *     @wraps(fn)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_trim_arity); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_cur_scope->__pyx_v_fn};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_fn);
  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_fn, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":257
 *     fn = _trim_arity(fn)
 * 
 *     @wraps(fn)             # <<<<<<<<<<<<<<
 *     def pa(s, l, t):
 *         if not bool(fn(s, l, t)):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_wraps); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_fn};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_22conditionAsParseAction_1pa, 0, __pyx_n_s_conditionAsParseAction_locals_pa, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__9)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_pa = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":262
 *             raise exc_type(s, l, msg)
 * 
 *     return pa             # <<<<<<<<<<<<<<
 * 
 * class ParseBaseException(Exception):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pa);
  __pyx_r = __pyx_v_pa;
  goto __pyx_L0;

  /* "cPyparsing.pyx":252
 * 
 * 
 * def conditionAsParseAction(fn, message=None, fatal=False):             # <<<<<<<<<<<<<<
 *     msg = message if message is not None else "failed user-defined condition"
 *     exc_type = ParseFatalException if fatal else ParseException
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.conditionAsParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pa);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":271
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):             # <<<<<<<<<<<<<<
 *         self.loc = loc
 *         if msg is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18ParseBaseException___init__, "ParseBaseException.__init__(self, pstr, loc=0, msg=None, elem=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18ParseBaseException_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException___init__};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_pstr = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_msg = 0;
  PyObject *__pyx_v_elem = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_pstr,&__pyx_n_s_loc,&__pyx_n_s_msg,&__pyx_n_s_elem,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 271, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pstr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 271, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, 1); __PYX_ERR(0, 271, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 271, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_msg);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 271, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_elem);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 271, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 271, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_pstr = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_msg = values[3];
    __pyx_v_elem = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, __pyx_nargs); __PYX_ERR(0, 271, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException___init__(__pyx_self, __pyx_v_self, __pyx_v_pstr, __pyx_v_loc, __pyx_v_msg, __pyx_v_elem);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_pstr, PyObject *__pyx_v_loc, PyObject *__pyx_v_msg, PyObject *__pyx_v_elem) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":272
 *     # constructor as small and fast as possible
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):
 *         self.loc = loc             # <<<<<<<<<<<<<<
 *         if msg is None:
 *             self.msg = pstr
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_loc, __pyx_v_loc) < 0) __PYX_ERR(0, 272, __pyx_L1_error)

  /* "cPyparsing.pyx":273
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):
 *         self.loc = loc
 *         if msg is None:             # <<<<<<<<<<<<<<
 *             self.msg = pstr
 *             self.pstr = ""
 */
  __pyx_t_1 = (__pyx_v_msg == Py_None);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":274
 *         self.loc = loc
 *         if msg is None:
 *             self.msg = pstr             # <<<<<<<<<<<<<<
 *             self.pstr = ""
 *         else:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_msg, __pyx_v_pstr) < 0) __PYX_ERR(0, 274, __pyx_L1_error)

    /* "cPyparsing.pyx":275
 *         if msg is None:
 *             self.msg = pstr
 *             self.pstr = ""             # <<<<<<<<<<<<<<
 *         else:
 *             self.msg = msg
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pstr, __pyx_kp_u__10) < 0) __PYX_ERR(0, 275, __pyx_L1_error)

    /* "cPyparsing.pyx":273
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):
 *         self.loc = loc
 *         if msg is None:             # <<<<<<<<<<<<<<
 *             self.msg = pstr
 *             self.pstr = ""
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":277
 *             self.pstr = ""
 *         else:
 *             self.msg = msg             # <<<<<<<<<<<<<<
 *             self.pstr = pstr
 *         self.parserElement = elem
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 277, __pyx_L1_error)

    /* "cPyparsing.pyx":278
 *         else:
 *             self.msg = msg
 *             self.pstr = pstr             # <<<<<<<<<<<<<<
 *         self.parserElement = elem
 *         self.args = (pstr, loc, msg)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pstr, __pyx_v_pstr) < 0) __PYX_ERR(0, 278, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":279
 *             self.msg = msg
 *             self.pstr = pstr
 *         self.parserElement = elem             # <<<<<<<<<<<<<<
 *         self.args = (pstr, loc, msg)
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parserElement, __pyx_v_elem) < 0) __PYX_ERR(0, 279, __pyx_L1_error)

  /* "cPyparsing.pyx":280
 *             self.pstr = pstr
 *         self.parserElement = elem
 *         self.args = (pstr, loc, msg)             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_pstr);
  __Pyx_GIVEREF(__pyx_v_pstr);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_pstr)) __PYX_ERR(0, 280, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_loc)) __PYX_ERR(0, 280, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_msg);
  __Pyx_GIVEREF(__pyx_v_msg);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_msg)) __PYX_ERR(0, 280, __pyx_L1_error);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_args, __pyx_t_2) < 0) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":271
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):             # <<<<<<<<<<<<<<
 *         self.loc = loc
 *         if msg is None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":282
 *         self.args = (pstr, loc, msg)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_exception(cls, pe):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_3_from_exception(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18ParseBaseException_2_from_exception, "ParseBaseException._from_exception(cls, pe)\n\n        internal factory method to simplify creating one type of ParseException\n        from another - avoids having __init__ signature conflicts among subclasses\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_3_from_exception = {"_from_exception", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18ParseBaseException_3_from_exception, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException_2_from_exception};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_3_from_exception(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_pe = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_exception (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_pe,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 282, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pe)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 282, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_from_exception", 1, 2, 2, 1); __PYX_ERR(0, 282, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_from_exception") < 0)) __PYX_ERR(0, 282, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_cls = values[0];
    __pyx_v_pe = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_exception", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 282, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseBaseException._from_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_2_from_exception(__pyx_self, __pyx_v_cls, __pyx_v_pe);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_2_from_exception(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_pe) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_exception", 1);

  /* "cPyparsing.pyx":288
 *         from another - avoids having __init__ signature conflicts among subclasses
 *         """
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, aname):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_pstr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_msg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_parserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_cls);
  __pyx_t_6 = __pyx_v_cls; __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_t_2, __pyx_t_3, __pyx_t_4, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 4+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":282
 *         self.args = (pstr, loc, msg)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_exception(cls, pe):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException._from_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":290
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)
 * 
 *     def __getattr__(self, aname):             # <<<<<<<<<<<<<<
 *         """supported attributes by name are:
 *            - lineno - returns the line number of the exception text
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_5__getattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18ParseBaseException_4__getattr__, "ParseBaseException.__getattr__(self, aname)\nsupported attributes by name are:\n           - lineno - returns the line number of the exception text\n           - col - returns the column number of the exception text\n           - line - returns the line containing the exception text\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_5__getattr__ = {"__getattr__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18ParseBaseException_5__getattr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException_4__getattr__};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_5__getattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_aname = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_aname,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 290, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_aname)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 290, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, 1); __PYX_ERR(0, 290, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__getattr__") < 0)) __PYX_ERR(0, 290, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_aname = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 290, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_4__getattr__(__pyx_self, __pyx_v_self, __pyx_v_aname);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_4__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_aname) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 1);

  /* "cPyparsing.pyx":296
 *            - line - returns the line containing the exception text
 *         """
 *         if aname == "lineno":             # <<<<<<<<<<<<<<
 *             return lineno(self.loc, self.pstr)
 *         elif aname in ("col", "column"):
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_aname, __pyx_n_u_lineno, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 296, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":297
 *         """
 *         if aname == "lineno":
 *             return lineno(self.loc, self.pstr)             # <<<<<<<<<<<<<<
 *         elif aname in ("col", "column"):
 *             return col(self.loc, self.pstr)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_lineno); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pstr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 297, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":296
 *            - line - returns the line containing the exception text
 *         """
 *         if aname == "lineno":             # <<<<<<<<<<<<<<
 *             return lineno(self.loc, self.pstr)
 *         elif aname in ("col", "column"):
 */
  }

  /* "cPyparsing.pyx":298
 *         if aname == "lineno":
 *             return lineno(self.loc, self.pstr)
 *         elif aname in ("col", "column"):             # <<<<<<<<<<<<<<
 *             return col(self.loc, self.pstr)
 *         elif aname == "line":
 */
  __Pyx_INCREF(__pyx_v_aname);
  __pyx_t_2 = __pyx_v_aname;
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_col, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 298, __pyx_L1_error)
  if (!__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_column, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 298, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __pyx_t_1;
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":299
 *             return lineno(self.loc, self.pstr)
 *         elif aname in ("col", "column"):
 *             return col(self.loc, self.pstr)             # <<<<<<<<<<<<<<
 *         elif aname == "line":
 *             return line(self.loc, self.pstr)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_col); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pstr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 299, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":298
 *         if aname == "lineno":
 *             return lineno(self.loc, self.pstr)
 *         elif aname in ("col", "column"):             # <<<<<<<<<<<<<<
 *             return col(self.loc, self.pstr)
 *         elif aname == "line":
 */
  }

  /* "cPyparsing.pyx":300
 *         elif aname in ("col", "column"):
 *             return col(self.loc, self.pstr)
 *         elif aname == "line":             # <<<<<<<<<<<<<<
 *             return line(self.loc, self.pstr)
 *         else:
 */
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_aname, __pyx_n_u_line, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 300, __pyx_L1_error)
  if (likely(__pyx_t_8)) {

    /* "cPyparsing.pyx":301
 *             return col(self.loc, self.pstr)
 *         elif aname == "line":
 *             return line(self.loc, self.pstr)             # <<<<<<<<<<<<<<
 *         else:
 *             raise AttributeError(aname)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_line); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pstr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 301, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":300
 *         elif aname in ("col", "column"):
 *             return col(self.loc, self.pstr)
 *         elif aname == "line":             # <<<<<<<<<<<<<<
 *             return line(self.loc, self.pstr)
 *         else:
 */
  }

  /* "cPyparsing.pyx":303
 *             return line(self.loc, self.pstr)
 *         else:
 *             raise AttributeError(aname)             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_AttributeError, __pyx_v_aname); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 303, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":290
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)
 * 
 *     def __getattr__(self, aname):             # <<<<<<<<<<<<<<
 *         """supported attributes by name are:
 *            - lineno - returns the line number of the exception text
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":305
 *             raise AttributeError(aname)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if self.pstr:
 *             if self.loc >= len(self.pstr):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_7__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18ParseBaseException_6__str__, "ParseBaseException.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_7__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18ParseBaseException_7__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException_6__str__};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_7__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 305, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 305, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 305, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_6__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_foundstr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_UCS4 __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":306
 * 
 *     def __str__(self):
 *         if self.pstr:             # <<<<<<<<<<<<<<
 *             if self.loc >= len(self.pstr):
 *                 foundstr = ', found end of text'
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pstr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":307
 *     def __str__(self):
 *         if self.pstr:
 *             if self.loc >= len(self.pstr):             # <<<<<<<<<<<<<<
 *                 foundstr = ', found end of text'
 *             else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pstr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_GE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":308
 *         if self.pstr:
 *             if self.loc >= len(self.pstr):
 *                 foundstr = ', found end of text'             # <<<<<<<<<<<<<<
 *             else:
 *                 foundstr = (', found %r' % self.pstr[self.loc:self.loc + 1]).replace(r'\\', '\\')
 */
      __Pyx_INCREF(__pyx_kp_u_found_end_of_text);
      __pyx_v_foundstr = __pyx_kp_u_found_end_of_text;

      /* "cPyparsing.pyx":307
 *     def __str__(self):
 *         if self.pstr:
 *             if self.loc >= len(self.pstr):             # <<<<<<<<<<<<<<
 *                 foundstr = ', found end of text'
 *             else:
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":310
 *                 foundstr = ', found end of text'
 *             else:
 *                 foundstr = (', found %r' % self.pstr[self.loc:self.loc + 1]).replace(r'\\', '\\')             # <<<<<<<<<<<<<<
 *         else:
 *             foundstr = ''
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pstr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_5, 0, 0, &__pyx_t_3, &__pyx_t_6, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_found_r, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_Replace(((PyObject*)__pyx_t_6), __pyx_kp_u__11, __pyx_kp_u__12, -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_foundstr = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":306
 * 
 *     def __str__(self):
 *         if self.pstr:             # <<<<<<<<<<<<<<
 *             if self.loc >= len(self.pstr):
 *                 foundstr = ', found end of text'
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":312
 *                 foundstr = (', found %r' % self.pstr[self.loc:self.loc + 1]).replace(r'\\', '\\')
 *         else:
 *             foundstr = ''             # <<<<<<<<<<<<<<
 *         return ("%s%s  (at char %d), (line:%d, col:%d)" %
 *                    (self.msg, foundstr, self.loc, self.lineno, self.column))
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_kp_u__10);
    __pyx_v_foundstr = __pyx_kp_u__10;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":313
 *         else:
 *             foundstr = ''
 *         return ("%s%s  (at char %d), (line:%d, col:%d)" %             # <<<<<<<<<<<<<<
 *                    (self.msg, foundstr, self.loc, self.lineno, self.column))
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = 0;
  __pyx_t_7 = 127;

  /* "cPyparsing.pyx":314
 *             foundstr = ''
 *         return ("%s%s  (at char %d), (line:%d, col:%d)" %
 *                    (self.msg, foundstr, self.loc, self.lineno, self.column))             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return _ustr(self)
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_msg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_6), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_7;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_foundstr), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_7;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u_at_char);
  __pyx_t_4 += 11;
  __Pyx_GIVEREF(__pyx_kp_u_at_char);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_at_char);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_IntOrLong(__pyx_t_3), __pyx_n_u_d); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_7;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_6);
  __pyx_t_6 = 0;
  __Pyx_INCREF(__pyx_kp_u_line_2);
  __pyx_t_4 += 9;
  __Pyx_GIVEREF(__pyx_kp_u_line_2);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u_line_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_lineno); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_IntOrLong(__pyx_t_6), __pyx_n_u_d); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_7;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u_col_2);
  __pyx_t_4 += 6;
  __Pyx_GIVEREF(__pyx_kp_u_col_2);
  PyTuple_SET_ITEM(__pyx_t_1, 6, __pyx_kp_u_col_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_column); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_IntOrLong(__pyx_t_3), __pyx_n_u_d); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_7;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_1, 7, __pyx_t_6);
  __pyx_t_6 = 0;
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_t_4 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__13);
  PyTuple_SET_ITEM(__pyx_t_1, 8, __pyx_kp_u__13);

  /* "cPyparsing.pyx":313
 *         else:
 *             foundstr = ''
 *         return ("%s%s  (at char %d), (line:%d, col:%d)" %             # <<<<<<<<<<<<<<
 *                    (self.msg, foundstr, self.loc, self.lineno, self.column))
 *     def __repr__(self):
 */
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_1, 9, __pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":305
 *             raise AttributeError(aname)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if self.pstr:
 *             if self.loc >= len(self.pstr):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_foundstr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":315
 *         return ("%s%s  (at char %d), (line:%d, col:%d)" %
 *                    (self.msg, foundstr, self.loc, self.lineno, self.column))
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 *     def markInputline(self, markerString=">!<"):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_9__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18ParseBaseException_8__repr__, "ParseBaseException.__repr__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_9__repr__ = {"__repr__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18ParseBaseException_9__repr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException_8__repr__};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_9__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 315, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__repr__") < 0)) __PYX_ERR(0, 315, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__repr__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 315, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_8__repr__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_8__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "cPyparsing.pyx":316
 *                    (self.msg, foundstr, self.loc, self.lineno, self.column))
 *     def __repr__(self):
 *         return _ustr(self)             # <<<<<<<<<<<<<<
 *     def markInputline(self, markerString=">!<"):
 *         """Extracts the exception line from the input string, and marks
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":315
 *         return ("%s%s  (at char %d), (line:%d, col:%d)" %
 *                    (self.msg, foundstr, self.loc, self.lineno, self.column))
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 *     def markInputline(self, markerString=">!<"):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":317
 *     def __repr__(self):
 *         return _ustr(self)
 *     def markInputline(self, markerString=">!<"):             # <<<<<<<<<<<<<<
 *         """Extracts the exception line from the input string, and marks
 *            the location of the exception with a special symbol.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_11markInputline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18ParseBaseException_10markInputline, "ParseBaseException.markInputline(self, markerString=u'>!<')\nExtracts the exception line from the input string, and marks\n           the location of the exception with a special symbol.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_11markInputline = {"markInputline", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18ParseBaseException_11markInputline, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException_10markInputline};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_11markInputline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_markerString = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("markInputline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_markerString,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__14)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 317, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_markerString);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 317, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "markInputline") < 0)) __PYX_ERR(0, 317, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_markerString = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("markInputline", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 317, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.markInputline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_10markInputline(__pyx_self, __pyx_v_self, __pyx_v_markerString);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_10markInputline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_markerString) {
  PyObject *__pyx_v_line_str = NULL;
  PyObject *__pyx_v_line_column = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("markInputline", 1);

  /* "cPyparsing.pyx":321
 *            the location of the exception with a special symbol.
 *         """
 *         line_str = self.line             # <<<<<<<<<<<<<<
 *         line_column = self.column - 1
 *         if markerString:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_line_str = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":322
 *         """
 *         line_str = self.line
 *         line_column = self.column - 1             # <<<<<<<<<<<<<<
 *         if markerString:
 *             line_str = "".join((line_str[:line_column],
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_SubtractObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_line_column = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":323
 *         line_str = self.line
 *         line_column = self.column - 1
 *         if markerString:             # <<<<<<<<<<<<<<
 *             line_str = "".join((line_str[:line_column],
 *                                 markerString, line_str[line_column:]))
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_markerString); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 323, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":324
 *         line_column = self.column - 1
 *         if markerString:
 *             line_str = "".join((line_str[:line_column],             # <<<<<<<<<<<<<<
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()
 */
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_line_str, 0, 0, NULL, &__pyx_v_line_column, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "cPyparsing.pyx":325
 *         if markerString:
 *             line_str = "".join((line_str[:line_column],
 *                                 markerString, line_str[line_column:]))             # <<<<<<<<<<<<<<
 *         return line_str.strip()
 *     def __dir__(self):
 */
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_line_str, 0, 0, &__pyx_v_line_column, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":324
 *         line_column = self.column - 1
 *         if markerString:
 *             line_str = "".join((line_str[:line_column],             # <<<<<<<<<<<<<<
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()
 */
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 324, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_markerString);
    __Pyx_GIVEREF(__pyx_v_markerString);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_markerString)) __PYX_ERR(0, 324, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_1)) __PYX_ERR(0, 324, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_line_str, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":323
 *         line_str = self.line
 *         line_column = self.column - 1
 *         if markerString:             # <<<<<<<<<<<<<<
 *             line_str = "".join((line_str[:line_column],
 *                                 markerString, line_str[line_column:]))
 */
  }

  /* "cPyparsing.pyx":326
 *             line_str = "".join((line_str[:line_column],
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()             # <<<<<<<<<<<<<<
 *     def __dir__(self):
 *         return "lineno col line".split() + dir(type(self))
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_line_str, __pyx_n_s_strip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":317
 *     def __repr__(self):
 *         return _ustr(self)
 *     def markInputline(self, markerString=">!<"):             # <<<<<<<<<<<<<<
 *         """Extracts the exception line from the input string, and marks
 *            the location of the exception with a special symbol.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.markInputline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line_str);
  __Pyx_XDECREF(__pyx_v_line_column);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":327
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return "lineno col line".split() + dir(type(self))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_13__dir__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18ParseBaseException_12__dir__, "ParseBaseException.__dir__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_13__dir__ = {"__dir__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18ParseBaseException_13__dir__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException_12__dir__};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_13__dir__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dir__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 327, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__dir__") < 0)) __PYX_ERR(0, 327, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__dir__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 327, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__dir__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_12__dir__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_12__dir__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dir__", 1);

  /* "cPyparsing.pyx":328
 *         return line_str.strip()
 *     def __dir__(self):
 *         return "lineno col line".split() + dir(type(self))             # <<<<<<<<<<<<<<
 * 
 * class ParseException(ParseBaseException):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_Split(__pyx_kp_u_lineno_col_line, ((PyObject *)NULL), -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Dir(((PyObject *)Py_TYPE(__pyx_v_self))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":327
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return "lineno col line".split() + dir(type(self))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__dir__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":355
 *     __slots__ = ()
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def explain(exc, depth=16):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14ParseException_1explain(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_14ParseException_explain, "ParseException.explain(exc, depth=16)\n\n        Method to take an exception and translate the Python internal traceback into a list\n        of the pyparsing expressions that caused the exception to be raised.\n\n        Parameters:\n\n         - exc - exception raised during parsing (need not be a ParseException, in support\n           of Python exceptions that might be raised in a parse action)\n         - depth (default=16) - number of levels back in the stack trace to list expression\n           and function names; if None, the full stack trace names will be listed; if 0, only\n           the failing input line, marker, and exception string will be shown\n\n        Returns a multi-line string listing the ParserElements and/or function names in the\n        exception's stack trace.\n\n        Note: the diagnostic output will include string representations of the expressions\n        that failed to parse. These representations will be more helpful if you use `setName` to\n        give identifiable names to your expressions. Otherwise they will use the default string\n        forms, which may be cryptic to read.\n\n        explain() is only supported under Python 3.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_14ParseException_1explain = {"explain", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_14ParseException_1explain, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_14ParseException_explain};
static PyObject *__pyx_pw_10cPyparsing_14ParseException_1explain(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_exc = 0;
  PyObject *__pyx_v_depth = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("explain (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_exc,&__pyx_n_s_depth,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_16)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 355, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_depth);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 355, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "explain") < 0)) __PYX_ERR(0, 355, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_exc = values[0];
    __pyx_v_depth = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("explain", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 355, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseException.explain", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14ParseException_explain(__pyx_self, __pyx_v_exc, __pyx_v_depth);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14ParseException_explain(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_depth) {
  PyObject *__pyx_v_inspect = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_callers = NULL;
  PyObject *__pyx_v_seen = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_ff = NULL;
  PyObject *__pyx_v_frm = NULL;
  PyObject *__pyx_v_f_self = NULL;
  PyTypeObject *__pyx_v_self_type = NULL;
  PyObject *__pyx_v_code = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("explain", 0);
  __Pyx_INCREF(__pyx_v_depth);

  /* "cPyparsing.pyx":379
 *         explain() is only supported under Python 3.
 *         """
 *         import inspect             # <<<<<<<<<<<<<<
 * 
 *         if depth is None:
 */
  __pyx_t_1 = __Pyx_patch_inspect(__Pyx_ImportDottedModule(__pyx_n_s_inspect, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_inspect = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":381
 *         import inspect
 * 
 *         if depth is None:             # <<<<<<<<<<<<<<
 *             depth = sys.getrecursionlimit()
 *         ret = []
 */
  __pyx_t_2 = (__pyx_v_depth == Py_None);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":382
 * 
 *         if depth is None:
 *             depth = sys.getrecursionlimit()             # <<<<<<<<<<<<<<
 *         ret = []
 *         if isinstance(exc, ParseBaseException):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sys); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_getrecursionlimit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_depth, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":381
 *         import inspect
 * 
 *         if depth is None:             # <<<<<<<<<<<<<<
 *             depth = sys.getrecursionlimit()
 *         ret = []
 */
  }

  /* "cPyparsing.pyx":383
 *         if depth is None:
 *             depth = sys.getrecursionlimit()
 *         ret = []             # <<<<<<<<<<<<<<
 *         if isinstance(exc, ParseBaseException):
 *             ret.append(exc.line)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ret = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":384
 *             depth = sys.getrecursionlimit()
 *         ret = []
 *         if isinstance(exc, ParseBaseException):             # <<<<<<<<<<<<<<
 *             ret.append(exc.line)
 *             ret.append(' ' * (exc.col - 1) + '^')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":385
 *         ret = []
 *         if isinstance(exc, ParseBaseException):
 *             ret.append(exc.line)             # <<<<<<<<<<<<<<
 *             ret.append(' ' * (exc.col - 1) + '^')
 *         ret.append("{0}: {1}".format(type(exc).__name__, exc))
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 385, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":386
 *         if isinstance(exc, ParseBaseException):
 *             ret.append(exc.line)
 *             ret.append(' ' * (exc.col - 1) + '^')             # <<<<<<<<<<<<<<
 *         ret.append("{0}: {1}".format(type(exc).__name__, exc))
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_col); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Multiply(__pyx_kp_u__16, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__17); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_t_4); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":384
 *             depth = sys.getrecursionlimit()
 *         ret = []
 *         if isinstance(exc, ParseBaseException):             # <<<<<<<<<<<<<<
 *             ret.append(exc.line)
 *             ret.append(' ' * (exc.col - 1) + '^')
 */
  }

  /* "cPyparsing.pyx":387
 *             ret.append(exc.line)
 *             ret.append(' ' * (exc.col - 1) + '^')
 *         ret.append("{0}: {1}".format(type(exc).__name__, exc))             # <<<<<<<<<<<<<<
 * 
 *         if depth > 0:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_1, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_exc)), __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_3, __pyx_v_exc};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_t_4); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":389
 *         ret.append("{0}: {1}".format(type(exc).__name__, exc))
 * 
 *         if depth > 0:             # <<<<<<<<<<<<<<
 *             callers = inspect.getinnerframes(exc.__traceback__, context=depth)
 *             seen = set()
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_depth, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 389, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":390
 * 
 *         if depth > 0:
 *             callers = inspect.getinnerframes(exc.__traceback__, context=depth)             # <<<<<<<<<<<<<<
 *             seen = set()
 *             for i, ff in enumerate(callers[-depth:]):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_inspect, __pyx_n_s_getinnerframes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_traceback); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_context, __pyx_v_depth) < 0) __PYX_ERR(0, 390, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_callers = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "cPyparsing.pyx":391
 *         if depth > 0:
 *             callers = inspect.getinnerframes(exc.__traceback__, context=depth)
 *             seen = set()             # <<<<<<<<<<<<<<
 *             for i, ff in enumerate(callers[-depth:]):
 *                 frm = ff[0]
 */
    __pyx_t_7 = PySet_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_v_seen = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "cPyparsing.pyx":392
 *             callers = inspect.getinnerframes(exc.__traceback__, context=depth)
 *             seen = set()
 *             for i, ff in enumerate(callers[-depth:]):             # <<<<<<<<<<<<<<
 *                 frm = ff[0]
 * 
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_t_7 = __pyx_int_0;
    __pyx_t_1 = PyNumber_Negative(__pyx_v_depth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_callers, 0, 0, &__pyx_t_1, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_1 = __pyx_t_3; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 392, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 392, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 392, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 392, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 392, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_9(__pyx_t_1);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 392, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_ff, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_7);
      __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_7, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7);
      __pyx_t_7 = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":393
 *             seen = set()
 *             for i, ff in enumerate(callers[-depth:]):
 *                 frm = ff[0]             # <<<<<<<<<<<<<<
 * 
 *                 f_self = frm.f_locals.get('self', None)
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_ff, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF_SET(__pyx_v_frm, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":395
 *                 frm = ff[0]
 * 
 *                 f_self = frm.f_locals.get('self', None)             # <<<<<<<<<<<<<<
 *                 if isinstance(f_self, ParserElement):
 *                     if frm.f_code.co_name not in ('parseImpl', '_parseNoCache'):
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_frm, __pyx_n_s_f_locals); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_f_self, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":396
 * 
 *                 f_self = frm.f_locals.get('self', None)
 *                 if isinstance(f_self, ParserElement):             # <<<<<<<<<<<<<<
 *                     if frm.f_code.co_name not in ('parseImpl', '_parseNoCache'):
 *                         continue
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyObject_IsInstance(__pyx_v_f_self, __pyx_t_3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 396, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":397
 *                 f_self = frm.f_locals.get('self', None)
 *                 if isinstance(f_self, ParserElement):
 *                     if frm.f_code.co_name not in ('parseImpl', '_parseNoCache'):             # <<<<<<<<<<<<<<
 *                         continue
 *                     if f_self in seen:
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_frm, __pyx_n_s_f_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 397, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_co_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 397, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_parseImpl, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 397, __pyx_L1_error)
        if (__pyx_t_10) {
        } else {
          __pyx_t_2 = __pyx_t_10;
          goto __pyx_L10_bool_binop_done;
        }
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_parseNoCache, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 397, __pyx_L1_error)
        __pyx_t_2 = __pyx_t_10;
        __pyx_L10_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_10 = __pyx_t_2;
        if (__pyx_t_10) {

          /* "cPyparsing.pyx":398
 *                 if isinstance(f_self, ParserElement):
 *                     if frm.f_code.co_name not in ('parseImpl', '_parseNoCache'):
 *                         continue             # <<<<<<<<<<<<<<
 *                     if f_self in seen:
 *                         continue
 */
          goto __pyx_L6_continue;

          /* "cPyparsing.pyx":397
 *                 f_self = frm.f_locals.get('self', None)
 *                 if isinstance(f_self, ParserElement):
 *                     if frm.f_code.co_name not in ('parseImpl', '_parseNoCache'):             # <<<<<<<<<<<<<<
 *                         continue
 *                     if f_self in seen:
 */
        }

        /* "cPyparsing.pyx":399
 *                     if frm.f_code.co_name not in ('parseImpl', '_parseNoCache'):
 *                         continue
 *                     if f_self in seen:             # <<<<<<<<<<<<<<
 *                         continue
 *                     seen.add(f_self)
 */
        __pyx_t_10 = (__Pyx_PySet_ContainsTF(__pyx_v_f_self, __pyx_v_seen, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 399, __pyx_L1_error)
        if (__pyx_t_10) {

          /* "cPyparsing.pyx":400
 *                         continue
 *                     if f_self in seen:
 *                         continue             # <<<<<<<<<<<<<<
 *                     seen.add(f_self)
 * 
 */
          goto __pyx_L6_continue;

          /* "cPyparsing.pyx":399
 *                     if frm.f_code.co_name not in ('parseImpl', '_parseNoCache'):
 *                         continue
 *                     if f_self in seen:             # <<<<<<<<<<<<<<
 *                         continue
 *                     seen.add(f_self)
 */
        }

        /* "cPyparsing.pyx":401
 *                     if f_self in seen:
 *                         continue
 *                     seen.add(f_self)             # <<<<<<<<<<<<<<
 * 
 *                     self_type = type(f_self)
 */
        __pyx_t_6 = PySet_Add(__pyx_v_seen, __pyx_v_f_self); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 401, __pyx_L1_error)

        /* "cPyparsing.pyx":403
 *                     seen.add(f_self)
 * 
 *                     self_type = type(f_self)             # <<<<<<<<<<<<<<
 *                     ret.append("{0}.{1} - {2}".format(self_type.__module__,
 *                                                       self_type.__name__,
 */
        __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_f_self)));
        __Pyx_XDECREF_SET(__pyx_v_self_type, ((PyTypeObject*)((PyObject *)Py_TYPE(__pyx_v_f_self))));

        /* "cPyparsing.pyx":404
 * 
 *                     self_type = type(f_self)
 *                     ret.append("{0}.{1} - {2}".format(self_type.__module__,             # <<<<<<<<<<<<<<
 *                                                       self_type.__name__,
 *                                                       f_self))
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_1_2, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 404, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self_type), __pyx_n_s_module); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 404, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);

        /* "cPyparsing.pyx":405
 *                     self_type = type(f_self)
 *                     ret.append("{0}.{1} - {2}".format(self_type.__module__,
 *                                                       self_type.__name__,             # <<<<<<<<<<<<<<
 *                                                       f_self))
 *                 elif f_self is not None:
 */
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self_type), __pyx_n_s_name); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 405, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);

        /* "cPyparsing.pyx":406
 *                     ret.append("{0}.{1} - {2}".format(self_type.__module__,
 *                                                       self_type.__name__,
 *                                                       f_self))             # <<<<<<<<<<<<<<
 *                 elif f_self is not None:
 *                     self_type = type(f_self)
 */
        __pyx_t_13 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_13, __pyx_t_11, __pyx_t_12, __pyx_v_f_self};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 3+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }

        /* "cPyparsing.pyx":404
 * 
 *                     self_type = type(f_self)
 *                     ret.append("{0}.{1} - {2}".format(self_type.__module__,             # <<<<<<<<<<<<<<
 *                                                       self_type.__name__,
 *                                                       f_self))
 */
        __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_t_4); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 404, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "cPyparsing.pyx":396
 * 
 *                 f_self = frm.f_locals.get('self', None)
 *                 if isinstance(f_self, ParserElement):             # <<<<<<<<<<<<<<
 *                     if frm.f_code.co_name not in ('parseImpl', '_parseNoCache'):
 *                         continue
 */
        goto __pyx_L8;
      }

      /* "cPyparsing.pyx":407
 *                                                       self_type.__name__,
 *                                                       f_self))
 *                 elif f_self is not None:             # <<<<<<<<<<<<<<
 *                     self_type = type(f_self)
 *                     ret.append("{0}.{1}".format(self_type.__module__,
 */
      __pyx_t_10 = (__pyx_v_f_self != Py_None);
      if (__pyx_t_10) {

        /* "cPyparsing.pyx":408
 *                                                       f_self))
 *                 elif f_self is not None:
 *                     self_type = type(f_self)             # <<<<<<<<<<<<<<
 *                     ret.append("{0}.{1}".format(self_type.__module__,
 *                                                 self_type.__name__))
 */
        __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_f_self)));
        __Pyx_XDECREF_SET(__pyx_v_self_type, ((PyTypeObject*)((PyObject *)Py_TYPE(__pyx_v_f_self))));

        /* "cPyparsing.pyx":409
 *                 elif f_self is not None:
 *                     self_type = type(f_self)
 *                     ret.append("{0}.{1}".format(self_type.__module__,             # <<<<<<<<<<<<<<
 *                                                 self_type.__name__))
 *                 else:
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_1_3, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 409, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self_type), __pyx_n_s_module); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 409, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);

        /* "cPyparsing.pyx":410
 *                     self_type = type(f_self)
 *                     ret.append("{0}.{1}".format(self_type.__module__,
 *                                                 self_type.__name__))             # <<<<<<<<<<<<<<
 *                 else:
 *                     code = frm.f_code
 */
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self_type), __pyx_n_s_name); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 410, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_13 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_t_12, __pyx_t_11};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }

        /* "cPyparsing.pyx":409
 *                 elif f_self is not None:
 *                     self_type = type(f_self)
 *                     ret.append("{0}.{1}".format(self_type.__module__,             # <<<<<<<<<<<<<<
 *                                                 self_type.__name__))
 *                 else:
 */
        __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_t_4); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 409, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "cPyparsing.pyx":407
 *                                                       self_type.__name__,
 *                                                       f_self))
 *                 elif f_self is not None:             # <<<<<<<<<<<<<<
 *                     self_type = type(f_self)
 *                     ret.append("{0}.{1}".format(self_type.__module__,
 */
        goto __pyx_L8;
      }

      /* "cPyparsing.pyx":412
 *                                                 self_type.__name__))
 *                 else:
 *                     code = frm.f_code             # <<<<<<<<<<<<<<
 *                     if code.co_name in ('wrapper', '<module>'):
 *                         continue
 */
      /*else*/ {
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_frm, __pyx_n_s_f_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 412, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_code, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":413
 *                 else:
 *                     code = frm.f_code
 *                     if code.co_name in ('wrapper', '<module>'):             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_code, __pyx_n_s_co_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 413, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_wrapper, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 413, __pyx_L1_error)
        if (!__pyx_t_2) {
        } else {
          __pyx_t_10 = __pyx_t_2;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_kp_u_module_2, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 413, __pyx_L1_error)
        __pyx_t_10 = __pyx_t_2;
        __pyx_L14_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __pyx_t_10;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":414
 *                     code = frm.f_code
 *                     if code.co_name in ('wrapper', '<module>'):
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                     ret.append("{0}".format(code.co_name))
 */
          goto __pyx_L6_continue;

          /* "cPyparsing.pyx":413
 *                 else:
 *                     code = frm.f_code
 *                     if code.co_name in ('wrapper', '<module>'):             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
        }

        /* "cPyparsing.pyx":416
 *                         continue
 * 
 *                     ret.append("{0}".format(code.co_name))             # <<<<<<<<<<<<<<
 * 
 *                 depth -= 1
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 416, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_code, __pyx_n_s_co_name); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 416, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_11};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 416, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_t_4); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 416, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_L8:;

      /* "cPyparsing.pyx":418
 *                     ret.append("{0}".format(code.co_name))
 * 
 *                 depth -= 1             # <<<<<<<<<<<<<<
 *                 if not depth:
 *                     break
 */
      __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_depth, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_depth, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":419
 * 
 *                 depth -= 1
 *                 if not depth:             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_depth); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 419, __pyx_L1_error)
      __pyx_t_10 = (!__pyx_t_2);
      if (__pyx_t_10) {

        /* "cPyparsing.pyx":420
 *                 depth -= 1
 *                 if not depth:
 *                     break             # <<<<<<<<<<<<<<
 * 
 *         return '\n'.join(ret)
 */
        goto __pyx_L7_break;

        /* "cPyparsing.pyx":419
 * 
 *                 depth -= 1
 *                 if not depth:             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
      }

      /* "cPyparsing.pyx":392
 *             callers = inspect.getinnerframes(exc.__traceback__, context=depth)
 *             seen = set()
 *             for i, ff in enumerate(callers[-depth:]):             # <<<<<<<<<<<<<<
 *                 frm = ff[0]
 * 
 */
      __pyx_L6_continue:;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L17_for_end;
    __pyx_L7_break:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L17_for_end;
    __pyx_L17_for_end:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":389
 *         ret.append("{0}: {1}".format(type(exc).__name__, exc))
 * 
 *         if depth > 0:             # <<<<<<<<<<<<<<
 *             callers = inspect.getinnerframes(exc.__traceback__, context=depth)
 *             seen = set()
 */
  }

  /* "cPyparsing.pyx":422
 *                     break
 * 
 *         return '\n'.join(ret)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = PyUnicode_Join(__pyx_kp_u__19, __pyx_v_ret); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":355
 *     __slots__ = ()
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def explain(exc, depth=16):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.ParseException.explain", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_inspect);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_callers);
  __Pyx_XDECREF(__pyx_v_seen);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_ff);
  __Pyx_XDECREF(__pyx_v_frm);
  __Pyx_XDECREF(__pyx_v_f_self);
  __Pyx_XDECREF((PyObject *)__pyx_v_self_type);
  __Pyx_XDECREF(__pyx_v_code);
  __Pyx_XDECREF(__pyx_v_depth);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":459
 *     grammar could be improperly recursive
 *     """
 *     def __init__(self, parseElementList):             # <<<<<<<<<<<<<<
 *         self.parseElementTrace = parseElementList
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_25RecursiveGrammarException_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_25RecursiveGrammarException___init__, "RecursiveGrammarException.__init__(self, parseElementList)");
static PyMethodDef __pyx_mdef_10cPyparsing_25RecursiveGrammarException_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_25RecursiveGrammarException_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_25RecursiveGrammarException___init__};
static PyObject *__pyx_pw_10cPyparsing_25RecursiveGrammarException_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 459, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseElementList)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 459, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 459, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 459, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 459, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.RecursiveGrammarException.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_25RecursiveGrammarException___init__(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_25RecursiveGrammarException___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":460
 *     """
 *     def __init__(self, parseElementList):
 *         self.parseElementTrace = parseElementList             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseElementTrace, __pyx_v_parseElementList) < 0) __PYX_ERR(0, 460, __pyx_L1_error)

  /* "cPyparsing.pyx":459
 *     grammar could be improperly recursive
 *     """
 *     def __init__(self, parseElementList):             # <<<<<<<<<<<<<<
 *         self.parseElementTrace = parseElementList
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.RecursiveGrammarException.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":462
 *         self.parseElementTrace = parseElementList
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_25RecursiveGrammarException_3__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_25RecursiveGrammarException_2__str__, "RecursiveGrammarException.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_25RecursiveGrammarException_3__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_25RecursiveGrammarException_3__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_25RecursiveGrammarException_2__str__};
static PyObject *__pyx_pw_10cPyparsing_25RecursiveGrammarException_3__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 462, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 462, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 462, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.RecursiveGrammarException.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_25RecursiveGrammarException_2__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_25RecursiveGrammarException_2__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":463
 * 
 *     def __str__(self):
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseElementTrace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_RecursiveGrammarException_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":462
 *         self.parseElementTrace = parseElementList
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.RecursiveGrammarException.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":504
 * 
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):             # <<<<<<<<<<<<<<
 *         self.tup = (p1, p2)
 *     def __getitem__(self, i):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23_ParseResultsWithOffset___init__, "_ParseResultsWithOffset.__init__(self, p1, p2)");
static PyMethodDef __pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23_ParseResultsWithOffset___init__};
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_p1 = 0;
  PyObject *__pyx_v_p2 = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_p1,&__pyx_n_s_p2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 504, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p1)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 504, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(0, 504, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 504, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(0, 504, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 504, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_p1 = values[1];
    __pyx_v_p2 = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 504, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23_ParseResultsWithOffset___init__(__pyx_self, __pyx_v_self, __pyx_v_p1, __pyx_v_p2);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_p1, PyObject *__pyx_v_p2) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":505
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)             # <<<<<<<<<<<<<<
 *     def __getitem__(self, i):
 *         return self.tup[i]
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_p1);
  __Pyx_GIVEREF(__pyx_v_p1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_p1)) __PYX_ERR(0, 505, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_p2);
  __Pyx_GIVEREF(__pyx_v_p2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_p2)) __PYX_ERR(0, 505, __pyx_L1_error);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_tup, __pyx_t_1) < 0) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":504
 * 
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):             # <<<<<<<<<<<<<<
 *         self.tup = (p1, p2)
 *     def __getitem__(self, i):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":506
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.tup[i]
 *     def __repr__(self):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_3__getitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23_ParseResultsWithOffset_2__getitem__, "_ParseResultsWithOffset.__getitem__(self, i)");
static PyMethodDef __pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_3__getitem__ = {"__getitem__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_3__getitem__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23_ParseResultsWithOffset_2__getitem__};
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_3__getitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_i = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_i,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 506, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_i)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 506, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, 1); __PYX_ERR(0, 506, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__getitem__") < 0)) __PYX_ERR(0, 506, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_i = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 506, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23_ParseResultsWithOffset_2__getitem__(__pyx_self, __pyx_v_self, __pyx_v_i);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_2__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 1);

  /* "cPyparsing.pyx":507
 *         self.tup = (p1, p2)
 *     def __getitem__(self, i):
 *         return self.tup[i]             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return repr(self.tup[0])
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_tup); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":506
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.tup[i]
 *     def __repr__(self):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":508
 *     def __getitem__(self, i):
 *         return self.tup[i]
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.tup[0])
 *     def setOffset(self, i):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_5__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23_ParseResultsWithOffset_4__repr__, "_ParseResultsWithOffset.__repr__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_5__repr__ = {"__repr__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_5__repr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23_ParseResultsWithOffset_4__repr__};
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_5__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 508, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__repr__") < 0)) __PYX_ERR(0, 508, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__repr__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 508, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23_ParseResultsWithOffset_4__repr__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "cPyparsing.pyx":509
 *         return self.tup[i]
 *     def __repr__(self):
 *         return repr(self.tup[0])             # <<<<<<<<<<<<<<
 *     def setOffset(self, i):
 *         self.tup = (self.tup[0], i)
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_repr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_tup); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":508
 *     def __getitem__(self, i):
 *         return self.tup[i]
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.tup[0])
 *     def setOffset(self, i):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":510
 *     def __repr__(self):
 *         return repr(self.tup[0])
 *     def setOffset(self, i):             # <<<<<<<<<<<<<<
 *         self.tup = (self.tup[0], i)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_7setOffset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23_ParseResultsWithOffset_6setOffset, "_ParseResultsWithOffset.setOffset(self, i)");
static PyMethodDef __pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_7setOffset = {"setOffset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_7setOffset, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23_ParseResultsWithOffset_6setOffset};
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_7setOffset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_i = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setOffset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_i,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 510, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_i)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 510, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("setOffset", 1, 2, 2, 1); __PYX_ERR(0, 510, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setOffset") < 0)) __PYX_ERR(0, 510, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_i = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setOffset", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 510, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.setOffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23_ParseResultsWithOffset_6setOffset(__pyx_self, __pyx_v_self, __pyx_v_i);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_6setOffset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setOffset", 1);

  /* "cPyparsing.pyx":511
 *         return repr(self.tup[0])
 *     def setOffset(self, i):
 *         self.tup = (self.tup[0], i)             # <<<<<<<<<<<<<<
 * 
 * class ParseResults(object):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_tup); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(0, 511, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_i);
  __Pyx_GIVEREF(__pyx_v_i);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_i)) __PYX_ERR(0, 511, __pyx_L1_error);
  __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_tup, __pyx_t_1) < 0) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":510
 *     def __repr__(self):
 *         return repr(self.tup[0])
 *     def setOffset(self, i):             # <<<<<<<<<<<<<<
 *         self.tup = (self.tup[0], i)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.setOffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":556
 *         - year: 1999
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):             # <<<<<<<<<<<<<<
 *         if isinstance(toklist, cls):
 *             return toklist
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_1__new__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults___new__, "ParseResults.__new__(cls, toklist=None, name=None, asList=True, modal=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_1__new__ = {"__new__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_1__new__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults___new__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_1__new__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_toklist = 0;
  CYTHON_UNUSED PyObject *__pyx_v_name = 0;
  CYTHON_UNUSED PyObject *__pyx_v_asList = 0;
  CYTHON_UNUSED PyObject *__pyx_v_modal = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__new__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_toklist,&__pyx_n_s_name_2,&__pyx_n_s_asList,&__pyx_n_s_modal,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 556, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_toklist);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 556, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 556, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_asList);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 556, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_modal);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 556, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__new__") < 0)) __PYX_ERR(0, 556, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cls = values[0];
    __pyx_v_toklist = values[1];
    __pyx_v_name = values[2];
    __pyx_v_asList = values[3];
    __pyx_v_modal = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__new__", 0, 1, 5, __pyx_nargs); __PYX_ERR(0, 556, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults___new__(__pyx_self, __pyx_v_cls, __pyx_v_toklist, __pyx_v_name, __pyx_v_asList, __pyx_v_modal);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_toklist, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_asList, CYTHON_UNUSED PyObject *__pyx_v_modal) {
  PyObject *__pyx_v_retobj = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__new__", 1);

  /* "cPyparsing.pyx":557
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):
 *         if isinstance(toklist, cls):             # <<<<<<<<<<<<<<
 *             return toklist
 *         retobj = object.__new__(cls)
 */
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_toklist, __pyx_v_cls); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 557, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":558
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):
 *         if isinstance(toklist, cls):
 *             return toklist             # <<<<<<<<<<<<<<
 *         retobj = object.__new__(cls)
 *         retobj.__doinit = True
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_toklist);
    __pyx_r = __pyx_v_toklist;
    goto __pyx_L0;

    /* "cPyparsing.pyx":557
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):
 *         if isinstance(toklist, cls):             # <<<<<<<<<<<<<<
 *             return toklist
 *         retobj = object.__new__(cls)
 */
  }

  /* "cPyparsing.pyx":559
 *         if isinstance(toklist, cls):
 *             return toklist
 *         retobj = object.__new__(cls)             # <<<<<<<<<<<<<<
 *         retobj.__doinit = True
 *         return retobj
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_cls};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_retobj = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":560
 *             return toklist
 *         retobj = object.__new__(cls)
 *         retobj.__doinit = True             # <<<<<<<<<<<<<<
 *         return retobj
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_retobj, __pyx_n_s_ParseResults__doinit, Py_True) < 0) __PYX_ERR(0, 560, __pyx_L1_error)

  /* "cPyparsing.pyx":561
 *         retobj = object.__new__(cls)
 *         retobj.__doinit = True
 *         return retobj             # <<<<<<<<<<<<<<
 * 
 *     # Performance tuning: we construct a *lot* of these, so keep this
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_retobj);
  __pyx_r = __pyx_v_retobj;
  goto __pyx_L0;

  /* "cPyparsing.pyx":556
 *         - year: 1999
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):             # <<<<<<<<<<<<<<
 *         if isinstance(toklist, cls):
 *             return toklist
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_retobj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":565
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if self.__doinit:
 *             self.__doinit = False
 */

static PyObject *__pyx_pf_10cPyparsing_89__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, Py_None)) __PYX_ERR(0, 565, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(0, 565, __pyx_L1_error);
  __Pyx_INCREF(((PyObject *)Py_True));
  __Pyx_GIVEREF(((PyObject *)Py_True));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, ((PyObject *)Py_True))) __PYX_ERR(0, 565, __pyx_L1_error);
  __Pyx_INCREF(((PyObject *)Py_True));
  __Pyx_GIVEREF(((PyObject *)Py_True));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, ((PyObject *)Py_True))) __PYX_ERR(0, 565, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_isinstance);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_isinstance);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_isinstance)) __PYX_ERR(0, 565, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 565, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_3__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_2__init__, "ParseResults.__init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_3__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_3__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_2__init__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_3__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_toklist = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_asList = 0;
  PyObject *__pyx_v_modal = 0;
  PyObject *__pyx_v_isinstance = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_toklist,&__pyx_n_s_name_2,&__pyx_n_s_asList,&__pyx_n_s_modal,&__pyx_n_s_isinstance,0};
    __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self);
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_isinstance);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 565, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_toklist);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 565, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 565, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_asList);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 565, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_modal);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 565, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_isinstance);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 565, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 565, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_toklist = values[1];
    __pyx_v_name = values[2];
    __pyx_v_asList = values[3];
    __pyx_v_modal = values[4];
    __pyx_v_isinstance = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 6, __pyx_nargs); __PYX_ERR(0, 565, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_2__init__(__pyx_self, __pyx_v_self, __pyx_v_toklist, __pyx_v_name, __pyx_v_asList, __pyx_v_modal, __pyx_v_isinstance);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_2__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_toklist, PyObject *__pyx_v_name, PyObject *__pyx_v_asList, PyObject *__pyx_v_modal, PyObject *__pyx_v_isinstance) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_toklist);
  __Pyx_INCREF(__pyx_v_name);

  /* "cPyparsing.pyx":566
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):
 *         if self.__doinit:             # <<<<<<<<<<<<<<
 *             self.__doinit = False
 *             self.__name = None
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__doinit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":567
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):
 *         if self.__doinit:
 *             self.__doinit = False             # <<<<<<<<<<<<<<
 *             self.__name = None
 *             self.__parent = None
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__doinit, Py_False) < 0) __PYX_ERR(0, 567, __pyx_L1_error)

    /* "cPyparsing.pyx":568
 *         if self.__doinit:
 *             self.__doinit = False
 *             self.__name = None             # <<<<<<<<<<<<<<
 *             self.__parent = None
 *             self.__accumNames = {}
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name, Py_None) < 0) __PYX_ERR(0, 568, __pyx_L1_error)

    /* "cPyparsing.pyx":569
 *             self.__doinit = False
 *             self.__name = None
 *             self.__parent = None             # <<<<<<<<<<<<<<
 *             self.__accumNames = {}
 *             self.__asList = asList
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent, Py_None) < 0) __PYX_ERR(0, 569, __pyx_L1_error)

    /* "cPyparsing.pyx":570
 *             self.__name = None
 *             self.__parent = None
 *             self.__accumNames = {}             # <<<<<<<<<<<<<<
 *             self.__asList = asList
 *             self.__modal = modal
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames, __pyx_t_1) < 0) __PYX_ERR(0, 570, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":571
 *             self.__parent = None
 *             self.__accumNames = {}
 *             self.__asList = asList             # <<<<<<<<<<<<<<
 *             self.__modal = modal
 *             if toklist is None:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__asList, __pyx_v_asList) < 0) __PYX_ERR(0, 571, __pyx_L1_error)

    /* "cPyparsing.pyx":572
 *             self.__accumNames = {}
 *             self.__asList = asList
 *             self.__modal = modal             # <<<<<<<<<<<<<<
 *             if toklist is None:
 *                 toklist = []
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__modal, __pyx_v_modal) < 0) __PYX_ERR(0, 572, __pyx_L1_error)

    /* "cPyparsing.pyx":573
 *             self.__asList = asList
 *             self.__modal = modal
 *             if toklist is None:             # <<<<<<<<<<<<<<
 *                 toklist = []
 *             if isinstance(toklist, list):
 */
    __pyx_t_2 = (__pyx_v_toklist == Py_None);
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":574
 *             self.__modal = modal
 *             if toklist is None:
 *                 toklist = []             # <<<<<<<<<<<<<<
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]
 */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 574, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_toklist, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":573
 *             self.__asList = asList
 *             self.__modal = modal
 *             if toklist is None:             # <<<<<<<<<<<<<<
 *                 toklist = []
 *             if isinstance(toklist, list):
 */
    }

    /* "cPyparsing.pyx":575
 *             if toklist is None:
 *                 toklist = []
 *             if isinstance(toklist, list):             # <<<<<<<<<<<<<<
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):
 */
    __Pyx_INCREF(__pyx_v_isinstance);
    __pyx_t_3 = __pyx_v_isinstance; __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_toklist, ((PyObject *)(&PyList_Type))};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 575, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 575, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":576
 *                 toklist = []
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]             # <<<<<<<<<<<<<<
 *             elif isinstance(toklist, _generatorType):
 *                 self.__toklist = list(toklist)
 */
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_toklist, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 576, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_1) < 0) __PYX_ERR(0, 576, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":575
 *             if toklist is None:
 *                 toklist = []
 *             if isinstance(toklist, list):             # <<<<<<<<<<<<<<
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":577
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):             # <<<<<<<<<<<<<<
 *                 self.__toklist = list(toklist)
 *             else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_generatorType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_isinstance);
    __pyx_t_4 = __pyx_v_isinstance; __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_toklist, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 577, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":578
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):
 *                 self.__toklist = list(toklist)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.__toklist = [toklist]
 */
      __pyx_t_1 = PySequence_List(__pyx_v_toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 578, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_1) < 0) __PYX_ERR(0, 578, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":577
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):             # <<<<<<<<<<<<<<
 *                 self.__toklist = list(toklist)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":580
 *                 self.__toklist = list(toklist)
 *             else:
 *                 self.__toklist = [toklist]             # <<<<<<<<<<<<<<
 *             self.__tokdict = dict()
 * 
 */
    /*else*/ {
      __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_toklist);
      __Pyx_GIVEREF(__pyx_v_toklist);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_toklist)) __PYX_ERR(0, 580, __pyx_L1_error);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_1) < 0) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "cPyparsing.pyx":581
 *             else:
 *                 self.__toklist = [toklist]
 *             self.__tokdict = dict()             # <<<<<<<<<<<<<<
 * 
 *         if name is not None and name:
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict, __pyx_t_1) < 0) __PYX_ERR(0, 581, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":566
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):
 *         if self.__doinit:             # <<<<<<<<<<<<<<
 *             self.__doinit = False
 *             self.__name = None
 */
  }

  /* "cPyparsing.pyx":583
 *             self.__tokdict = dict()
 * 
 *         if name is not None and name:             # <<<<<<<<<<<<<<
 *             if not modal:
 *                 self.__accumNames[name] = 0
 */
  __pyx_t_7 = (__pyx_v_name != Py_None);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_name); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 583, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_7;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":584
 * 
 *         if name is not None and name:
 *             if not modal:             # <<<<<<<<<<<<<<
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_modal); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 584, __pyx_L1_error)
    __pyx_t_7 = (!__pyx_t_2);
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":585
 *         if name is not None and name:
 *             if not modal:
 *                 self.__accumNames[name] = 0             # <<<<<<<<<<<<<<
 *             if isinstance(name, int):
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 585, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_name, __pyx_int_0) < 0))) __PYX_ERR(0, 585, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":584
 * 
 *         if name is not None and name:
 *             if not modal:             # <<<<<<<<<<<<<<
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):
 */
    }

    /* "cPyparsing.pyx":586
 *             if not modal:
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):             # <<<<<<<<<<<<<<
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name
 */
    __Pyx_INCREF(__pyx_v_isinstance);
    __pyx_t_4 = __pyx_v_isinstance; __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_name, ((PyObject *)(&PyInt_Type))};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 586, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":587
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency             # <<<<<<<<<<<<<<
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ustr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 587, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_name};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":586
 *             if not modal:
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):             # <<<<<<<<<<<<<<
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name
 */
    }

    /* "cPyparsing.pyx":588
 *             if isinstance(name, int):
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name             # <<<<<<<<<<<<<<
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 *                 if isinstance(toklist, basestring):
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name, __pyx_v_name) < 0) __PYX_ERR(0, 588, __pyx_L1_error)

    /* "cPyparsing.pyx":589
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):             # <<<<<<<<<<<<<<
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_basestring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(Py_None)));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(Py_None)));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(Py_None)))) __PYX_ERR(0, 589, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4)) __PYX_ERR(0, 589, __pyx_L1_error);
    __Pyx_INCREF((PyObject *)(&PyList_Type));
    __Pyx_GIVEREF((PyObject *)(&PyList_Type));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, ((PyObject *)(&PyList_Type)))) __PYX_ERR(0, 589, __pyx_L1_error);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_v_isinstance);
    __pyx_t_4 = __pyx_v_isinstance; __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_toklist, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {
    } else {
      __pyx_t_7 = __pyx_t_2;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_toklist);
    __pyx_t_4 = __pyx_v_toklist;
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_4, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 589, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_8) {
    } else {
      __pyx_t_2 = __pyx_t_8;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_kp_u__10, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 589, __pyx_L1_error)
    if (!__pyx_t_8) {
    } else {
      __pyx_t_2 = __pyx_t_8;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_4, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 589, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __pyx_t_8;
    __pyx_L14_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = __pyx_t_2;
    __pyx_t_7 = __pyx_t_8;
    __pyx_L12_bool_binop_done:;
    __pyx_t_8 = (!__pyx_t_7);
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":590
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 *                 if isinstance(toklist, basestring):             # <<<<<<<<<<<<<<
 *                     toklist = [toklist]
 *                 if asList:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_basestring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 590, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_isinstance);
      __pyx_t_3 = __pyx_v_isinstance; __pyx_t_6 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_toklist, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 590, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 590, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_8) {

        /* "cPyparsing.pyx":591
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]             # <<<<<<<<<<<<<<
 *                 if asList:
 *                     if isinstance(toklist, ParseResults):
 */
        __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 591, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_toklist);
        __Pyx_GIVEREF(__pyx_v_toklist);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_toklist)) __PYX_ERR(0, 591, __pyx_L1_error);
        __Pyx_DECREF_SET(__pyx_v_toklist, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":590
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 *                 if isinstance(toklist, basestring):             # <<<<<<<<<<<<<<
 *                     toklist = [toklist]
 *                 if asList:
 */
      }

      /* "cPyparsing.pyx":592
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]
 *                 if asList:             # <<<<<<<<<<<<<<
 *                     if isinstance(toklist, ParseResults):
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist.__toklist), 0)
 */
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_asList); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 592, __pyx_L1_error)
      if (__pyx_t_8) {

        /* "cPyparsing.pyx":593
 *                     toklist = [toklist]
 *                 if asList:
 *                     if isinstance(toklist, ParseResults):             # <<<<<<<<<<<<<<
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist.__toklist), 0)
 *                     else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 593, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_v_isinstance);
        __pyx_t_4 = __pyx_v_isinstance; __pyx_t_6 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_toklist, __pyx_t_3};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 593, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 593, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_8) {

          /* "cPyparsing.pyx":594
 *                 if asList:
 *                     if isinstance(toklist, ParseResults):
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist.__toklist), 0)             # <<<<<<<<<<<<<<
 *                     else:
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist[0]), 0)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 594, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 594, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_toklist, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 594, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_9};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 594, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
          __pyx_t_6 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_int_0};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          if (unlikely((PyObject_SetItem(__pyx_v_self, __pyx_v_name, __pyx_t_1) < 0))) __PYX_ERR(0, 594, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "cPyparsing.pyx":593
 *                     toklist = [toklist]
 *                 if asList:
 *                     if isinstance(toklist, ParseResults):             # <<<<<<<<<<<<<<
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist.__toklist), 0)
 *                     else:
 */
          goto __pyx_L19;
        }

        /* "cPyparsing.pyx":596
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist.__toklist), 0)
 *                     else:
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist[0]), 0)             # <<<<<<<<<<<<<<
 *                     self[name].__name = name
 *                 else:
 */
        /*else*/ {
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 596, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 596, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_toklist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 596, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_9};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 596, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
          __pyx_t_6 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_int_0};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          if (unlikely((PyObject_SetItem(__pyx_v_self, __pyx_v_name, __pyx_t_1) < 0))) __PYX_ERR(0, 596, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L19:;

        /* "cPyparsing.pyx":597
 *                     else:
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist[0]), 0)
 *                     self[name].__name = name             # <<<<<<<<<<<<<<
 *                 else:
 *                     try:
 */
        __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_self, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_ParseResults__name, __pyx_v_name) < 0) __PYX_ERR(0, 597, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":592
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]
 *                 if asList:             # <<<<<<<<<<<<<<
 *                     if isinstance(toklist, ParseResults):
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist.__toklist), 0)
 */
        goto __pyx_L18;
      }

      /* "cPyparsing.pyx":599
 *                     self[name].__name = name
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):
 */
      /*else*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          /*try:*/ {

            /* "cPyparsing.pyx":600
 *                 else:
 *                     try:
 *                         self[name] = toklist[0]             # <<<<<<<<<<<<<<
 *                     except (KeyError, TypeError, IndexError):
 *                         self[name] = toklist
 */
            __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_toklist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 600, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (unlikely((PyObject_SetItem(__pyx_v_self, __pyx_v_name, __pyx_t_1) < 0))) __PYX_ERR(0, 600, __pyx_L20_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "cPyparsing.pyx":599
 *                     self[name].__name = name
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):
 */
          }
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          goto __pyx_L25_try_end;
          __pyx_L20_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":601
 *                     try:
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):             # <<<<<<<<<<<<<<
 *                         self[name] = toklist
 * 
 */
          __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
          if (__pyx_t_5) {
            __Pyx_AddTraceback("cPyparsing.ParseResults.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_3) < 0) __PYX_ERR(0, 601, __pyx_L22_except_error)
            __Pyx_XGOTREF(__pyx_t_1);
            __Pyx_XGOTREF(__pyx_t_4);
            __Pyx_XGOTREF(__pyx_t_3);

            /* "cPyparsing.pyx":602
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):
 *                         self[name] = toklist             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, i):
 */
            if (unlikely((PyObject_SetItem(__pyx_v_self, __pyx_v_name, __pyx_v_toklist) < 0))) __PYX_ERR(0, 602, __pyx_L22_except_error)
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            goto __pyx_L21_exception_handled;
          }
          goto __pyx_L22_except_error;

          /* "cPyparsing.pyx":599
 *                     self[name].__name = name
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):
 */
          __pyx_L22_except_error:;
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          goto __pyx_L1_error;
          __pyx_L21_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          __pyx_L25_try_end:;
        }
      }
      __pyx_L18:;

      /* "cPyparsing.pyx":589
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):             # <<<<<<<<<<<<<<
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]
 */
    }

    /* "cPyparsing.pyx":583
 *             self.__tokdict = dict()
 * 
 *         if name is not None and name:             # <<<<<<<<<<<<<<
 *             if not modal:
 *                 self.__accumNames[name] = 0
 */
  }

  /* "cPyparsing.pyx":565
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if self.__doinit:
 *             self.__doinit = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_toklist);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":604
 *                         self[name] = toklist
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_5__getitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_4__getitem__, "ParseResults.__getitem__(self, i)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_5__getitem__ = {"__getitem__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_5__getitem__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_4__getitem__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_5__getitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_i = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_i,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_i)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, 1); __PYX_ERR(0, 604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__getitem__") < 0)) __PYX_ERR(0, 604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_i = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_4__getitem__(__pyx_self, __pyx_v_self, __pyx_v_i);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  PyObject *__pyx_8genexpr5__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 1);

  /* "cPyparsing.pyx":605
 * 
 *     def __getitem__(self, i):
 *         if isinstance(i, (int, slice)):             # <<<<<<<<<<<<<<
 *             return self.__toklist[i]
 *         else:
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_i); 
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = PySlice_Check(__pyx_v_i); 
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":606
 *     def __getitem__(self, i):
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]             # <<<<<<<<<<<<<<
 *         else:
 *             if i not in self.__accumNames:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":605
 * 
 *     def __getitem__(self, i):
 *         if isinstance(i, (int, slice)):             # <<<<<<<<<<<<<<
 *             return self.__toklist[i]
 *         else:
 */
  }

  /* "cPyparsing.pyx":608
 *             return self.__toklist[i]
 *         else:
 *             if i not in self.__accumNames:             # <<<<<<<<<<<<<<
 *                 return self.__tokdict[i][-1][0]
 *             else:
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 608, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_i, __pyx_t_4, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 608, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":609
 *         else:
 *             if i not in self.__accumNames:
 *                 return self.__tokdict[i][-1][0]             # <<<<<<<<<<<<<<
 *             else:
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 609, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 609, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_3, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 609, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 609, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":608
 *             return self.__toklist[i]
 *         else:
 *             if i not in self.__accumNames:             # <<<<<<<<<<<<<<
 *                 return self.__tokdict[i][-1][0]
 *             else:
 */
    }

    /* "cPyparsing.pyx":611
 *                 return self.__tokdict[i][-1][0]
 *             else:
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 611, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      { /* enter inner scope */
        __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 611, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 611, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_i); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 611, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
          __pyx_t_6 = __pyx_t_7; __Pyx_INCREF(__pyx_t_6);
          __pyx_t_8 = 0;
          __pyx_t_9 = NULL;
        } else {
          __pyx_t_8 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 611, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 611, __pyx_L9_error)
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        for (;;) {
          if (likely(!__pyx_t_9)) {
            if (likely(PyList_CheckExact(__pyx_t_6))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 611, __pyx_L9_error)
                #endif
                if (__pyx_t_8 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_7 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_7); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 611, __pyx_L9_error)
              #else
              __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 611, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_7);
              #endif
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 611, __pyx_L9_error)
                #endif
                if (__pyx_t_8 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_7); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 611, __pyx_L9_error)
              #else
              __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 611, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_7);
              #endif
            }
          } else {
            __pyx_t_7 = __pyx_t_9(__pyx_t_6);
            if (unlikely(!__pyx_t_7)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 611, __pyx_L9_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_7);
          }
          __Pyx_XDECREF_SET(__pyx_8genexpr5__pyx_v_v, __pyx_t_7);
          __pyx_t_7 = 0;
          __pyx_t_7 = __Pyx_GetItemInt(__pyx_8genexpr5__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 611, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_5, (PyObject*)__pyx_t_7))) __PYX_ERR(0, 611, __pyx_L9_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_v); __pyx_8genexpr5__pyx_v_v = 0;
        goto __pyx_L13_exit_scope;
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_v); __pyx_8genexpr5__pyx_v_v = 0;
        goto __pyx_L1_error;
        __pyx_L13_exit_scope:;
      } /* exit inner scope */
      __pyx_t_6 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 611, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;
    }
  }

  /* "cPyparsing.pyx":604
 *                         self[name] = toklist
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":613
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 */

static PyObject *__pyx_pf_10cPyparsing_91__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_isinstance);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_isinstance);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_isinstance)) __PYX_ERR(0, 613, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 613, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 613, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_7__setitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_6__setitem__, "ParseResults.__setitem__(self, k, v, isinstance=isinstance)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_7__setitem__ = {"__setitem__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_7__setitem__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_6__setitem__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_7__setitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_v = 0;
  PyObject *__pyx_v_isinstance = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_k,&__pyx_n_s_v,&__pyx_n_s_isinstance,0};
    __pyx_defaults1 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self);
    values[3] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_isinstance);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 613, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 613, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__setitem__", 0, 3, 4, 1); __PYX_ERR(0, 613, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_v)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 613, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__setitem__", 0, 3, 4, 2); __PYX_ERR(0, 613, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_isinstance);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 613, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setitem__") < 0)) __PYX_ERR(0, 613, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_k = values[1];
    __pyx_v_v = values[2];
    __pyx_v_isinstance = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setitem__", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 613, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_6__setitem__(__pyx_self, __pyx_v_self, __pyx_v_k, __pyx_v_v, __pyx_v_isinstance);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6__setitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_v, PyObject *__pyx_v_isinstance) {
  PyObject *__pyx_v_sub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 1);

  /* "cPyparsing.pyx":614
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):
 *         if isinstance(v, _ParseResultsWithOffset):             # <<<<<<<<<<<<<<
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_isinstance);
  __pyx_t_3 = __pyx_v_isinstance; __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_v, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":615
 *     def __setitem__(self, k, v, isinstance=isinstance):
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]             # <<<<<<<<<<<<<<
 *             sub = v[0]
 *         elif isinstance(k, (int, slice)):
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_k, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 615, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_v);
    __Pyx_GIVEREF(__pyx_v_v);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_v)) __PYX_ERR(0, 615, __pyx_L1_error);
    __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_v_k, __pyx_t_3) < 0))) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":616
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]             # <<<<<<<<<<<<<<
 *         elif isinstance(k, (int, slice)):
 *             self.__toklist[k] = v
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_sub = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":614
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):
 *         if isinstance(v, _ParseResultsWithOffset):             # <<<<<<<<<<<<<<
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":617
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]
 *         elif isinstance(k, (int, slice)):             # <<<<<<<<<<<<<<
 *             self.__toklist[k] = v
 *             sub = v
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)(&PyInt_Type));
  __Pyx_GIVEREF((PyObject *)(&PyInt_Type));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)(&PyInt_Type)))) __PYX_ERR(0, 617, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)(&PySlice_Type));
  __Pyx_GIVEREF((PyObject *)(&PySlice_Type));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)(&PySlice_Type)))) __PYX_ERR(0, 617, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_isinstance);
  __pyx_t_1 = __pyx_v_isinstance; __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_k, __pyx_t_2};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 617, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":618
 *             sub = v[0]
 *         elif isinstance(k, (int, slice)):
 *             self.__toklist[k] = v             # <<<<<<<<<<<<<<
 *             sub = v
 *         else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely((PyObject_SetItem(__pyx_t_3, __pyx_v_k, __pyx_v_v) < 0))) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":619
 *         elif isinstance(k, (int, slice)):
 *             self.__toklist[k] = v
 *             sub = v             # <<<<<<<<<<<<<<
 *         else:
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]
 */
    __Pyx_INCREF(__pyx_v_v);
    __pyx_v_sub = __pyx_v_v;

    /* "cPyparsing.pyx":617
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]
 *         elif isinstance(k, (int, slice)):             # <<<<<<<<<<<<<<
 *             self.__toklist[k] = v
 *             sub = v
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":621
 *             sub = v
 *         else:
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]             # <<<<<<<<<<<<<<
 *             sub = v
 *         if isinstance(sub, ParseResults):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_k, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 621, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_v, __pyx_int_0};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_k, __pyx_t_2) < 0))) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":622
 *         else:
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]
 *             sub = v             # <<<<<<<<<<<<<<
 *         if isinstance(sub, ParseResults):
 *             sub.__parent = wkref(self)
 */
    __Pyx_INCREF(__pyx_v_v);
    __pyx_v_sub = __pyx_v_v;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":623
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]
 *             sub = v
 *         if isinstance(sub, ParseResults):             # <<<<<<<<<<<<<<
 *             sub.__parent = wkref(self)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_isinstance);
  __pyx_t_3 = __pyx_v_isinstance; __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_sub, __pyx_t_1};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 623, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":624
 *             sub = v
 *         if isinstance(sub, ParseResults):
 *             sub.__parent = wkref(self)             # <<<<<<<<<<<<<<
 * 
 *     def __delitem__(self, i):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_wkref); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 624, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 624, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_sub, __pyx_n_s_ParseResults__parent, __pyx_t_2) < 0) __PYX_ERR(0, 624, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":623
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]
 *             sub = v
 *         if isinstance(sub, ParseResults):             # <<<<<<<<<<<<<<
 *             sub.__parent = wkref(self)
 * 
 */
  }

  /* "cPyparsing.pyx":613
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sub);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":626
 *             sub.__parent = wkref(self)
 * 
 *     def __delitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_9__delitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_8__delitem__, "ParseResults.__delitem__(self, i)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_9__delitem__ = {"__delitem__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_9__delitem__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_8__delitem__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_9__delitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_i = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__delitem__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_i,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 626, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_i)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 626, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__delitem__", 1, 2, 2, 1); __PYX_ERR(0, 626, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__delitem__") < 0)) __PYX_ERR(0, 626, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_i = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__delitem__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 626, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__delitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_8__delitem__(__pyx_self, __pyx_v_self, __pyx_v_i);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_8__delitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  Py_ssize_t __pyx_v_mylen;
  PyObject *__pyx_v_removed = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_occurrences = NULL;
  PyObject *__pyx_v_j = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_position = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  PyObject *(*__pyx_t_15)(PyObject *);
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *(*__pyx_t_19)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__delitem__", 0);
  __Pyx_INCREF(__pyx_v_i);

  /* "cPyparsing.pyx":627
 * 
 *     def __delitem__(self, i):
 *         if isinstance(i, (int, slice)):             # <<<<<<<<<<<<<<
 *             mylen = len(self.__toklist)
 *             del self.__toklist[i]
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_i); 
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = PySlice_Check(__pyx_v_i); 
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":628
 *     def __delitem__(self, i):
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)             # <<<<<<<<<<<<<<
 *             del self.__toklist[i]
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 628, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 628, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_mylen = __pyx_t_4;

    /* "cPyparsing.pyx":629
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 *             del self.__toklist[i]             # <<<<<<<<<<<<<<
 * 
 *             # convert int to slice
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely((PyObject_DelItem(__pyx_t_3, __pyx_v_i) < 0))) __PYX_ERR(0, 629, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":632
 * 
 *             # convert int to slice
 *             if isinstance(i, int):             # <<<<<<<<<<<<<<
 *                 if i < 0:
 *                     i += mylen
 */
    __pyx_t_1 = PyInt_Check(__pyx_v_i); 
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":633
 *             # convert int to slice
 *             if isinstance(i, int):
 *                 if i < 0:             # <<<<<<<<<<<<<<
 *                     i += mylen
 *                 i = slice(i, i + 1)
 */
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_i, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 633, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_1) {

        /* "cPyparsing.pyx":634
 *             if isinstance(i, int):
 *                 if i < 0:
 *                     i += mylen             # <<<<<<<<<<<<<<
 *                 i = slice(i, i + 1)
 *             # get removed indices
 */
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_mylen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 634, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = PyNumber_InPlaceAdd(__pyx_v_i, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 634, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "cPyparsing.pyx":633
 *             # convert int to slice
 *             if isinstance(i, int):
 *                 if i < 0:             # <<<<<<<<<<<<<<
 *                     i += mylen
 *                 i = slice(i, i + 1)
 */
      }

      /* "cPyparsing.pyx":635
 *                 if i < 0:
 *                     i += mylen
 *                 i = slice(i, i + 1)             # <<<<<<<<<<<<<<
 *             # get removed indices
 *             removed = list(range(*i.indices(mylen)))
 */
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 635, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PySlice_New(__pyx_v_i, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 635, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":632
 * 
 *             # convert int to slice
 *             if isinstance(i, int):             # <<<<<<<<<<<<<<
 *                 if i < 0:
 *                     i += mylen
 */
    }

    /* "cPyparsing.pyx":637
 *                 i = slice(i, i + 1)
 *             # get removed indices
 *             removed = list(range(*i.indices(mylen)))             # <<<<<<<<<<<<<<
 *             removed.reverse()
 *             # fixup indices in token dictionary
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_range); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_i, __pyx_n_s_indices); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyInt_FromSsize_t(__pyx_v_mylen); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 637, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = __Pyx_PySequence_Tuple(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PySequence_ListKeepNew(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_removed = ((PyObject*)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":638
 *             # get removed indices
 *             removed = list(range(*i.indices(mylen)))
 *             removed.reverse()             # <<<<<<<<<<<<<<
 *             # fixup indices in token dictionary
 *             for name, occurrences in self.__tokdict.items():
 */
    __pyx_t_10 = PyList_Reverse(__pyx_v_removed); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 638, __pyx_L1_error)

    /* "cPyparsing.pyx":640
 *             removed.reverse()
 *             # fixup indices in token dictionary
 *             for name, occurrences in self.__tokdict.items():             # <<<<<<<<<<<<<<
 *                 for j in removed:
 *                     for k, (value, position) in enumerate(occurrences):
 */
    __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (unlikely(__pyx_t_5 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
      __PYX_ERR(0, 640, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_dict_iterator(__pyx_t_5, 0, __pyx_n_s_items, (&__pyx_t_11), (&__pyx_t_9)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6);
    __pyx_t_6 = __pyx_t_3;
    __pyx_t_3 = 0;
    while (1) {
      __pyx_t_12 = __Pyx_dict_iter_next(__pyx_t_6, __pyx_t_11, &__pyx_t_4, &__pyx_t_3, &__pyx_t_5, NULL, __pyx_t_9);
      if (unlikely(__pyx_t_12 == 0)) break;
      if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_v_occurrences, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":641
 *             # fixup indices in token dictionary
 *             for name, occurrences in self.__tokdict.items():
 *                 for j in removed:             # <<<<<<<<<<<<<<
 *                     for k, (value, position) in enumerate(occurrences):
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 */
      __pyx_t_5 = __pyx_v_removed; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_13 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 641, __pyx_L1_error)
          #endif
          if (__pyx_t_13 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_13); __Pyx_INCREF(__pyx_t_3); __pyx_t_13++; if (unlikely((0 < 0))) __PYX_ERR(0, 641, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 641, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "cPyparsing.pyx":642
 *             for name, occurrences in self.__tokdict.items():
 *                 for j in removed:
 *                     for k, (value, position) in enumerate(occurrences):             # <<<<<<<<<<<<<<
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 *         else:
 */
        __Pyx_INCREF(__pyx_int_0);
        __pyx_t_3 = __pyx_int_0;
        if (likely(PyList_CheckExact(__pyx_v_occurrences)) || PyTuple_CheckExact(__pyx_v_occurrences)) {
          __pyx_t_7 = __pyx_v_occurrences; __Pyx_INCREF(__pyx_t_7);
          __pyx_t_14 = 0;
          __pyx_t_15 = NULL;
        } else {
          __pyx_t_14 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_v_occurrences); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 642, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 642, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_15)) {
            if (likely(PyList_CheckExact(__pyx_t_7))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 642, __pyx_L1_error)
                #endif
                if (__pyx_t_14 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_14); __Pyx_INCREF(__pyx_t_8); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 642, __pyx_L1_error)
              #else
              __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 642, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 642, __pyx_L1_error)
                #endif
                if (__pyx_t_14 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_14); __Pyx_INCREF(__pyx_t_8); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 642, __pyx_L1_error)
              #else
              __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 642, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            }
          } else {
            __pyx_t_8 = __pyx_t_15(__pyx_t_7);
            if (unlikely(!__pyx_t_8)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 642, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_8);
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
            PyObject* sequence = __pyx_t_8;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 642, __pyx_L1_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_16 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_17 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_16 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_17 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_16);
            __Pyx_INCREF(__pyx_t_17);
            #else
            __pyx_t_16 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 642, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            __pyx_t_17 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 642, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            #endif
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_18 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 642, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_18);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __pyx_t_19 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_18);
            index = 0; __pyx_t_16 = __pyx_t_19(__pyx_t_18); if (unlikely(!__pyx_t_16)) goto __pyx_L14_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_16);
            index = 1; __pyx_t_17 = __pyx_t_19(__pyx_t_18); if (unlikely(!__pyx_t_17)) goto __pyx_L14_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_17);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_19(__pyx_t_18), 2) < 0) __PYX_ERR(0, 642, __pyx_L1_error)
            __pyx_t_19 = NULL;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            goto __pyx_L15_unpacking_done;
            __pyx_L14_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            __pyx_t_19 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 642, __pyx_L1_error)
            __pyx_L15_unpacking_done:;
          }
          __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_16);
          __pyx_t_16 = 0;
          __Pyx_XDECREF_SET(__pyx_v_position, __pyx_t_17);
          __pyx_t_17 = 0;
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_3);
          __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 642, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_3);
          __pyx_t_3 = __pyx_t_8;
          __pyx_t_8 = 0;

          /* "cPyparsing.pyx":643
 *                 for j in removed:
 *                     for k, (value, position) in enumerate(occurrences):
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))             # <<<<<<<<<<<<<<
 *         else:
 *             del self.__tokdict[i]
 */
          __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 643, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_16 = PyObject_RichCompare(__pyx_v_position, __pyx_v_j, Py_GT); __Pyx_XGOTREF(__pyx_t_16); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 643, __pyx_L1_error)
          __pyx_t_18 = PyNumber_Subtract(__pyx_v_position, __pyx_t_16); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 643, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = NULL;
          __pyx_t_12 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_16)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
              __pyx_t_12 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_16, __pyx_v_value, __pyx_t_18};
            __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_17, __pyx_callargs+1-__pyx_t_12, 2+__pyx_t_12);
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 643, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          }
          if (unlikely((PyObject_SetItem(__pyx_v_occurrences, __pyx_v_k, __pyx_t_8) < 0))) __PYX_ERR(0, 643, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "cPyparsing.pyx":642
 *             for name, occurrences in self.__tokdict.items():
 *                 for j in removed:
 *                     for k, (value, position) in enumerate(occurrences):             # <<<<<<<<<<<<<<
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 *         else:
 */
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "cPyparsing.pyx":641
 *             # fixup indices in token dictionary
 *             for name, occurrences in self.__tokdict.items():
 *                 for j in removed:             # <<<<<<<<<<<<<<
 *                     for k, (value, position) in enumerate(occurrences):
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 */
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":627
 * 
 *     def __delitem__(self, i):
 *         if isinstance(i, (int, slice)):             # <<<<<<<<<<<<<<
 *             mylen = len(self.__toklist)
 *             del self.__toklist[i]
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":645
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 *         else:
 *             del self.__tokdict[i]             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, k):
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 645, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely((PyObject_DelItem(__pyx_t_6, __pyx_v_i) < 0))) __PYX_ERR(0, 645, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":626
 *             sub.__parent = wkref(self)
 * 
 *     def __delitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__delitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_removed);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_occurrences);
  __Pyx_XDECREF(__pyx_v_j);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_position);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":647
 *             del self.__tokdict[i]
 * 
 *     def __contains__(self, k):             # <<<<<<<<<<<<<<
 *         return k in self.__tokdict
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_11__contains__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_10__contains__, "ParseResults.__contains__(self, k)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_11__contains__ = {"__contains__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_11__contains__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_10__contains__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_11__contains__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_k = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_k,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 647, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 647, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__contains__", 1, 2, 2, 1); __PYX_ERR(0, 647, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__contains__") < 0)) __PYX_ERR(0, 647, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_k = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__contains__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 647, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_10__contains__(__pyx_self, __pyx_v_self, __pyx_v_k);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_10__contains__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_k) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__contains__", 1);

  /* "cPyparsing.pyx":648
 * 
 *     def __contains__(self, k):
 *         return k in self.__tokdict             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_k, __pyx_t_1, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":647
 *             del self.__tokdict[i]
 * 
 *     def __contains__(self, k):             # <<<<<<<<<<<<<<
 *         return k in self.__tokdict
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":650
 *         return k in self.__tokdict
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return len(self.__toklist)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_13__len__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_12__len__, "ParseResults.__len__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_13__len__ = {"__len__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_13__len__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_12__len__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_13__len__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 650, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__len__") < 0)) __PYX_ERR(0, 650, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__len__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 650, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_12__len__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_12__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__len__", 1);

  /* "cPyparsing.pyx":651
 * 
 *     def __len__(self):
 *         return len(self.__toklist)             # <<<<<<<<<<<<<<
 * 
 *     def __bool__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":650
 *         return k in self.__tokdict
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return len(self.__toklist)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":653
 *         return len(self.__toklist)
 * 
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return (not not self.__toklist)
 *     __nonzero__ = __bool__
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_15__bool__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_14__bool__, "ParseResults.__bool__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_15__bool__ = {"__bool__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_15__bool__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_14__bool__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_15__bool__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__bool__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 653, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__bool__") < 0)) __PYX_ERR(0, 653, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__bool__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 653, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__bool__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_14__bool__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_14__bool__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__bool__", 1);

  /* "cPyparsing.pyx":654
 * 
 *     def __bool__(self):
 *         return (not not self.__toklist)             # <<<<<<<<<<<<<<
 *     __nonzero__ = __bool__
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!(!__pyx_t_2))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":653
 *         return len(self.__toklist)
 * 
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return (not not self.__toklist)
 *     __nonzero__ = __bool__
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__bool__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":657
 *     __nonzero__ = __bool__
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return iter(self.__toklist)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_17__iter__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_16__iter__, "ParseResults.__iter__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_17__iter__ = {"__iter__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_17__iter__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_16__iter__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_17__iter__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 657, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__iter__") < 0)) __PYX_ERR(0, 657, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__iter__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 657, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_16__iter__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_16__iter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iter__", 1);

  /* "cPyparsing.pyx":658
 * 
 *     def __iter__(self):
 *         return iter(self.__toklist)             # <<<<<<<<<<<<<<
 * 
 *     def __reversed__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":657
 *     __nonzero__ = __bool__
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return iter(self.__toklist)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":660
 *         return iter(self.__toklist)
 * 
 *     def __reversed__(self):             # <<<<<<<<<<<<<<
 *         return iter(self.__toklist[::-1])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_19__reversed__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_18__reversed__, "ParseResults.__reversed__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_19__reversed__ = {"__reversed__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_19__reversed__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_18__reversed__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_19__reversed__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reversed__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 660, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__reversed__") < 0)) __PYX_ERR(0, 660, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__reversed__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 660, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__reversed__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_18__reversed__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_18__reversed__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reversed__", 1);

  /* "cPyparsing.pyx":661
 * 
 *     def __reversed__(self):
 *         return iter(self.__toklist[::-1])             # <<<<<<<<<<<<<<
 * 
 *     def _iterkeys(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_slice__21); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":660
 *         return iter(self.__toklist)
 * 
 *     def __reversed__(self):             # <<<<<<<<<<<<<<
 *         return iter(self.__toklist[::-1])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__reversed__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":663
 *         return iter(self.__toklist[::-1])
 * 
 *     def _iterkeys(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_21_iterkeys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_20_iterkeys, "ParseResults._iterkeys(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_21_iterkeys = {"_iterkeys", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_21_iterkeys, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_20_iterkeys};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_21_iterkeys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_iterkeys (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 663, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_iterkeys") < 0)) __PYX_ERR(0, 663, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_iterkeys", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 663, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults._iterkeys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_20_iterkeys(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_20_iterkeys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iterkeys", 1);

  /* "cPyparsing.pyx":664
 * 
 *     def _iterkeys(self):
 *         if hasattr(self.__tokdict, "iterkeys"):             # <<<<<<<<<<<<<<
 *             return self.__tokdict.iterkeys()
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_HasAttr(__pyx_t_1, __pyx_n_u_iterkeys); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":665
 *     def _iterkeys(self):
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()             # <<<<<<<<<<<<<<
 *         else:
 *             return iter(self.__tokdict)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 665, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_iterkeys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 665, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 665, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":664
 * 
 *     def _iterkeys(self):
 *         if hasattr(self.__tokdict, "iterkeys"):             # <<<<<<<<<<<<<<
 *             return self.__tokdict.iterkeys()
 *         else:
 */
  }

  /* "cPyparsing.pyx":667
 *             return self.__tokdict.iterkeys()
 *         else:
 *             return iter(self.__tokdict)             # <<<<<<<<<<<<<<
 * 
 *     def _itervalues(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":663
 *         return iter(self.__toklist[::-1])
 * 
 *     def _iterkeys(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults._iterkeys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":669
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_23_itervalues(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_22_itervalues, "ParseResults._itervalues(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_23_itervalues = {"_itervalues", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_23_itervalues, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_22_itervalues};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_23_itervalues(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_itervalues (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 669, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_itervalues") < 0)) __PYX_ERR(0, 669, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_itervalues", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 669, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults._itervalues", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_22_itervalues(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_11_itervalues_2generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":670
 * 
 *     def _itervalues(self):
 *         return (self[k] for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     def _iteritems(self):
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_11_itervalues_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_6_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 670, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_11_itervalues_2generator7, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults__itervalues_locals, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 670, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults._itervalues.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_11_itervalues_2generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 670, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 670, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 670, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 670, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 670, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 670, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 670, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 670, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 670, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 670, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 670, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 670, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":669
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_22_itervalues(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *__pyx_cur_scope;
  PyObject *__pyx_gb_10cPyparsing_12ParseResults_11_itervalues_2generator7 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_itervalues", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_5__itervalues(__pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 669, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":670
 * 
 *     def _itervalues(self):
 *         return (self[k] for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     def _iteritems(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_iterkeys_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __pyx_pf_10cPyparsing_12ParseResults_11_itervalues_genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":669
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults._itervalues", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_12ParseResults_11_itervalues_2generator7);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":672
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_25_iteritems(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_24_iteritems, "ParseResults._iteritems(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_25_iteritems = {"_iteritems", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_25_iteritems, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_24_iteritems};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_25_iteritems(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_iteritems (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 672, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_iteritems") < 0)) __PYX_ERR(0, 672, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_iteritems", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 672, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults._iteritems", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_24_iteritems(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_10_iteritems_2generator8(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":673
 * 
 *     def _iteritems(self):
 *         return ((k, self[k]) for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     if PY_3:
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_10_iteritems_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_8_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 673, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_10_iteritems_2generator8, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults__iteritems_locals_g, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 673, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults._iteritems.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_10_iteritems_2generator8(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 673, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 673, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 673, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 673, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 673, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 673, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 673, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 673, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 673, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 673, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 673, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 673, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 673, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_k);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_cur_scope->__pyx_v_k)) __PYX_ERR(0, 673, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4)) __PYX_ERR(0, 673, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 673, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":672
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_24_iteritems(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *__pyx_cur_scope;
  PyObject *__pyx_gb_10cPyparsing_12ParseResults_10_iteritems_2generator8 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iteritems", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_7__iteritems(__pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 672, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":673
 * 
 *     def _iteritems(self):
 *         return ((k, self[k]) for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     if PY_3:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_iterkeys_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __pyx_pf_10cPyparsing_12ParseResults_10_iteritems_genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":672
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults._iteritems", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_12ParseResults_10_iteritems_2generator8);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":695
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 *         def keys(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_27keys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_26keys, "ParseResults.keys(self)\nReturns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x).");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_27keys = {"keys", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_27keys, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_26keys};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_27keys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("keys (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 695, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "keys") < 0)) __PYX_ERR(0, 695, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("keys", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 695, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.keys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_26keys(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_26keys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("keys", 1);

  /* "cPyparsing.pyx":697
 *         def keys(self):
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())             # <<<<<<<<<<<<<<
 * 
 *         def values(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_iterkeys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":695
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 *         def keys(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.keys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":699
 *             return list(self.iterkeys())
 * 
 *         def values(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_29values(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_28values, "ParseResults.values(self)\nReturns all named result values (as a list in Python 2.x, as an iterator in Python 3.x).");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_29values = {"values", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_29values, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_28values};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_29values(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("values (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 699, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "values") < 0)) __PYX_ERR(0, 699, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("values", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 699, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.values", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_28values(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_28values(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("values", 1);

  /* "cPyparsing.pyx":701
 *         def values(self):
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())             # <<<<<<<<<<<<<<
 * 
 *         def items(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_itervalues); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":699
 *             return list(self.iterkeys())
 * 
 *         def values(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.values", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":703
 *             return list(self.itervalues())
 * 
 *         def items(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_31items(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_30items, "ParseResults.items(self)\nReturns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x).");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_31items = {"items", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_31items, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_30items};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_31items(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("items (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 703, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "items") < 0)) __PYX_ERR(0, 703, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("items", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 703, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.items", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_30items(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_30items(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("items", 1);

  /* "cPyparsing.pyx":705
 *         def items(self):
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())             # <<<<<<<<<<<<<<
 * 
 *     def haskeys(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_iteritems); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":703
 *             return list(self.itervalues())
 * 
 *         def items(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.items", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":707
 *             return list(self.iteritems())
 * 
 *     def haskeys(self):             # <<<<<<<<<<<<<<
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_33haskeys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_32haskeys, "ParseResults.haskeys(self)\nSince keys() returns an iterator, this method is helpful in bypassing\n           code that looks for the existence of any defined results names.");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_33haskeys = {"haskeys", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_33haskeys, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_32haskeys};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_33haskeys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("haskeys (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 707, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "haskeys") < 0)) __PYX_ERR(0, 707, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("haskeys", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 707, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.haskeys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_32haskeys(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_32haskeys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("haskeys", 1);

  /* "cPyparsing.pyx":710
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 *         return bool(self.__tokdict)             # <<<<<<<<<<<<<<
 * 
 *     def pop(self, *args, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!(!__pyx_t_2))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":707
 *             return list(self.iteritems())
 * 
 *     def haskeys(self):             # <<<<<<<<<<<<<<
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.haskeys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":712
 *         return bool(self.__tokdict)
 * 
 *     def pop(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Removes and returns item at specified index (default= ``last``).
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_35pop(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_34pop, "ParseResults.pop(self, *args, **kwargs)\n\n        Removes and returns item at specified index (default= ``last``).\n        Supports both ``list`` and ``dict`` semantics for ``pop()``. If\n        passed no argument or an integer argument, it will use ``list``\n        semantics and pop tokens from the list of parsed tokens. If passed\n        a non-integer argument (most likely a string), it will use ``dict``\n        semantics and pop the corresponding value from any defined results\n        names. A second default return value argument is supported, just as in\n        ``dict.pop()``.\n\n        Example::\n\n            def remove_first(tokens):\n                tokens.pop(0)\n            print(OneOrMore(Word(nums)).parseString(\"0 123 321\")) # -> ['0', '123', '321']\n            print(OneOrMore(Word(nums)).addParseAction(remove_first).parseString(\"0 123 321\")) # -> ['123', '321']\n\n            label = Word(alphas)\n            patt = label(\"LABEL\") + OneOrMore(Word(nums))\n            print(patt.parseString(\"AAB 123 321\").dump())\n\n            # Use pop() in a parse action to remove named result (note that corresponding value is not\n            # removed from list form of results)\n            def remove_LABEL(tokens):\n                tokens.pop(\"LABEL\")\n                return tokens\n            patt.addParseAction(remove_LABEL)\n            print(patt.parseString(\"AAB 123 321\").dump())\n\n        prints::\n\n            ['AAB', '123', '321']\n            - LABEL: AAB\n\n            ['AAB', '123', '321']\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_35pop = {"pop", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_35pop, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_34pop};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_35pop(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pop (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 712, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, used_pos_args, "pop") < 0)) __PYX_ERR(0, 712, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pop", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 712, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParseResults.pop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_34pop(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_34pop(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_defaultvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pop", 0);
  __Pyx_INCREF(__pyx_v_args);

  /* "cPyparsing.pyx":749
 *             ['AAB', '123', '321']
 *         """
 *         if not args:             # <<<<<<<<<<<<<<
 *             args = [-1]
 *         for k, v in kwargs.items():
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_args); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 749, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":750
 *         """
 *         if not args:
 *             args = [-1]             # <<<<<<<<<<<<<<
 *         for k, v in kwargs.items():
 *             if k == 'default':
 */
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_int_neg_1);
    __Pyx_GIVEREF(__pyx_int_neg_1);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_int_neg_1)) __PYX_ERR(0, 750, __pyx_L1_error);
    __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":749
 *             ['AAB', '123', '321']
 *         """
 *         if not args:             # <<<<<<<<<<<<<<
 *             args = [-1]
 *         for k, v in kwargs.items():
 */
  }

  /* "cPyparsing.pyx":751
 *         if not args:
 *             args = [-1]
 *         for k, v in kwargs.items():             # <<<<<<<<<<<<<<
 *             if k == 'default':
 *                 args = (args[0], v)
 */
  __pyx_t_4 = 0;
  __pyx_t_7 = __Pyx_dict_iterator(__pyx_v_kwargs, 1, __pyx_n_s_items, (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_3);
  __pyx_t_3 = __pyx_t_7;
  __pyx_t_7 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_3, __pyx_t_5, &__pyx_t_4, &__pyx_t_7, &__pyx_t_8, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "cPyparsing.pyx":752
 *             args = [-1]
 *         for k, v in kwargs.items():
 *             if k == 'default':             # <<<<<<<<<<<<<<
 *                 args = (args[0], v)
 *             else:
 */
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_default, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 752, __pyx_L1_error)
    if (likely(__pyx_t_2)) {

      /* "cPyparsing.pyx":753
 *         for k, v in kwargs.items():
 *             if k == 'default':
 *                 args = (args[0], v)             # <<<<<<<<<<<<<<
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 */
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 753, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 753, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_8);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8)) __PYX_ERR(0, 753, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_v);
      __Pyx_GIVEREF(__pyx_v_v);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_v)) __PYX_ERR(0, 753, __pyx_L1_error);
      __pyx_t_8 = 0;
      __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "cPyparsing.pyx":752
 *             args = [-1]
 *         for k, v in kwargs.items():
 *             if k == 'default':             # <<<<<<<<<<<<<<
 *                 args = (args[0], v)
 *             else:
 */
      goto __pyx_L6;
    }

    /* "cPyparsing.pyx":755
 *                 args = (args[0], v)
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)             # <<<<<<<<<<<<<<
 *         if (isinstance(args[0], int)
 *                 or len(args) == 1
 */
    /*else*/ {
      __pyx_t_7 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_pop_got_an_unexpected_keyword_ar, __pyx_v_k); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 755, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 755, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(0, 755, __pyx_L1_error)
    }
    __pyx_L6:;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":756
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 *         if (isinstance(args[0], int)             # <<<<<<<<<<<<<<
 *                 or len(args) == 1
 *                 or args[0] in self):
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyInt_Check(__pyx_t_3); 
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!__pyx_t_1) {
  } else {
    __pyx_t_2 = __pyx_t_1;
    goto __pyx_L8_bool_binop_done;
  }

  /* "cPyparsing.pyx":757
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 *         if (isinstance(args[0], int)
 *                 or len(args) == 1             # <<<<<<<<<<<<<<
 *                 or args[0] in self):
 *             index = args[0]
 */
  __pyx_t_5 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 757, __pyx_L1_error)
  __pyx_t_1 = (__pyx_t_5 == 1);
  if (!__pyx_t_1) {
  } else {
    __pyx_t_2 = __pyx_t_1;
    goto __pyx_L8_bool_binop_done;
  }

  /* "cPyparsing.pyx":758
 *         if (isinstance(args[0], int)
 *                 or len(args) == 1
 *                 or args[0] in self):             # <<<<<<<<<<<<<<
 *             index = args[0]
 *             ret = self[index]
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_v_self, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __pyx_t_1;
  __pyx_L8_bool_binop_done:;

  /* "cPyparsing.pyx":756
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 *         if (isinstance(args[0], int)             # <<<<<<<<<<<<<<
 *                 or len(args) == 1
 *                 or args[0] in self):
 */
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":759
 *                 or len(args) == 1
 *                 or args[0] in self):
 *             index = args[0]             # <<<<<<<<<<<<<<
 *             ret = self[index]
 *             del self[index]
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_index = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":760
 *                 or args[0] in self):
 *             index = args[0]
 *             ret = self[index]             # <<<<<<<<<<<<<<
 *             del self[index]
 *             return ret
 */
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_self, __pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_ret = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":761
 *             index = args[0]
 *             ret = self[index]
 *             del self[index]             # <<<<<<<<<<<<<<
 *             return ret
 *         else:
 */
    if (unlikely((PyObject_DelItem(__pyx_v_self, __pyx_v_index) < 0))) __PYX_ERR(0, 761, __pyx_L1_error)

    /* "cPyparsing.pyx":762
 *             ret = self[index]
 *             del self[index]
 *             return ret             # <<<<<<<<<<<<<<
 *         else:
 *             defaultvalue = args[1]
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_ret);
    __pyx_r = __pyx_v_ret;
    goto __pyx_L0;

    /* "cPyparsing.pyx":756
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 *         if (isinstance(args[0], int)             # <<<<<<<<<<<<<<
 *                 or len(args) == 1
 *                 or args[0] in self):
 */
  }

  /* "cPyparsing.pyx":764
 *             return ret
 *         else:
 *             defaultvalue = args[1]             # <<<<<<<<<<<<<<
 *             return defaultvalue
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_args, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_defaultvalue = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":765
 *         else:
 *             defaultvalue = args[1]
 *             return defaultvalue             # <<<<<<<<<<<<<<
 * 
 *     def get(self, key, defaultValue=None):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_defaultvalue);
    __pyx_r = __pyx_v_defaultvalue;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":712
 *         return bool(self.__tokdict)
 * 
 *     def pop(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Removes and returns item at specified index (default= ``last``).
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParseResults.pop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_defaultvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":767
 *             return defaultvalue
 * 
 *     def get(self, key, defaultValue=None):             # <<<<<<<<<<<<<<
 *         """
 *         Returns named result matching the given key, or if there is no
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_37get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_36get, "ParseResults.get(self, key, defaultValue=None)\n\n        Returns named result matching the given key, or if there is no\n        such name, then returns the given ``defaultValue`` or ``None`` if no\n        ``defaultValue`` is specified.\n\n        Similar to ``dict.get()``.\n\n        Example::\n\n            integer = Word(nums)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            result = date_str.parseString(\"1999/12/31\")\n            print(result.get(\"year\")) # -> '1999'\n            print(result.get(\"hour\", \"not specified\")) # -> 'not specified'\n            print(result.get(\"hour\")) # -> None\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_37get = {"get", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_37get, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_36get};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_37get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_defaultValue = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,&__pyx_n_s_defaultValue,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 767, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 767, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get", 0, 2, 3, 1); __PYX_ERR(0, 767, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_defaultValue);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 767, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get") < 0)) __PYX_ERR(0, 767, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
    __pyx_v_defaultValue = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 767, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_36get(__pyx_self, __pyx_v_self, __pyx_v_key, __pyx_v_defaultValue);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_36get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_defaultValue) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get", 1);

  /* "cPyparsing.pyx":785
 *             print(result.get("hour")) # -> None
 *         """
 *         if key in self:             # <<<<<<<<<<<<<<
 *             return self[key]
 *         else:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_key, __pyx_v_self, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 785, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":786
 *         """
 *         if key in self:
 *             return self[key]             # <<<<<<<<<<<<<<
 *         else:
 *             return defaultValue
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_self, __pyx_v_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 786, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":785
 *             print(result.get("hour")) # -> None
 *         """
 *         if key in self:             # <<<<<<<<<<<<<<
 *             return self[key]
 *         else:
 */
  }

  /* "cPyparsing.pyx":788
 *             return self[key]
 *         else:
 *             return defaultValue             # <<<<<<<<<<<<<<
 * 
 *     def insert(self, index, insStr):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_defaultValue);
    __pyx_r = __pyx_v_defaultValue;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":767
 *             return defaultvalue
 * 
 *     def get(self, key, defaultValue=None):             # <<<<<<<<<<<<<<
 *         """
 *         Returns named result matching the given key, or if there is no
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParseResults.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":790
 *             return defaultValue
 * 
 *     def insert(self, index, insStr):             # <<<<<<<<<<<<<<
 *         """
 *         Inserts new element at location index in the list of parsed tokens.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_39insert(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_38insert, "ParseResults.insert(self, index, insStr)\n\n        Inserts new element at location index in the list of parsed tokens.\n\n        Similar to ``list.insert()``.\n\n        Example::\n\n            print(OneOrMore(Word(nums)).parseString(\"0 123 321\")) # -> ['0', '123', '321']\n\n            # use a parse action to insert the parse location in the front of the parsed results\n            def insert_locn(locn, tokens):\n                tokens.insert(0, locn)\n            print(OneOrMore(Word(nums)).addParseAction(insert_locn).parseString(\"0 123 321\")) # -> [0, '0', '123', '321']\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_39insert = {"insert", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_39insert, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_38insert};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_39insert(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_index = 0;
  PyObject *__pyx_v_insStr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("insert (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_index,&__pyx_n_s_insStr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 790, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_index)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 790, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("insert", 1, 3, 3, 1); __PYX_ERR(0, 790, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_insStr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 790, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("insert", 1, 3, 3, 2); __PYX_ERR(0, 790, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "insert") < 0)) __PYX_ERR(0, 790, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_index = values[1];
    __pyx_v_insStr = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("insert", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 790, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_38insert(__pyx_self, __pyx_v_self, __pyx_v_index, __pyx_v_insStr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_38insert(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_insStr) {
  CYTHON_UNUSED PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_occurrences = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_position = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("insert", 1);

  /* "cPyparsing.pyx":805
 *             print(OneOrMore(Word(nums)).addParseAction(insert_locn).parseString("0 123 321")) # -> [0, '0', '123', '321']
 *         """
 *         self.__toklist.insert(index, insStr)             # <<<<<<<<<<<<<<
 *         # fixup indices in token dictionary
 *         for name, occurrences in self.__tokdict.items():
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_insert); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_index, __pyx_v_insStr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 805, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":807
 *         self.__toklist.insert(index, insStr)
 *         # fixup indices in token dictionary
 *         for name, occurrences in self.__tokdict.items():             # <<<<<<<<<<<<<<
 *             for k, (value, position) in enumerate(occurrences):
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 */
  __pyx_t_5 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 807, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_dict_iterator(__pyx_t_3, 0, __pyx_n_s_items, (&__pyx_t_6), (&__pyx_t_4)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_6, &__pyx_t_5, &__pyx_t_2, &__pyx_t_3, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 807, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_occurrences, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":808
 *         # fixup indices in token dictionary
 *         for name, occurrences in self.__tokdict.items():
 *             for k, (value, position) in enumerate(occurrences):             # <<<<<<<<<<<<<<
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_t_3 = __pyx_int_0;
    if (likely(PyList_CheckExact(__pyx_v_occurrences)) || PyTuple_CheckExact(__pyx_v_occurrences)) {
      __pyx_t_2 = __pyx_v_occurrences; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_occurrences); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 808, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 808, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 808, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_10 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_8); __Pyx_INCREF(__pyx_t_10); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 808, __pyx_L1_error)
          #else
          __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 808, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 808, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_8); __Pyx_INCREF(__pyx_t_10); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 808, __pyx_L1_error)
          #else
          __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 808, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          #endif
        }
      } else {
        __pyx_t_10 = __pyx_t_9(__pyx_t_2);
        if (unlikely(!__pyx_t_10)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 808, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_10);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_10))) || (PyList_CheckExact(__pyx_t_10))) {
        PyObject* sequence = __pyx_t_10;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 808, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_11 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_11 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_12);
        #else
        __pyx_t_11 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        #endif
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_13 = PyObject_GetIter(__pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_13);
        index = 0; __pyx_t_11 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_11)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_11);
        index = 1; __pyx_t_12 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_12)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_13), 2) < 0) __PYX_ERR(0, 808, __pyx_L1_error)
        __pyx_t_14 = NULL;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L8_unpacking_done;
        __pyx_L7_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_14 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 808, __pyx_L1_error)
        __pyx_L8_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_11);
      __pyx_t_11 = 0;
      __Pyx_XDECREF_SET(__pyx_v_position, __pyx_t_12);
      __pyx_t_12 = 0;
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_3);
      __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 808, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3);
      __pyx_t_3 = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "cPyparsing.pyx":809
 *         for name, occurrences in self.__tokdict.items():
 *             for k, (value, position) in enumerate(occurrences):
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))             # <<<<<<<<<<<<<<
 * 
 *     def append(self, item):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 809, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_11 = PyObject_RichCompare(__pyx_v_position, __pyx_v_index, Py_GT); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 809, __pyx_L1_error)
      __pyx_t_13 = PyNumber_Add(__pyx_v_position, __pyx_t_11); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 809, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_v_value, __pyx_t_13};
        __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 809, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      if (unlikely((PyObject_SetItem(__pyx_v_occurrences, __pyx_v_k, __pyx_t_10) < 0))) __PYX_ERR(0, 809, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "cPyparsing.pyx":808
 *         # fixup indices in token dictionary
 *         for name, occurrences in self.__tokdict.items():
 *             for k, (value, position) in enumerate(occurrences):             # <<<<<<<<<<<<<<
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":790
 *             return defaultValue
 * 
 *     def insert(self, index, insStr):             # <<<<<<<<<<<<<<
 *         """
 *         Inserts new element at location index in the list of parsed tokens.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.ParseResults.insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_occurrences);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_position);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":811
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         Add single element to end of ParseResults list of elements.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_41append(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_40append, "ParseResults.append(self, item)\n\n        Add single element to end of ParseResults list of elements.\n\n        Example::\n\n            print(OneOrMore(Word(nums)).parseString(\"0 123 321\")) # -> ['0', '123', '321']\n\n            # use a parse action to compute the sum of the parsed integers, and add it to the end\n            def append_sum(tokens):\n                tokens.append(sum(map(int, tokens)))\n            print(OneOrMore(Word(nums)).addParseAction(append_sum).parseString(\"0 123 321\")) # -> ['0', '123', '321', 444]\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_41append = {"append", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_41append, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_40append};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_41append(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_item = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("append (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_item,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 811, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_item)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 811, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("append", 1, 2, 2, 1); __PYX_ERR(0, 811, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "append") < 0)) __PYX_ERR(0, 811, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_item = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("append", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 811, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_40append(__pyx_self, __pyx_v_self, __pyx_v_item);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_40append(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "cPyparsing.pyx":824
 *             print(OneOrMore(Word(nums)).addParseAction(append_sum).parseString("0 123 321")) # -> ['0', '123', '321', 444]
 *         """
 *         self.__toklist.append(item)             # <<<<<<<<<<<<<<
 * 
 *     def extend(self, itemseq):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_v_item); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":811
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         Add single element to end of ParseResults list of elements.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":826
 *         self.__toklist.append(item)
 * 
 *     def extend(self, itemseq):             # <<<<<<<<<<<<<<
 *         """
 *         Add sequence of elements to end of ParseResults list of elements.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_43extend(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_42extend, "ParseResults.extend(self, itemseq)\n\n        Add sequence of elements to end of ParseResults list of elements.\n\n        Example::\n\n            patt = OneOrMore(Word(alphas))\n\n            # use a parse action to append the reverse of the matched strings, to make a palindrome\n            def make_palindrome(tokens):\n                tokens.extend(reversed([t[::-1] for t in tokens]))\n                return ''.join(tokens)\n            print(patt.addParseAction(make_palindrome).parseString(\"lskdj sdlkjf lksd\")) # -> 'lskdjsdlkjflksddsklfjkldsjdksl'\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_43extend = {"extend", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_43extend, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_42extend};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_43extend(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_itemseq = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extend (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_itemseq,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 826, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_itemseq)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 826, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("extend", 1, 2, 2, 1); __PYX_ERR(0, 826, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "extend") < 0)) __PYX_ERR(0, 826, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_itemseq = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extend", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 826, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_42extend(__pyx_self, __pyx_v_self, __pyx_v_itemseq);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_42extend(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_itemseq) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "cPyparsing.pyx":840
 *             print(patt.addParseAction(make_palindrome).parseString("lskdj sdlkjf lksd")) # -> 'lskdjsdlkjflksddsklfjkldsjdksl'
 *         """
 *         if isinstance(itemseq, ParseResults):             # <<<<<<<<<<<<<<
 *             self.__iadd__(itemseq)
 *         else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_itemseq, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":841
 *         """
 *         if isinstance(itemseq, ParseResults):
 *             self.__iadd__(itemseq)             # <<<<<<<<<<<<<<
 *         else:
 *             self.__toklist.extend(itemseq)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_iadd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 841, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_itemseq};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 841, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":840
 *             print(patt.addParseAction(make_palindrome).parseString("lskdj sdlkjf lksd")) # -> 'lskdjsdlkjflksddsklfjkldsjdksl'
 *         """
 *         if isinstance(itemseq, ParseResults):             # <<<<<<<<<<<<<<
 *             self.__iadd__(itemseq)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":843
 *             self.__iadd__(itemseq)
 *         else:
 *             self.__toklist.extend(itemseq)             # <<<<<<<<<<<<<<
 * 
 *     def clear(self):
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_extend); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_itemseq};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 843, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":826
 *         self.__toklist.append(item)
 * 
 *     def extend(self, itemseq):             # <<<<<<<<<<<<<<
 *         """
 *         Add sequence of elements to end of ParseResults list of elements.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":845
 *             self.__toklist.extend(itemseq)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         """
 *         Clear all elements and results names.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_45clear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_44clear, "ParseResults.clear(self)\n\n        Clear all elements and results names.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_45clear = {"clear", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_45clear, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_44clear};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_45clear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 845, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "clear") < 0)) __PYX_ERR(0, 845, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("clear", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 845, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_44clear(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_44clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clear", 1);

  /* "cPyparsing.pyx":849
 *         Clear all elements and results names.
 *         """
 *         del self.__toklist[:]             # <<<<<<<<<<<<<<
 *         self.__tokdict.clear()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_DelSlice(__pyx_t_1, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1) < 0) __PYX_ERR(0, 849, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":850
 *         """
 *         del self.__toklist[:]
 *         self.__tokdict.clear()             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, name):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_clear); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":845
 *             self.__toklist.extend(itemseq)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         """
 *         Clear all elements and results names.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":852
 *         self.__tokdict.clear()
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_47__getattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_46__getattr__, "ParseResults.__getattr__(self, name)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_47__getattr__ = {"__getattr__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_47__getattr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_46__getattr__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_47__getattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 852, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 852, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, 1); __PYX_ERR(0, 852, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__getattr__") < 0)) __PYX_ERR(0, 852, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 852, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_46__getattr__(__pyx_self, __pyx_v_self, __pyx_v_name);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_46__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 1);

  /* "cPyparsing.pyx":853
 * 
 *     def __getattr__(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self[name]
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":854
 *     def __getattr__(self, name):
 *         try:
 *             return self[name]             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             return ""
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_self, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 854, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":853
 * 
 *     def __getattr__(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self[name]
 *         except KeyError:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":855
 *         try:
 *             return self[name]
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             return ""
 * 
 */
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_5) {
      __Pyx_AddTraceback("cPyparsing.ParseResults.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 855, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "cPyparsing.pyx":856
 *             return self[name]
 *         except KeyError:
 *             return ""             # <<<<<<<<<<<<<<
 * 
 *     def __add__(self, other):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__10);
      __pyx_r = __pyx_kp_u__10;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":853
 * 
 *     def __getattr__(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self[name]
 *         except KeyError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":852
 *         self.__tokdict.clear()
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":858
 *             return ""
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         ret = self.copy()
 *         ret += other
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_49__add__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_48__add__, "ParseResults.__add__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_49__add__ = {"__add__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_49__add__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_48__add__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_49__add__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__add__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 858, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 858, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, 1); __PYX_ERR(0, 858, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__add__") < 0)) __PYX_ERR(0, 858, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 858, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_48__add__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_48__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__add__", 1);

  /* "cPyparsing.pyx":859
 * 
 *     def __add__(self, other):
 *         ret = self.copy()             # <<<<<<<<<<<<<<
 *         ret += other
 *         return ret
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":860
 *     def __add__(self, other):
 *         ret = self.copy()
 *         ret += other             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
  __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_ret, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":861
 *         ret = self.copy()
 *         ret += other
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def __iadd__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":858
 *             return ""
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         ret = self.copy()
 *         ret += other
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":863
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_51__iadd__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_50__iadd__, "ParseResults.__iadd__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_51__iadd__ = {"__iadd__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_51__iadd__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_50__iadd__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_51__iadd__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iadd__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 863, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 863, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__iadd__", 1, 2, 2, 1); __PYX_ERR(0, 863, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__iadd__") < 0)) __PYX_ERR(0, 863, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__iadd__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 863, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iadd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_50__iadd__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":866
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 *             addoffset = lambda a: offset if a < 0 else a + offset             # <<<<<<<<<<<<<<
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_8__iadd___lambda6(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_8__iadd___lambda6 = {"lambda6", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_8__iadd___lambda6, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_8__iadd___lambda6(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_a = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda6 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_a)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 866, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda6") < 0)) __PYX_ERR(0, 866, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_a = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda6", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 866, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iadd__.lambda6", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda6(__pyx_self, __pyx_v_a);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda6(PyObject *__pyx_self, PyObject *__pyx_v_a) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda6", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_a, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 866, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_cur_scope->__pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 866, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_cur_scope->__pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 866, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyNumber_Add(__pyx_v_a, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 866, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iadd__.lambda6", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":863
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_50__iadd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__ *__pyx_cur_scope;
  PyObject *__pyx_v_addoffset = NULL;
  PyObject *__pyx_v_otheritems = NULL;
  PyObject *__pyx_v_otherdictitems = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_8genexpr8__pyx_v_k = NULL;
  PyObject *__pyx_8genexpr8__pyx_v_vlist = NULL;
  PyObject *__pyx_8genexpr8__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  Py_ssize_t __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iadd__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_9___iadd__(__pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 863, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":864
 * 
 *     def __iadd__(self, other):
 *         if other.__tokdict:             # <<<<<<<<<<<<<<
 *             offset = len(self.__toklist)
 *             addoffset = lambda a: offset if a < 0 else a + offset
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":865
 *     def __iadd__(self, other):
 *         if other.__tokdict:
 *             offset = len(self.__toklist)             # <<<<<<<<<<<<<<
 *             addoffset = lambda a: offset if a < 0 else a + offset
 *             otheritems = other.__tokdict.items()
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 865, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_cur_scope->__pyx_v_offset = __pyx_t_3;

    /* "cPyparsing.pyx":866
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 *             addoffset = lambda a: offset if a < 0 else a + offset             # <<<<<<<<<<<<<<
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 */
    __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_8__iadd___lambda6, 0, __pyx_n_s_ParseResults___iadd___locals_lam, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 866, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_addoffset = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":867
 *             offset = len(self.__toklist)
 *             addoffset = lambda a: offset if a < 0 else a + offset
 *             otheritems = other.__tokdict.items()             # <<<<<<<<<<<<<<
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for k, vlist in otheritems for v in vlist]
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_items); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 867, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_v_otheritems = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":868
 *             addoffset = lambda a: offset if a < 0 else a + offset
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))             # <<<<<<<<<<<<<<
 *                               for k, vlist in otheritems for v in vlist]
 *             for k, v in otherdictitems:
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 868, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "cPyparsing.pyx":869
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for k, vlist in otheritems for v in vlist]             # <<<<<<<<<<<<<<
 *             for k, v in otherdictitems:
 *                 self[k] = v
 */
      if (likely(PyList_CheckExact(__pyx_v_otheritems)) || PyTuple_CheckExact(__pyx_v_otheritems)) {
        __pyx_t_5 = __pyx_v_otheritems; __Pyx_INCREF(__pyx_t_5);
        __pyx_t_3 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_3 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_otheritems); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 869, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 869, __pyx_L6_error)
      }
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 869, __pyx_L6_error)
              #endif
              if (__pyx_t_3 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 869, __pyx_L6_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 869, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 869, __pyx_L6_error)
              #endif
              if (__pyx_t_3 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 869, __pyx_L6_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 869, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_7(__pyx_t_5);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 869, __pyx_L6_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 869, __pyx_L6_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          #else
          __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 869, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 869, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_9);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_10 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 869, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_11 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10);
          index = 0; __pyx_t_8 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_8)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_8);
          index = 1; __pyx_t_9 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_9)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_10), 2) < 0) __PYX_ERR(0, 869, __pyx_L6_error)
          __pyx_t_11 = NULL;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          goto __pyx_L10_unpacking_done;
          __pyx_L9_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_11 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 869, __pyx_L6_error)
          __pyx_L10_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr8__pyx_v_k, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_8genexpr8__pyx_v_vlist, __pyx_t_9);
        __pyx_t_9 = 0;
        if (likely(PyList_CheckExact(__pyx_8genexpr8__pyx_v_vlist)) || PyTuple_CheckExact(__pyx_8genexpr8__pyx_v_vlist)) {
          __pyx_t_4 = __pyx_8genexpr8__pyx_v_vlist; __Pyx_INCREF(__pyx_t_4);
          __pyx_t_12 = 0;
          __pyx_t_13 = NULL;
        } else {
          __pyx_t_12 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_8genexpr8__pyx_v_vlist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 869, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 869, __pyx_L6_error)
        }
        for (;;) {
          if (likely(!__pyx_t_13)) {
            if (likely(PyList_CheckExact(__pyx_t_4))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 869, __pyx_L6_error)
                #endif
                if (__pyx_t_12 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_9 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_12); __Pyx_INCREF(__pyx_t_9); __pyx_t_12++; if (unlikely((0 < 0))) __PYX_ERR(0, 869, __pyx_L6_error)
              #else
              __pyx_t_9 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 869, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_9);
              #endif
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 869, __pyx_L6_error)
                #endif
                if (__pyx_t_12 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_9 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_12); __Pyx_INCREF(__pyx_t_9); __pyx_t_12++; if (unlikely((0 < 0))) __PYX_ERR(0, 869, __pyx_L6_error)
              #else
              __pyx_t_9 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 869, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_9);
              #endif
            }
          } else {
            __pyx_t_9 = __pyx_t_13(__pyx_t_4);
            if (unlikely(!__pyx_t_9)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 869, __pyx_L6_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_9);
          }
          __Pyx_XDECREF_SET(__pyx_8genexpr8__pyx_v_v, __pyx_t_9);
          __pyx_t_9 = 0;

          /* "cPyparsing.pyx":868
 *             addoffset = lambda a: offset if a < 0 else a + offset
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))             # <<<<<<<<<<<<<<
 *                               for k, vlist in otheritems for v in vlist]
 *             for k, v in otherdictitems:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 868, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_10 = __Pyx_GetItemInt(__pyx_8genexpr8__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 868, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_14 = __Pyx_GetItemInt(__pyx_8genexpr8__pyx_v_v, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 868, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_15 = __pyx_lambda_funcdef_lambda6(__pyx_v_addoffset, __pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 868, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = NULL;
          __pyx_t_6 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_6 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_14, __pyx_t_10, __pyx_t_15};
            __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 868, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 868, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_8genexpr8__pyx_v_k);
          __Pyx_GIVEREF(__pyx_8genexpr8__pyx_v_k);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_8genexpr8__pyx_v_k)) __PYX_ERR(0, 868, __pyx_L6_error);
          __Pyx_GIVEREF(__pyx_t_9);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_9)) __PYX_ERR(0, 868, __pyx_L6_error);
          __pyx_t_9 = 0;
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 868, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "cPyparsing.pyx":869
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for k, vlist in otheritems for v in vlist]             # <<<<<<<<<<<<<<
 *             for k, v in otherdictitems:
 *                 self[k] = v
 */
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_k); __pyx_8genexpr8__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_v); __pyx_8genexpr8__pyx_v_v = 0;
      __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_vlist); __pyx_8genexpr8__pyx_v_vlist = 0;
      goto __pyx_L15_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_k); __pyx_8genexpr8__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_v); __pyx_8genexpr8__pyx_v_v = 0;
      __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_vlist); __pyx_8genexpr8__pyx_v_vlist = 0;
      goto __pyx_L1_error;
      __pyx_L15_exit_scope:;
    } /* exit inner scope */
    __pyx_v_otherdictitems = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":870
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for k, vlist in otheritems for v in vlist]
 *             for k, v in otherdictitems:             # <<<<<<<<<<<<<<
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):
 */
    __pyx_t_1 = __pyx_v_otherdictitems; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 870, __pyx_L1_error)
        #endif
        if (__pyx_t_3 >= __pyx_temp) break;
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 870, __pyx_L1_error)
      #else
      __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 870, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
        PyObject* sequence = __pyx_t_5;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 870, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_8);
        #else
        __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 870, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 870, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 870, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_11 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
        index = 0; __pyx_t_4 = __pyx_t_11(__pyx_t_9); if (unlikely(!__pyx_t_4)) goto __pyx_L18_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_4);
        index = 1; __pyx_t_8 = __pyx_t_11(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L18_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_9), 2) < 0) __PYX_ERR(0, 870, __pyx_L1_error)
        __pyx_t_11 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L19_unpacking_done;
        __pyx_L18_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_11 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 870, __pyx_L1_error)
        __pyx_L19_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "cPyparsing.pyx":871
 *                               for k, vlist in otheritems for v in vlist]
 *             for k, v in otherdictitems:
 *                 self[k] = v             # <<<<<<<<<<<<<<
 *                 if isinstance(v[0], ParseResults):
 *                     v[0].__parent = wkref(self)
 */
      if (unlikely((PyObject_SetItem(__pyx_v_self, __pyx_v_k, __pyx_v_v) < 0))) __PYX_ERR(0, 871, __pyx_L1_error)

      /* "cPyparsing.pyx":872
 *             for k, v in otherdictitems:
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):             # <<<<<<<<<<<<<<
 *                     v[0].__parent = wkref(self)
 * 
 */
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_2 = PyObject_IsInstance(__pyx_t_5, __pyx_t_8); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 872, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":873
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):
 *                     v[0].__parent = wkref(self)             # <<<<<<<<<<<<<<
 * 
 *         self.__toklist += other.__toklist
 */
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_wkref); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 873, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_self};
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 873, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 873, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_PyObject_SetAttrStr(__pyx_t_5, __pyx_n_s_ParseResults__parent, __pyx_t_8) < 0) __PYX_ERR(0, 873, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "cPyparsing.pyx":872
 *             for k, v in otherdictitems:
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):             # <<<<<<<<<<<<<<
 *                     v[0].__parent = wkref(self)
 * 
 */
      }

      /* "cPyparsing.pyx":870
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for k, vlist in otheritems for v in vlist]
 *             for k, v in otherdictitems:             # <<<<<<<<<<<<<<
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":864
 * 
 *     def __iadd__(self, other):
 *         if other.__tokdict:             # <<<<<<<<<<<<<<
 *             offset = len(self.__toklist)
 *             addoffset = lambda a: offset if a < 0 else a + offset
 */
  }

  /* "cPyparsing.pyx":875
 *                     v[0].__parent = wkref(self)
 * 
 *         self.__toklist += other.__toklist             # <<<<<<<<<<<<<<
 *         self.__accumNames.update(other.__accumNames)
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_8) < 0) __PYX_ERR(0, 875, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":876
 * 
 *         self.__toklist += other.__toklist
 *         self.__accumNames.update(other.__accumNames)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 876, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":877
 *         self.__toklist += other.__toklist
 *         self.__accumNames.update(other.__accumNames)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __radd__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":863
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iadd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_addoffset);
  __Pyx_XDECREF(__pyx_v_otheritems);
  __Pyx_XDECREF(__pyx_v_otherdictitems);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_k);
  __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_vlist);
  __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_v);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":879
 *         return self
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_53__radd__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_52__radd__, "ParseResults.__radd__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_53__radd__ = {"__radd__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_53__radd__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_52__radd__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_53__radd__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__radd__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 879, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 879, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__radd__", 1, 2, 2, 1); __PYX_ERR(0, 879, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__radd__") < 0)) __PYX_ERR(0, 879, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__radd__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 879, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_52__radd__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_52__radd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__radd__", 1);

  /* "cPyparsing.pyx":880
 * 
 *     def __radd__(self, other):
 *         if isinstance(other, int) and other == 0:             # <<<<<<<<<<<<<<
 *             # useful for merging many ParseResults using sum() builtin
 *             return self.copy()
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_other); 
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_other, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 880, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":882
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 *             return self.copy()             # <<<<<<<<<<<<<<
 *         else:
 *             # this may raise a TypeError - so be it
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 882, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 882, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":880
 * 
 *     def __radd__(self, other):
 *         if isinstance(other, int) and other == 0:             # <<<<<<<<<<<<<<
 *             # useful for merging many ParseResults using sum() builtin
 *             return self.copy()
 */
  }

  /* "cPyparsing.pyx":885
 *         else:
 *             # this may raise a TypeError - so be it
 *             return other + self             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyNumber_Add(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":879
 *         return self
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":887
 *             return other + self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_55__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_54__repr__, "ParseResults.__repr__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_55__repr__ = {"__repr__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_55__repr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_54__repr__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_55__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 887, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__repr__") < 0)) __PYX_ERR(0, 887, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__repr__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 887, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_54__repr__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_54__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "cPyparsing.pyx":888
 * 
 *     def __repr__(self):
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u__22);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__22);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u__22);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_repr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__3);
  __pyx_t_2 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__3);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u__3);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_repr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__13);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u__13);
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":887
 *             return other + self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":890
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_57__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_56__str__, "ParseResults.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_57__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_57__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_56__str__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_57__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 890, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 890, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 890, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_56__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_7__str___2generator9(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":891
 * 
 *     def __str__(self):
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'             # <<<<<<<<<<<<<<
 * 
 *     def _asStringList(self, sep=''):
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_10_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 891, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_7__str___2generator9, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults___str___locals_gene, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_7__str___2generator9(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 891, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 891, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 891, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 891, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 891, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 891, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 891, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 891, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 891, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 891, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_i);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_i, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_i, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_6) {
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_ustr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 891, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_i};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 891, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_t_4 = __pyx_t_5;
      __pyx_t_5 = 0;
    } else {
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_repr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 891, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_i};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 891, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_t_4 = __pyx_t_5;
      __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":890
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_56__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_gb_10cPyparsing_12ParseResults_7__str___2generator9 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":891
 * 
 *     def __str__(self):
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'             # <<<<<<<<<<<<<<
 * 
 *     def _asStringList(self, sep=''):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_pf_10cPyparsing_12ParseResults_7__str___genexpr(NULL, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyUnicode_Join(__pyx_kp_u__3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_kp_u__2, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_1, __pyx_kp_u__4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":890
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_12ParseResults_7__str___2generator9);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":893
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 *     def _asStringList(self, sep=''):             # <<<<<<<<<<<<<<
 *         out = []
 *         for item in self.__toklist:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_59_asStringList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_58_asStringList, "ParseResults._asStringList(self, sep=u'')");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_59_asStringList = {"_asStringList", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_59_asStringList, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_58_asStringList};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_59_asStringList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_sep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_asStringList (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_sep,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__10)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 893, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_sep);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 893, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_asStringList") < 0)) __PYX_ERR(0, 893, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_sep = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_asStringList", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 893, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults._asStringList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_58_asStringList(__pyx_self, __pyx_v_self, __pyx_v_sep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_58_asStringList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sep) {
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_asStringList", 1);

  /* "cPyparsing.pyx":894
 * 
 *     def _asStringList(self, sep=''):
 *         out = []             # <<<<<<<<<<<<<<
 *         for item in self.__toklist:
 *             if out and sep:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":895
 *     def _asStringList(self, sep=''):
 *         out = []
 *         for item in self.__toklist:             # <<<<<<<<<<<<<<
 *             if out and sep:
 *                 out.append(sep)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 895, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 895, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 895, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 895, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 895, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 895, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 895, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 895, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":896
 *         out = []
 *         for item in self.__toklist:
 *             if out and sep:             # <<<<<<<<<<<<<<
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):
 */
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_out); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 896, __pyx_L1_error)
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_sep); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 896, __pyx_L1_error)
    __pyx_t_5 = __pyx_t_6;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":897
 *         for item in self.__toklist:
 *             if out and sep:
 *                 out.append(sep)             # <<<<<<<<<<<<<<
 *             if isinstance(item, ParseResults):
 *                 out += item._asStringList()
 */
      __pyx_t_7 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_v_sep); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 897, __pyx_L1_error)

      /* "cPyparsing.pyx":896
 *         out = []
 *         for item in self.__toklist:
 *             if out and sep:             # <<<<<<<<<<<<<<
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):
 */
    }

    /* "cPyparsing.pyx":898
 *             if out and sep:
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):             # <<<<<<<<<<<<<<
 *                 out += item._asStringList()
 *             else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_IsInstance(__pyx_v_item, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 898, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":899
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):
 *                 out += item._asStringList()             # <<<<<<<<<<<<<<
 *             else:
 *                 out.append(_ustr(item))
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_item, __pyx_n_s_asStringList); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 899, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 899, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 899, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "cPyparsing.pyx":898
 *             if out and sep:
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):             # <<<<<<<<<<<<<<
 *                 out += item._asStringList()
 *             else:
 */
      goto __pyx_L8;
    }

    /* "cPyparsing.pyx":901
 *                 out += item._asStringList()
 *             else:
 *                 out.append(_ustr(item))             # <<<<<<<<<<<<<<
 *         return out
 * 
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ustr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 901, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_item};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_7 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_t_8); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 901, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_L8:;

    /* "cPyparsing.pyx":895
 *     def _asStringList(self, sep=''):
 *         out = []
 *         for item in self.__toklist:             # <<<<<<<<<<<<<<
 *             if out and sep:
 *                 out.append(sep)
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":902
 *             else:
 *                 out.append(_ustr(item))
 *         return out             # <<<<<<<<<<<<<<
 * 
 *     def asList(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "cPyparsing.pyx":893
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 *     def _asStringList(self, sep=''):             # <<<<<<<<<<<<<<
 *         out = []
 *         for item in self.__toklist:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParseResults._asStringList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":904
 *         return out
 * 
 *     def asList(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the parse results as a nested list of matching tokens, all converted to strings.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_61asList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_60asList, "ParseResults.asList(self)\n\n        Returns the parse results as a nested list of matching tokens, all converted to strings.\n\n        Example::\n\n            patt = OneOrMore(Word(alphas))\n            result = patt.parseString(\"sldkj lsdkj sldkj\")\n            # even though the result prints in string-like form, it is actually a pyparsing ParseResults\n            print(type(result), result) # -> <class 'pyparsing.ParseResults'> ['sldkj', 'lsdkj', 'sldkj']\n\n            # Use asList() to create an actual list\n            result_list = result.asList()\n            print(type(result_list), result_list) # -> <class 'list'> ['sldkj', 'lsdkj', 'sldkj']\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_61asList = {"asList", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_61asList, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_60asList};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_61asList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asList (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 904, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "asList") < 0)) __PYX_ERR(0, 904, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("asList", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 904, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.asList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_60asList(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_60asList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_9genexpr10__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("asList", 1);

  /* "cPyparsing.pyx":919
 *             print(type(result_list), result_list) # -> <class 'list'> ['sldkj', 'lsdkj', 'sldkj']
 *         """
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]             # <<<<<<<<<<<<<<
 * 
 *     def asDict(self):
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 919, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 919, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 919, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 919, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 919, __pyx_L5_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 919, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 919, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 919, __pyx_L5_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 919, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 919, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 919, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr10__pyx_v_res, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 919, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PyObject_IsInstance(__pyx_9genexpr10__pyx_v_res, __pyx_t_6); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 919, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_7) {
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr10__pyx_v_res, __pyx_n_s_asList); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 919, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 919, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_t_2 = __pyx_t_6;
        __pyx_t_6 = 0;
      } else {
        __Pyx_INCREF(__pyx_9genexpr10__pyx_v_res);
        __pyx_t_2 = __pyx_9genexpr10__pyx_v_res;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 919, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_9genexpr10__pyx_v_res); __pyx_9genexpr10__pyx_v_res = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_9genexpr10__pyx_v_res); __pyx_9genexpr10__pyx_v_res = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":904
 *         return out
 * 
 *     def asList(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the parse results as a nested list of matching tokens, all converted to strings.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParseResults.asList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_9genexpr10__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":921
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_63asDict(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_62asDict, "ParseResults.asDict(self)\n\n        Returns the named parse results as a nested dictionary.\n\n        Example::\n\n            integer = Word(nums)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            result = date_str.parseString('12/31/1999')\n            print(type(result), repr(result)) # -> <class 'pyparsing.ParseResults'> (['12', '/', '31', '/', '1999'], {'day': [('1999', 4)], 'year': [('12', 0)], 'month': [('31', 2)]})\n\n            result_dict = result.asDict()\n            print(type(result_dict), repr(result_dict)) # -> <class 'dict'> {'day': '1999', 'year': '12', 'month': '31'}\n\n            # even though a ParseResults supports dict-like access, sometime you just need to have a dict\n            import json\n            print(json.dumps(result)) # -> Exception: TypeError: ... is not JSON serializable\n            print(json.dumps(result.asDict())) # -> {\"month\": \"31\", \"day\": \"1999\", \"year\": \"12\"}\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_63asDict = {"asDict", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_63asDict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_62asDict};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_63asDict(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asDict (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 921, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "asDict") < 0)) __PYX_ERR(0, 921, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("asDict", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 921, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.asDict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_62asDict(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":946
 *             item_fn = self.iteritems
 * 
 *         def toItem(obj):             # <<<<<<<<<<<<<<
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_6asDict_1toItem(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_6asDict_1toItem = {"toItem", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_6asDict_1toItem, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_6asDict_1toItem(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("toItem (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 946, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "toItem") < 0)) __PYX_ERR(0, 946, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_obj = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("toItem", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 946, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.asDict.toItem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(__pyx_self, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *__pyx_outer_scope;
  PyObject *__pyx_9genexpr11__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("toItem", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":947
 * 
 *         def toItem(obj):
 *             if isinstance(obj, ParseResults):             # <<<<<<<<<<<<<<
 *                 if obj.haskeys():
 *                     return obj.asDict()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 947, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":948
 *         def toItem(obj):
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():             # <<<<<<<<<<<<<<
 *                     return obj.asDict()
 *                 else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 948, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 948, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":949
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 *                     return obj.asDict()             # <<<<<<<<<<<<<<
 *                 else:
 *                     return [toItem(v) for v in obj]
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_asDict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 949, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":948
 *         def toItem(obj):
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():             # <<<<<<<<<<<<<<
 *                     return obj.asDict()
 *                 else:
 */
    }

    /* "cPyparsing.pyx":951
 *                     return obj.asDict()
 *                 else:
 *                     return [toItem(v) for v in obj]             # <<<<<<<<<<<<<<
 *             else:
 *                 return obj
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      { /* enter inner scope */
        __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 951, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (likely(PyList_CheckExact(__pyx_v_obj)) || PyTuple_CheckExact(__pyx_v_obj)) {
          __pyx_t_3 = __pyx_v_obj; __Pyx_INCREF(__pyx_t_3);
          __pyx_t_6 = 0;
          __pyx_t_7 = NULL;
        } else {
          __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_obj); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 951, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 951, __pyx_L7_error)
        }
        for (;;) {
          if (likely(!__pyx_t_7)) {
            if (likely(PyList_CheckExact(__pyx_t_3))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 951, __pyx_L7_error)
                #endif
                if (__pyx_t_6 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 951, __pyx_L7_error)
              #else
              __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 951, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 951, __pyx_L7_error)
                #endif
                if (__pyx_t_6 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 951, __pyx_L7_error)
              #else
              __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 951, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            }
          } else {
            __pyx_t_4 = __pyx_t_7(__pyx_t_3);
            if (unlikely(!__pyx_t_4)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 951, __pyx_L7_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_XDECREF_SET(__pyx_9genexpr11__pyx_v_v, __pyx_t_4);
          __pyx_t_4 = 0;
          if (unlikely(!__pyx_cur_scope->__pyx_v_toItem)) { __Pyx_RaiseClosureNameError("toItem"); __PYX_ERR(0, 951, __pyx_L7_error) }
          __pyx_t_4 = __pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(__pyx_cur_scope->__pyx_v_toItem, __pyx_9genexpr11__pyx_v_v); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 951, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 951, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v); __pyx_9genexpr11__pyx_v_v = 0;
        goto __pyx_L11_exit_scope;
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v); __pyx_9genexpr11__pyx_v_v = 0;
        goto __pyx_L1_error;
        __pyx_L11_exit_scope:;
      } /* exit inner scope */
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;
    }

    /* "cPyparsing.pyx":947
 * 
 *         def toItem(obj):
 *             if isinstance(obj, ParseResults):             # <<<<<<<<<<<<<<
 *                 if obj.haskeys():
 *                     return obj.asDict()
 */
  }

  /* "cPyparsing.pyx":953
 *                     return [toItem(v) for v in obj]
 *             else:
 *                 return obj             # <<<<<<<<<<<<<<
 * 
 *         return dict((k, toItem(v)) for k, v in item_fn())
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_obj);
    __pyx_r = __pyx_v_obj;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":946
 *             item_fn = self.iteritems
 * 
 *         def toItem(obj):             # <<<<<<<<<<<<<<
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.asDict.toItem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_6asDict_4generator10(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":955
 *                 return obj
 * 
 *         return dict((k, toItem(v)) for k, v in item_fn())             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6asDict_2genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_12_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 955, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_6asDict_4generator10, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults_asDict_locals_genex, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 955, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.asDict.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_6asDict_4generator10(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 955, __pyx_L1_error)
  __pyx_r = PyDict_New(); if (unlikely(!__pyx_r)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 955, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 955, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 955, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 955, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 955, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 955, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 955, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 955, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 955, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 955, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 955, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 955, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 955, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 955, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 955, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 955, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_v);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_v, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_toItem)) { __Pyx_RaiseClosureNameError("toItem"); __PYX_ERR(0, 955, __pyx_L1_error) }
    __pyx_t_4 = __pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_toItem, __pyx_cur_scope->__pyx_v_v); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 955, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(PyDict_SetItem(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_k, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 955, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":921
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_62asDict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *__pyx_cur_scope;
  PyObject *__pyx_v_item_fn = NULL;
  PyObject *__pyx_gb_10cPyparsing_12ParseResults_6asDict_4generator10 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("asDict", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_11_asDict(__pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 921, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":941
 *             print(json.dumps(result.asDict())) # -> {"month": "31", "day": "1999", "year": "12"}
 *         """
 *         if PY_3:             # <<<<<<<<<<<<<<
 *             item_fn = self.items
 *         else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PY_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":942
 *         """
 *         if PY_3:
 *             item_fn = self.items             # <<<<<<<<<<<<<<
 *         else:
 *             item_fn = self.iteritems
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_items); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_item_fn = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":941
 *             print(json.dumps(result.asDict())) # -> {"month": "31", "day": "1999", "year": "12"}
 *         """
 *         if PY_3:             # <<<<<<<<<<<<<<
 *             item_fn = self.items
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":944
 *             item_fn = self.items
 *         else:
 *             item_fn = self.iteritems             # <<<<<<<<<<<<<<
 * 
 *         def toItem(obj):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_iteritems); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_item_fn = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":946
 *             item_fn = self.iteritems
 * 
 *         def toItem(obj):             # <<<<<<<<<<<<<<
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_6asDict_1toItem, 0, __pyx_n_s_ParseResults_asDict_locals_toIte, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__24)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_toItem = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":955
 *                 return obj
 * 
 *         return dict((k, toItem(v)) for k, v in item_fn())             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_item_fn);
  __pyx_t_3 = __pyx_v_item_fn; __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 955, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __pyx_pf_10cPyparsing_12ParseResults_6asDict_2genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":921
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.asDict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_item_fn);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_12ParseResults_6asDict_4generator10);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":957
 *         return dict((k, toItem(v)) for k, v in item_fn())
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a new copy of a :class:`ParseResults` object.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_65copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_64copy, "ParseResults.copy(self)\n\n        Returns a new copy of a :class:`ParseResults` object.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_65copy = {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_65copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_64copy};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_65copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 957, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "copy") < 0)) __PYX_ERR(0, 957, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("copy", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 957, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_64copy(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_64copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 1);

  /* "cPyparsing.pyx":961
 *         Returns a new copy of a :class:`ParseResults` object.
 *         """
 *         ret = ParseResults(self.__toklist)             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] fast copy tokdict
 *         ret.__tokdict = self.__tokdict.copy()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":963
 *         ret = ParseResults(self.__toklist)
 *         # [CPYPARSING] fast copy tokdict
 *         ret.__tokdict = self.__tokdict.copy()             # <<<<<<<<<<<<<<
 *         ret.__parent = self.__parent
 *         ret.__accumNames.update(self.__accumNames)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ret, __pyx_n_s_ParseResults__tokdict, __pyx_t_1) < 0) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":964
 *         # [CPYPARSING] fast copy tokdict
 *         ret.__tokdict = self.__tokdict.copy()
 *         ret.__parent = self.__parent             # <<<<<<<<<<<<<<
 *         ret.__accumNames.update(self.__accumNames)
 *         ret.__name = self.__name
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ret, __pyx_n_s_ParseResults__parent, __pyx_t_1) < 0) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":965
 *         ret.__tokdict = self.__tokdict.copy()
 *         ret.__parent = self.__parent
 *         ret.__accumNames.update(self.__accumNames)             # <<<<<<<<<<<<<<
 *         ret.__name = self.__name
 *         return ret
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ret, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_update); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":966
 *         ret.__parent = self.__parent
 *         ret.__accumNames.update(self.__accumNames)
 *         ret.__name = self.__name             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ret, __pyx_n_s_ParseResults__name, __pyx_t_1) < 0) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":967
 *         ret.__accumNames.update(self.__accumNames)
 *         ret.__name = self.__name
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":957
 *         return dict((k, toItem(v)) for k, v in item_fn())
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a new copy of a :class:`ParseResults` object.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":969
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_67asXML(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_66asXML, "ParseResults.asXML(self, doctag=None, namedItemsOnly=False, indent=u'', formatted=True)\n\n        (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_67asXML = {"asXML", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_67asXML, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_66asXML};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_67asXML(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_doctag = 0;
  PyObject *__pyx_v_namedItemsOnly = 0;
  PyObject *__pyx_v_indent = 0;
  PyObject *__pyx_v_formatted = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asXML (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_doctag,&__pyx_n_s_namedItemsOnly,&__pyx_n_s_indent,&__pyx_n_s_formatted,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__10)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 969, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doctag);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 969, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_namedItemsOnly);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 969, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_indent);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 969, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_formatted);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 969, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "asXML") < 0)) __PYX_ERR(0, 969, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_doctag = values[1];
    __pyx_v_namedItemsOnly = values[2];
    __pyx_v_indent = values[3];
    __pyx_v_formatted = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("asXML", 0, 1, 5, __pyx_nargs); __PYX_ERR(0, 969, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.asXML", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_66asXML(__pyx_self, __pyx_v_self, __pyx_v_doctag, __pyx_v_namedItemsOnly, __pyx_v_indent, __pyx_v_formatted);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_5asXML_2generator11(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":975
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_5asXML_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_13_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 975, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_5asXML_2generator11, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults_asXML_locals_genexp, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 975, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.asXML.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_5asXML_2generator11(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 975, __pyx_L1_error)
  __pyx_r = PyDict_New(); if (unlikely(!__pyx_r)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 975, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_genexpr_arg_0 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 975, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_cur_scope->__pyx_genexpr_arg_0, 0, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_vlist);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_vlist, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":976
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 *                           for v in vlist)             # <<<<<<<<<<<<<<
 *         nextLevelIndent = indent + "  "
 * 
 */
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_vlist)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_vlist)) {
      __pyx_t_6 = __pyx_cur_scope->__pyx_v_vlist; __Pyx_INCREF(__pyx_t_6);
      __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_vlist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 976, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 976, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_6))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 976, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_5); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 976, __pyx_L1_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 976, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 976, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_5); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 976, __pyx_L1_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 976, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_9(__pyx_t_6);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 976, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_v);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_v, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":975
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_v, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 975, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(PyDict_SetItem(__pyx_r, (PyObject*)__pyx_t_5, (PyObject*)__pyx_cur_scope->__pyx_v_k))) __PYX_ERR(0, 975, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":976
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 *                           for v in vlist)             # <<<<<<<<<<<<<<
 *         nextLevelIndent = indent + "  "
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":975
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":969
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_66asXML(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_doctag, PyObject *__pyx_v_namedItemsOnly, PyObject *__pyx_v_indent, PyObject *__pyx_v_formatted) {
  PyObject *__pyx_v_nl = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_namedItems = NULL;
  PyObject *__pyx_v_nextLevelIndent = NULL;
  PyObject *__pyx_v_selfTag = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_resTag = NULL;
  PyObject *__pyx_v_xmlBodyText = NULL;
  PyObject *__pyx_gb_10cPyparsing_12ParseResults_5asXML_2generator11 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("asXML", 0);
  __Pyx_INCREF(__pyx_v_indent);

  /* "cPyparsing.pyx":973
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 *         """
 *         nl = "\n"             # <<<<<<<<<<<<<<
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 */
  __Pyx_INCREF(__pyx_kp_u__19);
  __pyx_v_nl = __pyx_kp_u__19;

  /* "cPyparsing.pyx":974
 *         """
 *         nl = "\n"
 *         out = []             # <<<<<<<<<<<<<<
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 *                           for v in vlist)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":975
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_pf_10cPyparsing_12ParseResults_5asXML_genexpr(NULL, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_namedItems = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":977
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "             # <<<<<<<<<<<<<<
 * 
 *         # collapse out indents if formatting is not desired
 */
  __pyx_t_1 = PyNumber_Add(__pyx_v_indent, __pyx_kp_u__25); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_nextLevelIndent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":980
 * 
 *         # collapse out indents if formatting is not desired
 *         if not formatted:             # <<<<<<<<<<<<<<
 *             indent = ""
 *             nextLevelIndent = ""
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_formatted); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 980, __pyx_L1_error)
  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":981
 *         # collapse out indents if formatting is not desired
 *         if not formatted:
 *             indent = ""             # <<<<<<<<<<<<<<
 *             nextLevelIndent = ""
 *             nl = ""
 */
    __Pyx_INCREF(__pyx_kp_u__10);
    __Pyx_DECREF_SET(__pyx_v_indent, __pyx_kp_u__10);

    /* "cPyparsing.pyx":982
 *         if not formatted:
 *             indent = ""
 *             nextLevelIndent = ""             # <<<<<<<<<<<<<<
 *             nl = ""
 * 
 */
    __Pyx_INCREF(__pyx_kp_u__10);
    __Pyx_DECREF_SET(__pyx_v_nextLevelIndent, __pyx_kp_u__10);

    /* "cPyparsing.pyx":983
 *             indent = ""
 *             nextLevelIndent = ""
 *             nl = ""             # <<<<<<<<<<<<<<
 * 
 *         selfTag = None
 */
    __Pyx_INCREF(__pyx_kp_u__10);
    __Pyx_DECREF_SET(__pyx_v_nl, __pyx_kp_u__10);

    /* "cPyparsing.pyx":980
 * 
 *         # collapse out indents if formatting is not desired
 *         if not formatted:             # <<<<<<<<<<<<<<
 *             indent = ""
 *             nextLevelIndent = ""
 */
  }

  /* "cPyparsing.pyx":985
 *             nl = ""
 * 
 *         selfTag = None             # <<<<<<<<<<<<<<
 *         if doctag is not None:
 *             selfTag = doctag
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_selfTag = Py_None;

  /* "cPyparsing.pyx":986
 * 
 *         selfTag = None
 *         if doctag is not None:             # <<<<<<<<<<<<<<
 *             selfTag = doctag
 *         else:
 */
  __pyx_t_4 = (__pyx_v_doctag != Py_None);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":987
 *         selfTag = None
 *         if doctag is not None:
 *             selfTag = doctag             # <<<<<<<<<<<<<<
 *         else:
 *             if self.__name:
 */
    __Pyx_INCREF(__pyx_v_doctag);
    __Pyx_DECREF_SET(__pyx_v_selfTag, __pyx_v_doctag);

    /* "cPyparsing.pyx":986
 * 
 *         selfTag = None
 *         if doctag is not None:             # <<<<<<<<<<<<<<
 *             selfTag = doctag
 *         else:
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":989
 *             selfTag = doctag
 *         else:
 *             if self.__name:             # <<<<<<<<<<<<<<
 *                 selfTag = self.__name
 * 
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 989, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":990
 *         else:
 *             if self.__name:
 *                 selfTag = self.__name             # <<<<<<<<<<<<<<
 * 
 *         if not selfTag:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_selfTag, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":989
 *             selfTag = doctag
 *         else:
 *             if self.__name:             # <<<<<<<<<<<<<<
 *                 selfTag = self.__name
 * 
 */
    }
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":992
 *                 selfTag = self.__name
 * 
 *         if not selfTag:             # <<<<<<<<<<<<<<
 *             if namedItemsOnly:
 *                 return ""
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_selfTag); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 992, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_4);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":993
 * 
 *         if not selfTag:
 *             if namedItemsOnly:             # <<<<<<<<<<<<<<
 *                 return ""
 *             else:
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_namedItemsOnly); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 993, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":994
 *         if not selfTag:
 *             if namedItemsOnly:
 *                 return ""             # <<<<<<<<<<<<<<
 *             else:
 *                 selfTag = "ITEM"
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__10);
      __pyx_r = __pyx_kp_u__10;
      goto __pyx_L0;

      /* "cPyparsing.pyx":993
 * 
 *         if not selfTag:
 *             if namedItemsOnly:             # <<<<<<<<<<<<<<
 *                 return ""
 *             else:
 */
    }

    /* "cPyparsing.pyx":996
 *                 return ""
 *             else:
 *                 selfTag = "ITEM"             # <<<<<<<<<<<<<<
 * 
 *         out += [nl, indent, "<", selfTag, ">"]
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_n_u_ITEM);
      __Pyx_DECREF_SET(__pyx_v_selfTag, __pyx_n_u_ITEM);
    }

    /* "cPyparsing.pyx":992
 *                 selfTag = self.__name
 * 
 *         if not selfTag:             # <<<<<<<<<<<<<<
 *             if namedItemsOnly:
 *                 return ""
 */
  }

  /* "cPyparsing.pyx":998
 *                 selfTag = "ITEM"
 * 
 *         out += [nl, indent, "<", selfTag, ">"]             # <<<<<<<<<<<<<<
 * 
 *         for i, res in enumerate(self.__toklist):
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_nl);
  __Pyx_GIVEREF(__pyx_v_nl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_nl)) __PYX_ERR(0, 998, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_indent);
  __Pyx_GIVEREF(__pyx_v_indent);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_indent)) __PYX_ERR(0, 998, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_u__26);
  __Pyx_GIVEREF(__pyx_kp_u__26);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u__26)) __PYX_ERR(0, 998, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_selfTag);
  __Pyx_GIVEREF(__pyx_v_selfTag);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 3, __pyx_v_selfTag)) __PYX_ERR(0, 998, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_u__27);
  __Pyx_GIVEREF(__pyx_kp_u__27);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u__27)) __PYX_ERR(0, 998, __pyx_L1_error);
  __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1000
 *         out += [nl, indent, "<", selfTag, ">"]
 * 
 *         for i, res in enumerate(self.__toklist):             # <<<<<<<<<<<<<<
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_2 = __pyx_int_0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_5 = __pyx_t_1; __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1000, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1000, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1000, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1000, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1000, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1000, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1000, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1000, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_5);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1000, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_res, __pyx_t_1);
    __pyx_t_1 = 0;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_2);
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1000, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1001
 * 
 *         for i, res in enumerate(self.__toklist):
 *             if isinstance(res, ParseResults):             # <<<<<<<<<<<<<<
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1001, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_IsInstance(__pyx_v_res, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 1001, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":1002
 *         for i, res in enumerate(self.__toklist):
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:             # <<<<<<<<<<<<<<
 *                     out += [res.asXML(namedItems[i],
 *                                       namedItemsOnly and doctag is None,
 */
      if (unlikely(__pyx_v_namedItems == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 1002, __pyx_L1_error)
      }
      __pyx_t_3 = (__Pyx_PyDict_ContainsTF(__pyx_v_i, __pyx_v_namedItems, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1002, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":1003
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],             # <<<<<<<<<<<<<<
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_asXML); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1003, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(__pyx_v_namedItems == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1003, __pyx_L1_error)
        }
        __pyx_t_9 = __Pyx_PyDict_GetItem(__pyx_v_namedItems, __pyx_v_i); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1003, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);

        /* "cPyparsing.pyx":1004
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],
 *                                       namedItemsOnly and doctag is None,             # <<<<<<<<<<<<<<
 *                                       nextLevelIndent,
 *                                       formatted)]
 */
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_namedItemsOnly); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1004, __pyx_L1_error)
        if (__pyx_t_3) {
        } else {
          __Pyx_INCREF(__pyx_v_namedItemsOnly);
          __pyx_t_10 = __pyx_v_namedItemsOnly;
          goto __pyx_L12_bool_binop_done;
        }
        __pyx_t_3 = (__pyx_v_doctag == Py_None);
        __pyx_t_11 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1004, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_10 = __pyx_t_11;
        __pyx_t_11 = 0;
        __pyx_L12_bool_binop_done:;

        /* "cPyparsing.pyx":1006
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 *                                       formatted)]             # <<<<<<<<<<<<<<
 *                 else:
 *                     out += [res.asXML(None,
 */
        __pyx_t_11 = NULL;
        __pyx_t_12 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_12 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_11, __pyx_t_9, __pyx_t_10, __pyx_v_nextLevelIndent, __pyx_v_formatted};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_12, 4+__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }

        /* "cPyparsing.pyx":1003
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],             # <<<<<<<<<<<<<<
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 */
        __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1003, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error);
        __pyx_t_1 = 0;
        __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":1002
 *         for i, res in enumerate(self.__toklist):
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:             # <<<<<<<<<<<<<<
 *                     out += [res.asXML(namedItems[i],
 *                                       namedItemsOnly and doctag is None,
 */
        goto __pyx_L11;
      }

      /* "cPyparsing.pyx":1008
 *                                       formatted)]
 *                 else:
 *                     out += [res.asXML(None,             # <<<<<<<<<<<<<<
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 */
      /*else*/ {
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_asXML); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1008, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);

        /* "cPyparsing.pyx":1009
 *                 else:
 *                     out += [res.asXML(None,
 *                                       namedItemsOnly and doctag is None,             # <<<<<<<<<<<<<<
 *                                       nextLevelIndent,
 *                                       formatted)]
 */
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_namedItemsOnly); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1009, __pyx_L1_error)
        if (__pyx_t_3) {
        } else {
          __Pyx_INCREF(__pyx_v_namedItemsOnly);
          __pyx_t_10 = __pyx_v_namedItemsOnly;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_3 = (__pyx_v_doctag == Py_None);
        __pyx_t_9 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1009, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = __pyx_t_9;
        __pyx_t_9 = 0;
        __pyx_L14_bool_binop_done:;

        /* "cPyparsing.pyx":1011
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 *                                       formatted)]             # <<<<<<<<<<<<<<
 *             else:
 *                 # individual token, see if there is a name for it
 */
        __pyx_t_9 = NULL;
        __pyx_t_12 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_12 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_9, Py_None, __pyx_t_10, __pyx_v_nextLevelIndent, __pyx_v_formatted};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_12, 4+__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1008, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }

        /* "cPyparsing.pyx":1008
 *                                       formatted)]
 *                 else:
 *                     out += [res.asXML(None,             # <<<<<<<<<<<<<<
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 */
        __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1008, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_t_1)) __PYX_ERR(0, 1008, __pyx_L1_error);
        __pyx_t_1 = 0;
        __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1008, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;
      }
      __pyx_L11:;

      /* "cPyparsing.pyx":1001
 * 
 *         for i, res in enumerate(self.__toklist):
 *             if isinstance(res, ParseResults):             # <<<<<<<<<<<<<<
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],
 */
      goto __pyx_L10;
    }

    /* "cPyparsing.pyx":1014
 *             else:
 *                 # individual token, see if there is a name for it
 *                 resTag = None             # <<<<<<<<<<<<<<
 *                 if i in namedItems:
 *                     resTag = namedItems[i]
 */
    /*else*/ {
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_resTag, Py_None);

      /* "cPyparsing.pyx":1015
 *                 # individual token, see if there is a name for it
 *                 resTag = None
 *                 if i in namedItems:             # <<<<<<<<<<<<<<
 *                     resTag = namedItems[i]
 *                 if not resTag:
 */
      if (unlikely(__pyx_v_namedItems == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 1015, __pyx_L1_error)
      }
      __pyx_t_3 = (__Pyx_PyDict_ContainsTF(__pyx_v_i, __pyx_v_namedItems, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1015, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":1016
 *                 resTag = None
 *                 if i in namedItems:
 *                     resTag = namedItems[i]             # <<<<<<<<<<<<<<
 *                 if not resTag:
 *                     if namedItemsOnly:
 */
        if (unlikely(__pyx_v_namedItems == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1016, __pyx_L1_error)
        }
        __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_namedItems, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1016, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_resTag, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":1015
 *                 # individual token, see if there is a name for it
 *                 resTag = None
 *                 if i in namedItems:             # <<<<<<<<<<<<<<
 *                     resTag = namedItems[i]
 *                 if not resTag:
 */
      }

      /* "cPyparsing.pyx":1017
 *                 if i in namedItems:
 *                     resTag = namedItems[i]
 *                 if not resTag:             # <<<<<<<<<<<<<<
 *                     if namedItemsOnly:
 *                         continue
 */
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_resTag); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1017, __pyx_L1_error)
      __pyx_t_4 = (!__pyx_t_3);
      if (__pyx_t_4) {

        /* "cPyparsing.pyx":1018
 *                     resTag = namedItems[i]
 *                 if not resTag:
 *                     if namedItemsOnly:             # <<<<<<<<<<<<<<
 *                         continue
 *                     else:
 */
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_namedItemsOnly); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1018, __pyx_L1_error)
        if (__pyx_t_4) {

          /* "cPyparsing.pyx":1019
 *                 if not resTag:
 *                     if namedItemsOnly:
 *                         continue             # <<<<<<<<<<<<<<
 *                     else:
 *                         resTag = "ITEM"
 */
          goto __pyx_L8_continue;

          /* "cPyparsing.pyx":1018
 *                     resTag = namedItems[i]
 *                 if not resTag:
 *                     if namedItemsOnly:             # <<<<<<<<<<<<<<
 *                         continue
 *                     else:
 */
        }

        /* "cPyparsing.pyx":1021
 *                         continue
 *                     else:
 *                         resTag = "ITEM"             # <<<<<<<<<<<<<<
 *                 xmlBodyText = _xml_escape(_ustr(res))
 *                 out += [nl, nextLevelIndent, "<", resTag, ">",
 */
        /*else*/ {
          __Pyx_INCREF(__pyx_n_u_ITEM);
          __Pyx_DECREF_SET(__pyx_v_resTag, __pyx_n_u_ITEM);
        }

        /* "cPyparsing.pyx":1017
 *                 if i in namedItems:
 *                     resTag = namedItems[i]
 *                 if not resTag:             # <<<<<<<<<<<<<<
 *                     if namedItemsOnly:
 *                         continue
 */
      }

      /* "cPyparsing.pyx":1022
 *                     else:
 *                         resTag = "ITEM"
 *                 xmlBodyText = _xml_escape(_ustr(res))             # <<<<<<<<<<<<<<
 *                 out += [nl, nextLevelIndent, "<", resTag, ">",
 *                         xmlBodyText,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_xml_escape); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ustr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_12 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_res};
        __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __pyx_t_9 = NULL;
      __pyx_t_12 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_12 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_10};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_xmlBodyText, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":1023
 *                         resTag = "ITEM"
 *                 xmlBodyText = _xml_escape(_ustr(res))
 *                 out += [nl, nextLevelIndent, "<", resTag, ">",             # <<<<<<<<<<<<<<
 *                         xmlBodyText,
 *                                                 "</", resTag, ">"]
 */
      __pyx_t_1 = PyList_New(9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1023, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_nl);
      __Pyx_GIVEREF(__pyx_v_nl);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_nl)) __PYX_ERR(0, 1023, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_nextLevelIndent);
      __Pyx_GIVEREF(__pyx_v_nextLevelIndent);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_nextLevelIndent)) __PYX_ERR(0, 1023, __pyx_L1_error);
      __Pyx_INCREF(__pyx_kp_u__26);
      __Pyx_GIVEREF(__pyx_kp_u__26);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u__26)) __PYX_ERR(0, 1023, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_resTag);
      __Pyx_GIVEREF(__pyx_v_resTag);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 3, __pyx_v_resTag)) __PYX_ERR(0, 1023, __pyx_L1_error);
      __Pyx_INCREF(__pyx_kp_u__27);
      __Pyx_GIVEREF(__pyx_kp_u__27);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u__27)) __PYX_ERR(0, 1023, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_xmlBodyText);
      __Pyx_GIVEREF(__pyx_v_xmlBodyText);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 5, __pyx_v_xmlBodyText)) __PYX_ERR(0, 1023, __pyx_L1_error);
      __Pyx_INCREF(__pyx_kp_u__28);
      __Pyx_GIVEREF(__pyx_kp_u__28);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 6, __pyx_kp_u__28)) __PYX_ERR(0, 1023, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_resTag);
      __Pyx_GIVEREF(__pyx_v_resTag);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 7, __pyx_v_resTag)) __PYX_ERR(0, 1023, __pyx_L1_error);
      __Pyx_INCREF(__pyx_kp_u__27);
      __Pyx_GIVEREF(__pyx_kp_u__27);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 8, __pyx_kp_u__27)) __PYX_ERR(0, 1023, __pyx_L1_error);
      __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1023, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_8));
      __pyx_t_8 = 0;
    }
    __pyx_L10:;

    /* "cPyparsing.pyx":1000
 *         out += [nl, indent, "<", selfTag, ">"]
 * 
 *         for i, res in enumerate(self.__toklist):             # <<<<<<<<<<<<<<
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:
 */
    __pyx_L8_continue:;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1027
 *                                                 "</", resTag, ">"]
 * 
 *         out += [nl, indent, "</", selfTag, ">"]             # <<<<<<<<<<<<<<
 *         return "".join(out)
 * 
 */
  __pyx_t_2 = PyList_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_nl);
  __Pyx_GIVEREF(__pyx_v_nl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_nl)) __PYX_ERR(0, 1027, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_indent);
  __Pyx_GIVEREF(__pyx_v_indent);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_indent)) __PYX_ERR(0, 1027, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_u__28);
  __Pyx_GIVEREF(__pyx_kp_u__28);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__28)) __PYX_ERR(0, 1027, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_selfTag);
  __Pyx_GIVEREF(__pyx_v_selfTag);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_v_selfTag)) __PYX_ERR(0, 1027, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_u__27);
  __Pyx_GIVEREF(__pyx_kp_u__27);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_kp_u__27)) __PYX_ERR(0, 1027, __pyx_L1_error);
  __pyx_t_5 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_5));
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":1028
 * 
 *         out += [nl, indent, "</", selfTag, ">"]
 *         return "".join(out)             # <<<<<<<<<<<<<<
 * 
 *     def __lookup(self, sub):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__10, __pyx_v_out); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":969
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.ParseResults.asXML", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_nl);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_namedItems);
  __Pyx_XDECREF(__pyx_v_nextLevelIndent);
  __Pyx_XDECREF(__pyx_v_selfTag);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_resTag);
  __Pyx_XDECREF(__pyx_v_xmlBodyText);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_12ParseResults_5asXML_2generator11);
  __Pyx_XDECREF(__pyx_v_indent);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1030
 *         return "".join(out)
 * 
 *     def __lookup(self, sub):             # <<<<<<<<<<<<<<
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_69__lookup(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_68__lookup, "ParseResults.__lookup(self, sub)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_69__lookup = {"__lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_69__lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_68__lookup};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_69__lookup(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_sub = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_sub,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1030, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_sub)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1030, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__lookup", 1, 2, 2, 1); __PYX_ERR(0, 1030, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__lookup") < 0)) __PYX_ERR(0, 1030, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_sub = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__lookup", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1030, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_68__lookup(__pyx_self, __pyx_v_self, __pyx_v_sub);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_68__lookup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sub) {
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_vlist = NULL;
  PyObject *__pyx_v_v = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_loc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__lookup", 1);

  /* "cPyparsing.pyx":1031
 * 
 *     def __lookup(self, sub):
 *         for k, vlist in self.__tokdict.items():             # <<<<<<<<<<<<<<
 *             for v, loc in vlist:
 *                 if sub is v:
 */
  __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (unlikely(__pyx_t_5 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 1031, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_dict_iterator(__pyx_t_5, 0, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_6;
  __pyx_t_6 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_6, &__pyx_t_5, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 1031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_vlist, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":1032
 *     def __lookup(self, sub):
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:             # <<<<<<<<<<<<<<
 *                 if sub is v:
 *                     return k
 */
    if (likely(PyList_CheckExact(__pyx_v_vlist)) || PyTuple_CheckExact(__pyx_v_vlist)) {
      __pyx_t_5 = __pyx_v_vlist; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_vlist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1032, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1032, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1032, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_6); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 1032, __pyx_L1_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1032, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1032, __pyx_L1_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_6); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 1032, __pyx_L1_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1032, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_9(__pyx_t_5);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1032, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1032, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_10 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_10 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_11 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        #else
        __pyx_t_10 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_12 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_12);
        index = 0; __pyx_t_10 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_10)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_10);
        index = 1; __pyx_t_11 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_11)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_12), 2) < 0) __PYX_ERR(0, 1032, __pyx_L1_error)
        __pyx_t_13 = NULL;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L8_unpacking_done;
        __pyx_L7_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_13 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1032, __pyx_L1_error)
        __pyx_L8_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_10);
      __pyx_t_10 = 0;
      __Pyx_XDECREF_SET(__pyx_v_loc, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "cPyparsing.pyx":1033
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 *                 if sub is v:             # <<<<<<<<<<<<<<
 *                     return k
 *         return None
 */
      __pyx_t_14 = (__pyx_v_sub == __pyx_v_v);
      if (__pyx_t_14) {

        /* "cPyparsing.pyx":1034
 *             for v, loc in vlist:
 *                 if sub is v:
 *                     return k             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_k);
        __pyx_r = __pyx_v_k;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L0;

        /* "cPyparsing.pyx":1033
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 *                 if sub is v:             # <<<<<<<<<<<<<<
 *                     return k
 *         return None
 */
      }

      /* "cPyparsing.pyx":1032
 *     def __lookup(self, sub):
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:             # <<<<<<<<<<<<<<
 *                 if sub is v:
 *                     return k
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1035
 *                 if sub is v:
 *                     return k
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def getName(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "cPyparsing.pyx":1030
 *         return "".join(out)
 * 
 *     def __lookup(self, sub):             # <<<<<<<<<<<<<<
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_vlist);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1037
 *         return None
 * 
 *     def getName(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Returns the results name for this token expression. Useful when several
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_71getName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_70getName, "ParseResults.getName(self)\n\n        Returns the results name for this token expression. Useful when several\n        different expressions might match at a particular location.\n\n        Example::\n\n            integer = Word(nums)\n            ssn_expr = Regex(r\"\\d\\d\\d-\\d\\d-\\d\\d\\d\\d\")\n            house_number_expr = Suppress('#') + Word(nums, alphanums)\n            user_data = (Group(house_number_expr)(\"house_number\")\n                        | Group(ssn_expr)(\"ssn\")\n                        | Group(integer)(\"age\"))\n            user_info = OneOrMore(user_data)\n\n            result = user_info.parseString(\"22 111-22-3333 #221B\")\n            for item in result:\n                print(item.getName(), ':', item[0])\n\n        prints::\n\n            age : 22\n            ssn : 111-22-3333\n            house_number : 221B\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_71getName = {"getName", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_71getName, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_70getName};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_71getName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getName (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1037, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getName") < 0)) __PYX_ERR(0, 1037, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getName", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1037, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.getName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_70getName(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_70getName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_par = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getName", 1);

  /* "cPyparsing.pyx":1062
 *             house_number : 221B
 *         """
 *         if self.__name:             # <<<<<<<<<<<<<<
 *             return self.__name
 *         elif self.__parent:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1062, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1063
 *         """
 *         if self.__name:
 *             return self.__name             # <<<<<<<<<<<<<<
 *         elif self.__parent:
 *             par = self.__parent()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1063, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1062
 *             house_number : 221B
 *         """
 *         if self.__name:             # <<<<<<<<<<<<<<
 *             return self.__name
 *         elif self.__parent:
 */
  }

  /* "cPyparsing.pyx":1064
 *         if self.__name:
 *             return self.__name
 *         elif self.__parent:             # <<<<<<<<<<<<<<
 *             par = self.__parent()
 *             if par:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1064, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1065
 *             return self.__name
 *         elif self.__parent:
 *             par = self.__parent()             # <<<<<<<<<<<<<<
 *             if par:
 *                 return par.__lookup(self)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1065, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_par = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1066
 *         elif self.__parent:
 *             par = self.__parent()
 *             if par:             # <<<<<<<<<<<<<<
 *                 return par.__lookup(self)
 *             else:
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_par); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1066, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1067
 *             par = self.__parent()
 *             if par:
 *                 return par.__lookup(self)             # <<<<<<<<<<<<<<
 *             else:
 *                 return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_par, __pyx_n_s_ParseResults__lookup); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1067, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1067, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":1066
 *         elif self.__parent:
 *             par = self.__parent()
 *             if par:             # <<<<<<<<<<<<<<
 *                 return par.__lookup(self)
 *             else:
 */
    }

    /* "cPyparsing.pyx":1069
 *                 return par.__lookup(self)
 *             else:
 *                 return None             # <<<<<<<<<<<<<<
 *         elif (len(self) == 1
 *               and len(self.__tokdict) == 1
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
    }

    /* "cPyparsing.pyx":1064
 *         if self.__name:
 *             return self.__name
 *         elif self.__parent:             # <<<<<<<<<<<<<<
 *             par = self.__parent()
 *             if par:
 */
  }

  /* "cPyparsing.pyx":1070
 *             else:
 *                 return None
 *         elif (len(self) == 1             # <<<<<<<<<<<<<<
 *               and len(self.__tokdict) == 1
 *               and next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 */
  __pyx_t_6 = PyObject_Length(__pyx_v_self); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1070, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 == 1);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }

  /* "cPyparsing.pyx":1071
 *                 return None
 *         elif (len(self) == 1
 *               and len(self.__tokdict) == 1             # <<<<<<<<<<<<<<
 *               and next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 *             return next(iter(self.__tokdict.keys()))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1071, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (__pyx_t_6 == 1);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }

  /* "cPyparsing.pyx":1072
 *         elif (len(self) == 1
 *               and len(self.__tokdict) == 1
 *               and next(iter(self.__tokdict.values()))[0][1] in (0, -1)):             # <<<<<<<<<<<<<<
 *             return next(iter(self.__tokdict.keys()))
 *         else:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_values); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1072, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyIter_Next(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_4, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1072, __pyx_L1_error)
  if (!__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1072, __pyx_L1_error)
  __pyx_t_7 = __pyx_t_8;
  __pyx_L8_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = __pyx_t_7;
  __pyx_t_2 = __pyx_t_8;
  __pyx_L5_bool_binop_done:;

  /* "cPyparsing.pyx":1070
 *             else:
 *                 return None
 *         elif (len(self) == 1             # <<<<<<<<<<<<<<
 *               and len(self.__tokdict) == 1
 *               and next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 */
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1073
 *               and len(self.__tokdict) == 1
 *               and next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 *             return next(iter(self.__tokdict.keys()))             # <<<<<<<<<<<<<<
 *         else:
 *             return None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_keys); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1073, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyIter_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1070
 *             else:
 *                 return None
 *         elif (len(self) == 1             # <<<<<<<<<<<<<<
 *               and len(self.__tokdict) == 1
 *               and next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 */
  }

  /* "cPyparsing.pyx":1075
 *             return next(iter(self.__tokdict.keys()))
 *         else:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *     def dump(self, indent='', full=True, include_list=True, _depth=0):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":1037
 *         return None
 * 
 *     def getName(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Returns the results name for this token expression. Useful when several
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.getName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_par);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1077
 *             return None
 * 
 *     def dump(self, indent='', full=True, include_list=True, _depth=0):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_73dump(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_72dump, "ParseResults.dump(self, indent=u'', full=True, include_list=True, _depth=0)\n\n        Diagnostic method for listing out the contents of\n        a :class:`ParseResults`. Accepts an optional ``indent`` argument so\n        that this string can be embedded in a nested display of other data.\n\n        Example::\n\n            integer = Word(nums)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            result = date_str.parseString('12/31/1999')\n            print(result.dump())\n\n        prints::\n\n            ['12', '/', '31', '/', '1999']\n            - day: 1999\n            - month: 31\n            - year: 12\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_73dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_73dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_72dump};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_73dump(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_indent = 0;
  PyObject *__pyx_v_full = 0;
  PyObject *__pyx_v_include_list = 0;
  PyObject *__pyx_v__depth = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_indent,&__pyx_n_s_full,&__pyx_n_s_include_list,&__pyx_n_s_depth_2,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__10)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1077, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_indent);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1077, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_full);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1077, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_include_list);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1077, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_depth_2);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1077, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 1077, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_indent = values[1];
    __pyx_v_full = values[2];
    __pyx_v_include_list = values[3];
    __pyx_v__depth = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 0, 1, 5, __pyx_nargs); __PYX_ERR(0, 1077, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_72dump(__pyx_self, __pyx_v_self, __pyx_v_indent, __pyx_v_full, __pyx_v_include_list, __pyx_v__depth);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_2generator12(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":1107
 *         if full:
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())             # <<<<<<<<<<<<<<
 *                 for k, v in items:
 *                     if out:
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4dump_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_14_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1107, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_4dump_2generator12, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults_dump_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.dump.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_2generator12(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1107, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 1107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 1107, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_genexpr_arg_0 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 1107, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_cur_scope->__pyx_genexpr_arg_0, 0, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_v);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_v, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_k};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 1107, __pyx_L1_error);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_v);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_v);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_cur_scope->__pyx_v_v)) __PYX_ERR(0, 1107, __pyx_L1_error);
    __pyx_t_6 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_5generator13(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":1119
 *                     else:
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):             # <<<<<<<<<<<<<<
 *                 v = self
 *                 for i, vv in enumerate(v):
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4dump_3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_15_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1119, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_4dump_5generator13, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults_dump_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 1119, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.dump.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_5generator13(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1119, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 1119, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1119, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1119, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 1119, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1119, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1119, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 1119, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1119, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1119, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_vv);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_vv, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_vv, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1119, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1077
 *             return None
 * 
 *     def dump(self, indent='', full=True, include_list=True, _depth=0):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_72dump(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_indent, PyObject *__pyx_v_full, PyObject *__pyx_v_include_list, PyObject *__pyx_v__depth) {
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_NL = NULL;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_vv = NULL;
  PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_2generator12 = 0;
  PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_5generator13 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  Py_ssize_t __pyx_t_11;
  Py_UCS4 __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 1);

  /* "cPyparsing.pyx":1098
 *             - year: 12
 *         """
 *         out = []             # <<<<<<<<<<<<<<
 *         NL = '\n'
 *         if include_list:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1099
 *         """
 *         out = []
 *         NL = '\n'             # <<<<<<<<<<<<<<
 *         if include_list:
 *             out.append(indent + _ustr(self.asList()))
 */
  __Pyx_INCREF(__pyx_kp_u__19);
  __pyx_v_NL = __pyx_kp_u__19;

  /* "cPyparsing.pyx":1100
 *         out = []
 *         NL = '\n'
 *         if include_list:             # <<<<<<<<<<<<<<
 *             out.append(indent + _ustr(self.asList()))
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_include_list); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1100, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1101
 *         NL = '\n'
 *         if include_list:
 *             out.append(indent + _ustr(self.asList()))             # <<<<<<<<<<<<<<
 *         else:
 *             out.append('')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_asList); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1101, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1101, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_v_indent, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_3); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1101, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1100
 *         out = []
 *         NL = '\n'
 *         if include_list:             # <<<<<<<<<<<<<<
 *             out.append(indent + _ustr(self.asList()))
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":1103
 *             out.append(indent + _ustr(self.asList()))
 *         else:
 *             out.append('')             # <<<<<<<<<<<<<<
 * 
 *         if full:
 */
  /*else*/ {
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_out, __pyx_kp_u__10); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1103, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":1105
 *             out.append('')
 * 
 *         if full:             # <<<<<<<<<<<<<<
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_full); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1105, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1106
 * 
 *         if full:
 *             if self.haskeys():             # <<<<<<<<<<<<<<
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1106, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1106, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1107
 *         if full:
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())             # <<<<<<<<<<<<<<
 *                 for k, v in items:
 *                     if out:
 */
      __pyx_t_1 = __pyx_pf_10cPyparsing_12ParseResults_4dump_genexpr(NULL, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_8 = PyList_Sort(__pyx_t_3); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1107, __pyx_L1_error)
      __pyx_v_items = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":1108
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:             # <<<<<<<<<<<<<<
 *                     if out:
 *                         out.append(NL)
 */
      __pyx_t_3 = __pyx_v_items; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_9 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1108, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 1108, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1108, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1108, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_5);
          #else
          __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1108, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1108, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_6 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1108, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
          index = 0; __pyx_t_1 = __pyx_t_10(__pyx_t_6); if (unlikely(!__pyx_t_1)) goto __pyx_L8_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          index = 1; __pyx_t_5 = __pyx_t_10(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L8_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_5);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_6), 2) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
          __pyx_t_10 = NULL;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L9_unpacking_done;
          __pyx_L8_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_10 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1108, __pyx_L1_error)
          __pyx_L9_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "cPyparsing.pyx":1109
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:
 *                     if out:             # <<<<<<<<<<<<<<
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * _depth), k))
 */
        __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_out) != 0);
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":1110
 *                 for k, v in items:
 *                     if out:
 *                         out.append(NL)             # <<<<<<<<<<<<<<
 *                     out.append("%s%s- %s: " % (indent, ('  ' * _depth), k))
 *                     if isinstance(v, ParseResults):
 */
          __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_out, __pyx_v_NL); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1110, __pyx_L1_error)

          /* "cPyparsing.pyx":1109
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:
 *                     if out:             # <<<<<<<<<<<<<<
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * _depth), k))
 */
        }

        /* "cPyparsing.pyx":1111
 *                     if out:
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * _depth), k))             # <<<<<<<<<<<<<<
 *                     if isinstance(v, ParseResults):
 *                         if v:
 */
        __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1111, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_11 = 0;
        __pyx_t_12 = 127;
        __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_indent), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1111, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_12;
        __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_5 = PyNumber_Multiply(__pyx_kp_u__25, __pyx_v__depth); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1111, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1111, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_12;
        __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_INCREF(__pyx_kp_u__29);
        __pyx_t_11 += 2;
        __Pyx_GIVEREF(__pyx_kp_u__29);
        PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_kp_u__29);
        __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_k), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1111, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_12;
        __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_INCREF(__pyx_kp_u__30);
        __pyx_t_11 += 2;
        __Pyx_GIVEREF(__pyx_kp_u__30);
        PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_kp_u__30);
        __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_4, 5, __pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1111, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1111, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":1112
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * _depth), k))
 *                     if isinstance(v, ParseResults):             # <<<<<<<<<<<<<<
 *                         if v:
 *                             out.append(v.dump(indent=indent, full=full, include_list=include_list, _depth=_depth + 1))
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1112, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = PyObject_IsInstance(__pyx_v_v, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1112, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":1113
 *                     out.append("%s%s- %s: " % (indent, ('  ' * _depth), k))
 *                     if isinstance(v, ParseResults):
 *                         if v:             # <<<<<<<<<<<<<<
 *                             out.append(v.dump(indent=indent, full=full, include_list=include_list, _depth=_depth + 1))
 *                         else:
 */
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_v); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1113, __pyx_L1_error)
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":1114
 *                     if isinstance(v, ParseResults):
 *                         if v:
 *                             out.append(v.dump(indent=indent, full=full, include_list=include_list, _depth=_depth + 1))             # <<<<<<<<<<<<<<
 *                         else:
 *                             out.append(_ustr(v))
 */
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_v, __pyx_n_s_dump); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1114, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1114, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_indent, __pyx_v_indent) < 0) __PYX_ERR(0, 1114, __pyx_L1_error)
            if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_full, __pyx_v_full) < 0) __PYX_ERR(0, 1114, __pyx_L1_error)
            if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_include_list, __pyx_v_include_list) < 0) __PYX_ERR(0, 1114, __pyx_L1_error)
            __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v__depth, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1114, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_depth_2, __pyx_t_5) < 0) __PYX_ERR(0, 1114, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1114, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1114, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "cPyparsing.pyx":1113
 *                     out.append("%s%s- %s: " % (indent, ('  ' * _depth), k))
 *                     if isinstance(v, ParseResults):
 *                         if v:             # <<<<<<<<<<<<<<
 *                             out.append(v.dump(indent=indent, full=full, include_list=include_list, _depth=_depth + 1))
 *                         else:
 */
            goto __pyx_L12;
          }

          /* "cPyparsing.pyx":1116
 *                             out.append(v.dump(indent=indent, full=full, include_list=include_list, _depth=_depth + 1))
 *                         else:
 *                             out.append(_ustr(v))             # <<<<<<<<<<<<<<
 *                     else:
 *                         out.append(repr(v))
 */
          /*else*/ {
            __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ustr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1116, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_1 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_4))) {
              __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
              if (likely(__pyx_t_1)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                __Pyx_INCREF(__pyx_t_1);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_4, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_v};
              __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1116, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            }
            __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1116, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          __pyx_L12:;

          /* "cPyparsing.pyx":1112
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * _depth), k))
 *                     if isinstance(v, ParseResults):             # <<<<<<<<<<<<<<
 *                         if v:
 *                             out.append(v.dump(indent=indent, full=full, include_list=include_list, _depth=_depth + 1))
 */
          goto __pyx_L11;
        }

        /* "cPyparsing.pyx":1118
 *                             out.append(_ustr(v))
 *                     else:
 *                         out.append(repr(v))             # <<<<<<<<<<<<<<
 *             elif any(isinstance(vv, ParseResults) for vv in self):
 *                 v = self
 */
        /*else*/ {
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_repr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1118, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_1 = NULL;
          __pyx_t_7 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_7 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_v};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1118, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1118, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_L11:;

        /* "cPyparsing.pyx":1108
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:             # <<<<<<<<<<<<<<
 *                     if out:
 *                         out.append(NL)
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":1106
 * 
 *         if full:
 *             if self.haskeys():             # <<<<<<<<<<<<<<
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":1119
 *                     else:
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):             # <<<<<<<<<<<<<<
 *                 v = self
 *                 for i, vv in enumerate(v):
 */
    __pyx_t_3 = __pyx_pf_10cPyparsing_12ParseResults_4dump_3genexpr(NULL, __pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1119, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1120
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):
 *                 v = self             # <<<<<<<<<<<<<<
 *                 for i, vv in enumerate(v):
 *                     if isinstance(vv, ParseResults):
 */
      __Pyx_INCREF(__pyx_v_self);
      __pyx_v_v = __pyx_v_self;

      /* "cPyparsing.pyx":1121
 *             elif any(isinstance(vv, ParseResults) for vv in self):
 *                 v = self
 *                 for i, vv in enumerate(v):             # <<<<<<<<<<<<<<
 *                     if isinstance(vv, ParseResults):
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,
 */
      __Pyx_INCREF(__pyx_int_0);
      __pyx_t_5 = __pyx_int_0;
      if (likely(PyList_CheckExact(__pyx_v_v)) || PyTuple_CheckExact(__pyx_v_v)) {
        __pyx_t_3 = __pyx_v_v; __Pyx_INCREF(__pyx_t_3);
        __pyx_t_9 = 0;
        __pyx_t_13 = NULL;
      } else {
        __pyx_t_9 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_v); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1121, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1121, __pyx_L1_error)
      }
      for (;;) {
        if (likely(!__pyx_t_13)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1121, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 1121, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1121, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1121, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 1121, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1121, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_13(__pyx_t_3);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1121, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_v_vv, __pyx_t_4);
        __pyx_t_4 = 0;
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
        __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_5, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1121, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5);
        __pyx_t_5 = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":1122
 *                 v = self
 *                 for i, vv in enumerate(v):
 *                     if isinstance(vv, ParseResults):             # <<<<<<<<<<<<<<
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,
 *                                                             ('  ' * (_depth)),
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1122, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyObject_IsInstance(__pyx_v_vv, __pyx_t_4); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1122, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":1123
 *                 for i, vv in enumerate(v):
 *                     if isinstance(vv, ParseResults):
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,             # <<<<<<<<<<<<<<
 *                                                             ('  ' * (_depth)),
 *                                                             i,
 */
          __pyx_t_4 = PyTuple_New(9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1123, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = 0;
          __pyx_t_12 = 127;
          __Pyx_INCREF(__pyx_kp_u__19);
          __pyx_t_11 += 1;
          __Pyx_GIVEREF(__pyx_kp_u__19);
          PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u__19);
          __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_indent), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1123, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":1124
 *                     if isinstance(vv, ParseResults):
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,
 *                                                             ('  ' * (_depth)),             # <<<<<<<<<<<<<<
 *                                                             i,
 *                                                             indent,
 */
          __pyx_t_1 = PyNumber_Multiply(__pyx_kp_u__25, __pyx_v__depth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1124, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_1), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1124, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_6);
          __pyx_t_6 = 0;
          __Pyx_INCREF(__pyx_kp_u__2);
          __pyx_t_11 += 1;
          __Pyx_GIVEREF(__pyx_kp_u__2);
          PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_kp_u__2);

          /* "cPyparsing.pyx":1125
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,
 *                                                             ('  ' * (_depth)),
 *                                                             i,             # <<<<<<<<<<<<<<
 *                                                             indent,
 *                                                             ('  ' * (_depth + 1)),
 */
          __pyx_t_6 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_IntOrLong(__pyx_v_i), __pyx_n_u_d); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1125, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_6);
          __pyx_t_6 = 0;
          __Pyx_INCREF(__pyx_kp_u__31);
          __pyx_t_11 += 3;
          __Pyx_GIVEREF(__pyx_kp_u__31);
          PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_kp_u__31);

          /* "cPyparsing.pyx":1126
 *                                                             ('  ' * (_depth)),
 *                                                             i,
 *                                                             indent,             # <<<<<<<<<<<<<<
 *                                                             ('  ' * (_depth + 1)),
 *                                                             vv.dump(indent=indent,
 */
          __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_indent), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1126, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_4, 6, __pyx_t_6);
          __pyx_t_6 = 0;

          /* "cPyparsing.pyx":1127
 *                                                             i,
 *                                                             indent,
 *                                                             ('  ' * (_depth + 1)),             # <<<<<<<<<<<<<<
 *                                                             vv.dump(indent=indent,
 *                                                                     full=full,
 */
          __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v__depth, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1127, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_1 = PyNumber_Multiply(__pyx_kp_u__25, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1127, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_1), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1127, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_4, 7, __pyx_t_6);
          __pyx_t_6 = 0;

          /* "cPyparsing.pyx":1128
 *                                                             indent,
 *                                                             ('  ' * (_depth + 1)),
 *                                                             vv.dump(indent=indent,             # <<<<<<<<<<<<<<
 *                                                                     full=full,
 *                                                                     include_list=include_list,
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_vv, __pyx_n_s_dump); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1128, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1128, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_indent, __pyx_v_indent) < 0) __PYX_ERR(0, 1128, __pyx_L1_error)

          /* "cPyparsing.pyx":1129
 *                                                             ('  ' * (_depth + 1)),
 *                                                             vv.dump(indent=indent,
 *                                                                     full=full,             # <<<<<<<<<<<<<<
 *                                                                     include_list=include_list,
 *                                                                     _depth=_depth + 1)))
 */
          if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_full, __pyx_v_full) < 0) __PYX_ERR(0, 1128, __pyx_L1_error)

          /* "cPyparsing.pyx":1130
 *                                                             vv.dump(indent=indent,
 *                                                                     full=full,
 *                                                                     include_list=include_list,             # <<<<<<<<<<<<<<
 *                                                                     _depth=_depth + 1)))
 *                     else:
 */
          if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_include_list, __pyx_v_include_list) < 0) __PYX_ERR(0, 1128, __pyx_L1_error)

          /* "cPyparsing.pyx":1131
 *                                                                     full=full,
 *                                                                     include_list=include_list,
 *                                                                     _depth=_depth + 1)))             # <<<<<<<<<<<<<<
 *                     else:
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,
 */
          __pyx_t_14 = __Pyx_PyInt_AddObjC(__pyx_v__depth, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1131, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_depth_2, __pyx_t_14) < 0) __PYX_ERR(0, 1128, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

          /* "cPyparsing.pyx":1128
 *                                                             indent,
 *                                                             ('  ' * (_depth + 1)),
 *                                                             vv.dump(indent=indent,             # <<<<<<<<<<<<<<
 *                                                                     full=full,
 *                                                                     include_list=include_list,
 */
          __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1128, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_14), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1128, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_4, 8, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":1123
 *                 for i, vv in enumerate(v):
 *                     if isinstance(vv, ParseResults):
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,             # <<<<<<<<<<<<<<
 *                                                             ('  ' * (_depth)),
 *                                                             i,
 */
          __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_4, 9, __pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1123, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1123, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "cPyparsing.pyx":1122
 *                 v = self
 *                 for i, vv in enumerate(v):
 *                     if isinstance(vv, ParseResults):             # <<<<<<<<<<<<<<
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,
 *                                                             ('  ' * (_depth)),
 */
          goto __pyx_L16;
        }

        /* "cPyparsing.pyx":1133
 *                                                                     _depth=_depth + 1)))
 *                     else:
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,             # <<<<<<<<<<<<<<
 *                                                             ('  ' * (_depth)),
 *                                                             i,
 */
        /*else*/ {
          __pyx_t_1 = PyTuple_New(9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1133, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_11 = 0;
          __pyx_t_12 = 127;
          __Pyx_INCREF(__pyx_kp_u__19);
          __pyx_t_11 += 1;
          __Pyx_GIVEREF(__pyx_kp_u__19);
          PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u__19);
          __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_indent), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1133, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_4);
          PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":1134
 *                     else:
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,
 *                                                             ('  ' * (_depth)),             # <<<<<<<<<<<<<<
 *                                                             i,
 *                                                             indent,
 */
          __pyx_t_4 = PyNumber_Multiply(__pyx_kp_u__25, __pyx_v__depth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1134, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1134, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_14);
          PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_14);
          __pyx_t_14 = 0;
          __Pyx_INCREF(__pyx_kp_u__2);
          __pyx_t_11 += 1;
          __Pyx_GIVEREF(__pyx_kp_u__2);
          PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u__2);

          /* "cPyparsing.pyx":1135
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,
 *                                                             ('  ' * (_depth)),
 *                                                             i,             # <<<<<<<<<<<<<<
 *                                                             indent,
 *                                                             ('  ' * (_depth + 1)),
 */
          __pyx_t_14 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_IntOrLong(__pyx_v_i), __pyx_n_u_d); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1135, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_14);
          PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_t_14);
          __pyx_t_14 = 0;
          __Pyx_INCREF(__pyx_kp_u__31);
          __pyx_t_11 += 3;
          __Pyx_GIVEREF(__pyx_kp_u__31);
          PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_kp_u__31);

          /* "cPyparsing.pyx":1136
 *                                                             ('  ' * (_depth)),
 *                                                             i,
 *                                                             indent,             # <<<<<<<<<<<<<<
 *                                                             ('  ' * (_depth + 1)),
 *                                                             _ustr(vv)))
 */
          __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_indent), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1136, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_14);
          PyTuple_SET_ITEM(__pyx_t_1, 6, __pyx_t_14);
          __pyx_t_14 = 0;

          /* "cPyparsing.pyx":1137
 *                                                             i,
 *                                                             indent,
 *                                                             ('  ' * (_depth + 1)),             # <<<<<<<<<<<<<<
 *                                                             _ustr(vv)))
 * 
 */
          __pyx_t_14 = __Pyx_PyInt_AddObjC(__pyx_v__depth, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1137, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_4 = PyNumber_Multiply(__pyx_kp_u__25, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1137, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1137, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_14);
          PyTuple_SET_ITEM(__pyx_t_1, 7, __pyx_t_14);
          __pyx_t_14 = 0;

          /* "cPyparsing.pyx":1138
 *                                                             indent,
 *                                                             ('  ' * (_depth + 1)),
 *                                                             _ustr(vv)))             # <<<<<<<<<<<<<<
 * 
 *         return "".join(out)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ustr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1138, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = NULL;
          __pyx_t_7 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_7 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_vv};
            __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1138, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_14), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1138, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_12;
          __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_4);
          PyTuple_SET_ITEM(__pyx_t_1, 8, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":1133
 *                                                                     _depth=_depth + 1)))
 *                     else:
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,             # <<<<<<<<<<<<<<
 *                                                             ('  ' * (_depth)),
 *                                                             i,
 */
          __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 9, __pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1133, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_4); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1133, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_L16:;

        /* "cPyparsing.pyx":1121
 *             elif any(isinstance(vv, ParseResults) for vv in self):
 *                 v = self
 *                 for i, vv in enumerate(v):             # <<<<<<<<<<<<<<
 *                     if isinstance(vv, ParseResults):
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent,
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":1119
 *                     else:
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):             # <<<<<<<<<<<<<<
 *                 v = self
 *                 for i, vv in enumerate(v):
 */
    }
    __pyx_L5:;

    /* "cPyparsing.pyx":1105
 *             out.append('')
 * 
 *         if full:             # <<<<<<<<<<<<<<
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())
 */
  }

  /* "cPyparsing.pyx":1140
 *                                                             _ustr(vv)))
 * 
 *         return "".join(out)             # <<<<<<<<<<<<<<
 * 
 *     def pprint(self, *args, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__10, __pyx_v_out); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1077
 *             return None
 * 
 *     def dump(self, indent='', full=True, include_list=True, _depth=0):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("cPyparsing.ParseResults.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_NL);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_vv);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_12ParseResults_4dump_2generator12);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_12ParseResults_4dump_5generator13);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1142
 *         return "".join(out)
 * 
 *     def pprint(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Pretty-printer for parsed results as a list, using the
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_75pprint(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_74pprint, "ParseResults.pprint(self, *args, **kwargs)\n\n        Pretty-printer for parsed results as a list, using the\n        `pprint <https://docs.python.org/3/library/pprint.html>`_ module.\n        Accepts additional positional or keyword args as defined for\n        `pprint.pprint <https://docs.python.org/3/library/pprint.html#pprint.pprint>`_ .\n\n        Example::\n\n            ident = Word(alphas, alphanums)\n            num = Word(nums)\n            func = Forward()\n            term = ident | num | Group('(' + func + ')')\n            func <<= ident + Group(Optional(delimitedList(term)))\n            result = func.parseString(\"fna a,b,(fnb c,d,200),100\")\n            result.pprint(width=40)\n\n        prints::\n\n            ['fna',\n             ['a',\n              'b',\n              ['(', 'fnb', ['c', 'd', '200'], ')'],\n              '100']]\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_75pprint = {"pprint", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_75pprint, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_74pprint};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_75pprint(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pprint (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1142, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, used_pos_args, "pprint") < 0)) __PYX_ERR(0, 1142, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pprint", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 1142, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParseResults.pprint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_74pprint(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_74pprint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pprint", 1);

  /* "cPyparsing.pyx":1167
 *               '100']]
 *         """
 *         pprint.pprint(self.asList(), *args, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     # add support for pickle protocol
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pprint); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_pprint); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_asList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 1167, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_v_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1142
 *         return "".join(out)
 * 
 *     def pprint(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Pretty-printer for parsed results as a list, using the
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.pprint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1170
 * 
 *     # add support for pickle protocol
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_77__getstate__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_76__getstate__, "ParseResults.__getstate__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_77__getstate__ = {"__getstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_77__getstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_76__getstate__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_77__getstate__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1170, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__getstate__") < 0)) __PYX_ERR(0, 1170, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1170, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_76__getstate__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_76__getstate__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getstate__", 1);

  /* "cPyparsing.pyx":1171
 *     # add support for pickle protocol
 *     def __getstate__(self):
 *         return (self.__toklist,             # <<<<<<<<<<<<<<
 *                 (self.__tokdict.copy(),
 *                  self.__parent is not None and self.__parent() or None,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "cPyparsing.pyx":1172
 *     def __getstate__(self):
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),             # <<<<<<<<<<<<<<
 *                  self.__parent is not None and self.__parent() or None,
 *                  self.__accumNames,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }

  /* "cPyparsing.pyx":1173
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 *                  self.__parent is not None and self.__parent() or None,             # <<<<<<<<<<<<<<
 *                  self.__accumNames,
 *                  self.__name))
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = (__pyx_t_3 != Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!__pyx_t_6) {
    goto __pyx_L4_next_or;
  } else {
  }
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1173, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1173, __pyx_L1_error)
  if (!__pyx_t_6) {
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = __pyx_t_3;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_L4_next_or:;
  __Pyx_INCREF(Py_None);
  __pyx_t_4 = Py_None;
  __pyx_L3_bool_binop_done:;

  /* "cPyparsing.pyx":1174
 *                 (self.__tokdict.copy(),
 *                  self.__parent is not None and self.__parent() or None,
 *                  self.__accumNames,             # <<<<<<<<<<<<<<
 *                  self.__name))
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "cPyparsing.pyx":1175
 *                  self.__parent is not None and self.__parent() or None,
 *                  self.__accumNames,
 *                  self.__name))             # <<<<<<<<<<<<<<
 * 
 *     def __setstate__(self, state):
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "cPyparsing.pyx":1172
 *     def __getstate__(self):
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),             # <<<<<<<<<<<<<<
 *                  self.__parent is not None and self.__parent() or None,
 *                  self.__accumNames,
 */
  __pyx_t_8 = PyTuple_New(4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2)) __PYX_ERR(0, 1172, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_4)) __PYX_ERR(0, 1172, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_3)) __PYX_ERR(0, 1172, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 3, __pyx_t_7)) __PYX_ERR(0, 1172, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1171
 *     # add support for pickle protocol
 *     def __getstate__(self):
 *         return (self.__toklist,             # <<<<<<<<<<<<<<
 *                 (self.__tokdict.copy(),
 *                  self.__parent is not None and self.__parent() or None,
 */
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1)) __PYX_ERR(0, 1171, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_8)) __PYX_ERR(0, 1171, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_8 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1170
 * 
 *     # add support for pickle protocol
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1177
 *                  self.__name))
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.__toklist = state[0]
 *         self.__tokdict, par, inAccumNames, self.__name = state[1]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_79__setstate__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_78__setstate__, "ParseResults.__setstate__(self, state)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_79__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_79__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_78__setstate__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_79__setstate__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1177, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1177, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 2, 2, 1); __PYX_ERR(0, 1177, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 1177, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_state = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1177, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_78__setstate__(__pyx_self, __pyx_v_self, __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_78__setstate__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_v_par = NULL;
  PyObject *__pyx_v_inAccumNames = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);

  /* "cPyparsing.pyx":1178
 * 
 *     def __setstate__(self, state):
 *         self.__toklist = state[0]             # <<<<<<<<<<<<<<
 *         self.__tokdict, par, inAccumNames, self.__name = state[1]
 *         self.__accumNames = {}
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_1) < 0) __PYX_ERR(0, 1178, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1179
 *     def __setstate__(self, state):
 *         self.__toklist = state[0]
 *         self.__tokdict, par, inAccumNames, self.__name = state[1]             # <<<<<<<<<<<<<<
 *         self.__accumNames = {}
 *         self.__accumNames.update(inAccumNames)
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 4)) {
      if (size > 4) __Pyx_RaiseTooManyValuesError(4);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1179, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 3); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 2); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 3); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_5);
    #else
    {
      Py_ssize_t i;
      PyObject** temps[4] = {&__pyx_t_2,&__pyx_t_3,&__pyx_t_4,&__pyx_t_5};
      for (i=0; i < 4; i++) {
        PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 1179, __pyx_L1_error)
        __Pyx_GOTREF(item);
        *(temps[i]) = item;
      }
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    PyObject** temps[4] = {&__pyx_t_2,&__pyx_t_3,&__pyx_t_4,&__pyx_t_5};
    __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
    for (index=0; index < 4; index++) {
      PyObject* item = __pyx_t_7(__pyx_t_6); if (unlikely(!item)) goto __pyx_L3_unpacking_failed;
      __Pyx_GOTREF(item);
      *(temps[index]) = item;
    }
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 4) < 0) __PYX_ERR(0, 1179, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1179, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict, __pyx_t_2) < 0) __PYX_ERR(0, 1179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_par = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_inAccumNames = __pyx_t_4;
  __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name, __pyx_t_5) < 0) __PYX_ERR(0, 1179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":1180
 *         self.__toklist = state[0]
 *         self.__tokdict, par, inAccumNames, self.__name = state[1]
 *         self.__accumNames = {}             # <<<<<<<<<<<<<<
 *         self.__accumNames.update(inAccumNames)
 *         if par is not None:
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames, __pyx_t_1) < 0) __PYX_ERR(0, 1180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1181
 *         self.__tokdict, par, inAccumNames, self.__name = state[1]
 *         self.__accumNames = {}
 *         self.__accumNames.update(inAccumNames)             # <<<<<<<<<<<<<<
 *         if par is not None:
 *             self.__parent = wkref(par)
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_inAccumNames};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1182
 *         self.__accumNames = {}
 *         self.__accumNames.update(inAccumNames)
 *         if par is not None:             # <<<<<<<<<<<<<<
 *             self.__parent = wkref(par)
 *         else:
 */
  __pyx_t_9 = (__pyx_v_par != Py_None);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":1183
 *         self.__accumNames.update(inAccumNames)
 *         if par is not None:
 *             self.__parent = wkref(par)             # <<<<<<<<<<<<<<
 *         else:
 *             self.__parent = None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_wkref); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_par};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent, __pyx_t_1) < 0) __PYX_ERR(0, 1183, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1182
 *         self.__accumNames = {}
 *         self.__accumNames.update(inAccumNames)
 *         if par is not None:             # <<<<<<<<<<<<<<
 *             self.__parent = wkref(par)
 *         else:
 */
    goto __pyx_L5;
  }

  /* "cPyparsing.pyx":1185
 *             self.__parent = wkref(par)
 *         else:
 *             self.__parent = None             # <<<<<<<<<<<<<<
 * 
 *     def __getnewargs__(self):
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent, Py_None) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  }
  __pyx_L5:;

  /* "cPyparsing.pyx":1177
 *                  self.__name))
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.__toklist = state[0]
 *         self.__tokdict, par, inAccumNames, self.__name = state[1]
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_par);
  __Pyx_XDECREF(__pyx_v_inAccumNames);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1187
 *             self.__parent = None
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_81__getnewargs__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_80__getnewargs__, "ParseResults.__getnewargs__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_81__getnewargs__ = {"__getnewargs__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_81__getnewargs__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_80__getnewargs__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_81__getnewargs__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getnewargs__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1187, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__getnewargs__") < 0)) __PYX_ERR(0, 1187, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getnewargs__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1187, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getnewargs__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_80__getnewargs__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_80__getnewargs__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getnewargs__", 1);

  /* "cPyparsing.pyx":1188
 * 
 *     def __getnewargs__(self):
 *         return self.__toklist, self.__name, self.__asList, self.__modal             # <<<<<<<<<<<<<<
 * 
 *     def __dir__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__asList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__modal); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 1188, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(0, 1188, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3)) __PYX_ERR(0, 1188, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_4)) __PYX_ERR(0, 1188, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1187
 *             self.__parent = None
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getnewargs__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1190
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return dir(type(self)) + list(self.keys())
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_83__dir__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_82__dir__, "ParseResults.__dir__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_83__dir__ = {"__dir__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_83__dir__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_82__dir__};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_83__dir__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dir__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1190, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__dir__") < 0)) __PYX_ERR(0, 1190, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__dir__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1190, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.__dir__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_82__dir__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_82__dir__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dir__", 1);

  /* "cPyparsing.pyx":1191
 * 
 *     def __dir__(self):
 *         return dir(type(self)) + list(self.keys())             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_Dir(((PyObject *)Py_TYPE(__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_keys); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PySequence_ListKeepNew(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1190
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return dir(type(self)) + list(self.keys())
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__dir__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1193
 *         return dir(type(self)) + list(self.keys())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_dict(cls, other, name=None):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_85from_dict(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12ParseResults_84from_dict, "ParseResults.from_dict(cls, other, name=None)\n\n        Helper classmethod to construct a ParseResults from a dict, preserving the\n        name-value relations as results names. If an optional 'name' argument is\n        given, a nested ParseResults will be returned\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_85from_dict = {"from_dict", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_85from_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_84from_dict};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_85from_dict(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_dict (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_other,&__pyx_n_s_name_2,0};

    /* "cPyparsing.pyx":1194
 * 
 *     @classmethod
 *     def from_dict(cls, other, name=None):             # <<<<<<<<<<<<<<
 *         """
 *         Helper classmethod to construct a ParseResults from a dict, preserving the
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1193, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1193, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("from_dict", 0, 2, 3, 1); __PYX_ERR(0, 1193, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1193, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "from_dict") < 0)) __PYX_ERR(0, 1193, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cls = values[0];
    __pyx_v_other = values[1];
    __pyx_v_name = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_dict", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 1193, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.from_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_84from_dict(__pyx_self, __pyx_v_cls, __pyx_v_other, __pyx_v_name);

  /* "cPyparsing.pyx":1193
 *         return dir(type(self)) + list(self.keys())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_dict(cls, other, name=None):
 *         """
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1200
 *         given, a nested ParseResults will be returned
 *         """
 *         def is_iterable(obj):             # <<<<<<<<<<<<<<
 *             try:
 *                 iter(obj)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_9from_dict_1is_iterable(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_9from_dict_1is_iterable = {"is_iterable", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12ParseResults_9from_dict_1is_iterable, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_9from_dict_1is_iterable(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_iterable (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1200, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_iterable") < 0)) __PYX_ERR(0, 1200, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_obj = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_iterable", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1200, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseResults.from_dict.is_iterable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_9from_dict_is_iterable(__pyx_self, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_9from_dict_is_iterable(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_iterable", 1);

  /* "cPyparsing.pyx":1201
 *         """
 *         def is_iterable(obj):
 *             try:             # <<<<<<<<<<<<<<
 *                 iter(obj)
 *             except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":1202
 *         def is_iterable(obj):
 *             try:
 *                 iter(obj)             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 return False
 */
      __pyx_t_4 = PyObject_GetIter(__pyx_v_obj); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1202, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1201
 *         """
 *         def is_iterable(obj):
 *             try:             # <<<<<<<<<<<<<<
 *                 iter(obj)
 *             except Exception:
 */
    }

    /* "cPyparsing.pyx":1206
 *                 return False
 *             else:
 *                 if PY_3:             # <<<<<<<<<<<<<<
 *                     return not isinstance(obj, (str, bytes))
 *                 else:
 */
    /*else:*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_PY_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1206, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1206, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":1207
 *             else:
 *                 if PY_3:
 *                     return not isinstance(obj, (str, bytes))             # <<<<<<<<<<<<<<
 *                 else:
 *                     return not isinstance(obj, basestring)
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1207, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_4); 
        if (!__pyx_t_6) {
        } else {
          __pyx_t_5 = __pyx_t_6;
          goto __pyx_L10_bool_binop_done;
        }
        __pyx_t_6 = PyBytes_Check(__pyx_v_obj); 
        __pyx_t_5 = __pyx_t_6;
        __pyx_L10_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyBool_FromLong((!__pyx_t_5)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1207, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L6_except_return;

        /* "cPyparsing.pyx":1206
 *                 return False
 *             else:
 *                 if PY_3:             # <<<<<<<<<<<<<<
 *                     return not isinstance(obj, (str, bytes))
 *                 else:
 */
      }

      /* "cPyparsing.pyx":1209
 *                     return not isinstance(obj, (str, bytes))
 *                 else:
 *                     return not isinstance(obj, basestring)             # <<<<<<<<<<<<<<
 * 
 *         ret = cls([])
 */
      /*else*/ {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_basestring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1209, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1209, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyBool_FromLong((!__pyx_t_5)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1209, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L6_except_return;
      }
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1203
 *             try:
 *                 iter(obj)
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 return False
 *             else:
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.ParseResults.from_dict.is_iterable", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1203, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "cPyparsing.pyx":1204
 *                 iter(obj)
 *             except Exception:
 *                 return False             # <<<<<<<<<<<<<<
 *             else:
 *                 if PY_3:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":1201
 *         """
 *         def is_iterable(obj):
 *             try:             # <<<<<<<<<<<<<<
 *                 iter(obj)
 *             except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":1200
 *         given, a nested ParseResults will be returned
 *         """
 *         def is_iterable(obj):             # <<<<<<<<<<<<<<
 *             try:
 *                 iter(obj)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParseResults.from_dict.is_iterable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1193
 *         return dir(type(self)) + list(self.keys())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_dict(cls, other, name=None):
 *         """
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_84from_dict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_other, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_is_iterable = 0;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_dict", 1);

  /* "cPyparsing.pyx":1200
 *         given, a nested ParseResults will be returned
 *         """
 *         def is_iterable(obj):             # <<<<<<<<<<<<<<
 *             try:
 *                 iter(obj)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_9from_dict_1is_iterable, 0, __pyx_n_s_ParseResults_from_dict_locals_is, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__33)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_is_iterable = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1211
 *                     return not isinstance(obj, basestring)
 * 
 *         ret = cls([])             # <<<<<<<<<<<<<<
 *         for k, v in other.items():
 *             if isinstance(v, Mapping):
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_cls);
  __pyx_t_3 = __pyx_v_cls; __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1212
 * 
 *         ret = cls([])
 *         for k, v in other.items():             # <<<<<<<<<<<<<<
 *             if isinstance(v, Mapping):
 *                 ret += cls.from_dict(v, name=k)
 */
  __pyx_t_6 = 0;
  if (unlikely(__pyx_v_other == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 1212, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_other, 0, __pyx_n_s_items, (&__pyx_t_7), (&__pyx_t_5)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  while (1) {
    __pyx_t_8 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_7, &__pyx_t_6, &__pyx_t_3, &__pyx_t_2, NULL, __pyx_t_5);
    if (unlikely(__pyx_t_8 == 0)) break;
    if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 1212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1213
 *         ret = cls([])
 *         for k, v in other.items():
 *             if isinstance(v, Mapping):             # <<<<<<<<<<<<<<
 *                 ret += cls.from_dict(v, name=k)
 *             else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Mapping); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = PyObject_IsInstance(__pyx_v_v, __pyx_t_2); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 1213, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_9) {

      /* "cPyparsing.pyx":1214
 *         for k, v in other.items():
 *             if isinstance(v, Mapping):
 *                 ret += cls.from_dict(v, name=k)             # <<<<<<<<<<<<<<
 *             else:
 *                 ret += cls([v], name=k, asList=is_iterable(v))
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_from_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_v);
      __Pyx_GIVEREF(__pyx_v_v);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_v)) __PYX_ERR(0, 1214, __pyx_L1_error);
      __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_name_2, __pyx_v_k) < 0) __PYX_ERR(0, 1214, __pyx_L1_error)
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_ret, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1213
 *         ret = cls([])
 *         for k, v in other.items():
 *             if isinstance(v, Mapping):             # <<<<<<<<<<<<<<
 *                 ret += cls.from_dict(v, name=k)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":1216
 *                 ret += cls.from_dict(v, name=k)
 *             else:
 *                 ret += cls([v], name=k, asList=is_iterable(v))             # <<<<<<<<<<<<<<
 *         if name is not None:
 *             ret = cls([ret], name=name)
 */
    /*else*/ {
      __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_v);
      __Pyx_GIVEREF(__pyx_v_v);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_v)) __PYX_ERR(0, 1216, __pyx_L1_error);
      __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(0, 1216, __pyx_L1_error);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_name_2, __pyx_v_k) < 0) __PYX_ERR(0, 1216, __pyx_L1_error)
      __pyx_t_3 = __pyx_pf_10cPyparsing_12ParseResults_9from_dict_is_iterable(__pyx_v_is_iterable, __pyx_v_v); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_asList, __pyx_t_3) < 0) __PYX_ERR(0, 1216, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_v_cls, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_ret, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_4);
      __pyx_t_4 = 0;
    }
    __pyx_L5:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1217
 *             else:
 *                 ret += cls([v], name=k, asList=is_iterable(v))
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             ret = cls([ret], name=name)
 *         return ret
 */
  __pyx_t_9 = (__pyx_v_name != Py_None);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":1218
 *                 ret += cls([v], name=k, asList=is_iterable(v))
 *         if name is not None:
 *             ret = cls([ret], name=name)             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_ret);
    __Pyx_GIVEREF(__pyx_v_ret);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_ret)) __PYX_ERR(0, 1218, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 1218, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_name_2, __pyx_v_name) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_v_cls, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1217
 *             else:
 *                 ret += cls([v], name=k, asList=is_iterable(v))
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             ret = cls([ret], name=name)
 *         return ret
 */
  }

  /* "cPyparsing.pyx":1219
 *         if name is not None:
 *             ret = cls([ret], name=name)
 *         return ret             # <<<<<<<<<<<<<<
 * 
 * MutableMapping.register(ParseResults)
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1193
 *         return dir(type(self)) + list(self.keys())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_dict(cls, other, name=None):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.ParseResults.from_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_is_iterable);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1223
 * MutableMapping.register(ParseResults)
 * 
 * def col (loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current column within a string, counting newlines as line separators.
 *    The first column is number 1.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13col(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12col, "col(loc, strg)\nReturns current column within a string, counting newlines as line separators.\n   The first column is number 1.\n\n   Note: the default parsing behavior is to expand tabs in the input string\n   before starting the parsing process.  See\n   :class:`ParserElement.parseString` for more\n   information on parsing strings containing ``<TAB>`` s, and suggested\n   methods to maintain a consistent view of the parsed string, the parse\n   location, and line and column positions within the parsed string.\n   ");
static PyMethodDef __pyx_mdef_10cPyparsing_13col = {"col", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13col, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12col};
static PyObject *__pyx_pw_10cPyparsing_13col(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_strg = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("col (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loc,&__pyx_n_s_strg,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1223, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_strg)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1223, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("col", 1, 2, 2, 1); __PYX_ERR(0, 1223, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "col") < 0)) __PYX_ERR(0, 1223, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_loc = values[0];
    __pyx_v_strg = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("col", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1223, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.col", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12col(__pyx_self, __pyx_v_loc, __pyx_v_strg);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12col(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_loc, PyObject *__pyx_v_strg) {
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("col", 1);

  /* "cPyparsing.pyx":1234
 *    location, and line and column positions within the parsed string.
 *    """
 *     s = strg             # <<<<<<<<<<<<<<
 *     return 1 if 0 < loc < len(s) and s[loc-1] == '\n' else loc - s.rfind("\n", 0, loc)
 * 
 */
  __Pyx_INCREF(__pyx_v_strg);
  __pyx_v_s = __pyx_v_strg;

  /* "cPyparsing.pyx":1235
 *    """
 *     s = strg
 *     return 1 if 0 < loc < len(s) and s[loc-1] == '\n' else loc - s.rfind("\n", 0, loc)             # <<<<<<<<<<<<<<
 * 
 * def lineno(loc, strg):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyObject_RichCompare(__pyx_int_0, __pyx_v_loc, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1235, __pyx_L1_error)
  if (__Pyx_PyObject_IsTrue(__pyx_t_3)) {
    __Pyx_DECREF(__pyx_t_3);
    __pyx_t_4 = PyObject_Length(__pyx_v_s); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1235, __pyx_L1_error)
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_5, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1235, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_2 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_loc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_s, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_kp_u__19, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = __pyx_t_6;
  __pyx_L3_bool_binop_done:;
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_int_1);
    __pyx_t_1 = __pyx_int_1;
  } else {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_rfind); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_kp_u__19, __pyx_int_0, __pyx_v_loc};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 3+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1235, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Subtract(__pyx_v_loc, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1223
 * MutableMapping.register(ParseResults)
 * 
 * def col (loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current column within a string, counting newlines as line separators.
 *    The first column is number 1.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.col", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1237
 *     return 1 if 0 < loc < len(s) and s[loc-1] == '\n' else loc - s.rfind("\n", 0, loc)
 * 
 * def lineno(loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current line number within a string, counting newlines as line separators.
 *     The first line is number 1.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15lineno(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_14lineno, "lineno(loc, strg)\nReturns current line number within a string, counting newlines as line separators.\n    The first line is number 1.\n\n    Note - the default parsing behavior is to expand tabs in the input string\n    before starting the parsing process.  See :class:`ParserElement.parseString`\n    for more information on parsing strings containing ``<TAB>`` s, and\n    suggested methods to maintain a consistent view of the parsed string, the\n    parse location, and line and column positions within the parsed string.\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_15lineno = {"lineno", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15lineno, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_14lineno};
static PyObject *__pyx_pw_10cPyparsing_15lineno(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_strg = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lineno (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loc,&__pyx_n_s_strg,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1237, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_strg)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1237, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lineno", 1, 2, 2, 1); __PYX_ERR(0, 1237, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lineno") < 0)) __PYX_ERR(0, 1237, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_loc = values[0];
    __pyx_v_strg = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lineno", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1237, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.lineno", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14lineno(__pyx_self, __pyx_v_loc, __pyx_v_strg);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14lineno(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_loc, PyObject *__pyx_v_strg) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lineno", 1);

  /* "cPyparsing.pyx":1247
 *     parse location, and line and column positions within the parsed string.
 *     """
 *     return strg.count("\n", 0, loc) + 1             # <<<<<<<<<<<<<<
 * 
 * def line(loc, strg):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_strg, __pyx_n_s_count); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_kp_u__19, __pyx_int_0, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1237
 *     return 1 if 0 < loc < len(s) and s[loc-1] == '\n' else loc - s.rfind("\n", 0, loc)
 * 
 * def lineno(loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current line number within a string, counting newlines as line separators.
 *     The first line is number 1.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.lineno", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1249
 *     return strg.count("\n", 0, loc) + 1
 * 
 * def line(loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *        """
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_17line(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_16line, "line(loc, strg)\nReturns the line of text containing loc within a string, counting newlines as line separators.\n       ");
static PyMethodDef __pyx_mdef_10cPyparsing_17line = {"line", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_17line, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_16line};
static PyObject *__pyx_pw_10cPyparsing_17line(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_strg = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("line (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loc,&__pyx_n_s_strg,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1249, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_strg)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1249, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("line", 1, 2, 2, 1); __PYX_ERR(0, 1249, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "line") < 0)) __PYX_ERR(0, 1249, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_loc = values[0];
    __pyx_v_strg = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("line", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1249, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16line(__pyx_self, __pyx_v_loc, __pyx_v_strg);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16line(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_loc, PyObject *__pyx_v_strg) {
  PyObject *__pyx_v_lastCR = NULL;
  PyObject *__pyx_v_nextCR = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("line", 1);

  /* "cPyparsing.pyx":1252
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *        """
 *     lastCR = strg.rfind("\n", 0, loc)             # <<<<<<<<<<<<<<
 *     nextCR = strg.find("\n", loc)
 *     if nextCR >= 0:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_strg, __pyx_n_s_rfind); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_kp_u__19, __pyx_int_0, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_lastCR = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1253
 *        """
 *     lastCR = strg.rfind("\n", 0, loc)
 *     nextCR = strg.find("\n", loc)             # <<<<<<<<<<<<<<
 *     if nextCR >= 0:
 *         return strg[lastCR + 1:nextCR]
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_strg, __pyx_n_s_find); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_kp_u__19, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_nextCR = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1254
 *     lastCR = strg.rfind("\n", 0, loc)
 *     nextCR = strg.find("\n", loc)
 *     if nextCR >= 0:             # <<<<<<<<<<<<<<
 *         return strg[lastCR + 1:nextCR]
 *     else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_nextCR, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1254, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":1255
 *     nextCR = strg.find("\n", loc)
 *     if nextCR >= 0:
 *         return strg[lastCR + 1:nextCR]             # <<<<<<<<<<<<<<
 *     else:
 *         return strg[lastCR + 1:]
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_lastCR, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_strg, 0, 0, &__pyx_t_1, &__pyx_v_nextCR, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1254
 *     lastCR = strg.rfind("\n", 0, loc)
 *     nextCR = strg.find("\n", loc)
 *     if nextCR >= 0:             # <<<<<<<<<<<<<<
 *         return strg[lastCR + 1:nextCR]
 *     else:
 */
  }

  /* "cPyparsing.pyx":1257
 *         return strg[lastCR + 1:nextCR]
 *     else:
 *         return strg[lastCR + 1:]             # <<<<<<<<<<<<<<
 * 
 * def _defaultStartDebugAction(instring, loc, expr):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_lastCR, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_strg, 0, 0, &__pyx_t_2, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":1249
 *     return strg.count("\n", 0, loc) + 1
 * 
 * def line(loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *        """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lastCR);
  __Pyx_XDECREF(__pyx_v_nextCR);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1259
 *         return strg[lastCR + 1:]
 * 
 * def _defaultStartDebugAction(instring, loc, expr):             # <<<<<<<<<<<<<<
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19_defaultStartDebugAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18_defaultStartDebugAction, "_defaultStartDebugAction(instring, loc, expr)");
static PyMethodDef __pyx_mdef_10cPyparsing_19_defaultStartDebugAction = {"_defaultStartDebugAction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_19_defaultStartDebugAction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18_defaultStartDebugAction};
static PyObject *__pyx_pw_10cPyparsing_19_defaultStartDebugAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_expr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_defaultStartDebugAction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_expr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1259, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1259, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultStartDebugAction", 1, 3, 3, 1); __PYX_ERR(0, 1259, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1259, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultStartDebugAction", 1, 3, 3, 2); __PYX_ERR(0, 1259, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_defaultStartDebugAction") < 0)) __PYX_ERR(0, 1259, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_instring = values[0];
    __pyx_v_loc = values[1];
    __pyx_v_expr = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_defaultStartDebugAction", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1259, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._defaultStartDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18_defaultStartDebugAction(__pyx_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_expr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18_defaultStartDebugAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  Py_UCS4 __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_defaultStartDebugAction", 1);

  /* "cPyparsing.pyx":1260
 * 
 * def _defaultStartDebugAction(instring, loc, expr):
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))             # <<<<<<<<<<<<<<
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Match, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_at_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_loc};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = 0;
  __pyx_t_7 = 127;
  __Pyx_INCREF(__pyx_kp_u__22);
  __pyx_t_6 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__22);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u__22);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_lineno); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_loc, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_IntOrLong(__pyx_t_1), __pyx_n_u_d); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_7;
  __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__34);
  __pyx_t_6 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__34);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__34);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_col); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_loc, __pyx_v_instring};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_IntOrLong(__pyx_t_5), __pyx_n_u_d); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_7;
  __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_t_6 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__13);
  PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_kp_u__13);
  __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_2, 5, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1259
 *         return strg[lastCR + 1:]
 * 
 * def _defaultStartDebugAction(instring, loc, expr):             # <<<<<<<<<<<<<<
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing._defaultStartDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1262
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):             # <<<<<<<<<<<<<<
 *     # [CPYPARSING] use custom list_str
 *     print("Matched " + _ustr(expr) + " -> " + list_str(toks.asList()))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_21_defaultSuccessDebugAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_20_defaultSuccessDebugAction, "_defaultSuccessDebugAction(instring, startloc, endloc, expr, toks)");
static PyMethodDef __pyx_mdef_10cPyparsing_21_defaultSuccessDebugAction = {"_defaultSuccessDebugAction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_21_defaultSuccessDebugAction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_20_defaultSuccessDebugAction};
static PyObject *__pyx_pw_10cPyparsing_21_defaultSuccessDebugAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_startloc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_endloc = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_toks = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_defaultSuccessDebugAction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_instring,&__pyx_n_s_startloc,&__pyx_n_s_endloc,&__pyx_n_s_expr,&__pyx_n_s_toks,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1262, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_startloc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1262, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, 1); __PYX_ERR(0, 1262, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_endloc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1262, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, 2); __PYX_ERR(0, 1262, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1262, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, 3); __PYX_ERR(0, 1262, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_toks)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1262, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, 4); __PYX_ERR(0, 1262, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_defaultSuccessDebugAction") < 0)) __PYX_ERR(0, 1262, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
    }
    __pyx_v_instring = values[0];
    __pyx_v_startloc = values[1];
    __pyx_v_endloc = values[2];
    __pyx_v_expr = values[3];
    __pyx_v_toks = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 1262, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._defaultSuccessDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_20_defaultSuccessDebugAction(__pyx_self, __pyx_v_instring, __pyx_v_startloc, __pyx_v_endloc, __pyx_v_expr, __pyx_v_toks);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_20_defaultSuccessDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_startloc, CYTHON_UNUSED PyObject *__pyx_v_endloc, PyObject *__pyx_v_expr, PyObject *__pyx_v_toks) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_defaultSuccessDebugAction", 1);

  /* "cPyparsing.pyx":1264
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):
 *     # [CPYPARSING] use custom list_str
 *     print("Matched " + _ustr(expr) + " -> " + list_str(toks.asList()))             # <<<<<<<<<<<<<<
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Matched, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__35); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_list_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_toks, __pyx_n_s_asList); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1262
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):             # <<<<<<<<<<<<<<
 *     # [CPYPARSING] use custom list_str
 *     print("Matched " + _ustr(expr) + " -> " + list_str(toks.asList()))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing._defaultSuccessDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1266
 *     print("Matched " + _ustr(expr) + " -> " + list_str(toks.asList()))
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):             # <<<<<<<<<<<<<<
 *     print("Exception raised:" + _ustr(exc))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23_defaultExceptionDebugAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_22_defaultExceptionDebugAction, "_defaultExceptionDebugAction(instring, loc, expr, exc)");
static PyMethodDef __pyx_mdef_10cPyparsing_23_defaultExceptionDebugAction = {"_defaultExceptionDebugAction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23_defaultExceptionDebugAction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_22_defaultExceptionDebugAction};
static PyObject *__pyx_pw_10cPyparsing_23_defaultExceptionDebugAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_exc = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_defaultExceptionDebugAction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_expr,&__pyx_n_s_exc,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1266, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1266, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultExceptionDebugAction", 1, 4, 4, 1); __PYX_ERR(0, 1266, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1266, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultExceptionDebugAction", 1, 4, 4, 2); __PYX_ERR(0, 1266, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1266, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultExceptionDebugAction", 1, 4, 4, 3); __PYX_ERR(0, 1266, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_defaultExceptionDebugAction") < 0)) __PYX_ERR(0, 1266, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_instring = values[0];
    __pyx_v_loc = values[1];
    __pyx_v_expr = values[2];
    __pyx_v_exc = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_defaultExceptionDebugAction", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 1266, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._defaultExceptionDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_22_defaultExceptionDebugAction(__pyx_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_expr, __pyx_v_exc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_22_defaultExceptionDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_expr, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_defaultExceptionDebugAction", 1);

  /* "cPyparsing.pyx":1267
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):
 *     print("Exception raised:" + _ustr(exc))             # <<<<<<<<<<<<<<
 * 
 * def nullDebugAction(*args):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_exc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1267, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Exception_raised, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1266
 *     print("Matched " + _ustr(expr) + " -> " + list_str(toks.asList()))
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):             # <<<<<<<<<<<<<<
 *     print("Exception raised:" + _ustr(exc))
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._defaultExceptionDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1269
 *     print("Exception raised:" + _ustr(exc))
 * 
 * def nullDebugAction(*args):             # <<<<<<<<<<<<<<
 *     """'Do-nothing' debug action, to suppress debugging output during parsing."""
 *     pass
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_25nullDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_24nullDebugAction, "nullDebugAction(*args)\n'Do-nothing' debug action, to suppress debugging output during parsing.");
static PyMethodDef __pyx_mdef_10cPyparsing_25nullDebugAction = {"nullDebugAction", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_10cPyparsing_25nullDebugAction, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_24nullDebugAction};
static PyObject *__pyx_pw_10cPyparsing_25nullDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nullDebugAction (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nullDebugAction", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_10cPyparsing_24nullDebugAction(__pyx_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_24nullDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nullDebugAction", 1);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1296
 * # this version is Python 2.x-3.x cross-compatible
 * 'decorator to trim function calls to match the arity of the target'
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_27_trim_arity(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_26_trim_arity, "_trim_arity(func, maxargs=2)");
static PyMethodDef __pyx_mdef_10cPyparsing_27_trim_arity = {"_trim_arity", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_27_trim_arity, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_26_trim_arity};
static PyObject *__pyx_pw_10cPyparsing_27_trim_arity(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_func = 0;
  PyObject *__pyx_v_maxargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_trim_arity (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_func,&__pyx_n_s_maxargs,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_2)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_func)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1296, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_maxargs);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1296, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_trim_arity") < 0)) __PYX_ERR(0, 1296, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_func = values[0];
    __pyx_v_maxargs = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_trim_arity", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1296, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._trim_arity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_26_trim_arity(__pyx_self, __pyx_v_func, __pyx_v_maxargs);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1306
 *         # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *         if system_version[:2] >= (3, 5):
 *             def extract_stack(limit=0):             # <<<<<<<<<<<<<<
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 *                 offset = -3 if system_version == (3, 5, 0) else -2
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_1extract_stack(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11_trim_arity_1extract_stack = {"extract_stack", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11_trim_arity_1extract_stack, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_1extract_stack(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_limit = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extract_stack (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_limit,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_limit);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1306, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "extract_stack") < 0)) __PYX_ERR(0, 1306, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_limit = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extract_stack", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1306, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._trim_arity.extract_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11_trim_arity_extract_stack(__pyx_self, __pyx_v_limit);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_extract_stack(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_limit) {
  long __pyx_v_offset;
  PyObject *__pyx_v_frame_summary = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extract_stack", 1);

  /* "cPyparsing.pyx":1308
 *             def extract_stack(limit=0):
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 *                 offset = -3 if system_version == (3, 5, 0) else -2             # <<<<<<<<<<<<<<
 *                 frame_summary = traceback.extract_stack(limit=-offset + limit - 1)[offset]
 *                 return [frame_summary[:2]]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_system_version); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_tuple__36, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {
    __pyx_t_1 = -3L;
  } else {
    __pyx_t_1 = -2L;
  }
  __pyx_v_offset = __pyx_t_1;

  /* "cPyparsing.pyx":1309
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 *                 offset = -3 if system_version == (3, 5, 0) else -2
 *                 frame_summary = traceback.extract_stack(limit=-offset + limit - 1)[offset]             # <<<<<<<<<<<<<<
 *                 return [frame_summary[:2]]
 *             def extract_tb(tb, limit=0):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_traceback_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_extract_stack); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyInt_From_long((-__pyx_v_offset)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_v_limit); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_t_6, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_limit, __pyx_t_5) < 0) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_5, __pyx_v_offset, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_frame_summary = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1310
 *                 offset = -3 if system_version == (3, 5, 0) else -2
 *                 frame_summary = traceback.extract_stack(limit=-offset + limit - 1)[offset]
 *                 return [frame_summary[:2]]             # <<<<<<<<<<<<<<
 *             def extract_tb(tb, limit=0):
 *                 frames = traceback.extract_tb(tb, limit=limit)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_frame_summary, 0, 2, NULL, NULL, &__pyx_slice__37, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 1310, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1306
 *         # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *         if system_version[:2] >= (3, 5):
 *             def extract_stack(limit=0):             # <<<<<<<<<<<<<<
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 *                 offset = -3 if system_version == (3, 5, 0) else -2
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing._trim_arity.extract_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_frame_summary);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1311
 *                 frame_summary = traceback.extract_stack(limit=-offset + limit - 1)[offset]
 *                 return [frame_summary[:2]]
 *             def extract_tb(tb, limit=0):             # <<<<<<<<<<<<<<
 *                 frames = traceback.extract_tb(tb, limit=limit)
 *                 frame_summary = frames[-1]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_3extract_tb(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11_trim_arity_3extract_tb = {"extract_tb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11_trim_arity_3extract_tb, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_3extract_tb(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_tb = 0;
  PyObject *__pyx_v_limit = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extract_tb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tb,&__pyx_n_s_limit,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tb)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1311, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_limit);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1311, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "extract_tb") < 0)) __PYX_ERR(0, 1311, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_tb = values[0];
    __pyx_v_limit = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extract_tb", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1311, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._trim_arity.extract_tb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11_trim_arity_2extract_tb(__pyx_self, __pyx_v_tb, __pyx_v_limit);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_2extract_tb(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tb, PyObject *__pyx_v_limit) {
  PyObject *__pyx_v_frames = NULL;
  PyObject *__pyx_v_frame_summary = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extract_tb", 1);

  /* "cPyparsing.pyx":1312
 *                 return [frame_summary[:2]]
 *             def extract_tb(tb, limit=0):
 *                 frames = traceback.extract_tb(tb, limit=limit)             # <<<<<<<<<<<<<<
 *                 frame_summary = frames[-1]
 *                 return [frame_summary[:2]]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_traceback_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_extract_tb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_tb);
  __Pyx_GIVEREF(__pyx_v_tb);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_tb)) __PYX_ERR(0, 1312, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_limit, __pyx_v_limit) < 0) __PYX_ERR(0, 1312, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_frames = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1313
 *             def extract_tb(tb, limit=0):
 *                 frames = traceback.extract_tb(tb, limit=limit)
 *                 frame_summary = frames[-1]             # <<<<<<<<<<<<<<
 *                 return [frame_summary[:2]]
 *         else:
 */
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_frames, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_frame_summary = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1314
 *                 frames = traceback.extract_tb(tb, limit=limit)
 *                 frame_summary = frames[-1]
 *                 return [frame_summary[:2]]             # <<<<<<<<<<<<<<
 *         else:
 *             extract_stack = traceback.extract_stack
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_frame_summary, 0, 2, NULL, NULL, &__pyx_slice__37, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 1314, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1311
 *                 frame_summary = traceback.extract_stack(limit=-offset + limit - 1)[offset]
 *                 return [frame_summary[:2]]
 *             def extract_tb(tb, limit=0):             # <<<<<<<<<<<<<<
 *                 frames = traceback.extract_tb(tb, limit=limit)
 *                 frame_summary = frames[-1]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._trim_arity.extract_tb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_frames);
  __Pyx_XDECREF(__pyx_v_frame_summary);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1325
 *     pa_call_line_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)
 * 
 *     def wrapper(*args):             # <<<<<<<<<<<<<<
 *         while 1:
 *             try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_5wrapper(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11_trim_arity_5wrapper = {"wrapper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_10cPyparsing_11_trim_arity_5wrapper, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_5wrapper(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wrapper (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "wrapper", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_10cPyparsing_11_trim_arity_4wrapper(__pyx_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_4wrapper(PyObject *__pyx_self, PyObject *__pyx_v_args) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *__pyx_outer_scope;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_tb = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  char const *__pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  int __pyx_t_26;
  PyObject *__pyx_t_27 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wrapper", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1326
 * 
 *     def wrapper(*args):
 *         while 1:             # <<<<<<<<<<<<<<
 *             try:
 *                 ret = func(*args[limit[0]:])
 */
  while (1) {

    /* "cPyparsing.pyx":1327
 *     def wrapper(*args):
 *         while 1:
 *             try:             # <<<<<<<<<<<<<<
 *                 ret = func(*args[limit[0]:])
 *                 foundArity[0] = True
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      /*try:*/ {

        /* "cPyparsing.pyx":1328
 *         while 1:
 *             try:
 *                 ret = func(*args[limit[0]:])             # <<<<<<<<<<<<<<
 *                 foundArity[0] = True
 *                 return ret
 */
        if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 1328, __pyx_L5_error) }
        if (unlikely(!__pyx_cur_scope->__pyx_v_limit)) { __Pyx_RaiseClosureNameError("limit"); __PYX_ERR(0, 1328, __pyx_L5_error) }
        if (unlikely(__pyx_cur_scope->__pyx_v_limit == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1328, __pyx_L5_error)
        }
        __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_cur_scope->__pyx_v_limit, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1328, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = (__pyx_t_4 == Py_None);
        if (__pyx_t_6) {
          __pyx_t_5 = 0;
        } else {
          __pyx_t_7 = __Pyx_PyIndex_AsSsize_t(__pyx_t_4); if (unlikely((__pyx_t_7 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1328, __pyx_L5_error)
          __pyx_t_5 = __pyx_t_7;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyTuple_GetSlice(__pyx_v_args, __pyx_t_5, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1328, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_func, __pyx_t_4, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1328, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ret, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "cPyparsing.pyx":1329
 *             try:
 *                 ret = func(*args[limit[0]:])
 *                 foundArity[0] = True             # <<<<<<<<<<<<<<
 *                 return ret
 *             except TypeError:
 */
        if (unlikely(!__pyx_cur_scope->__pyx_v_foundArity)) { __Pyx_RaiseClosureNameError("foundArity"); __PYX_ERR(0, 1329, __pyx_L5_error) }
        if (unlikely(__pyx_cur_scope->__pyx_v_foundArity == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1329, __pyx_L5_error)
        }
        if (unlikely((__Pyx_SetItemInt(__pyx_cur_scope->__pyx_v_foundArity, 0, Py_True, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(0, 1329, __pyx_L5_error)

        /* "cPyparsing.pyx":1330
 *                 ret = func(*args[limit[0]:])
 *                 foundArity[0] = True
 *                 return ret             # <<<<<<<<<<<<<<
 *             except TypeError:
 *                 # re-raise TypeErrors if they did not come from our arity testing
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_ret);
        __pyx_r = __pyx_v_ret;
        goto __pyx_L9_try_return;

        /* "cPyparsing.pyx":1327
 *     def wrapper(*args):
 *         while 1:
 *             try:             # <<<<<<<<<<<<<<
 *                 ret = func(*args[limit[0]:])
 *                 foundArity[0] = True
 */
      }
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":1331
 *                 foundArity[0] = True
 *                 return ret
 *             except TypeError:             # <<<<<<<<<<<<<<
 *                 # re-raise TypeErrors if they did not come from our arity testing
 *                 if foundArity[0]:
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
      if (__pyx_t_9) {
        __Pyx_AddTraceback("cPyparsing._trim_arity.wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_4, &__pyx_t_10) < 0) __PYX_ERR(0, 1331, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_10);

        /* "cPyparsing.pyx":1333
 *             except TypeError:
 *                 # re-raise TypeErrors if they did not come from our arity testing
 *                 if foundArity[0]:             # <<<<<<<<<<<<<<
 *                     raise
 *                 else:
 */
        if (unlikely(!__pyx_cur_scope->__pyx_v_foundArity)) { __Pyx_RaiseClosureNameError("foundArity"); __PYX_ERR(0, 1333, __pyx_L7_except_error) }
        if (unlikely(__pyx_cur_scope->__pyx_v_foundArity == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1333, __pyx_L7_except_error)
        }
        __pyx_t_11 = __Pyx_GetItemInt_List(__pyx_cur_scope->__pyx_v_foundArity, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1333, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1333, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(__pyx_t_6)) {

          /* "cPyparsing.pyx":1334
 *                 # re-raise TypeErrors if they did not come from our arity testing
 *                 if foundArity[0]:
 *                     raise             # <<<<<<<<<<<<<<
 *                 else:
 *                     # [CPYPARSING] use _trim_arity.inspect_tracebacks
 */
          __Pyx_GIVEREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestoreWithState(__pyx_t_8, __pyx_t_4, __pyx_t_10);
          __pyx_t_8 = 0; __pyx_t_4 = 0; __pyx_t_10 = 0; 
          __PYX_ERR(0, 1334, __pyx_L7_except_error)

          /* "cPyparsing.pyx":1333
 *             except TypeError:
 *                 # re-raise TypeErrors if they did not come from our arity testing
 *                 if foundArity[0]:             # <<<<<<<<<<<<<<
 *                     raise
 *                 else:
 */
        }

        /* "cPyparsing.pyx":1337
 *                 else:
 *                     # [CPYPARSING] use _trim_arity.inspect_tracebacks
 *                     if _trim_arity.inspect_tracebacks:             # <<<<<<<<<<<<<<
 *                         try:
 *                             tb = sys.exc_info()[-1]
 */
        /*else*/ {
          __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_trim_arity); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1337, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_inspect_tracebacks); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1337, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1337, __pyx_L7_except_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_6) {

            /* "cPyparsing.pyx":1338
 *                     # [CPYPARSING] use _trim_arity.inspect_tracebacks
 *                     if _trim_arity.inspect_tracebacks:
 *                         try:             # <<<<<<<<<<<<<<
 *                             tb = sys.exc_info()[-1]
 *                             if not extract_tb(tb, limit=2)[-1][:2] == pa_call_line_synth:
 */
            /*try:*/ {

              /* "cPyparsing.pyx":1339
 *                     if _trim_arity.inspect_tracebacks:
 *                         try:
 *                             tb = sys.exc_info()[-1]             # <<<<<<<<<<<<<<
 *                             if not extract_tb(tb, limit=2)[-1][:2] == pa_call_line_synth:
 *                                 raise
 */
              __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_sys); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1339, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_11);
              __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_exc_info); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1339, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              __pyx_t_11 = NULL;
              __pyx_t_9 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_13))) {
                __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
                if (likely(__pyx_t_11)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                  __Pyx_INCREF(__pyx_t_11);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_13, function);
                  __pyx_t_9 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
                __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
                __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1339, __pyx_L20_error)
                __Pyx_GOTREF(__pyx_t_12);
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              }
              __pyx_t_13 = __Pyx_GetItemInt(__pyx_t_12, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1339, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF_SET(__pyx_v_tb, __pyx_t_13);
              __pyx_t_13 = 0;

              /* "cPyparsing.pyx":1340
 *                         try:
 *                             tb = sys.exc_info()[-1]
 *                             if not extract_tb(tb, limit=2)[-1][:2] == pa_call_line_synth:             # <<<<<<<<<<<<<<
 *                                 raise
 *                         finally:
 */
              if (unlikely(!__pyx_cur_scope->__pyx_v_extract_tb)) { __Pyx_RaiseClosureNameError("extract_tb"); __PYX_ERR(0, 1340, __pyx_L20_error) }
              __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1340, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_INCREF(__pyx_v_tb);
              __Pyx_GIVEREF(__pyx_v_tb);
              if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_v_tb)) __PYX_ERR(0, 1340, __pyx_L20_error);
              __pyx_t_12 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1340, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_12);
              if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_limit, __pyx_int_2) < 0) __PYX_ERR(0, 1340, __pyx_L20_error)
              __pyx_t_11 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_extract_tb, __pyx_t_13, __pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1340, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __pyx_t_12 = __Pyx_GetItemInt(__pyx_t_11, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1340, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              __pyx_t_11 = __Pyx_PyObject_GetSlice(__pyx_t_12, 0, 2, NULL, NULL, &__pyx_slice__37, 0, 1, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1340, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (unlikely(!__pyx_cur_scope->__pyx_v_pa_call_line_synth)) { __Pyx_RaiseClosureNameError("pa_call_line_synth"); __PYX_ERR(0, 1340, __pyx_L20_error) }
              __pyx_t_12 = PyObject_RichCompare(__pyx_t_11, __pyx_cur_scope->__pyx_v_pa_call_line_synth, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1340, __pyx_L20_error)
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1340, __pyx_L20_error)
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __pyx_t_14 = (!__pyx_t_6);
              if (unlikely(__pyx_t_14)) {

                /* "cPyparsing.pyx":1341
 *                             tb = sys.exc_info()[-1]
 *                             if not extract_tb(tb, limit=2)[-1][:2] == pa_call_line_synth:
 *                                 raise             # <<<<<<<<<<<<<<
 *                         finally:
 *                             try:
 */
                __Pyx_GIVEREF(__pyx_t_8);
                __Pyx_GIVEREF(__pyx_t_4);
                __Pyx_XGIVEREF(__pyx_t_10);
                __Pyx_ErrRestoreWithState(__pyx_t_8, __pyx_t_4, __pyx_t_10);
                __pyx_t_8 = 0; __pyx_t_4 = 0; __pyx_t_10 = 0; 
                __PYX_ERR(0, 1341, __pyx_L20_error)

                /* "cPyparsing.pyx":1340
 *                         try:
 *                             tb = sys.exc_info()[-1]
 *                             if not extract_tb(tb, limit=2)[-1][:2] == pa_call_line_synth:             # <<<<<<<<<<<<<<
 *                                 raise
 *                         finally:
 */
              }
            }

            /* "cPyparsing.pyx":1343
 *                                 raise
 *                         finally:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 del tb
 *                             except NameError:
 */
            /*finally:*/ {
              /*normal exit:*/{
                {
                  (void)__pyx_t_15; (void)__pyx_t_16; (void)__pyx_t_17; /* mark used */
                  /*try:*/ {

                    /* "cPyparsing.pyx":1344
 *                         finally:
 *                             try:
 *                                 del tb             # <<<<<<<<<<<<<<
 *                             except NameError:
 *                                 pass
 */
                    __Pyx_DECREF(__pyx_v_tb); __pyx_v_tb = 0;

                    /* "cPyparsing.pyx":1343
 *                                 raise
 *                         finally:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 del tb
 *                             except NameError:
 */
                  }
                }
                goto __pyx_L21;
              }
              __pyx_L20_error:;
              /*exception exit:*/{
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
                __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
                if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
                __Pyx_XGOTREF(__pyx_t_17);
                __Pyx_XGOTREF(__pyx_t_16);
                __Pyx_XGOTREF(__pyx_t_15);
                __Pyx_XGOTREF(__pyx_t_20);
                __Pyx_XGOTREF(__pyx_t_21);
                __Pyx_XGOTREF(__pyx_t_22);
                __pyx_t_9 = __pyx_lineno; __pyx_t_18 = __pyx_clineno; __pyx_t_19 = __pyx_filename;
                {
                  {
                    __Pyx_PyThreadState_declare
                    __Pyx_PyThreadState_assign
                    __Pyx_ExceptionSave(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
                    __Pyx_XGOTREF(__pyx_t_23);
                    __Pyx_XGOTREF(__pyx_t_24);
                    __Pyx_XGOTREF(__pyx_t_25);
                    /*try:*/ {

                      /* "cPyparsing.pyx":1344
 *                         finally:
 *                             try:
 *                                 del tb             # <<<<<<<<<<<<<<
 *                             except NameError:
 *                                 pass
 */
                      if (unlikely(!__pyx_v_tb)) { __Pyx_RaiseUnboundLocalError("tb"); __PYX_ERR(0, 1344, __pyx_L35_error) }
                      __Pyx_DECREF(__pyx_v_tb); __pyx_v_tb = 0;

                      /* "cPyparsing.pyx":1343
 *                                 raise
 *                         finally:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 del tb
 *                             except NameError:
 */
                    }
                    __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                    __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                    __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                    goto __pyx_L42_try_end;
                    __pyx_L35_error:;
                    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;

                    /* "cPyparsing.pyx":1345
 *                             try:
 *                                 del tb
 *                             except NameError:             # <<<<<<<<<<<<<<
 *                                 pass
 * 
 */
                    __pyx_t_26 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_NameError);
                    if (__pyx_t_26) {
                      __Pyx_ErrRestore(0,0,0);
                      goto __pyx_L36_exception_handled;
                    }
                    goto __pyx_L37_except_error;

                    /* "cPyparsing.pyx":1343
 *                                 raise
 *                         finally:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 del tb
 *                             except NameError:
 */
                    __pyx_L37_except_error:;
                    __Pyx_XGIVEREF(__pyx_t_23);
                    __Pyx_XGIVEREF(__pyx_t_24);
                    __Pyx_XGIVEREF(__pyx_t_25);
                    __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
                    goto __pyx_L34_error;
                    __pyx_L36_exception_handled:;
                    __Pyx_XGIVEREF(__pyx_t_23);
                    __Pyx_XGIVEREF(__pyx_t_24);
                    __Pyx_XGIVEREF(__pyx_t_25);
                    __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
                    __pyx_L42_try_end:;
                  }
                }
                if (PY_MAJOR_VERSION >= 3) {
                  __Pyx_XGIVEREF(__pyx_t_20);
                  __Pyx_XGIVEREF(__pyx_t_21);
                  __Pyx_XGIVEREF(__pyx_t_22);
                  __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
                }
                __Pyx_XGIVEREF(__pyx_t_17);
                __Pyx_XGIVEREF(__pyx_t_16);
                __Pyx_XGIVEREF(__pyx_t_15);
                __Pyx_ErrRestore(__pyx_t_17, __pyx_t_16, __pyx_t_15);
                __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
                __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_18; __pyx_filename = __pyx_t_19;
                goto __pyx_L7_except_error;
                __pyx_L34_error:;
                if (PY_MAJOR_VERSION >= 3) {
                  __Pyx_XGIVEREF(__pyx_t_20);
                  __Pyx_XGIVEREF(__pyx_t_21);
                  __Pyx_XGIVEREF(__pyx_t_22);
                  __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
                }
                __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
                goto __pyx_L7_except_error;
              }
              __pyx_L21:;
            }

            /* "cPyparsing.pyx":1337
 *                 else:
 *                     # [CPYPARSING] use _trim_arity.inspect_tracebacks
 *                     if _trim_arity.inspect_tracebacks:             # <<<<<<<<<<<<<<
 *                         try:
 *                             tb = sys.exc_info()[-1]
 */
          }
        }

        /* "cPyparsing.pyx":1348
 *                                 pass
 * 
 *                 if limit[0] <= maxargs:             # <<<<<<<<<<<<<<
 *                     limit[0] += 1
 *                     continue
 */
        if (unlikely(!__pyx_cur_scope->__pyx_v_limit)) { __Pyx_RaiseClosureNameError("limit"); __PYX_ERR(0, 1348, __pyx_L7_except_error) }
        if (unlikely(__pyx_cur_scope->__pyx_v_limit == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 1348, __pyx_L7_except_error)
        }
        __pyx_t_12 = __Pyx_GetItemInt_List(__pyx_cur_scope->__pyx_v_limit, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1348, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (unlikely(!__pyx_cur_scope->__pyx_v_maxargs)) { __Pyx_RaiseClosureNameError("maxargs"); __PYX_ERR(0, 1348, __pyx_L7_except_error) }
        __pyx_t_11 = PyObject_RichCompare(__pyx_t_12, __pyx_cur_scope->__pyx_v_maxargs, Py_LE); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1348, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 1348, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (__pyx_t_14) {

          /* "cPyparsing.pyx":1349
 * 
 *                 if limit[0] <= maxargs:
 *                     limit[0] += 1             # <<<<<<<<<<<<<<
 *                     continue
 *                 raise
 */
          if (unlikely(!__pyx_cur_scope->__pyx_v_limit)) { __Pyx_RaiseClosureNameError("limit"); __PYX_ERR(0, 1349, __pyx_L7_except_error) }
          if (unlikely(__pyx_cur_scope->__pyx_v_limit == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 1349, __pyx_L7_except_error)
          }
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_limit);
          __pyx_t_27 = __pyx_cur_scope->__pyx_v_limit;
          __pyx_t_5 = 0;
          if (unlikely(__pyx_t_27 == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 1349, __pyx_L7_except_error)
          }
          __pyx_t_11 = __Pyx_GetItemInt_List(__pyx_t_27, __pyx_t_5, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1349, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = __Pyx_PyInt_AddObjC(__pyx_t_11, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1349, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(__pyx_t_27 == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 1349, __pyx_L7_except_error)
          }
          if (unlikely((__Pyx_SetItemInt(__pyx_t_27, __pyx_t_5, __pyx_t_12, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1) < 0))) __PYX_ERR(0, 1349, __pyx_L7_except_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;

          /* "cPyparsing.pyx":1350
 *                 if limit[0] <= maxargs:
 *                     limit[0] += 1
 *                     continue             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
          goto __pyx_L13_except_continue;

          /* "cPyparsing.pyx":1348
 *                                 pass
 * 
 *                 if limit[0] <= maxargs:             # <<<<<<<<<<<<<<
 *                     limit[0] += 1
 *                     continue
 */
        }

        /* "cPyparsing.pyx":1351
 *                     limit[0] += 1
 *                     continue
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *     # copy func name to wrapper for sensible debug output
 */
        __Pyx_GIVEREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ErrRestoreWithState(__pyx_t_8, __pyx_t_4, __pyx_t_10);
        __pyx_t_8 = 0; __pyx_t_4 = 0; __pyx_t_10 = 0; 
        __PYX_ERR(0, 1351, __pyx_L7_except_error)
        __pyx_L13_except_continue:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L11_try_continue;
      }
      goto __pyx_L7_except_error;

      /* "cPyparsing.pyx":1327
 *     def wrapper(*args):
 *         while 1:
 *             try:             # <<<<<<<<<<<<<<
 *                 ret = func(*args[limit[0]:])
 *                 foundArity[0] = True
 */
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L1_error;
      __pyx_L11_try_continue:;
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L3_continue;
      __pyx_L9_try_return:;
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L0;
    }
    __pyx_L3_continue:;
  }

  /* "cPyparsing.pyx":1325
 *     pa_call_line_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)
 * 
 *     def wrapper(*args):             # <<<<<<<<<<<<<<
 *         while 1:
 *             try:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_AddTraceback("cPyparsing._trim_arity.wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_tb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1298
 * def _trim_arity(func, maxargs=2):
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)             # <<<<<<<<<<<<<<
 *     limit = [0]
 *     foundArity = [False]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_6lambda12(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11_trim_arity_6lambda12 = {"lambda12", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11_trim_arity_6lambda12, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_6lambda12(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda12 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1298, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1298, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda12", 1, 3, 3, 1); __PYX_ERR(0, 1298, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1298, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda12", 1, 3, 3, 2); __PYX_ERR(0, 1298, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda12") < 0)) __PYX_ERR(0, 1298, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda12", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1298, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._trim_arity.lambda12", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda12(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda12(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda12", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 1298, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_func; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_t};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._trim_arity.lambda12", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1296
 * # this version is Python 2.x-3.x cross-compatible
 * 'decorator to trim function calls to match the arity of the target'
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)
 */

static PyObject *__pyx_pf_10cPyparsing_26_trim_arity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_maxargs) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *__pyx_cur_scope;
  CYTHON_UNUSED PyObject *__pyx_v_extract_stack = 0;
  PyObject *__pyx_v_wrapper = 0;
  PyObject *__pyx_v_func_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_trim_arity", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_16__trim_arity(__pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1296, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_func = __pyx_v_func;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);
  __pyx_cur_scope->__pyx_v_maxargs = __pyx_v_maxargs;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_maxargs);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_maxargs);

  /* "cPyparsing.pyx":1297
 * 'decorator to trim function calls to match the arity of the target'
 * def _trim_arity(func, maxargs=2):
 *     if func in singleArgBuiltins:             # <<<<<<<<<<<<<<
 *         return lambda s, l, t: func(t)
 *     limit = [0]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_singleArgBuiltins); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_func, __pyx_t_1, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1297, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1298
 * def _trim_arity(func, maxargs=2):
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)             # <<<<<<<<<<<<<<
 *     limit = [0]
 *     foundArity = [False]
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11_trim_arity_6lambda12, 0, __pyx_n_s_trim_arity_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1297
 * 'decorator to trim function calls to match the arity of the target'
 * def _trim_arity(func, maxargs=2):
 *     if func in singleArgBuiltins:             # <<<<<<<<<<<<<<
 *         return lambda s, l, t: func(t)
 *     limit = [0]
 */
  }

  /* "cPyparsing.pyx":1299
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)
 *     limit = [0]             # <<<<<<<<<<<<<<
 *     foundArity = [False]
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_int_0)) __PYX_ERR(0, 1299, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_limit = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1300
 *         return lambda s, l, t: func(t)
 *     limit = [0]
 *     foundArity = [False]             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] use _trim_arity.inspect_tracebacks
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, Py_False)) __PYX_ERR(0, 1300, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_foundArity = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1303
 * 
 *     # [CPYPARSING] use _trim_arity.inspect_tracebacks
 *     if _trim_arity.inspect_tracebacks:             # <<<<<<<<<<<<<<
 *         # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *         if system_version[:2] >= (3, 5):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_trim_arity); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_inspect_tracebacks); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1305
 *     if _trim_arity.inspect_tracebacks:
 *         # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *         if system_version[:2] >= (3, 5):             # <<<<<<<<<<<<<<
 *             def extract_stack(limit=0):
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_system_version); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_3, 0, 2, NULL, NULL, &__pyx_slice__37, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_tuple__38, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1305, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1305, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1306
 *         # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *         if system_version[:2] >= (3, 5):
 *             def extract_stack(limit=0):             # <<<<<<<<<<<<<<
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 *                 offset = -3 if system_version == (3, 5, 0) else -2
 */
      __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11_trim_arity_1extract_stack, 0, __pyx_n_s_trim_arity_locals_extract_stack, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__40)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1306, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__41);
      __pyx_v_extract_stack = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":1311
 *                 frame_summary = traceback.extract_stack(limit=-offset + limit - 1)[offset]
 *                 return [frame_summary[:2]]
 *             def extract_tb(tb, limit=0):             # <<<<<<<<<<<<<<
 *                 frames = traceback.extract_tb(tb, limit=limit)
 *                 frame_summary = frames[-1]
 */
      __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11_trim_arity_3extract_tb, 0, __pyx_n_s_trim_arity_locals_extract_tb, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__43)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__41);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_v_extract_tb = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":1305
 *     if _trim_arity.inspect_tracebacks:
 *         # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *         if system_version[:2] >= (3, 5):             # <<<<<<<<<<<<<<
 *             def extract_stack(limit=0):
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":1316
 *                 return [frame_summary[:2]]
 *         else:
 *             extract_stack = traceback.extract_stack             # <<<<<<<<<<<<<<
 *             extract_tb = traceback.extract_tb
 * 
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_traceback_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_extract_stack); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_extract_stack = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":1317
 *         else:
 *             extract_stack = traceback.extract_stack
 *             extract_tb = traceback.extract_tb             # <<<<<<<<<<<<<<
 * 
 *     # synthesize what would be returned by traceback.extract_stack at the call to
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_traceback_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1317, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_extract_tb); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1317, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_v_extract_tb = __pyx_t_3;
      __pyx_t_3 = 0;
    }
    __pyx_L5:;

    /* "cPyparsing.pyx":1303
 * 
 *     # [CPYPARSING] use _trim_arity.inspect_tracebacks
 *     if _trim_arity.inspect_tracebacks:             # <<<<<<<<<<<<<<
 *         # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *         if system_version[:2] >= (3, 5):
 */
  }

  /* "cPyparsing.pyx":1323
 * 
 *     # [CPYPARSING] use preprocessed constants
 *     pa_call_line_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)             # <<<<<<<<<<<<<<
 * 
 *     def wrapper(*args):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_FILE_NAME); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_WRAP_CALL_LINE_NUM); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(0, 1323, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(0, 1323, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_pa_call_line_synth = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1325
 *     pa_call_line_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)
 * 
 *     def wrapper(*args):             # <<<<<<<<<<<<<<
 *         while 1:
 *             try:
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11_trim_arity_5wrapper, 0, __pyx_n_s_trim_arity_locals_wrapper, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__45)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_wrapper = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1354
 * 
 *     # copy func name to wrapper for sensible debug output
 *     func_name = "<parse action>"             # <<<<<<<<<<<<<<
 *     try:
 *         func_name = getattr(func, '__name__',
 */
  __Pyx_INCREF(__pyx_kp_u_parse_action);
  __pyx_v_func_name = __pyx_kp_u_parse_action;

  /* "cPyparsing.pyx":1355
 *     # copy func name to wrapper for sensible debug output
 *     func_name = "<parse action>"
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    /*try:*/ {

      /* "cPyparsing.pyx":1356
 *     func_name = "<parse action>"
 *     try:
 *         func_name = getattr(func, '__name__',             # <<<<<<<<<<<<<<
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 */
      __pyx_t_4 = __pyx_cur_scope->__pyx_v_func;
      __Pyx_INCREF(__pyx_t_4);

      /* "cPyparsing.pyx":1357
 *     try:
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         func_name = str(func)
 */
      __pyx_t_1 = __pyx_cur_scope->__pyx_v_func;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_GetAttr(__pyx_t_1, __pyx_n_u_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1357, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1357, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":1356
 *     func_name = "<parse action>"
 *     try:
 *         func_name = getattr(func, '__name__',             # <<<<<<<<<<<<<<
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 */
      __pyx_t_3 = __Pyx_GetAttr3(__pyx_t_4, __pyx_n_u_name, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1356, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_func_name, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":1355
 *     # copy func name to wrapper for sensible debug output
 *     func_name = "<parse action>"
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1358
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 *     except Exception:             # <<<<<<<<<<<<<<
 *         func_name = str(func)
 * 
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing._trim_arity", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_4) < 0) __PYX_ERR(0, 1358, __pyx_L8_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "cPyparsing.pyx":1359
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 *         func_name = str(func)             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] apply py_str
 */
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_str); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1359, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_cur_scope->__pyx_v_func};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1359, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_func_name, __pyx_t_9);
      __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L7_exception_handled;
    }
    goto __pyx_L8_except_error;

    /* "cPyparsing.pyx":1355
 *     # copy func name to wrapper for sensible debug output
 *     func_name = "<parse action>"
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
    __pyx_L8_except_error:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    goto __pyx_L1_error;
    __pyx_L7_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    __pyx_L11_try_end:;
  }

  /* "cPyparsing.pyx":1362
 * 
 *     # [CPYPARSING] apply py_str
 *     wrapper.__name__ = py_str(func_name)             # <<<<<<<<<<<<<<
 * 
 *     return wrapper
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_py_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_func_name};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_wrapper, __pyx_n_s_name, __pyx_t_4) < 0) __PYX_ERR(0, 1362, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1364
 *     wrapper.__name__ = py_str(func_name)
 * 
 *     return wrapper             # <<<<<<<<<<<<<<
 * 
 * # [CPYPARSING] add _trim_arity.inspect_tracebacks
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrapper);
  __pyx_r = __pyx_v_wrapper;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1296
 * # this version is Python 2.x-3.x cross-compatible
 * 'decorator to trim function calls to match the arity of the target'
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing._trim_arity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_extract_stack);
  __Pyx_XDECREF(__pyx_v_wrapper);
  __Pyx_XDECREF(__pyx_v_func_name);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1378
 * # [CPYPARSING] caches are normal global classes
 * class _UnboundedCache(object):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.not_in_cache = object()
 *         # [CPYPARSING] add self.cache
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15_UnboundedCache___init__, "_UnboundedCache.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15_UnboundedCache_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15_UnboundedCache___init__};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1378, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1378, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1378, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":1379
 * class _UnboundedCache(object):
 *     def __init__(self):
 *         self.not_in_cache = object()             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] add self.cache
 *         self.cache = {}
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_not_in_cache, __pyx_t_1) < 0) __PYX_ERR(0, 1379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1381
 *         self.not_in_cache = object()
 *         # [CPYPARSING] add self.cache
 *         self.cache = {}             # <<<<<<<<<<<<<<
 * 
 *     def get(self, key):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_cache, __pyx_t_1) < 0) __PYX_ERR(0, 1381, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1378
 * # [CPYPARSING] caches are normal global classes
 * class _UnboundedCache(object):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.not_in_cache = object()
 *         # [CPYPARSING] add self.cache
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1383
 *         self.cache = {}
 * 
 *     def get(self, key):             # <<<<<<<<<<<<<<
 *         return self.cache.get(key, self.not_in_cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_3get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15_UnboundedCache_2get, "_UnboundedCache.get(self, key)");
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_3get = {"get", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15_UnboundedCache_3get, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15_UnboundedCache_2get};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_3get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1383, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1383, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, 1); __PYX_ERR(0, 1383, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get") < 0)) __PYX_ERR(0, 1383, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1383, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_2get(__pyx_self, __pyx_v_self, __pyx_v_key);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_2get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get", 1);

  /* "cPyparsing.pyx":1384
 * 
 *     def get(self, key):
 *         return self.cache.get(key, self.not_in_cache)             # <<<<<<<<<<<<<<
 * 
 *     def set(self, key, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_not_in_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_key, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1383
 *         self.cache = {}
 * 
 *     def get(self, key):             # <<<<<<<<<<<<<<
 *         return self.cache.get(key, self.not_in_cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1386
 *         return self.cache.get(key, self.not_in_cache)
 * 
 *     def set(self, key, value):             # <<<<<<<<<<<<<<
 *         self.cache[key] = value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_5set(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15_UnboundedCache_4set, "_UnboundedCache.set(self, key, value)");
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_5set = {"set", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15_UnboundedCache_5set, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15_UnboundedCache_4set};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_5set(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1386, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1386, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 1); __PYX_ERR(0, 1386, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1386, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 2); __PYX_ERR(0, 1386, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set") < 0)) __PYX_ERR(0, 1386, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
    __pyx_v_value = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1386, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_4set(__pyx_self, __pyx_v_self, __pyx_v_key, __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_4set(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set", 1);

  /* "cPyparsing.pyx":1387
 * 
 *     def set(self, key, value):
 *         self.cache[key] = value             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] add update
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_key, __pyx_v_value) < 0))) __PYX_ERR(0, 1387, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1386
 *         return self.cache.get(key, self.not_in_cache)
 * 
 *     def set(self, key, value):             # <<<<<<<<<<<<<<
 *         self.cache[key] = value
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1390
 * 
 *     # [CPYPARSING] add update
 *     def update(self, update_dict):             # <<<<<<<<<<<<<<
 *         self.cache.update(update_dict)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_7update(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15_UnboundedCache_6update, "_UnboundedCache.update(self, update_dict)");
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_7update = {"update", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15_UnboundedCache_7update, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15_UnboundedCache_6update};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_7update(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_update_dict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("update (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_update_dict,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1390, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_update_dict)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1390, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("update", 1, 2, 2, 1); __PYX_ERR(0, 1390, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "update") < 0)) __PYX_ERR(0, 1390, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_update_dict = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("update", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1390, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_6update(__pyx_self, __pyx_v_self, __pyx_v_update_dict);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_6update(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_update_dict) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update", 1);

  /* "cPyparsing.pyx":1391
 *     # [CPYPARSING] add update
 *     def update(self, update_dict):
 *         self.cache.update(update_dict)             # <<<<<<<<<<<<<<
 * 
 *     def clear(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_update); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_update_dict};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1390
 * 
 *     # [CPYPARSING] add update
 *     def update(self, update_dict):             # <<<<<<<<<<<<<<
 *         self.cache.update(update_dict)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1393
 *         self.cache.update(update_dict)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         self.cache.clear()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_9clear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15_UnboundedCache_8clear, "_UnboundedCache.clear(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_9clear = {"clear", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15_UnboundedCache_9clear, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15_UnboundedCache_8clear};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_9clear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1393, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "clear") < 0)) __PYX_ERR(0, 1393, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("clear", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1393, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_8clear(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clear", 1);

  /* "cPyparsing.pyx":1394
 * 
 *     def clear(self):
 *         self.cache.clear()             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_clear); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1393
 *         self.cache.update(update_dict)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         self.cache.clear()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1396
 *         self.cache.clear()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return len(self.cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_11__len__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15_UnboundedCache_10__len__, "_UnboundedCache.__len__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_11__len__ = {"__len__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15_UnboundedCache_11__len__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15_UnboundedCache_10__len__};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_11__len__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1396, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__len__") < 0)) __PYX_ERR(0, 1396, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__len__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1396, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_10__len__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_10__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__len__", 1);

  /* "cPyparsing.pyx":1397
 * 
 *     def __len__(self):
 *         return len(self.cache)             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] add __reduce__
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1396
 *         self.cache.clear()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return len(self.cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1400
 * 
 *     # [CPYPARSING] add __reduce__
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         return (self.__class__, (), {"cache": self.cache})
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_13__reduce__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15_UnboundedCache_12__reduce__, "_UnboundedCache.__reduce__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_13__reduce__ = {"__reduce__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15_UnboundedCache_13__reduce__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15_UnboundedCache_12__reduce__};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_13__reduce__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1400, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__reduce__") < 0)) __PYX_ERR(0, 1400, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__reduce__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1400, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_12__reduce__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_12__reduce__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce__", 1);

  /* "cPyparsing.pyx":1401
 *     # [CPYPARSING] add __reduce__
 *     def __reduce__(self):
 *         return (self.__class__, (), {"cache": self.cache})             # <<<<<<<<<<<<<<
 * 
 * if _OrderedDict is not None:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_cache, __pyx_t_3) < 0) __PYX_ERR(0, 1401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 1401, __pyx_L1_error);
  __Pyx_INCREF(__pyx_empty_tuple);
  __Pyx_GIVEREF(__pyx_empty_tuple);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_empty_tuple)) __PYX_ERR(0, 1401, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(0, 1401, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1400
 * 
 *     # [CPYPARSING] add __reduce__
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         return (self.__class__, (), {"cache": self.cache})
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1405
 * if _OrderedDict is not None:
 *     class _FifoCache(object):
 *         def __init__(self, size):             # <<<<<<<<<<<<<<
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache___init__, "_FifoCache.__init__(self, size)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache___init__};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_size = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1405, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1405, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 1405, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1405, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_size = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1405, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache___init__(__pyx_self, __pyx_v_self, __pyx_v_size);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_size) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":1406
 *     class _FifoCache(object):
 *         def __init__(self, size):
 *             self.not_in_cache = object()             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] add self.size, self.cache
 *             self.size = size
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_not_in_cache, __pyx_t_1) < 0) __PYX_ERR(0, 1406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1408
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 *             self.size = size             # <<<<<<<<<<<<<<
 *             self.cache = _OrderedDict()
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_size, __pyx_v_size) < 0) __PYX_ERR(0, 1408, __pyx_L1_error)

  /* "cPyparsing.pyx":1409
 *             # [CPYPARSING] add self.size, self.cache
 *             self.size = size
 *             self.cache = _OrderedDict()             # <<<<<<<<<<<<<<
 * 
 *         def get(self, key):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_cache, __pyx_t_1) < 0) __PYX_ERR(0, 1409, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1405
 * if _OrderedDict is not None:
 *     class _FifoCache(object):
 *         def __init__(self, size):             # <<<<<<<<<<<<<<
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1411
 *             self.cache = _OrderedDict()
 * 
 *         def get(self, key):             # <<<<<<<<<<<<<<
 *             return self.cache.get(key, self.not_in_cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_3get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_2get, "_FifoCache.get(self, key)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_3get = {"get", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_3get, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_2get};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_3get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1411, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1411, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, 1); __PYX_ERR(0, 1411, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get") < 0)) __PYX_ERR(0, 1411, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1411, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_2get(__pyx_self, __pyx_v_self, __pyx_v_key);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_2get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get", 1);

  /* "cPyparsing.pyx":1412
 * 
 *         def get(self, key):
 *             return self.cache.get(key, self.not_in_cache)             # <<<<<<<<<<<<<<
 * 
 *         def set(self, key, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_not_in_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_key, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1411
 *             self.cache = _OrderedDict()
 * 
 *         def get(self, key):             # <<<<<<<<<<<<<<
 *             return self.cache.get(key, self.not_in_cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._FifoCache.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1414
 *             return self.cache.get(key, self.not_in_cache)
 * 
 *         def set(self, key, value):             # <<<<<<<<<<<<<<
 *             self.cache[key] = value
 *             while len(self.cache) > self.size:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_5set(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_4set, "_FifoCache.set(self, key, value)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_5set = {"set", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_5set, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_4set};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_5set(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1414, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1414, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 1); __PYX_ERR(0, 1414, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1414, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 2); __PYX_ERR(0, 1414, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set") < 0)) __PYX_ERR(0, 1414, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
    __pyx_v_value = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1414, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_4set(__pyx_self, __pyx_v_self, __pyx_v_key, __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_4set(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set", 1);

  /* "cPyparsing.pyx":1415
 * 
 *         def set(self, key, value):
 *             self.cache[key] = value             # <<<<<<<<<<<<<<
 *             while len(self.cache) > self.size:
 *                 try:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_key, __pyx_v_value) < 0))) __PYX_ERR(0, 1415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1416
 *         def set(self, key, value):
 *             self.cache[key] = value
 *             while len(self.cache) > self.size:             # <<<<<<<<<<<<<<
 *                 try:
 *                     self.cache.popitem(False)
 */
  while (1) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1416, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1416, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1416, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_5) break;

    /* "cPyparsing.pyx":1417
 *             self.cache[key] = value
 *             while len(self.cache) > self.size:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.cache.popitem(False)
 *                 except KeyError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "cPyparsing.pyx":1418
 *             while len(self.cache) > self.size:
 *                 try:
 *                     self.cache.popitem(False)             # <<<<<<<<<<<<<<
 *                 except KeyError:
 *                     pass
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1418, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_popitem); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1418, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        __pyx_t_9 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_9 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, Py_False};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1418, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "cPyparsing.pyx":1417
 *             self.cache[key] = value
 *             while len(self.cache) > self.size:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.cache.popitem(False)
 *                 except KeyError:
 */
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1419
 *                 try:
 *                     self.cache.popitem(False)
 *                 except KeyError:             # <<<<<<<<<<<<<<
 *                     pass
 * 
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
      if (__pyx_t_9) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;

      /* "cPyparsing.pyx":1417
 *             self.cache[key] = value
 *             while len(self.cache) > self.size:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.cache.popitem(False)
 *                 except KeyError:
 */
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_L12_try_end:;
    }
  }

  /* "cPyparsing.pyx":1414
 *             return self.cache.get(key, self.not_in_cache)
 * 
 *         def set(self, key, value):             # <<<<<<<<<<<<<<
 *             self.cache[key] = value
 *             while len(self.cache) > self.size:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._FifoCache.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1423
 * 
 *         # [CPYPARSING] add update
 *         def update(self, update_dict):             # <<<<<<<<<<<<<<
 *             self.cache.update(update_dict)
 *             while len(self.cache) > self.size:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_7update(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_6update, "_FifoCache.update(self, update_dict)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_7update = {"update", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_7update, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_6update};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_7update(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_update_dict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("update (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_update_dict,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1423, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_update_dict)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1423, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("update", 1, 2, 2, 1); __PYX_ERR(0, 1423, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "update") < 0)) __PYX_ERR(0, 1423, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_update_dict = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("update", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1423, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_6update(__pyx_self, __pyx_v_self, __pyx_v_update_dict);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_6update(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_update_dict) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update", 1);

  /* "cPyparsing.pyx":1424
 *         # [CPYPARSING] add update
 *         def update(self, update_dict):
 *             self.cache.update(update_dict)             # <<<<<<<<<<<<<<
 *             while len(self.cache) > self.size:
 *                 try:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_update); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_update_dict};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1425
 *         def update(self, update_dict):
 *             self.cache.update(update_dict)
 *             while len(self.cache) > self.size:             # <<<<<<<<<<<<<<
 *                 try:
 *                     self.cache.popitem(False)
 */
  while (1) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1425, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1425, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1425, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!__pyx_t_6) break;

    /* "cPyparsing.pyx":1426
 *             self.cache.update(update_dict)
 *             while len(self.cache) > self.size:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.cache.popitem(False)
 *                 except KeyError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "cPyparsing.pyx":1427
 *             while len(self.cache) > self.size:
 *                 try:
 *                     self.cache.popitem(False)             # <<<<<<<<<<<<<<
 *                 except KeyError:
 *                     pass
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1427, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_popitem); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1427, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, Py_False};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1427, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":1426
 *             self.cache.update(update_dict)
 *             while len(self.cache) > self.size:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.cache.popitem(False)
 *                 except KeyError:
 */
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":1428
 *                 try:
 *                     self.cache.popitem(False)
 *                 except KeyError:             # <<<<<<<<<<<<<<
 *                     pass
 * 
 */
      __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
      if (__pyx_t_4) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;

      /* "cPyparsing.pyx":1426
 *             self.cache.update(update_dict)
 *             while len(self.cache) > self.size:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.cache.popitem(False)
 *                 except KeyError:
 */
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_L12_try_end:;
    }
  }

  /* "cPyparsing.pyx":1423
 * 
 *         # [CPYPARSING] add update
 *         def update(self, update_dict):             # <<<<<<<<<<<<<<
 *             self.cache.update(update_dict)
 *             while len(self.cache) > self.size:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._FifoCache.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1431
 *                     pass
 * 
 *         def clear(self):             # <<<<<<<<<<<<<<
 *             self.cache.clear()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_9clear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_8clear, "_FifoCache.clear(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_9clear = {"clear", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_9clear, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_8clear};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_9clear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1431, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "clear") < 0)) __PYX_ERR(0, 1431, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("clear", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1431, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_8clear(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clear", 1);

  /* "cPyparsing.pyx":1432
 * 
 *         def clear(self):
 *             self.cache.clear()             # <<<<<<<<<<<<<<
 * 
 *         def __len__(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_clear); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1431
 *                     pass
 * 
 *         def clear(self):             # <<<<<<<<<<<<<<
 *             self.cache.clear()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._FifoCache.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1434
 *             self.cache.clear()
 * 
 *         def __len__(self):             # <<<<<<<<<<<<<<
 *             return len(self.cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_11__len__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_10__len__, "_FifoCache.__len__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_11__len__ = {"__len__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_11__len__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_10__len__};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_11__len__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1434, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__len__") < 0)) __PYX_ERR(0, 1434, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__len__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1434, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_10__len__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_10__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__len__", 1);

  /* "cPyparsing.pyx":1435
 * 
 *         def __len__(self):
 *             return len(self.cache)             # <<<<<<<<<<<<<<
 * 
 *         # [CPYPARSING] add __reduce__
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1434
 *             self.cache.clear()
 * 
 *         def __len__(self):             # <<<<<<<<<<<<<<
 *             return len(self.cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1438
 * 
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):             # <<<<<<<<<<<<<<
 *             return (self.__class__, (self.size,), {"cache": self.cache})
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_13__reduce__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_12__reduce__, "_FifoCache.__reduce__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_13__reduce__ = {"__reduce__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_13__reduce__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_12__reduce__};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_13__reduce__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1438, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__reduce__") < 0)) __PYX_ERR(0, 1438, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__reduce__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1438, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_12__reduce__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_12__reduce__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce__", 1);

  /* "cPyparsing.pyx":1439
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):
 *             return (self.__class__, (self.size,), {"cache": self.cache})             # <<<<<<<<<<<<<<
 * 
 * else:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 1439, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_cache, __pyx_t_4) < 0) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 1439, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3)) __PYX_ERR(0, 1439, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2)) __PYX_ERR(0, 1439, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1438
 * 
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):             # <<<<<<<<<<<<<<
 *             return (self.__class__, (self.size,), {"cache": self.cache})
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1443
 * else:
 *     class _FifoCache(object):
 *         def __init__(self, size):             # <<<<<<<<<<<<<<
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_15__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_14__init__, "_FifoCache.__init__(self, size)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_15__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_15__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_14__init__};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_15__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_size = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1443, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1443, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 1443, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1443, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_size = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1443, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_14__init__(__pyx_self, __pyx_v_self, __pyx_v_size);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_14__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_size) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":1444
 *     class _FifoCache(object):
 *         def __init__(self, size):
 *             self.not_in_cache = object()             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] add self.size, self.cache
 *             self.size = size
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_not_in_cache, __pyx_t_1) < 0) __PYX_ERR(0, 1444, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1446
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 *             self.size = size             # <<<<<<<<<<<<<<
 *             self.cache = {}
 *             self.key_fifo = collections.deque([], self.size)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_size, __pyx_v_size) < 0) __PYX_ERR(0, 1446, __pyx_L1_error)

  /* "cPyparsing.pyx":1447
 *             # [CPYPARSING] add self.size, self.cache
 *             self.size = size
 *             self.cache = {}             # <<<<<<<<<<<<<<
 *             self.key_fifo = collections.deque([], self.size)
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_cache, __pyx_t_1) < 0) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1448
 *             self.size = size
 *             self.cache = {}
 *             self.key_fifo = collections.deque([], self.size)             # <<<<<<<<<<<<<<
 * 
 *         def get(self, key):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_collections); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_deque); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_key_fifo, __pyx_t_1) < 0) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1443
 * else:
 *     class _FifoCache(object):
 *         def __init__(self, size):             # <<<<<<<<<<<<<<
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1450
 *             self.key_fifo = collections.deque([], self.size)
 * 
 *         def get(self, key):             # <<<<<<<<<<<<<<
 *             return self.cache.get(key, self.not_in_cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_17get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_16get, "_FifoCache.get(self, key)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_17get = {"get", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_17get, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_16get};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_17get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1450, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1450, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, 1); __PYX_ERR(0, 1450, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get") < 0)) __PYX_ERR(0, 1450, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1450, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_16get(__pyx_self, __pyx_v_self, __pyx_v_key);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_16get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get", 1);

  /* "cPyparsing.pyx":1451
 * 
 *         def get(self, key):
 *             return self.cache.get(key, self.not_in_cache)             # <<<<<<<<<<<<<<
 * 
 *         def set(self, key, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_not_in_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_key, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1450
 *             self.key_fifo = collections.deque([], self.size)
 * 
 *         def get(self, key):             # <<<<<<<<<<<<<<
 *             return self.cache.get(key, self.not_in_cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._FifoCache.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1453
 *             return self.cache.get(key, self.not_in_cache)
 * 
 *         def set(self, key, value):             # <<<<<<<<<<<<<<
 *             self.cache[key] = value
 *             while len(self.key_fifo) > self.size:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_19set(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_18set, "_FifoCache.set(self, key, value)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_19set = {"set", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_19set, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_18set};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_19set(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1453, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1453, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 1); __PYX_ERR(0, 1453, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1453, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 2); __PYX_ERR(0, 1453, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set") < 0)) __PYX_ERR(0, 1453, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
    __pyx_v_value = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1453, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_18set(__pyx_self, __pyx_v_self, __pyx_v_key, __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_18set(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set", 1);

  /* "cPyparsing.pyx":1454
 * 
 *         def set(self, key, value):
 *             self.cache[key] = value             # <<<<<<<<<<<<<<
 *             while len(self.key_fifo) > self.size:
 *                 self.cache.pop(self.key_fifo.popleft(), None)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_key, __pyx_v_value) < 0))) __PYX_ERR(0, 1454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1455
 *         def set(self, key, value):
 *             self.cache[key] = value
 *             while len(self.key_fifo) > self.size:             # <<<<<<<<<<<<<<
 *                 self.cache.pop(self.key_fifo.popleft(), None)
 *             self.key_fifo.append(key)
 */
  while (1) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_key_fifo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_5) break;

    /* "cPyparsing.pyx":1456
 *             self.cache[key] = value
 *             while len(self.key_fifo) > self.size:
 *                 self.cache.pop(self.key_fifo.popleft(), None)             # <<<<<<<<<<<<<<
 *             self.key_fifo.append(key)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_pop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_key_fifo); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_popleft); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1456, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_3, Py_None};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1456, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }

  /* "cPyparsing.pyx":1457
 *             while len(self.key_fifo) > self.size:
 *                 self.cache.pop(self.key_fifo.popleft(), None)
 *             self.key_fifo.append(key)             # <<<<<<<<<<<<<<
 * 
 *         def clear(self):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_key_fifo); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_4, __pyx_v_key); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1453
 *             return self.cache.get(key, self.not_in_cache)
 * 
 *         def set(self, key, value):             # <<<<<<<<<<<<<<
 *             self.cache[key] = value
 *             while len(self.key_fifo) > self.size:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing._FifoCache.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1459
 *             self.key_fifo.append(key)
 * 
 *         def clear(self):             # <<<<<<<<<<<<<<
 *             self.cache.clear()
 *             self.key_fifo.clear()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_21clear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_20clear, "_FifoCache.clear(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_21clear = {"clear", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_21clear, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_20clear};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_21clear(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1459, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "clear") < 0)) __PYX_ERR(0, 1459, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("clear", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1459, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_20clear(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_20clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clear", 1);

  /* "cPyparsing.pyx":1460
 * 
 *         def clear(self):
 *             self.cache.clear()             # <<<<<<<<<<<<<<
 *             self.key_fifo.clear()
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_clear); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1460, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1461
 *         def clear(self):
 *             self.cache.clear()
 *             self.key_fifo.clear()             # <<<<<<<<<<<<<<
 * 
 *         def __len__(self):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_key_fifo); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_clear); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1459
 *             self.key_fifo.append(key)
 * 
 *         def clear(self):             # <<<<<<<<<<<<<<
 *             self.cache.clear()
 *             self.key_fifo.clear()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._FifoCache.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1463
 *             self.key_fifo.clear()
 * 
 *         def __len__(self):             # <<<<<<<<<<<<<<
 *             return len(self.cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_23__len__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_22__len__, "_FifoCache.__len__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_23__len__ = {"__len__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_23__len__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_22__len__};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_23__len__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1463, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__len__") < 0)) __PYX_ERR(0, 1463, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__len__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1463, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_22__len__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_22__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__len__", 1);

  /* "cPyparsing.pyx":1464
 * 
 *         def __len__(self):
 *             return len(self.cache)             # <<<<<<<<<<<<<<
 * 
 *         # [CPYPARSING] add __reduce__
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1464, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1463
 *             self.key_fifo.clear()
 * 
 *         def __len__(self):             # <<<<<<<<<<<<<<
 *             return len(self.cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1467
 * 
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):             # <<<<<<<<<<<<<<
 *             return (self.__class__, (self.size,), {"cache": self.cache, "key_fifo": self.key_fifo})
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_25__reduce__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_FifoCache_24__reduce__, "_FifoCache.__reduce__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_25__reduce__ = {"__reduce__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_FifoCache_25__reduce__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_FifoCache_24__reduce__};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_25__reduce__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1467, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__reduce__") < 0)) __PYX_ERR(0, 1467, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__reduce__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1467, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._FifoCache.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_24__reduce__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_24__reduce__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce__", 1);

  /* "cPyparsing.pyx":1468
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):
 *             return (self.__class__, (self.size,), {"cache": self.cache, "key_fifo": self.key_fifo})             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 1468, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_cache); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_cache, __pyx_t_4) < 0) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_key_fifo); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_key_fifo, __pyx_t_4) < 0) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 1468, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3)) __PYX_ERR(0, 1468, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2)) __PYX_ERR(0, 1468, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1467
 * 
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):             # <<<<<<<<<<<<<<
 *             return (self.__class__, (self.size,), {"cache": self.cache, "key_fifo": self.key_fifo})
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1476
 *     verbose_stacktrace = False
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultWhitespaceChars(chars):
 *         r"""
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_setDefaultWhitespaceChars, "ParserElement.setDefaultWhitespaceChars(chars)\n\n        Overrides the default whitespace chars\n\n        Example::\n\n            # default whitespace chars are space, <TAB> and newline\n            OneOrMore(Word(alphas)).parseString(\"abc def\\nghi jkl\")  # -> ['abc', 'def', 'ghi', 'jkl']\n\n            # change to just treat newline as significant\n            ParserElement.setDefaultWhitespaceChars(\" \\t\")\n            OneOrMore(Word(alphas)).parseString(\"abc def\\nghi jkl\")  # -> ['abc', 'def']\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars = {"setDefaultWhitespaceChars", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_setDefaultWhitespaceChars};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_chars = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setDefaultWhitespaceChars (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_chars,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chars)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1476, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setDefaultWhitespaceChars") < 0)) __PYX_ERR(0, 1476, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_chars = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setDefaultWhitespaceChars", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1476, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDefaultWhitespaceChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_setDefaultWhitespaceChars(__pyx_self, __pyx_v_chars);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_setDefaultWhitespaceChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setDefaultWhitespaceChars", 1);

  /* "cPyparsing.pyx":1490
 *             OneOrMore(Word(alphas)).parseString("abc def\nghi jkl")  # -> ['abc', 'def']
 *         """
 *         ParserElement.DEFAULT_WHITE_CHARS = chars             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_WHITE_CHARS, __pyx_v_chars) < 0) __PYX_ERR(0, 1490, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1476
 *     verbose_stacktrace = False
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultWhitespaceChars(chars):
 *         r"""
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDefaultWhitespaceChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1492
 *         ParserElement.DEFAULT_WHITE_CHARS = chars
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def inlineLiteralsUsing(cls):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_3inlineLiteralsUsing(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_2inlineLiteralsUsing, "ParserElement.inlineLiteralsUsing(cls)\n\n        Set class to be used for inclusion of string literals into a parser.\n\n        Example::\n\n            # default literal class used is Literal\n            integer = Word(nums)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            date_str.parseString(\"1999/12/31\")  # -> ['1999', '/', '12', '/', '31']\n\n\n            # change to Suppress\n            ParserElement.inlineLiteralsUsing(Suppress)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            date_str.parseString(\"1999/12/31\")  # -> ['1999', '12', '31']\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_3inlineLiteralsUsing = {"inlineLiteralsUsing", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_3inlineLiteralsUsing, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_2inlineLiteralsUsing};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_3inlineLiteralsUsing(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inlineLiteralsUsing (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1492, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "inlineLiteralsUsing") < 0)) __PYX_ERR(0, 1492, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_cls = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("inlineLiteralsUsing", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1492, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.inlineLiteralsUsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_2inlineLiteralsUsing(__pyx_self, __pyx_v_cls);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_2inlineLiteralsUsing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inlineLiteralsUsing", 1);

  /* "cPyparsing.pyx":1512
 *             date_str.parseString("1999/12/31")  # -> ['1999', '12', '31']
 *         """
 *         ParserElement._literalStringClass = cls             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_literalStringClass, __pyx_v_cls) < 0) __PYX_ERR(0, 1512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1492
 *         ParserElement.DEFAULT_WHITE_CHARS = chars
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def inlineLiteralsUsing(cls):
 *         """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.inlineLiteralsUsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1514
 *         ParserElement._literalStringClass = cls
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _trim_traceback(cls, tb):
 *         while tb.tb_next:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_5_trim_traceback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_4_trim_traceback, "ParserElement._trim_traceback(cls, tb)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_5_trim_traceback = {"_trim_traceback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_5_trim_traceback, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_4_trim_traceback};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_5_trim_traceback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_tb = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_trim_traceback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_tb,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1514, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tb)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1514, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_trim_traceback", 1, 2, 2, 1); __PYX_ERR(0, 1514, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_trim_traceback") < 0)) __PYX_ERR(0, 1514, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_cls = values[0];
    __pyx_v_tb = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_trim_traceback", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1514, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement._trim_traceback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_4_trim_traceback(__pyx_self, __pyx_v_cls, __pyx_v_tb);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_4_trim_traceback(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_cls, PyObject *__pyx_v_tb) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_trim_traceback", 0);
  __Pyx_INCREF(__pyx_v_tb);

  /* "cPyparsing.pyx":1516
 *     @classmethod
 *     def _trim_traceback(cls, tb):
 *         while tb.tb_next:             # <<<<<<<<<<<<<<
 *             tb = tb.tb_next
 *         return tb
 */
  while (1) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tb, __pyx_n_s_tb_next); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1516, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_2) break;

    /* "cPyparsing.pyx":1517
 *     def _trim_traceback(cls, tb):
 *         while tb.tb_next:
 *             tb = tb.tb_next             # <<<<<<<<<<<<<<
 *         return tb
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tb, __pyx_n_s_tb_next); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_tb, __pyx_t_1);
    __pyx_t_1 = 0;
  }

  /* "cPyparsing.pyx":1518
 *         while tb.tb_next:
 *             tb = tb.tb_next
 *         return tb             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] add collectParseElements
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_tb);
  __pyx_r = __pyx_v_tb;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1514
 *         ParserElement._literalStringClass = cls
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _trim_traceback(cls, tb):
 *         while tb.tb_next:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement._trim_traceback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1523
 *     _all_parse_elements = None
 *     parse_element_index = None
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def collectParseElements():
 *         ParserElement._all_parse_elements = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_7collectParseElements(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_6collectParseElements, "ParserElement.collectParseElements()");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_7collectParseElements = {"collectParseElements", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_7collectParseElements, METH_NOARGS, __pyx_doc_10cPyparsing_13ParserElement_6collectParseElements};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_7collectParseElements(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("collectParseElements (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_6collectParseElements(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_6collectParseElements(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("collectParseElements", 1);

  /* "cPyparsing.pyx":1525
 *     @staticmethod
 *     def collectParseElements():
 *         ParserElement._all_parse_elements = []             # <<<<<<<<<<<<<<
 *         return ParserElement._all_parse_elements
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_all_parse_elements, __pyx_t_1) < 0) __PYX_ERR(0, 1525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1526
 *     def collectParseElements():
 *         ParserElement._all_parse_elements = []
 *         return ParserElement._all_parse_elements             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, savelist=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_all_parse_elements); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1523
 *     _all_parse_elements = None
 *     parse_element_index = None
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def collectParseElements():
 *         ParserElement._all_parse_elements = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParserElement.collectParseElements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1528
 *         return ParserElement._all_parse_elements
 * 
 *     def __init__(self, savelist=False):             # <<<<<<<<<<<<<<
 *         self.parseAction = list()
 *         self.failAction = None
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_9__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_8__init__, "ParserElement.__init__(self, savelist=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_9__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_9__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_8__init__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_9__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_savelist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_savelist,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1528, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_savelist);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1528, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1528, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_savelist = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1528, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_8__init__(__pyx_self, __pyx_v_self, __pyx_v_savelist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_8__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_savelist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":1529
 * 
 *     def __init__(self, savelist=False):
 *         self.parseAction = list()             # <<<<<<<<<<<<<<
 *         self.failAction = None
 *         # ~ self.name = "<unknown>"  # don't define self.name, let subclasses try/except upcall
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseAction, __pyx_t_1) < 0) __PYX_ERR(0, 1529, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1530
 *     def __init__(self, savelist=False):
 *         self.parseAction = list()
 *         self.failAction = None             # <<<<<<<<<<<<<<
 *         # ~ self.name = "<unknown>"  # don't define self.name, let subclasses try/except upcall
 *         self.strRepr = None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_failAction, Py_None) < 0) __PYX_ERR(0, 1530, __pyx_L1_error)

  /* "cPyparsing.pyx":1532
 *         self.failAction = None
 *         # ~ self.name = "<unknown>"  # don't define self.name, let subclasses try/except upcall
 *         self.strRepr = None             # <<<<<<<<<<<<<<
 *         self.resultsName = None
 *         self.saveAsList = savelist
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 1532, __pyx_L1_error)

  /* "cPyparsing.pyx":1533
 *         # ~ self.name = "<unknown>"  # don't define self.name, let subclasses try/except upcall
 *         self.strRepr = None
 *         self.resultsName = None             # <<<<<<<<<<<<<<
 *         self.saveAsList = savelist
 *         self.skipWhitespace = True
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_resultsName, Py_None) < 0) __PYX_ERR(0, 1533, __pyx_L1_error)

  /* "cPyparsing.pyx":1534
 *         self.strRepr = None
 *         self.resultsName = None
 *         self.saveAsList = savelist             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.whiteChars = set(ParserElement.DEFAULT_WHITE_CHARS)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_v_savelist) < 0) __PYX_ERR(0, 1534, __pyx_L1_error)

  /* "cPyparsing.pyx":1535
 *         self.resultsName = None
 *         self.saveAsList = savelist
 *         self.skipWhitespace = True             # <<<<<<<<<<<<<<
 *         self.whiteChars = set(ParserElement.DEFAULT_WHITE_CHARS)
 *         self.copyDefaultWhiteChars = True
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_True) < 0) __PYX_ERR(0, 1535, __pyx_L1_error)

  /* "cPyparsing.pyx":1536
 *         self.saveAsList = savelist
 *         self.skipWhitespace = True
 *         self.whiteChars = set(ParserElement.DEFAULT_WHITE_CHARS)             # <<<<<<<<<<<<<<
 *         self.copyDefaultWhiteChars = True
 *         self.mayReturnEmpty = False # used when checking for left-recursion
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PySet_New(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_whiteChars, __pyx_t_1) < 0) __PYX_ERR(0, 1536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1537
 *         self.skipWhitespace = True
 *         self.whiteChars = set(ParserElement.DEFAULT_WHITE_CHARS)
 *         self.copyDefaultWhiteChars = True             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = False # used when checking for left-recursion
 *         self.keepTabs = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_copyDefaultWhiteChars, Py_True) < 0) __PYX_ERR(0, 1537, __pyx_L1_error)

  /* "cPyparsing.pyx":1538
 *         self.whiteChars = set(ParserElement.DEFAULT_WHITE_CHARS)
 *         self.copyDefaultWhiteChars = True
 *         self.mayReturnEmpty = False # used when checking for left-recursion             # <<<<<<<<<<<<<<
 *         self.keepTabs = False
 *         self.ignoreExprs = list()
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_False) < 0) __PYX_ERR(0, 1538, __pyx_L1_error)

  /* "cPyparsing.pyx":1539
 *         self.copyDefaultWhiteChars = True
 *         self.mayReturnEmpty = False # used when checking for left-recursion
 *         self.keepTabs = False             # <<<<<<<<<<<<<<
 *         self.ignoreExprs = list()
 *         self.debug = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_keepTabs, Py_False) < 0) __PYX_ERR(0, 1539, __pyx_L1_error)

  /* "cPyparsing.pyx":1540
 *         self.mayReturnEmpty = False # used when checking for left-recursion
 *         self.keepTabs = False
 *         self.ignoreExprs = list()             # <<<<<<<<<<<<<<
 *         self.debug = False
 *         self.streamlined = False
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs, __pyx_t_1) < 0) __PYX_ERR(0, 1540, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1541
 *         self.keepTabs = False
 *         self.ignoreExprs = list()
 *         self.debug = False             # <<<<<<<<<<<<<<
 *         self.streamlined = False
 *         self.mayIndexError = True # used to optimize exception handling for subclasses that don't advance parse index
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debug, Py_False) < 0) __PYX_ERR(0, 1541, __pyx_L1_error)

  /* "cPyparsing.pyx":1542
 *         self.ignoreExprs = list()
 *         self.debug = False
 *         self.streamlined = False             # <<<<<<<<<<<<<<
 *         self.mayIndexError = True # used to optimize exception handling for subclasses that don't advance parse index
 *         self.errmsg = ""
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_streamlined, Py_False) < 0) __PYX_ERR(0, 1542, __pyx_L1_error)

  /* "cPyparsing.pyx":1543
 *         self.debug = False
 *         self.streamlined = False
 *         self.mayIndexError = True # used to optimize exception handling for subclasses that don't advance parse index             # <<<<<<<<<<<<<<
 *         self.errmsg = ""
 *         self.modalResults = True # used to mark results names as modal (report only last) or cumulative (list all)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_True) < 0) __PYX_ERR(0, 1543, __pyx_L1_error)

  /* "cPyparsing.pyx":1544
 *         self.streamlined = False
 *         self.mayIndexError = True # used to optimize exception handling for subclasses that don't advance parse index
 *         self.errmsg = ""             # <<<<<<<<<<<<<<
 *         self.modalResults = True # used to mark results names as modal (report only last) or cumulative (list all)
 *         self.debugActions = (None, None, None)  # custom debug actions
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u__10) < 0) __PYX_ERR(0, 1544, __pyx_L1_error)

  /* "cPyparsing.pyx":1545
 *         self.mayIndexError = True # used to optimize exception handling for subclasses that don't advance parse index
 *         self.errmsg = ""
 *         self.modalResults = True # used to mark results names as modal (report only last) or cumulative (list all)             # <<<<<<<<<<<<<<
 *         self.debugActions = (None, None, None)  # custom debug actions
 *         self.re = None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_modalResults, Py_True) < 0) __PYX_ERR(0, 1545, __pyx_L1_error)

  /* "cPyparsing.pyx":1546
 *         self.errmsg = ""
 *         self.modalResults = True # used to mark results names as modal (report only last) or cumulative (list all)
 *         self.debugActions = (None, None, None)  # custom debug actions             # <<<<<<<<<<<<<<
 *         self.re = None
 *         self.callPreparse = True # used to avoid redundant calls to preParse
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debugActions, __pyx_tuple__46) < 0) __PYX_ERR(0, 1546, __pyx_L1_error)

  /* "cPyparsing.pyx":1547
 *         self.modalResults = True # used to mark results names as modal (report only last) or cumulative (list all)
 *         self.debugActions = (None, None, None)  # custom debug actions
 *         self.re = None             # <<<<<<<<<<<<<<
 *         self.callPreparse = True # used to avoid redundant calls to preParse
 *         self.callDuringTry = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, Py_None) < 0) __PYX_ERR(0, 1547, __pyx_L1_error)

  /* "cPyparsing.pyx":1548
 *         self.debugActions = (None, None, None)  # custom debug actions
 *         self.re = None
 *         self.callPreparse = True # used to avoid redundant calls to preParse             # <<<<<<<<<<<<<<
 *         self.callDuringTry = False
 *         # [CPYPARSING] collect parse element indices
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse, Py_True) < 0) __PYX_ERR(0, 1548, __pyx_L1_error)

  /* "cPyparsing.pyx":1549
 *         self.re = None
 *         self.callPreparse = True # used to avoid redundant calls to preParse
 *         self.callDuringTry = False             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] collect parse element indices
 *         if ParserElement._all_parse_elements is not None:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry, Py_False) < 0) __PYX_ERR(0, 1549, __pyx_L1_error)

  /* "cPyparsing.pyx":1551
 *         self.callDuringTry = False
 *         # [CPYPARSING] collect parse element indices
 *         if ParserElement._all_parse_elements is not None:             # <<<<<<<<<<<<<<
 *             self.parse_element_index = len(ParserElement._all_parse_elements)
 *             ParserElement._all_parse_elements.append(wkref(self))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_all_parse_elements); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1552
 *         # [CPYPARSING] collect parse element indices
 *         if ParserElement._all_parse_elements is not None:
 *             self.parse_element_index = len(ParserElement._all_parse_elements)             # <<<<<<<<<<<<<<
 *             ParserElement._all_parse_elements.append(wkref(self))
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_all_parse_elements); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parse_element_index, __pyx_t_1) < 0) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1553
 *         if ParserElement._all_parse_elements is not None:
 *             self.parse_element_index = len(ParserElement._all_parse_elements)
 *             ParserElement._all_parse_elements.append(wkref(self))             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_all_parse_elements); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_wkref); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1553, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_8 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1551
 *         self.callDuringTry = False
 *         # [CPYPARSING] collect parse element indices
 *         if ParserElement._all_parse_elements is not None:             # <<<<<<<<<<<<<<
 *             self.parse_element_index = len(ParserElement._all_parse_elements)
 *             ParserElement._all_parse_elements.append(wkref(self))
 */
  }

  /* "cPyparsing.pyx":1528
 *         return ParserElement._all_parse_elements
 * 
 *     def __init__(self, savelist=False):             # <<<<<<<<<<<<<<
 *         self.parseAction = list()
 *         self.failAction = None
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1555
 *             ParserElement._all_parse_elements.append(wkref(self))
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Make a copy of this :class:`ParserElement`.  Useful for defining
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_11copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_10copy, "ParserElement.copy(self)\n\n        Make a copy of this :class:`ParserElement`.  Useful for defining\n        different parse actions for the same parsing pattern, using copies of\n        the original parse element.\n\n        Example::\n\n            integer = Word(nums).setParseAction(lambda toks: int(toks[0]))\n            integerK = integer.copy().addParseAction(lambda toks: toks[0] * 1024) + Suppress(\"K\")\n            integerM = integer.copy().addParseAction(lambda toks: toks[0] * 1024 * 1024) + Suppress(\"M\")\n\n            print(OneOrMore(integerK | integerM | integer).parseString(\"5K 100 640K 256M\"))\n\n        prints::\n\n            [5120, 100, 655360, 268435456]\n\n        Equivalent form of ``expr.copy()`` is just ``expr()``::\n\n            integerM = integer().addParseAction(lambda toks: toks[0] * 1024 * 1024) + Suppress(\"M\")\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_11copy = {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_11copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_10copy};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_11copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1555, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "copy") < 0)) __PYX_ERR(0, 1555, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("copy", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1555, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_10copy(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_10copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_cpy = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 1);

  /* "cPyparsing.pyx":1577
 *             integerM = integer().addParseAction(lambda toks: toks[0] * 1024 * 1024) + Suppress("M")
 *         """
 *         cpy = copy.copy(self)             # <<<<<<<<<<<<<<
 *         cpy.parseAction = self.parseAction[:]
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_cpy = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1578
 *         """
 *         cpy = copy.copy(self)
 *         cpy.parseAction = self.parseAction[:]             # <<<<<<<<<<<<<<
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 *         if self.copyDefaultWhiteChars:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cpy, __pyx_n_s_parseAction, __pyx_t_3) < 0) __PYX_ERR(0, 1578, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1579
 *         cpy = copy.copy(self)
 *         cpy.parseAction = self.parseAction[:]
 *         cpy.ignoreExprs = self.ignoreExprs[:]             # <<<<<<<<<<<<<<
 *         if self.copyDefaultWhiteChars:
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_3, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cpy, __pyx_n_s_ignoreExprs, __pyx_t_1) < 0) __PYX_ERR(0, 1579, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1580
 *         cpy.parseAction = self.parseAction[:]
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 *         if self.copyDefaultWhiteChars:             # <<<<<<<<<<<<<<
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         # [CPYPARSING] get new parse element index
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copyDefaultWhiteChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1580, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":1581
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 *         if self.copyDefaultWhiteChars:
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] get new parse element index
 *         if ParserElement._all_parse_elements is not None:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_cpy, __pyx_n_s_whiteChars, __pyx_t_3) < 0) __PYX_ERR(0, 1581, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1580
 *         cpy.parseAction = self.parseAction[:]
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 *         if self.copyDefaultWhiteChars:             # <<<<<<<<<<<<<<
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         # [CPYPARSING] get new parse element index
 */
  }

  /* "cPyparsing.pyx":1583
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         # [CPYPARSING] get new parse element index
 *         if ParserElement._all_parse_elements is not None:             # <<<<<<<<<<<<<<
 *             cpy.parse_element_index = len(ParserElement._all_parse_elements)
 *             ParserElement._all_parse_elements.append(wkref(cpy))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_all_parse_elements); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":1584
 *         # [CPYPARSING] get new parse element index
 *         if ParserElement._all_parse_elements is not None:
 *             cpy.parse_element_index = len(ParserElement._all_parse_elements)             # <<<<<<<<<<<<<<
 *             ParserElement._all_parse_elements.append(wkref(cpy))
 *         return cpy
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_all_parse_elements); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1584, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_cpy, __pyx_n_s_parse_element_index, __pyx_t_3) < 0) __PYX_ERR(0, 1584, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1585
 *         if ParserElement._all_parse_elements is not None:
 *             cpy.parse_element_index = len(ParserElement._all_parse_elements)
 *             ParserElement._all_parse_elements.append(wkref(cpy))             # <<<<<<<<<<<<<<
 *         return cpy
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_all_parse_elements); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_wkref); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_cpy};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1585, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_8 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_3); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1585, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1583
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         # [CPYPARSING] get new parse element index
 *         if ParserElement._all_parse_elements is not None:             # <<<<<<<<<<<<<<
 *             cpy.parse_element_index = len(ParserElement._all_parse_elements)
 *             ParserElement._all_parse_elements.append(wkref(cpy))
 */
  }

  /* "cPyparsing.pyx":1586
 *             cpy.parse_element_index = len(ParserElement._all_parse_elements)
 *             ParserElement._all_parse_elements.append(wkref(cpy))
 *         return cpy             # <<<<<<<<<<<<<<
 * 
 *     def setName(self, name):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cpy);
  __pyx_r = __pyx_v_cpy;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1555
 *             ParserElement._all_parse_elements.append(wkref(self))
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Make a copy of this :class:`ParserElement`.  Useful for defining
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cpy);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1588
 *         return cpy
 * 
 *     def setName(self, name):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for this expression, makes debugging and exception messages clearer.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_13setName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_12setName, "ParserElement.setName(self, name)\n\n        Define name for this expression, makes debugging and exception messages clearer.\n\n        Example::\n\n            Word(nums).parseString(\"ABC\")  # -> Exception: Expected W:(0123...) (at char 0), (line:1, col:1)\n            Word(nums).setName(\"integer\").parseString(\"ABC\")  # -> Exception: Expected integer (at char 0), (line:1, col:1)\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_13setName = {"setName", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_13setName, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_12setName};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_13setName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setName (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1588, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1588, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("setName", 1, 2, 2, 1); __PYX_ERR(0, 1588, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setName") < 0)) __PYX_ERR(0, 1588, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setName", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1588, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.setName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_12setName(__pyx_self, __pyx_v_self, __pyx_v_name);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_12setName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setName", 1);

  /* "cPyparsing.pyx":1597
 *             Word(nums).setName("integer").parseString("ABC")  # -> Exception: Expected integer (at char 0), (line:1, col:1)
 *         """
 *         self.name = name             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         if __diag__.enable_debug_on_named_expressions:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_v_name) < 0) __PYX_ERR(0, 1597, __pyx_L1_error)

  /* "cPyparsing.pyx":1598
 *         """
 *         self.name = name
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         if __diag__.enable_debug_on_named_expressions:
 *             self.setDebug()
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 1598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1599
 *         self.name = name
 *         self.errmsg = "Expected " + self.name
 *         if __diag__.enable_debug_on_named_expressions:             # <<<<<<<<<<<<<<
 *             self.setDebug()
 *         return self
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_diag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_enable_debug_on_named_expression); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1600
 *         self.errmsg = "Expected " + self.name
 *         if __diag__.enable_debug_on_named_expressions:
 *             self.setDebug()             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setDebug); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1600, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1599
 *         self.name = name
 *         self.errmsg = "Expected " + self.name
 *         if __diag__.enable_debug_on_named_expressions:             # <<<<<<<<<<<<<<
 *             self.setDebug()
 *         return self
 */
  }

  /* "cPyparsing.pyx":1601
 *         if __diag__.enable_debug_on_named_expressions:
 *             self.setDebug()
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setResultsName(self, name, listAllMatches=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1588
 *         return cpy
 * 
 *     def setName(self, name):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for this expression, makes debugging and exception messages clearer.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1603
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for referencing matching tokens as a nested attribute
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_15setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_14setResultsName, "ParserElement.setResultsName(self, name, listAllMatches=False)\n\n        Define name for referencing matching tokens as a nested attribute\n        of the returned parse results.\n        NOTE: this returns a *copy* of the original :class:`ParserElement` object;\n        this is so that the client can define a basic element, such as an\n        integer, and reference it in multiple places with different names.\n\n        You can also set results names using the abbreviated syntax,\n        ``expr(\"name\")`` in place of ``expr.setResultsName(\"name\")``\n        - see :class:`__call__`.\n\n        Example::\n\n            date_str = (integer.setResultsName(\"year\") + '/'\n                        + integer.setResultsName(\"month\") + '/'\n                        + integer.setResultsName(\"day\"))\n\n            # equivalent form:\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_15setResultsName = {"setResultsName", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_15setResultsName, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_14setResultsName};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_15setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_listAllMatches = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setResultsName (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,&__pyx_n_s_listAllMatches,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1603, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1603, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("setResultsName", 0, 2, 3, 1); __PYX_ERR(0, 1603, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listAllMatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1603, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setResultsName") < 0)) __PYX_ERR(0, 1603, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_listAllMatches = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setResultsName", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 1603, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_14setResultsName(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_listAllMatches);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_14setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setResultsName", 1);

  /* "cPyparsing.pyx":1624
 *             date_str = integer("year") + '/' + integer("month") + '/' + integer("day")
 *         """
 *         return self._setResultsName(name, listAllMatches)             # <<<<<<<<<<<<<<
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_name, __pyx_v_listAllMatches};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1624, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1603
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for referencing matching tokens as a nested attribute
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1626
 *         return self._setResultsName(name, listAllMatches)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         newself = self.copy()
 *         if name.endswith("*"):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_17_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_16_setResultsName, "ParserElement._setResultsName(self, name, listAllMatches=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_17_setResultsName = {"_setResultsName", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_17_setResultsName, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_16_setResultsName};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_17_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_listAllMatches = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_setResultsName (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,&__pyx_n_s_listAllMatches,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1626, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1626, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, 1); __PYX_ERR(0, 1626, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listAllMatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1626, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_setResultsName") < 0)) __PYX_ERR(0, 1626, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_listAllMatches = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 1626, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_16_setResultsName(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_listAllMatches);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_16_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches) {
  PyObject *__pyx_v_newself = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_setResultsName", 0);
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_INCREF(__pyx_v_listAllMatches);

  /* "cPyparsing.pyx":1627
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         newself = self.copy()             # <<<<<<<<<<<<<<
 *         if name.endswith("*"):
 *             name = name[:-1]
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_newself = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1628
 *     def _setResultsName(self, name, listAllMatches=False):
 *         newself = self.copy()
 *         if name.endswith("*"):             # <<<<<<<<<<<<<<
 *             name = name[:-1]
 *             listAllMatches = True
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_endswith); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u__15};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1628, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1628, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":1629
 *         newself = self.copy()
 *         if name.endswith("*"):
 *             name = name[:-1]             # <<<<<<<<<<<<<<
 *             listAllMatches = True
 *         newself.resultsName = name
 */
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_name, 0, -1L, NULL, NULL, &__pyx_slice__47, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1630
 *         if name.endswith("*"):
 *             name = name[:-1]
 *             listAllMatches = True             # <<<<<<<<<<<<<<
 *         newself.resultsName = name
 *         newself.modalResults = not listAllMatches
 */
    __Pyx_INCREF(Py_True);
    __Pyx_DECREF_SET(__pyx_v_listAllMatches, Py_True);

    /* "cPyparsing.pyx":1628
 *     def _setResultsName(self, name, listAllMatches=False):
 *         newself = self.copy()
 *         if name.endswith("*"):             # <<<<<<<<<<<<<<
 *             name = name[:-1]
 *             listAllMatches = True
 */
  }

  /* "cPyparsing.pyx":1631
 *             name = name[:-1]
 *             listAllMatches = True
 *         newself.resultsName = name             # <<<<<<<<<<<<<<
 *         newself.modalResults = not listAllMatches
 *         return newself
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_newself, __pyx_n_s_resultsName, __pyx_v_name) < 0) __PYX_ERR(0, 1631, __pyx_L1_error)

  /* "cPyparsing.pyx":1632
 *             listAllMatches = True
 *         newself.resultsName = name
 *         newself.modalResults = not listAllMatches             # <<<<<<<<<<<<<<
 *         return newself
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_listAllMatches); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1632, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyBool_FromLong((!__pyx_t_5)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_newself, __pyx_n_s_modalResults, __pyx_t_1) < 0) __PYX_ERR(0, 1632, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1633
 *         newself.resultsName = name
 *         newself.modalResults = not listAllMatches
 *         return newself             # <<<<<<<<<<<<<<
 * 
 *     def setBreak(self, breakFlag=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_newself);
  __pyx_r = __pyx_v_newself;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1626
 *         return self._setResultsName(name, listAllMatches)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         newself = self.copy()
 *         if name.endswith("*"):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_newself);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_listAllMatches);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1635
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set ``breakFlag`` to True to enable, False to
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_19setBreak(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_18setBreak, "ParserElement.setBreak(self, breakFlag=True)\nMethod to invoke the Python pdb debugger when this element is\n           about to be parsed. Set ``breakFlag`` to True to enable, False to\n           disable.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_19setBreak = {"setBreak", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_19setBreak, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_18setBreak};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_19setBreak(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_breakFlag = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setBreak (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_breakFlag,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1635, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_breakFlag);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1635, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setBreak") < 0)) __PYX_ERR(0, 1635, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_breakFlag = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setBreak", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1635, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.setBreak", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_18setBreak(__pyx_self, __pyx_v_self, __pyx_v_breakFlag);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1642
 *         if breakFlag:
 *             _parseMethod = self._parse
 *             def breaker(instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *                 import pdb
 *                 # this call to pdb.set_trace() is intentional, not a checkin error
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_8setBreak_1breaker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_8setBreak_1breaker = {"breaker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_8setBreak_1breaker, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_8setBreak_1breaker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_v_callPreParse = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("breaker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,&__pyx_n_s_callPreParse,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1642, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1642, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("breaker", 0, 2, 4, 1); __PYX_ERR(0, 1642, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1642, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_callPreParse);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1642, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "breaker") < 0)) __PYX_ERR(0, 1642, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_instring = values[0];
    __pyx_v_loc = values[1];
    __pyx_v_doActions = values[2];
    __pyx_v_callPreParse = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("breaker", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 1642, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.setBreak.breaker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_8setBreak_breaker(__pyx_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_8setBreak_breaker(PyObject *__pyx_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *__pyx_outer_scope;
  PyObject *__pyx_v_pdb = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("breaker", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1643
 *             _parseMethod = self._parse
 *             def breaker(instring, loc, doActions=True, callPreParse=True):
 *                 import pdb             # <<<<<<<<<<<<<<
 *                 # this call to pdb.set_trace() is intentional, not a checkin error
 *                 pdb.set_trace()
 */
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_pdb, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pdb = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1645
 *                 import pdb
 *                 # this call to pdb.set_trace() is intentional, not a checkin error
 *                 pdb.set_trace()             # <<<<<<<<<<<<<<
 *                 return _parseMethod(instring, loc, doActions, callPreParse)
 *             breaker._originalParseMethod = _parseMethod
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_pdb, __pyx_n_s_set_trace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1645, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1646
 *                 # this call to pdb.set_trace() is intentional, not a checkin error
 *                 pdb.set_trace()
 *                 return _parseMethod(instring, loc, doActions, callPreParse)             # <<<<<<<<<<<<<<
 *             breaker._originalParseMethod = _parseMethod
 *             self._parse = breaker
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v__parseMethod)) { __Pyx_RaiseClosureNameError("_parseMethod"); __PYX_ERR(0, 1646, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v__parseMethod);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v__parseMethod; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1642
 *         if breakFlag:
 *             _parseMethod = self._parse
 *             def breaker(instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *                 import pdb
 *                 # this call to pdb.set_trace() is intentional, not a checkin error
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setBreak.breaker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pdb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1635
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set ``breakFlag`` to True to enable, False to
 */

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_18setBreak(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_breakFlag) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *__pyx_cur_scope;
  PyObject *__pyx_v_breaker = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setBreak", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_17_setBreak(__pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1635, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":1640
 *            disable.
 *         """
 *         if breakFlag:             # <<<<<<<<<<<<<<
 *             _parseMethod = self._parse
 *             def breaker(instring, loc, doActions=True, callPreParse=True):
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_breakFlag); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1640, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":1641
 *         """
 *         if breakFlag:
 *             _parseMethod = self._parse             # <<<<<<<<<<<<<<
 *             def breaker(instring, loc, doActions=True, callPreParse=True):
 *                 import pdb
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_v__parseMethod = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1642
 *         if breakFlag:
 *             _parseMethod = self._parse
 *             def breaker(instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *                 import pdb
 *                 # this call to pdb.set_trace() is intentional, not a checkin error
 */
    __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_8setBreak_1breaker, 0, __pyx_n_s_ParserElement_setBreak_locals_br, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__49)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1642, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__50);
    __pyx_v_breaker = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1647
 *                 pdb.set_trace()
 *                 return _parseMethod(instring, loc, doActions, callPreParse)
 *             breaker._originalParseMethod = _parseMethod             # <<<<<<<<<<<<<<
 *             self._parse = breaker
 *         else:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_breaker, __pyx_n_s_originalParseMethod, __pyx_cur_scope->__pyx_v__parseMethod) < 0) __PYX_ERR(0, 1647, __pyx_L1_error)

    /* "cPyparsing.pyx":1648
 *                 return _parseMethod(instring, loc, doActions, callPreParse)
 *             breaker._originalParseMethod = _parseMethod
 *             self._parse = breaker             # <<<<<<<<<<<<<<
 *         else:
 *             if hasattr(self._parse, "_originalParseMethod"):
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parse, __pyx_v_breaker) < 0) __PYX_ERR(0, 1648, __pyx_L1_error)

    /* "cPyparsing.pyx":1640
 *            disable.
 *         """
 *         if breakFlag:             # <<<<<<<<<<<<<<
 *             _parseMethod = self._parse
 *             def breaker(instring, loc, doActions=True, callPreParse=True):
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":1650
 *             self._parse = breaker
 *         else:
 *             if hasattr(self._parse, "_originalParseMethod"):             # <<<<<<<<<<<<<<
 *                 self._parse = self._parse._originalParseMethod
 *         return self
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1650, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_HasAttr(__pyx_t_2, __pyx_n_u_originalParseMethod); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1650, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":1651
 *         else:
 *             if hasattr(self._parse, "_originalParseMethod"):
 *                 self._parse = self._parse._originalParseMethod             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1651, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_originalParseMethod); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1651, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parse, __pyx_t_3) < 0) __PYX_ERR(0, 1651, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":1650
 *             self._parse = breaker
 *         else:
 *             if hasattr(self._parse, "_originalParseMethod"):             # <<<<<<<<<<<<<<
 *                 self._parse = self._parse._originalParseMethod
 *         return self
 */
    }
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":1652
 *             if hasattr(self._parse, "_originalParseMethod"):
 *                 self._parse = self._parse._originalParseMethod
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setParseAction(self, *fns, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1635
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set ``breakFlag`` to True to enable, False to
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setBreak", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_breaker);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1654
 *         return self
 * 
 *     def setParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Define one or more actions to perform when successfully matching parse element definition.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_21setParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_20setParseAction, "ParserElement.setParseAction(self, *fns, **kwargs)\n\n        Define one or more actions to perform when successfully matching parse element definition.\n        Parse action fn is a callable method with 0-3 arguments, called as ``fn(s, loc, toks)`` ,\n        ``fn(loc, toks)`` , ``fn(toks)`` , or just ``fn()`` , where:\n\n        - s   = the original string being parsed (see note below)\n        - loc = the location of the matching substring\n        - toks = a list of the matched tokens, packaged as a :class:`ParseResults` object\n\n        If the functions in fns modify the tokens, they can return them as the return\n        value from fn, and the modified list of tokens will replace the original.\n        Otherwise, fn does not need to return any value.\n\n        If None is passed as the parse action, all previously added parse actions for this\n        expression are cleared.\n\n        Optional keyword arguments:\n        - callDuringTry = (default= ``False``) indicate if parse action should be run during lookaheads and alternate testing\n\n        Note: the default parsing behavior is to expand tabs in the input string\n        before starting the parsing process.  See :class:`parseString for more\n        information on parsing strings containing ``<TAB>`` s, and suggested\n        methods to maintain a consistent view of the parsed string, the parse\n        location, and line and column positions within the parsed string.\n\n        Example::\n\n            integer = Word(nums)\n            date_str = integer + '/' + integer + '/' + integer\n\n            date_str.parseString(\"1999/12/31\")  # -> ['1999', '/', '12', '/', '31']\n\n            # use parse action to convert to ints at parse time\n            integer = Word(nums).setParseAction(lambda toks: int(toks[0]))\n            date_str = integer + '/' + integer + '/' + integer\n\n            # note that integer fields are now ints, not strings\n            date_str.parseString(\"1999/12/31\")  # -> [1""999, '/', 12, '/', 31]\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_21setParseAction = {"setParseAction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_21setParseAction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_20setParseAction};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_21setParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fns = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setParseAction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  __pyx_v_fns = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_fns)) {
    __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_fns);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1654, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, used_pos_args, "setParseAction") < 0)) __PYX_ERR(0, 1654, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setParseAction", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 1654, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_fns); __pyx_v_fns = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_20setParseAction(__pyx_self, __pyx_v_self, __pyx_v_fns, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_fns);
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_13ParserElement_14setParseAction_2generator14(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":1697
 *             self.parseAction = []
 *         else:
 *             if not all(callable(fn) for fn in fns):             # <<<<<<<<<<<<<<
 *                 raise TypeError("parse actions must be callable")
 *             self.parseAction = list(map(_trim_arity, list(fns)))
 */

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_14setParseAction_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_18_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1697, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_13ParserElement_14setParseAction_2generator14, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParserElement_setParseAction_loc, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 1697, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setParseAction.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_13ParserElement_14setParseAction_2generator14(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1697, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 1697, __pyx_L1_error) }
  __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1697, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 1697, __pyx_L1_error)
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_fn);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_fn, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyCallable_Check(__pyx_cur_scope->__pyx_v_fn); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1697, __pyx_L1_error)
    __pyx_t_5 = (!__pyx_t_4);
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1654
 *         return self
 * 
 *     def setParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Define one or more actions to perform when successfully matching parse element definition.
 */

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_20setParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_gb_10cPyparsing_13ParserElement_14setParseAction_2generator14 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setParseAction", 1);

  /* "cPyparsing.pyx":1694
 *             date_str.parseString("1999/12/31")  # -> [1999, '/', 12, '/', 31]
 *         """
 *         if list(fns) == [None,]:             # <<<<<<<<<<<<<<
 *             self.parseAction = []
 *         else:
 */
  __pyx_t_1 = PySequence_List(__pyx_v_fns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, Py_None)) __PYX_ERR(0, 1694, __pyx_L1_error);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1694, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1694, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":1695
 *         """
 *         if list(fns) == [None,]:
 *             self.parseAction = []             # <<<<<<<<<<<<<<
 *         else:
 *             if not all(callable(fn) for fn in fns):
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseAction, __pyx_t_3) < 0) __PYX_ERR(0, 1695, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1694
 *             date_str.parseString("1999/12/31")  # -> [1999, '/', 12, '/', 31]
 *         """
 *         if list(fns) == [None,]:             # <<<<<<<<<<<<<<
 *             self.parseAction = []
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":1697
 *             self.parseAction = []
 *         else:
 *             if not all(callable(fn) for fn in fns):             # <<<<<<<<<<<<<<
 *                 raise TypeError("parse actions must be callable")
 *             self.parseAction = list(map(_trim_arity, list(fns)))
 */
  /*else*/ {
    __pyx_t_3 = __pyx_pf_10cPyparsing_13ParserElement_14setParseAction_genexpr(NULL, __pyx_v_fns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1697, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = (!__pyx_t_4);
    if (unlikely(__pyx_t_5)) {

      /* "cPyparsing.pyx":1698
 *         else:
 *             if not all(callable(fn) for fn in fns):
 *                 raise TypeError("parse actions must be callable")             # <<<<<<<<<<<<<<
 *             self.parseAction = list(map(_trim_arity, list(fns)))
 *             self.callDuringTry = kwargs.get("callDuringTry", False)
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__51, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1698, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 1698, __pyx_L1_error)

      /* "cPyparsing.pyx":1697
 *             self.parseAction = []
 *         else:
 *             if not all(callable(fn) for fn in fns):             # <<<<<<<<<<<<<<
 *                 raise TypeError("parse actions must be callable")
 *             self.parseAction = list(map(_trim_arity, list(fns)))
 */
    }

    /* "cPyparsing.pyx":1699
 *             if not all(callable(fn) for fn in fns):
 *                 raise TypeError("parse actions must be callable")
 *             self.parseAction = list(map(_trim_arity, list(fns)))             # <<<<<<<<<<<<<<
 *             self.callDuringTry = kwargs.get("callDuringTry", False)
 *         return self
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_trim_arity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_List(__pyx_v_fns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(0, 1699, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(0, 1699, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PySequence_ListKeepNew(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseAction, __pyx_t_1) < 0) __PYX_ERR(0, 1699, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1700
 *                 raise TypeError("parse actions must be callable")
 *             self.parseAction = list(map(_trim_arity, list(fns)))
 *             self.callDuringTry = kwargs.get("callDuringTry", False)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_callDuringTry, Py_False); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry, __pyx_t_1) < 0) __PYX_ERR(0, 1700, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":1701
 *             self.parseAction = list(map(_trim_arity, list(fns)))
 *             self.callDuringTry = kwargs.get("callDuringTry", False)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def addParseAction(self, *fns, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1654
 *         return self
 * 
 *     def setParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Define one or more actions to perform when successfully matching parse element definition.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_13ParserElement_14setParseAction_2generator14);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1703
 *         return self
 * 
 *     def addParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Add one or more parse actions to expression's list of parse actions. See :class:`setParseAction`.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_23addParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_22addParseAction, "ParserElement.addParseAction(self, *fns, **kwargs)\n\n        Add one or more parse actions to expression's list of parse actions. See :class:`setParseAction`.\n\n        See examples in :class:`copy`.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_23addParseAction = {"addParseAction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_23addParseAction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_22addParseAction};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_23addParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fns = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addParseAction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  __pyx_v_fns = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_fns)) {
    __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_fns);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1703, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, used_pos_args, "addParseAction") < 0)) __PYX_ERR(0, 1703, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("addParseAction", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 1703, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_fns); __pyx_v_fns = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParserElement.addParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_22addParseAction(__pyx_self, __pyx_v_self, __pyx_v_fns, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_fns);
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_22addParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addParseAction", 1);

  /* "cPyparsing.pyx":1709
 *         See examples in :class:`copy`.
 *         """
 *         self.parseAction += list(map(_trim_arity, list(fns)))             # <<<<<<<<<<<<<<
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_trim_arity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PySequence_List(__pyx_v_fns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 1709, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3)) __PYX_ERR(0, 1709, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PySequence_ListKeepNew(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseAction, __pyx_t_3) < 0) __PYX_ERR(0, 1709, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1710
 *         """
 *         self.parseAction += list(map(_trim_arity, list(fns)))
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1710, __pyx_L1_error)
  if (!__pyx_t_5) {
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_callDuringTry, Py_False); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_L3_bool_binop_done:;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry, __pyx_t_3) < 0) __PYX_ERR(0, 1710, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1711
 *         self.parseAction += list(map(_trim_arity, list(fns)))
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def addCondition(self, *fns, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1703
 *         return self
 * 
 *     def addParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Add one or more parse actions to expression's list of parse actions. See :class:`setParseAction`.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.addParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1713
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         :class:`setParseAction` for function call signatures. Unlike ``setParseAction``,
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_25addCondition(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_24addCondition, "ParserElement.addCondition(self, *fns, **kwargs)\nAdd a boolean predicate function to expression's list of parse actions. See\n        :class:`setParseAction` for function call signatures. Unlike ``setParseAction``,\n        functions passed to ``addCondition`` need to return boolean success/fail of the condition.\n\n        Optional keyword arguments:\n        - message = define a custom message to be used in the raised exception\n        - fatal   = if True, will raise ParseFatalException to stop parsing immediately; otherwise will raise ParseException\n\n        Example::\n\n            integer = Word(nums).setParseAction(lambda toks: int(toks[0]))\n            year_int = integer.copy()\n            year_int.addCondition(lambda toks: toks[0] >= 2000, message=\"Only support years 2000 and later\")\n            date_str = year_int + '/' + integer + '/' + integer\n\n            result = date_str.parseString(\"1999/12/31\")  # -> Exception: Only support years 2000 and later (at char 0), (line:1, col:1)\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_25addCondition = {"addCondition", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_25addCondition, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_24addCondition};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_25addCondition(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fns = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addCondition (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  __pyx_v_fns = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_fns)) {
    __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_fns);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1713, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, used_pos_args, "addCondition") < 0)) __PYX_ERR(0, 1713, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("addCondition", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 1713, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_fns); __pyx_v_fns = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParserElement.addCondition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_24addCondition(__pyx_self, __pyx_v_self, __pyx_v_fns, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_fns);
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_24addCondition(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_fn = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addCondition", 1);

  /* "cPyparsing.pyx":1731
 *             result = date_str.parseString("1999/12/31")  # -> Exception: Only support years 2000 and later (at char 0), (line:1, col:1)
 *         """
 *         for fn in fns:             # <<<<<<<<<<<<<<
 *             self.parseAction.append(conditionAsParseAction(fn, message=kwargs.get('message'),
 *                                                            fatal=kwargs.get('fatal', False)))
 */
  __pyx_t_1 = __pyx_v_fns; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1731, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 1731, __pyx_L1_error)
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_fn, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1732
 *         """
 *         for fn in fns:
 *             self.parseAction.append(conditionAsParseAction(fn, message=kwargs.get('message'),             # <<<<<<<<<<<<<<
 *                                                            fatal=kwargs.get('fatal', False)))
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_conditionAsParseAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_fn);
    __Pyx_GIVEREF(__pyx_v_fn);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_fn)) __PYX_ERR(0, 1732, __pyx_L1_error);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_message, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_message, __pyx_t_7) < 0) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":1733
 *         for fn in fns:
 *             self.parseAction.append(conditionAsParseAction(fn, message=kwargs.get('message'),
 *                                                            fatal=kwargs.get('fatal', False)))             # <<<<<<<<<<<<<<
 * 
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)
 */
    __pyx_t_7 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_fatal, Py_False); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_fatal, __pyx_t_7) < 0) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":1732
 *         """
 *         for fn in fns:
 *             self.parseAction.append(conditionAsParseAction(fn, message=kwargs.get('message'),             # <<<<<<<<<<<<<<
 *                                                            fatal=kwargs.get('fatal', False)))
 * 
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_8 = __Pyx_PyObject_Append(__pyx_t_3, __pyx_t_7); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":1731
 *             result = date_str.parseString("1999/12/31")  # -> Exception: Only support years 2000 and later (at char 0), (line:1, col:1)
 *         """
 *         for fn in fns:             # <<<<<<<<<<<<<<
 *             self.parseAction.append(conditionAsParseAction(fn, message=kwargs.get('message'),
 *                                                            fatal=kwargs.get('fatal', False)))
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1735
 *                                                            fatal=kwargs.get('fatal', False)))
 * 
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1735, __pyx_L1_error)
  if (!__pyx_t_9) {
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_1 = __pyx_t_7;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_7 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_callDuringTry, Py_False); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_1 = __pyx_t_7;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_L6_bool_binop_done:;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry, __pyx_t_1) < 0) __PYX_ERR(0, 1735, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1736
 * 
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setFailAction(self, fn):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1713
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         :class:`setParseAction` for function call signatures. Unlike ``setParseAction``,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.addCondition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fn);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1738
 *         return self
 * 
 *     def setFailAction(self, fn):             # <<<<<<<<<<<<<<
 *         """Define action to perform if parsing fails at this expression.
 *            Fail acton fn is a callable function that takes the arguments
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_27setFailAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_26setFailAction, "ParserElement.setFailAction(self, fn)\nDefine action to perform if parsing fails at this expression.\n           Fail acton fn is a callable function that takes the arguments\n           ``fn(s, loc, expr, err)`` where:\n           - s = string being parsed\n           - loc = location where expression match was attempted and failed\n           - expr = the parse expression that failed\n           - err = the exception thrown\n           The function returns no value.  It may throw :class:`ParseFatalException`\n           if it is desired to stop parsing immediately.");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_27setFailAction = {"setFailAction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_27setFailAction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_26setFailAction};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_27setFailAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fn = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setFailAction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_fn,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1738, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fn)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1738, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("setFailAction", 1, 2, 2, 1); __PYX_ERR(0, 1738, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setFailAction") < 0)) __PYX_ERR(0, 1738, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_fn = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setFailAction", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1738, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.setFailAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_26setFailAction(__pyx_self, __pyx_v_self, __pyx_v_fn);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_26setFailAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fn) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setFailAction", 1);

  /* "cPyparsing.pyx":1748
 *            The function returns no value.  It may throw :class:`ParseFatalException`
 *            if it is desired to stop parsing immediately."""
 *         self.failAction = fn             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_failAction, __pyx_v_fn) < 0) __PYX_ERR(0, 1748, __pyx_L1_error)

  /* "cPyparsing.pyx":1749
 *            if it is desired to stop parsing immediately."""
 *         self.failAction = fn
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1738
 *         return self
 * 
 *     def setFailAction(self, fn):             # <<<<<<<<<<<<<<
 *         """Define action to perform if parsing fails at this expression.
 *            Fail acton fn is a callable function that takes the arguments
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setFailAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1770
 *     #                 exprsFound = True
 *     #     return loc
 *     def _skipIgnorables(self, instring, loc):             # <<<<<<<<<<<<<<
 *         exprsFound = True
 *         while exprsFound:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_29_skipIgnorables(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_28_skipIgnorables, "ParserElement._skipIgnorables(self, instring, loc)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_29_skipIgnorables = {"_skipIgnorables", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_29_skipIgnorables, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_28_skipIgnorables};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_29_skipIgnorables(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_skipIgnorables (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1770, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1770, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_skipIgnorables", 1, 3, 3, 1); __PYX_ERR(0, 1770, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1770, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_skipIgnorables", 1, 3, 3, 2); __PYX_ERR(0, 1770, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_skipIgnorables") < 0)) __PYX_ERR(0, 1770, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_skipIgnorables", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1770, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement._skipIgnorables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_28_skipIgnorables(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_28_skipIgnorables(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc) {
  int __pyx_v_exprsFound;
  PyObject *__pyx_v_e = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_dummy = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_skipIgnorables", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":1771
 *     #     return loc
 *     def _skipIgnorables(self, instring, loc):
 *         exprsFound = True             # <<<<<<<<<<<<<<
 *         while exprsFound:
 *             exprsFound = False
 */
  __pyx_v_exprsFound = 1;

  /* "cPyparsing.pyx":1772
 *     def _skipIgnorables(self, instring, loc):
 *         exprsFound = True
 *         while exprsFound:             # <<<<<<<<<<<<<<
 *             exprsFound = False
 *             for e in self.ignoreExprs:
 */
  while (1) {
    if (!__pyx_v_exprsFound) break;

    /* "cPyparsing.pyx":1773
 *         exprsFound = True
 *         while exprsFound:
 *             exprsFound = False             # <<<<<<<<<<<<<<
 *             for e in self.ignoreExprs:
 *                 try:
 */
    __pyx_v_exprsFound = 0;

    /* "cPyparsing.pyx":1774
 *         while exprsFound:
 *             exprsFound = False
 *             for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 try:
 *                     while 1:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1774, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1774, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1774, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1774, __pyx_L1_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 1774, __pyx_L1_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1774, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1774, __pyx_L1_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 1774, __pyx_L1_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1774, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1774, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":1775
 *             exprsFound = False
 *             for e in self.ignoreExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     while 1:
 *                         loc, dummy = e._parse(instring, loc)
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        /*try:*/ {

          /* "cPyparsing.pyx":1776
 *             for e in self.ignoreExprs:
 *                 try:
 *                     while 1:             # <<<<<<<<<<<<<<
 *                         loc, dummy = e._parse(instring, loc)
 *                         exprsFound = True
 */
          while (1) {

            /* "cPyparsing.pyx":1777
 *                 try:
 *                     while 1:
 *                         loc, dummy = e._parse(instring, loc)             # <<<<<<<<<<<<<<
 *                         exprsFound = True
 *                 except ParseException:
 */
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1777, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_9 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_9)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_v_instring, __pyx_v_loc};
              __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1777, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
              PyObject* sequence = __pyx_t_1;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 2)) {
                if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 1777, __pyx_L7_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
              } else {
                __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
              }
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_9);
              #else
              __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1777, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_8);
              __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1777, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_9);
              #endif
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else {
              Py_ssize_t index = -1;
              __pyx_t_11 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1777, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_11);
              index = 0; __pyx_t_8 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_8)) goto __pyx_L17_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_8);
              index = 1; __pyx_t_9 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_9)) goto __pyx_L17_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_9);
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_11), 2) < 0) __PYX_ERR(0, 1777, __pyx_L7_error)
              __pyx_t_12 = NULL;
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              goto __pyx_L18_unpacking_done;
              __pyx_L17_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              __pyx_t_12 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 1777, __pyx_L7_error)
              __pyx_L18_unpacking_done:;
            }
            __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_8);
            __pyx_t_8 = 0;
            __Pyx_XDECREF_SET(__pyx_v_dummy, __pyx_t_9);
            __pyx_t_9 = 0;

            /* "cPyparsing.pyx":1778
 *                     while 1:
 *                         loc, dummy = e._parse(instring, loc)
 *                         exprsFound = True             # <<<<<<<<<<<<<<
 *                 except ParseException:
 *                     pass
 */
            __pyx_v_exprsFound = 1;
          }

          /* "cPyparsing.pyx":1775
 *             exprsFound = False
 *             for e in self.ignoreExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     while 1:
 *                         loc, dummy = e._parse(instring, loc)
 */
        }
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L14_try_end;
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "cPyparsing.pyx":1779
 *                         loc, dummy = e._parse(instring, loc)
 *                         exprsFound = True
 *                 except ParseException:             # <<<<<<<<<<<<<<
 *                     pass
 *         return loc
 */
        __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_9, &__pyx_t_8);
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1779, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_11);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_ErrRestore(__pyx_t_1, __pyx_t_9, __pyx_t_8);
        __pyx_t_1 = 0; __pyx_t_9 = 0; __pyx_t_8 = 0;
        if (__pyx_t_10) {
          __Pyx_ErrRestore(0,0,0);
          goto __pyx_L8_exception_handled;
        }
        goto __pyx_L9_except_error;

        /* "cPyparsing.pyx":1775
 *             exprsFound = False
 *             for e in self.ignoreExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     while 1:
 *                         loc, dummy = e._parse(instring, loc)
 */
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
        goto __pyx_L1_error;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
        __pyx_L14_try_end:;
      }

      /* "cPyparsing.pyx":1774
 *         while exprsFound:
 *             exprsFound = False
 *             for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 try:
 *                     while 1:
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "cPyparsing.pyx":1781
 *                 except ParseException:
 *                     pass
 *         return loc             # <<<<<<<<<<<<<<
 * 
 *     def preParse(self, instring, loc):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_r = __pyx_v_loc;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1770
 *     #                 exprsFound = True
 *     #     return loc
 *     def _skipIgnorables(self, instring, loc):             # <<<<<<<<<<<<<<
 *         exprsFound = True
 *         while exprsFound:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.ParserElement._skipIgnorables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_dummy);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1783
 *         return loc
 * 
 *     def preParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_31preParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_30preParse, "ParserElement.preParse(self, instring, loc)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_31preParse = {"preParse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_31preParse, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_30preParse};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_31preParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("preParse (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1783, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1783, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, 1); __PYX_ERR(0, 1783, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1783, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, 2); __PYX_ERR(0, 1783, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "preParse") < 0)) __PYX_ERR(0, 1783, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1783, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.preParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_30preParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_30preParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc) {
  PyObject *__pyx_v_wt = NULL;
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("preParse", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":1784
 * 
 *     def preParse(self, instring, loc):
 *         if self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             loc = self._skipIgnorables(instring, loc)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1784, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1785
 *     def preParse(self, instring, loc):
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)             # <<<<<<<<<<<<<<
 * 
 *         if self.skipWhitespace:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_skipIgnorables); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1785, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_instring, __pyx_v_loc};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1785, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1784
 * 
 *     def preParse(self, instring, loc):
 *         if self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             loc = self._skipIgnorables(instring, loc)
 * 
 */
  }

  /* "cPyparsing.pyx":1787
 *             loc = self._skipIgnorables(instring, loc)
 * 
 *         if self.skipWhitespace:             # <<<<<<<<<<<<<<
 *             wt = self.whiteChars
 *             instrlen = len(instring)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1787, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1788
 * 
 *         if self.skipWhitespace:
 *             wt = self.whiteChars             # <<<<<<<<<<<<<<
 *             instrlen = len(instring)
 *             while loc < instrlen and instring[loc] in wt:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_wt = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1789
 *         if self.skipWhitespace:
 *             wt = self.whiteChars
 *             instrlen = len(instring)             # <<<<<<<<<<<<<<
 *             while loc < instrlen and instring[loc] in wt:
 *                 loc += 1
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1789, __pyx_L1_error)
    __pyx_v_instrlen = __pyx_t_6;

    /* "cPyparsing.pyx":1790
 *             wt = self.whiteChars
 *             instrlen = len(instring)
 *             while loc < instrlen and instring[loc] in wt:             # <<<<<<<<<<<<<<
 *                 loc += 1
 * 
 */
    while (1) {
      __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_instrlen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1790, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1790, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1790, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
      } else {
        __pyx_t_2 = __pyx_t_7;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1790, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_v_wt, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1790, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_2 = __pyx_t_7;
      __pyx_L7_bool_binop_done:;
      if (!__pyx_t_2) break;

      /* "cPyparsing.pyx":1791
 *             instrlen = len(instring)
 *             while loc < instrlen and instring[loc] in wt:
 *                 loc += 1             # <<<<<<<<<<<<<<
 * 
 *         return loc
 */
      __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1791, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_3);
      __pyx_t_3 = 0;
    }

    /* "cPyparsing.pyx":1787
 *             loc = self._skipIgnorables(instring, loc)
 * 
 *         if self.skipWhitespace:             # <<<<<<<<<<<<<<
 *             wt = self.whiteChars
 *             instrlen = len(instring)
 */
  }

  /* "cPyparsing.pyx":1793
 *                 loc += 1
 * 
 *         return loc             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_r = __pyx_v_loc;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1783
 *         return loc
 * 
 *     def preParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.preParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wt);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1795
 *         return loc
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_33parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_32parseImpl, "ParserElement.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_33parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_33parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_32parseImpl};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_33parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1795, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1795, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 1795, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1795, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 1795, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1795, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 1795, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 1795, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_32parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_32parseImpl(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":1796
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 *     def postParse(self, instring, loc, tokenlist):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_loc)) __PYX_ERR(0, 1796, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1)) __PYX_ERR(0, 1796, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1795
 *         return loc
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1798
 *         return loc, []
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return tokenlist
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_35postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_34postParse, "ParserElement.postParse(self, instring, loc, tokenlist)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_35postParse = {"postParse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_35postParse, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_34postParse};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_35postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_tokenlist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1798, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1798, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 1798, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1798, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 1798, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tokenlist)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1798, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 1798, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "postParse") < 0)) __PYX_ERR(0, 1798, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 1798, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_34postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_34postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse", 1);

  /* "cPyparsing.pyx":1799
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         return tokenlist             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_tokenlist);
  __pyx_r = __pyx_v_tokenlist;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1798
 *         return loc, []
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return tokenlist
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1899
 * 
 *     #     return loc, retTokens
 *     def _parseNoCache(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] TRY, MATCH, FAIL are constants
 *         debugging = (self.debug)  # and doActions)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_37_parseNoCache(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_36_parseNoCache, "ParserElement._parseNoCache(self, instring, loc, doActions=True, callPreParse=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_37_parseNoCache = {"_parseNoCache", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_37_parseNoCache, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_36_parseNoCache};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_37_parseNoCache(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_v_callPreParse = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_parseNoCache (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,&__pyx_n_s_callPreParse,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1899, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1899, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_parseNoCache", 0, 3, 5, 1); __PYX_ERR(0, 1899, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1899, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_parseNoCache", 0, 3, 5, 2); __PYX_ERR(0, 1899, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1899, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_callPreParse);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1899, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_parseNoCache") < 0)) __PYX_ERR(0, 1899, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
    __pyx_v_callPreParse = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_parseNoCache", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 1899, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_36_parseNoCache(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_36_parseNoCache(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse) {
  PyObject *__pyx_v_debugging = NULL;
  PyObject *__pyx_v_preloc = NULL;
  PyObject *__pyx_v_tokensStart = NULL;
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_v_retTokens = NULL;
  PyObject *__pyx_v_fn = NULL;
  PyObject *__pyx_v_parse_action_exc = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *(*__pyx_t_15)(PyObject *);
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_t_20;
  char const *__pyx_t_21;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *(*__pyx_t_25)(PyObject *);
  char const *__pyx_t_26;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  char const *__pyx_t_30;
  char const *__pyx_t_31;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parseNoCache", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":1901
 *     def _parseNoCache(self, instring, loc, doActions=True, callPreParse=True):
 *         # [CPYPARSING] TRY, MATCH, FAIL are constants
 *         debugging = (self.debug)  # and doActions)             # <<<<<<<<<<<<<<
 * 
 *         if debugging or self.failAction:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debug); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_debugging = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1903
 *         debugging = (self.debug)  # and doActions)
 * 
 *         if debugging or self.failAction:             # <<<<<<<<<<<<<<
 *             # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *             if self.debugActions[TRY]:
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1903, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1903, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1905
 *         if debugging or self.failAction:
 *             # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *             if self.debugActions[TRY]:             # <<<<<<<<<<<<<<
 *                 self.debugActions[TRY](instring, loc, self)
 *             try:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_TRY); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1905, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1906
 *             # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *             if self.debugActions[TRY]:
 *                 self.debugActions[TRY](instring, loc, self)             # <<<<<<<<<<<<<<
 *             try:
 *                 if callPreParse and self.callPreparse:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1906, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_TRY); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1906, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1906, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc, __pyx_v_self};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1906, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":1905
 *         if debugging or self.failAction:
 *             # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *             if self.debugActions[TRY]:             # <<<<<<<<<<<<<<
 *                 self.debugActions[TRY](instring, loc, self)
 *             try:
 */
    }

    /* "cPyparsing.pyx":1907
 *             if self.debugActions[TRY]:
 *                 self.debugActions[TRY](instring, loc, self)
 *             try:             # <<<<<<<<<<<<<<
 *                 if callPreParse and self.callPreparse:
 *                     preloc = self.preParse(instring, loc)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "cPyparsing.pyx":1908
 *                 self.debugActions[TRY](instring, loc, self)
 *             try:
 *                 if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                     preloc = self.preParse(instring, loc)
 *                 else:
 */
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_callPreParse); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1908, __pyx_L7_error)
        if (__pyx_t_3) {
        } else {
          __pyx_t_2 = __pyx_t_3;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1908, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1908, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_2 = __pyx_t_3;
        __pyx_L14_bool_binop_done:;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":1909
 *             try:
 *                 if callPreParse and self.callPreparse:
 *                     preloc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *                 else:
 *                     preloc = loc
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1909, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_1 = NULL;
          __pyx_t_7 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_7 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1909, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
          __pyx_v_preloc = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "cPyparsing.pyx":1908
 *                 self.debugActions[TRY](instring, loc, self)
 *             try:
 *                 if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                     preloc = self.preParse(instring, loc)
 *                 else:
 */
          goto __pyx_L13;
        }

        /* "cPyparsing.pyx":1911
 *                     preloc = self.preParse(instring, loc)
 *                 else:
 *                     preloc = loc             # <<<<<<<<<<<<<<
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):
 */
        /*else*/ {
          __Pyx_INCREF(__pyx_v_loc);
          __pyx_v_preloc = __pyx_v_loc;
        }
        __pyx_L13:;

        /* "cPyparsing.pyx":1912
 *                 else:
 *                     preloc = loc
 *                 tokensStart = preloc             # <<<<<<<<<<<<<<
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:
 */
        __Pyx_INCREF(__pyx_v_preloc);
        __pyx_v_tokensStart = __pyx_v_preloc;

        /* "cPyparsing.pyx":1913
 *                     preloc = loc
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                     try:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1913, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1913, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (!__pyx_t_3) {
        } else {
          __pyx_t_2 = __pyx_t_3;
          goto __pyx_L17_bool_binop_done;
        }
        __pyx_t_11 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1913, __pyx_L7_error)
        __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1913, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyObject_RichCompare(__pyx_v_preloc, __pyx_t_5, Py_GE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1913, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1913, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_2 = __pyx_t_3;
        __pyx_L17_bool_binop_done:;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":1914
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:             # <<<<<<<<<<<<<<
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:
 */
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_14);
            /*try:*/ {

              /* "cPyparsing.pyx":1915
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                     except IndexError:
 *                         raise ParseException(instring, len(instring), self.errmsg, self)
 */
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1915, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_1 = NULL;
              __pyx_t_7 = 0;
              #if CYTHON_UNPACK_METHODS
              if (likely(PyMethod_Check(__pyx_t_5))) {
                __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
                if (likely(__pyx_t_1)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                  __Pyx_INCREF(__pyx_t_1);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_5, function);
                  __pyx_t_7 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
                __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1915, __pyx_L19_error)
                __Pyx_GOTREF(__pyx_t_6);
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              }
              if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
                PyObject* sequence = __pyx_t_6;
                Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                if (unlikely(size != 2)) {
                  if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                  else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                  __PYX_ERR(0, 1915, __pyx_L19_error)
                }
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                if (likely(PyTuple_CheckExact(sequence))) {
                  __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
                  __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
                } else {
                  __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
                  __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
                }
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(__pyx_t_1);
                #else
                __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1915, __pyx_L19_error)
                __Pyx_GOTREF(__pyx_t_5);
                __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1915, __pyx_L19_error)
                __Pyx_GOTREF(__pyx_t_1);
                #endif
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              } else {
                Py_ssize_t index = -1;
                __pyx_t_4 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1915, __pyx_L19_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
                index = 0; __pyx_t_5 = __pyx_t_15(__pyx_t_4); if (unlikely(!__pyx_t_5)) goto __pyx_L25_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_5);
                index = 1; __pyx_t_1 = __pyx_t_15(__pyx_t_4); if (unlikely(!__pyx_t_1)) goto __pyx_L25_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_1);
                if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_4), 2) < 0) __PYX_ERR(0, 1915, __pyx_L19_error)
                __pyx_t_15 = NULL;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                goto __pyx_L26_unpacking_done;
                __pyx_L25_unpacking_failed:;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __pyx_t_15 = NULL;
                if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                __PYX_ERR(0, 1915, __pyx_L19_error)
                __pyx_L26_unpacking_done:;
              }
              __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_5);
              __pyx_t_5 = 0;
              __pyx_v_tokens = __pyx_t_1;
              __pyx_t_1 = 0;

              /* "cPyparsing.pyx":1914
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:             # <<<<<<<<<<<<<<
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:
 */
            }
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            goto __pyx_L24_try_end;
            __pyx_L19_error:;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "cPyparsing.pyx":1916
 *                     try:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:             # <<<<<<<<<<<<<<
 *                         raise ParseException(instring, len(instring), self.errmsg, self)
 *                 else:
 */
            __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
            if (__pyx_t_7) {
              __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_5) < 0) __PYX_ERR(0, 1916, __pyx_L21_except_error)
              __Pyx_XGOTREF(__pyx_t_6);
              __Pyx_XGOTREF(__pyx_t_1);
              __Pyx_XGOTREF(__pyx_t_5);

              /* "cPyparsing.pyx":1917
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:
 *                         raise ParseException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *                 else:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
              __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1917, __pyx_L21_except_error)
              __Pyx_GOTREF(__pyx_t_16);
              __pyx_t_11 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1917, __pyx_L21_except_error)
              __pyx_t_17 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1917, __pyx_L21_except_error)
              __Pyx_GOTREF(__pyx_t_17);
              __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1917, __pyx_L21_except_error)
              __Pyx_GOTREF(__pyx_t_18);
              __pyx_t_19 = NULL;
              __pyx_t_7 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_16))) {
                __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_16);
                if (likely(__pyx_t_19)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
                  __Pyx_INCREF(__pyx_t_19);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_16, function);
                  __pyx_t_7 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[5] = {__pyx_t_19, __pyx_v_instring, __pyx_t_17, __pyx_t_18, __pyx_v_self};
                __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
                __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
                __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
                __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
                if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1917, __pyx_L21_except_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
              }
              __Pyx_Raise(__pyx_t_4, 0, 0, 0);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __PYX_ERR(0, 1917, __pyx_L21_except_error)
            }
            goto __pyx_L21_except_error;

            /* "cPyparsing.pyx":1914
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:             # <<<<<<<<<<<<<<
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:
 */
            __pyx_L21_except_error:;
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
            goto __pyx_L7_error;
            __pyx_L24_try_end:;
          }

          /* "cPyparsing.pyx":1913
 *                     preloc = loc
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                     try:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
          goto __pyx_L16;
        }

        /* "cPyparsing.pyx":1919
 *                         raise ParseException(instring, len(instring), self.errmsg, self)
 *                 else:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *             except Exception as err:
 *                 # ~ print ("Exception raised:", err)
 */
        /*else*/ {
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1919, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_6 = NULL;
          __pyx_t_7 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_7 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_6, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1919, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
            PyObject* sequence = __pyx_t_5;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 1919, __pyx_L7_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_6);
            #else
            __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1919, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1919, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_4 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1919, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
            index = 0; __pyx_t_1 = __pyx_t_15(__pyx_t_4); if (unlikely(!__pyx_t_1)) goto __pyx_L29_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_1);
            index = 1; __pyx_t_6 = __pyx_t_15(__pyx_t_4); if (unlikely(!__pyx_t_6)) goto __pyx_L29_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_6);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_4), 2) < 0) __PYX_ERR(0, 1919, __pyx_L7_error)
            __pyx_t_15 = NULL;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            goto __pyx_L30_unpacking_done;
            __pyx_L29_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_15 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 1919, __pyx_L7_error)
            __pyx_L30_unpacking_done:;
          }
          __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
          __pyx_t_1 = 0;
          __pyx_v_tokens = __pyx_t_6;
          __pyx_t_6 = 0;
        }
        __pyx_L16:;

        /* "cPyparsing.pyx":1907
 *             if self.debugActions[TRY]:
 *                 self.debugActions[TRY](instring, loc, self)
 *             try:             # <<<<<<<<<<<<<<
 *                 if callPreParse and self.callPreparse:
 *                     preloc = self.preParse(instring, loc)
 */
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L12_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
      __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":1920
 *                 else:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *             except Exception as err:             # <<<<<<<<<<<<<<
 *                 # ~ print ("Exception raised:", err)
 *                 if self.debugActions[FAIL]:
 */
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_7) {
        __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_1) < 0) __PYX_ERR(0, 1920, __pyx_L9_except_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_err = __pyx_t_6;
        /*try:*/ {

          /* "cPyparsing.pyx":1922
 *             except Exception as err:
 *                 # ~ print ("Exception raised:", err)
 *                 if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                     self.debugActions[FAIL](instring, tokensStart, self, err)
 *                 if self.failAction:
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1922, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1922, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_18 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_16); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1922, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_18); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1922, __pyx_L36_error)
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":1923
 *                 # ~ print ("Exception raised:", err)
 *                 if self.debugActions[FAIL]:
 *                     self.debugActions[FAIL](instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                 if self.failAction:
 *                     self.failAction(instring, tokensStart, self, err)
 */
            __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1923, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1923, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_17 = __Pyx_PyObject_GetItem(__pyx_t_16, __pyx_t_4); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1923, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_v_tokensStart)) { __Pyx_RaiseUnboundLocalError("tokensStart"); __PYX_ERR(0, 1923, __pyx_L36_error) }
            __pyx_t_4 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_17))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_17);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_17, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
              __pyx_t_18 = __Pyx_PyObject_FastCall(__pyx_t_17, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1923, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_18);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            }
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

            /* "cPyparsing.pyx":1922
 *             except Exception as err:
 *                 # ~ print ("Exception raised:", err)
 *                 if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                     self.debugActions[FAIL](instring, tokensStart, self, err)
 *                 if self.failAction:
 */
          }

          /* "cPyparsing.pyx":1924
 *                 if self.debugActions[FAIL]:
 *                     self.debugActions[FAIL](instring, tokensStart, self, err)
 *                 if self.failAction:             # <<<<<<<<<<<<<<
 *                     self.failAction(instring, tokensStart, self, err)
 *                 raise
 */
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1924, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_18); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1924, __pyx_L36_error)
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":1925
 *                     self.debugActions[FAIL](instring, tokensStart, self, err)
 *                 if self.failAction:
 *                     self.failAction(instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                 raise
 *         else:
 */
            __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1925, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_17);
            if (unlikely(!__pyx_v_tokensStart)) { __Pyx_RaiseUnboundLocalError("tokensStart"); __PYX_ERR(0, 1925, __pyx_L36_error) }
            __pyx_t_4 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_17))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_17);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_17, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
              __pyx_t_18 = __Pyx_PyObject_FastCall(__pyx_t_17, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1925, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_18);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            }
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

            /* "cPyparsing.pyx":1924
 *                 if self.debugActions[FAIL]:
 *                     self.debugActions[FAIL](instring, tokensStart, self, err)
 *                 if self.failAction:             # <<<<<<<<<<<<<<
 *                     self.failAction(instring, tokensStart, self, err)
 *                 raise
 */
          }

          /* "cPyparsing.pyx":1926
 *                 if self.failAction:
 *                     self.failAction(instring, tokensStart, self, err)
 *                 raise             # <<<<<<<<<<<<<<
 *         else:
 *             if callPreParse and self.callPreparse:
 */
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_1);
          __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_6, __pyx_t_1);
          __pyx_t_5 = 0; __pyx_t_6 = 0; __pyx_t_1 = 0; 
          __PYX_ERR(0, 1926, __pyx_L36_error)
        }

        /* "cPyparsing.pyx":1920
 *                 else:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *             except Exception as err:             # <<<<<<<<<<<<<<
 *                 # ~ print ("Exception raised:", err)
 *                 if self.debugActions[FAIL]:
 */
        /*finally:*/ {
          __pyx_L36_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_12 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_13, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_13, &__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_23);
            __Pyx_XGOTREF(__pyx_t_24);
            __pyx_t_7 = __pyx_lineno; __pyx_t_20 = __pyx_clineno; __pyx_t_21 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_XGIVEREF(__pyx_t_23);
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
            }
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ErrRestore(__pyx_t_14, __pyx_t_13, __pyx_t_12);
            __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_12 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
            __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_20; __pyx_filename = __pyx_t_21;
            goto __pyx_L9_except_error;
          }
        }
      }
      goto __pyx_L9_except_error;

      /* "cPyparsing.pyx":1907
 *             if self.debugActions[TRY]:
 *                 self.debugActions[TRY](instring, loc, self)
 *             try:             # <<<<<<<<<<<<<<
 *                 if callPreParse and self.callPreparse:
 *                     preloc = self.preParse(instring, loc)
 */
      __pyx_L9_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L12_try_end:;
    }

    /* "cPyparsing.pyx":1903
 *         debugging = (self.debug)  # and doActions)
 * 
 *         if debugging or self.failAction:             # <<<<<<<<<<<<<<
 *             # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *             if self.debugActions[TRY]:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":1928
 *                 raise
 *         else:
 *             if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                 preloc = self.preParse(instring, loc)
 *             else:
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_callPreParse); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1928, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L45_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1928, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L45_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1929
 *         else:
 *             if callPreParse and self.callPreparse:
 *                 preloc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *             else:
 *                 preloc = loc
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1929, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = NULL;
      __pyx_t_20 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_20 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_20, 2+__pyx_t_20);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1929, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_v_preloc = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":1928
 *                 raise
 *         else:
 *             if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                 preloc = self.preParse(instring, loc)
 *             else:
 */
      goto __pyx_L44;
    }

    /* "cPyparsing.pyx":1931
 *                 preloc = self.preParse(instring, loc)
 *             else:
 *                 preloc = loc             # <<<<<<<<<<<<<<
 *             tokensStart = preloc
 *             if self.mayIndexError or preloc >= len(instring):
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_v_loc);
      __pyx_v_preloc = __pyx_v_loc;
    }
    __pyx_L44:;

    /* "cPyparsing.pyx":1932
 *             else:
 *                 preloc = loc
 *             tokensStart = preloc             # <<<<<<<<<<<<<<
 *             if self.mayIndexError or preloc >= len(instring):
 *                 try:
 */
    __Pyx_INCREF(__pyx_v_preloc);
    __pyx_v_tokensStart = __pyx_v_preloc;

    /* "cPyparsing.pyx":1933
 *                 preloc = loc
 *             tokensStart = preloc
 *             if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1933, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1933, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L48_bool_binop_done;
    }
    __pyx_t_11 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1933, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1933, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyObject_RichCompare(__pyx_v_preloc, __pyx_t_1, Py_GE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1933, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1933, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L48_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1934
 *             tokensStart = preloc
 *             if self.mayIndexError or preloc >= len(instring):
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_9, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "cPyparsing.pyx":1935
 *             if self.mayIndexError or preloc >= len(instring):
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                 except IndexError:
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1935, __pyx_L50_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_5 = NULL;
          __pyx_t_20 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_20 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
            __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_20, 3+__pyx_t_20);
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1935, __pyx_L50_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
            PyObject* sequence = __pyx_t_6;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 1935, __pyx_L50_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_5);
            #else
            __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1935, __pyx_L50_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1935, __pyx_L50_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_18 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1935, __pyx_L50_error)
            __Pyx_GOTREF(__pyx_t_18);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_18);
            index = 0; __pyx_t_1 = __pyx_t_15(__pyx_t_18); if (unlikely(!__pyx_t_1)) goto __pyx_L56_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_1);
            index = 1; __pyx_t_5 = __pyx_t_15(__pyx_t_18); if (unlikely(!__pyx_t_5)) goto __pyx_L56_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_5);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_18), 2) < 0) __PYX_ERR(0, 1935, __pyx_L50_error)
            __pyx_t_15 = NULL;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            goto __pyx_L57_unpacking_done;
            __pyx_L56_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            __pyx_t_15 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 1935, __pyx_L50_error)
            __pyx_L57_unpacking_done:;
          }
          __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
          __pyx_t_1 = 0;
          __pyx_v_tokens = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "cPyparsing.pyx":1934
 *             tokensStart = preloc
 *             if self.mayIndexError or preloc >= len(instring):
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 */
        }
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L55_try_end;
        __pyx_L50_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "cPyparsing.pyx":1936
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:             # <<<<<<<<<<<<<<
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 *             else:
 */
        __pyx_t_20 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
        if (__pyx_t_20) {
          __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(0, 1936, __pyx_L52_except_error)
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_1);

          /* "cPyparsing.pyx":1937
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 *                     raise ParseException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *             else:
 *                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1937, __pyx_L52_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_11 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1937, __pyx_L52_except_error)
          __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1937, __pyx_L52_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1937, __pyx_L52_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_19 = NULL;
          __pyx_t_20 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_19)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_19);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
              __pyx_t_20 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_19, __pyx_v_instring, __pyx_t_4, __pyx_t_16, __pyx_v_self};
            __pyx_t_18 = __Pyx_PyObject_FastCall(__pyx_t_17, __pyx_callargs+1-__pyx_t_20, 4+__pyx_t_20);
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1937, __pyx_L52_except_error)
            __Pyx_GOTREF(__pyx_t_18);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          }
          __Pyx_Raise(__pyx_t_18, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __PYX_ERR(0, 1937, __pyx_L52_except_error)
        }
        goto __pyx_L52_except_error;

        /* "cPyparsing.pyx":1934
 *             tokensStart = preloc
 *             if self.mayIndexError or preloc >= len(instring):
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 */
        __pyx_L52_except_error:;
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L55_try_end:;
      }

      /* "cPyparsing.pyx":1933
 *                 preloc = loc
 *             tokensStart = preloc
 *             if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
      goto __pyx_L47;
    }

    /* "cPyparsing.pyx":1939
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 *             else:
 *                 loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 * 
 *         tokens = self.postParse(instring, loc, tokens)
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1939, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_20 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_20 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_6, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_20, 3+__pyx_t_20);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1939, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1939, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1939, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1939, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_18 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1939, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_18);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_18);
        index = 0; __pyx_t_5 = __pyx_t_15(__pyx_t_18); if (unlikely(!__pyx_t_5)) goto __pyx_L60_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 1; __pyx_t_6 = __pyx_t_15(__pyx_t_18); if (unlikely(!__pyx_t_6)) goto __pyx_L60_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_18), 2) < 0) __PYX_ERR(0, 1939, __pyx_L1_error)
        __pyx_t_15 = NULL;
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
        goto __pyx_L61_unpacking_done;
        __pyx_L60_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
        __pyx_t_15 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1939, __pyx_L1_error)
        __pyx_L61_unpacking_done:;
      }
      __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_v_tokens = __pyx_t_6;
      __pyx_t_6 = 0;
    }
    __pyx_L47:;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":1941
 *                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 * 
 *         tokens = self.postParse(instring, loc, tokens)             # <<<<<<<<<<<<<<
 * 
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_postParse); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = NULL;
  __pyx_t_20 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_20 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokens};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_20, 3+__pyx_t_20);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1941, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1943
 *         tokens = self.postParse(instring, loc, tokens)
 * 
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)             # <<<<<<<<<<<<<<
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_tokens);
  __Pyx_GIVEREF(__pyx_v_tokens);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_tokens)) __PYX_ERR(0, 1943, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6)) __PYX_ERR(0, 1943, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_asList, __pyx_t_18) < 0) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_modal, __pyx_t_18) < 0) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_18 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_retTokens = __pyx_t_18;
  __pyx_t_18 = 0;

  /* "cPyparsing.pyx":1944
 * 
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *         if self.parseAction and (doActions or self.callDuringTry):             # <<<<<<<<<<<<<<
 *             if debugging:
 *                 try:
 */
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_18); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L63_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_doActions); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1944, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L63_bool_binop_done;
  }
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_18); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L63_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1945
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:             # <<<<<<<<<<<<<<
 *                 try:
 *                     for fn in self.parseAction:
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1945, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1946
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:
 *                 try:             # <<<<<<<<<<<<<<
 *                     for fn in self.parseAction:
 *                         try:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        /*try:*/ {

          /* "cPyparsing.pyx":1947
 *             if debugging:
 *                 try:
 *                     for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)
 */
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1947, __pyx_L67_error)
          __Pyx_GOTREF(__pyx_t_18);
          if (likely(PyList_CheckExact(__pyx_t_18)) || PyTuple_CheckExact(__pyx_t_18)) {
            __pyx_t_6 = __pyx_t_18; __Pyx_INCREF(__pyx_t_6);
            __pyx_t_11 = 0;
            __pyx_t_25 = NULL;
          } else {
            __pyx_t_11 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_18); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1947, __pyx_L67_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_25 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 1947, __pyx_L67_error)
          }
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          for (;;) {
            if (likely(!__pyx_t_25)) {
              if (likely(PyList_CheckExact(__pyx_t_6))) {
                {
                  Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
                  #if !CYTHON_ASSUME_SAFE_MACROS
                  if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1947, __pyx_L67_error)
                  #endif
                  if (__pyx_t_11 >= __pyx_temp) break;
                }
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_18 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_11); __Pyx_INCREF(__pyx_t_18); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1947, __pyx_L67_error)
                #else
                __pyx_t_18 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1947, __pyx_L67_error)
                __Pyx_GOTREF(__pyx_t_18);
                #endif
              } else {
                {
                  Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
                  #if !CYTHON_ASSUME_SAFE_MACROS
                  if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1947, __pyx_L67_error)
                  #endif
                  if (__pyx_t_11 >= __pyx_temp) break;
                }
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_18 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_11); __Pyx_INCREF(__pyx_t_18); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1947, __pyx_L67_error)
                #else
                __pyx_t_18 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1947, __pyx_L67_error)
                __Pyx_GOTREF(__pyx_t_18);
                #endif
              }
            } else {
              __pyx_t_18 = __pyx_t_25(__pyx_t_6);
              if (unlikely(!__pyx_t_18)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 1947, __pyx_L67_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_18);
            }
            __Pyx_XDECREF_SET(__pyx_v_fn, __pyx_t_18);
            __pyx_t_18 = 0;

            /* "cPyparsing.pyx":1948
 *                 try:
 *                     for fn in self.parseAction:
 *                         try:             # <<<<<<<<<<<<<<
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:
 */
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_24, &__pyx_t_23, &__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_24);
              __Pyx_XGOTREF(__pyx_t_23);
              __Pyx_XGOTREF(__pyx_t_22);
              /*try:*/ {

                /* "cPyparsing.pyx":1949
 *                     for fn in self.parseAction:
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)             # <<<<<<<<<<<<<<
 *                         except IndexError as parse_action_exc:
 *                             exc = ParseException("exception raised in parse action")
 */
                __Pyx_INCREF(__pyx_v_fn);
                __pyx_t_5 = __pyx_v_fn; __pyx_t_1 = NULL;
                __pyx_t_20 = 0;
                #if CYTHON_UNPACK_METHODS
                if (unlikely(PyMethod_Check(__pyx_t_5))) {
                  __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
                  if (likely(__pyx_t_1)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                    __Pyx_INCREF(__pyx_t_1);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_5, function);
                    __pyx_t_20 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
                  __pyx_t_18 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_20, 3+__pyx_t_20);
                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                  if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1949, __pyx_L75_error)
                  __Pyx_GOTREF(__pyx_t_18);
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                }
                __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_18);
                __pyx_t_18 = 0;

                /* "cPyparsing.pyx":1948
 *                 try:
 *                     for fn in self.parseAction:
 *                         try:             # <<<<<<<<<<<<<<
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:
 */
              }
              __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
              __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
              __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
              goto __pyx_L82_try_end;
              __pyx_L75_error:;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

              /* "cPyparsing.pyx":1950
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                             exc = ParseException("exception raised in parse action")
 *                             exc.__cause__ = parse_action_exc
 */
              __pyx_t_20 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
              if (__pyx_t_20) {
                __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_18, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(0, 1950, __pyx_L77_except_error)
                __Pyx_XGOTREF(__pyx_t_18);
                __Pyx_XGOTREF(__pyx_t_5);
                __Pyx_XGOTREF(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_5);
                __pyx_v_parse_action_exc = __pyx_t_5;
                /*try:*/ {

                  /* "cPyparsing.pyx":1951
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:
 *                             exc = ParseException("exception raised in parse action")             # <<<<<<<<<<<<<<
 *                             exc.__cause__ = parse_action_exc
 *                             raise exc
 */
                  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1951, __pyx_L88_error)
                  __Pyx_GOTREF(__pyx_t_16);
                  __pyx_t_4 = NULL;
                  __pyx_t_20 = 0;
                  #if CYTHON_UNPACK_METHODS
                  if (unlikely(PyMethod_Check(__pyx_t_16))) {
                    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_16);
                    if (likely(__pyx_t_4)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
                      __Pyx_INCREF(__pyx_t_4);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_16, function);
                      __pyx_t_20 = 1;
                    }
                  }
                  #endif
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_exception_raised_in_parse_action};
                    __pyx_t_17 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_20, 1+__pyx_t_20);
                    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                    if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1951, __pyx_L88_error)
                    __Pyx_GOTREF(__pyx_t_17);
                    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
                  }
                  __pyx_v_exc = __pyx_t_17;
                  __pyx_t_17 = 0;

                  /* "cPyparsing.pyx":1952
 *                         except IndexError as parse_action_exc:
 *                             exc = ParseException("exception raised in parse action")
 *                             exc.__cause__ = parse_action_exc             # <<<<<<<<<<<<<<
 *                             raise exc
 * 
 */
                  if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_cause, __pyx_v_parse_action_exc) < 0) __PYX_ERR(0, 1952, __pyx_L88_error)

                  /* "cPyparsing.pyx":1953
 *                             exc = ParseException("exception raised in parse action")
 *                             exc.__cause__ = parse_action_exc
 *                             raise exc             # <<<<<<<<<<<<<<
 * 
 *                         if tokens is not None and tokens is not retTokens:
 */
                  __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
                  __PYX_ERR(0, 1953, __pyx_L88_error)
                }

                /* "cPyparsing.pyx":1950
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                             exc = ParseException("exception raised in parse action")
 *                             exc.__cause__ = parse_action_exc
 */
                /*finally:*/ {
                  __pyx_L88_error:;
                  /*exception exit:*/{
                    __Pyx_PyThreadState_declare
                    __Pyx_PyThreadState_assign
                    __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0;
                    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                    __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
                    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                    if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_27, &__pyx_t_28, &__pyx_t_29);
                    if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
                    __Pyx_XGOTREF(__pyx_t_12);
                    __Pyx_XGOTREF(__pyx_t_13);
                    __Pyx_XGOTREF(__pyx_t_14);
                    __Pyx_XGOTREF(__pyx_t_27);
                    __Pyx_XGOTREF(__pyx_t_28);
                    __Pyx_XGOTREF(__pyx_t_29);
                    __pyx_t_20 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_26 = __pyx_filename;
                    {
                      __Pyx_DECREF(__pyx_v_parse_action_exc); __pyx_v_parse_action_exc = 0;
                    }
                    if (PY_MAJOR_VERSION >= 3) {
                      __Pyx_XGIVEREF(__pyx_t_27);
                      __Pyx_XGIVEREF(__pyx_t_28);
                      __Pyx_XGIVEREF(__pyx_t_29);
                      __Pyx_ExceptionReset(__pyx_t_27, __pyx_t_28, __pyx_t_29);
                    }
                    __Pyx_XGIVEREF(__pyx_t_12);
                    __Pyx_XGIVEREF(__pyx_t_13);
                    __Pyx_XGIVEREF(__pyx_t_14);
                    __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
                    __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0;
                    __pyx_lineno = __pyx_t_20; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_26;
                    goto __pyx_L77_except_error;
                  }
                }
              }
              goto __pyx_L77_except_error;

              /* "cPyparsing.pyx":1948
 *                 try:
 *                     for fn in self.parseAction:
 *                         try:             # <<<<<<<<<<<<<<
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:
 */
              __pyx_L77_except_error:;
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_XGIVEREF(__pyx_t_23);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_24, __pyx_t_23, __pyx_t_22);
              goto __pyx_L67_error;
              __pyx_L82_try_end:;
            }

            /* "cPyparsing.pyx":1955
 *                             raise exc
 * 
 *                         if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                             retTokens = ParseResults(tokens,
 *                                                       self.resultsName,
 */
            __pyx_t_3 = (__pyx_v_tokens != Py_None);
            if (__pyx_t_3) {
            } else {
              __pyx_t_2 = __pyx_t_3;
              goto __pyx_L95_bool_binop_done;
            }
            __pyx_t_3 = (__pyx_v_tokens != __pyx_v_retTokens);
            __pyx_t_2 = __pyx_t_3;
            __pyx_L95_bool_binop_done:;
            if (__pyx_t_2) {

              /* "cPyparsing.pyx":1956
 * 
 *                         if tokens is not None and tokens is not retTokens:
 *                             retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                       self.resultsName,
 *                                                       asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
              __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1956, __pyx_L67_error)
              __Pyx_GOTREF(__pyx_t_1);

              /* "cPyparsing.pyx":1957
 *                         if tokens is not None and tokens is not retTokens:
 *                             retTokens = ParseResults(tokens,
 *                                                       self.resultsName,             # <<<<<<<<<<<<<<
 *                                                       asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                       modal=self.modalResults)
 */
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1957, __pyx_L67_error)
              __Pyx_GOTREF(__pyx_t_5);

              /* "cPyparsing.pyx":1956
 * 
 *                         if tokens is not None and tokens is not retTokens:
 *                             retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                       self.resultsName,
 *                                                       asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
              __pyx_t_18 = PyTuple_New(2); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1956, __pyx_L67_error)
              __Pyx_GOTREF(__pyx_t_18);
              __Pyx_INCREF(__pyx_v_tokens);
              __Pyx_GIVEREF(__pyx_v_tokens);
              if (__Pyx_PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_v_tokens)) __PYX_ERR(0, 1956, __pyx_L67_error);
              __Pyx_GIVEREF(__pyx_t_5);
              if (__Pyx_PyTuple_SET_ITEM(__pyx_t_18, 1, __pyx_t_5)) __PYX_ERR(0, 1956, __pyx_L67_error);
              __pyx_t_5 = 0;

              /* "cPyparsing.pyx":1958
 *                             retTokens = ParseResults(tokens,
 *                                                       self.resultsName,
 *                                                       asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),             # <<<<<<<<<<<<<<
 *                                                       modal=self.modalResults)
 *                 except Exception as err:
 */
              __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1958, __pyx_L67_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1958, __pyx_L67_error)
              __Pyx_GOTREF(__pyx_t_16);
              __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_16); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1958, __pyx_L67_error)
              if (__pyx_t_2) {
                __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
              } else {
                __Pyx_INCREF(__pyx_t_16);
                __pyx_t_17 = __pyx_t_16;
                __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
                goto __pyx_L97_bool_binop_done;
              }
              __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1958, __pyx_L67_error)
              __Pyx_GOTREF(__pyx_t_16);
              __pyx_t_3 = PyObject_IsInstance(__pyx_v_tokens, __pyx_t_16); 
              if (!__pyx_t_3) {
              } else {
                __pyx_t_2 = __pyx_t_3;
                goto __pyx_L99_bool_binop_done;
              }
              __pyx_t_3 = PyList_Check(__pyx_v_tokens); 
              __pyx_t_2 = __pyx_t_3;
              __pyx_L99_bool_binop_done:;
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
              __pyx_t_16 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1958, __pyx_L67_error)
              __Pyx_GOTREF(__pyx_t_16);
              __pyx_t_17 = __pyx_t_16;
              __pyx_t_16 = 0;
              __pyx_L97_bool_binop_done:;
              if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_asList, __pyx_t_17) < 0) __PYX_ERR(0, 1958, __pyx_L67_error)
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

              /* "cPyparsing.pyx":1959
 *                                                       self.resultsName,
 *                                                       asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                       modal=self.modalResults)             # <<<<<<<<<<<<<<
 *                 except Exception as err:
 *                     # ~ print "Exception raised in user parse action:", err
 */
              __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1959, __pyx_L67_error)
              __Pyx_GOTREF(__pyx_t_17);
              if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_modal, __pyx_t_17) < 0) __PYX_ERR(0, 1958, __pyx_L67_error)
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

              /* "cPyparsing.pyx":1956
 * 
 *                         if tokens is not None and tokens is not retTokens:
 *                             retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                       self.resultsName,
 *                                                       asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
              __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_18, __pyx_t_5); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1956, __pyx_L67_error)
              __Pyx_GOTREF(__pyx_t_17);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF_SET(__pyx_v_retTokens, __pyx_t_17);
              __pyx_t_17 = 0;

              /* "cPyparsing.pyx":1955
 *                             raise exc
 * 
 *                         if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                             retTokens = ParseResults(tokens,
 *                                                       self.resultsName,
 */
            }

            /* "cPyparsing.pyx":1947
 *             if debugging:
 *                 try:
 *                     for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)
 */
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "cPyparsing.pyx":1946
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:
 *                 try:             # <<<<<<<<<<<<<<
 *                     for fn in self.parseAction:
 *                         try:
 */
        }
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L72_try_end;
        __pyx_L67_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "cPyparsing.pyx":1960
 *                                                       asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                       modal=self.modalResults)
 *                 except Exception as err:             # <<<<<<<<<<<<<<
 *                     # ~ print "Exception raised in user parse action:", err
 *                     if self.debugActions[FAIL]:
 */
        __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
        if (__pyx_t_7) {
          __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_17, &__pyx_t_5) < 0) __PYX_ERR(0, 1960, __pyx_L69_except_error)
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_17);
          __pyx_v_err = __pyx_t_17;
          /*try:*/ {

            /* "cPyparsing.pyx":1962
 *                 except Exception as err:
 *                     # ~ print "Exception raised in user parse action:", err
 *                     if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)
 *                     raise
 */
            __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1962, __pyx_L107_error)
            __Pyx_GOTREF(__pyx_t_18);
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1962, __pyx_L107_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_16 = __Pyx_PyObject_GetItem(__pyx_t_18, __pyx_t_1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1962, __pyx_L107_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_16); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1962, __pyx_L107_error)
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            if (__pyx_t_2) {

              /* "cPyparsing.pyx":1963
 *                     # ~ print "Exception raised in user parse action:", err
 *                     if self.debugActions[FAIL]:
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                     raise
 *             else:
 */
              __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1963, __pyx_L107_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_GetModuleGlobalName(__pyx_t_18, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1963, __pyx_L107_error)
              __Pyx_GOTREF(__pyx_t_18);
              __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_18); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1963, __pyx_L107_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
              __pyx_t_18 = NULL;
              __pyx_t_7 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_4))) {
                __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_4);
                if (likely(__pyx_t_18)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                  __Pyx_INCREF(__pyx_t_18);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_4, function);
                  __pyx_t_7 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[5] = {__pyx_t_18, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
                __pyx_t_16 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
                __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1963, __pyx_L107_error)
                __Pyx_GOTREF(__pyx_t_16);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              }
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

              /* "cPyparsing.pyx":1962
 *                 except Exception as err:
 *                     # ~ print "Exception raised in user parse action:", err
 *                     if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)
 *                     raise
 */
            }

            /* "cPyparsing.pyx":1964
 *                     if self.debugActions[FAIL]:
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)
 *                     raise             # <<<<<<<<<<<<<<
 *             else:
 *                 for fn in self.parseAction:
 */
            __Pyx_GIVEREF(__pyx_t_6);
            __Pyx_GIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_5);
            __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_17, __pyx_t_5);
            __pyx_t_6 = 0; __pyx_t_17 = 0; __pyx_t_5 = 0; 
            __PYX_ERR(0, 1964, __pyx_L107_error)
          }

          /* "cPyparsing.pyx":1960
 *                                                       asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                       modal=self.modalResults)
 *                 except Exception as err:             # <<<<<<<<<<<<<<
 *                     # ~ print "Exception raised in user parse action:", err
 *                     if self.debugActions[FAIL]:
 */
          /*finally:*/ {
            __pyx_L107_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_29 = 0; __pyx_t_28 = 0; __pyx_t_27 = 0;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_29, &__pyx_t_28, &__pyx_t_27);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
              __Pyx_XGOTREF(__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_23);
              __Pyx_XGOTREF(__pyx_t_24);
              __Pyx_XGOTREF(__pyx_t_29);
              __Pyx_XGOTREF(__pyx_t_28);
              __Pyx_XGOTREF(__pyx_t_27);
              __pyx_t_7 = __pyx_lineno; __pyx_t_20 = __pyx_clineno; __pyx_t_30 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_29);
                __Pyx_XGIVEREF(__pyx_t_28);
                __Pyx_XGIVEREF(__pyx_t_27);
                __Pyx_ExceptionReset(__pyx_t_29, __pyx_t_28, __pyx_t_27);
              }
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_XGIVEREF(__pyx_t_23);
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_ErrRestore(__pyx_t_22, __pyx_t_23, __pyx_t_24);
              __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_29 = 0; __pyx_t_28 = 0; __pyx_t_27 = 0;
              __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_20; __pyx_filename = __pyx_t_30;
              goto __pyx_L69_except_error;
            }
          }
        }
        goto __pyx_L69_except_error;

        /* "cPyparsing.pyx":1946
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:
 *                 try:             # <<<<<<<<<<<<<<
 *                     for fn in self.parseAction:
 *                         try:
 */
        __pyx_L69_except_error:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L1_error;
        __pyx_L72_try_end:;
      }

      /* "cPyparsing.pyx":1945
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:             # <<<<<<<<<<<<<<
 *                 try:
 *                     for fn in self.parseAction:
 */
      goto __pyx_L66;
    }

    /* "cPyparsing.pyx":1966
 *                     raise
 *             else:
 *                 for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                     try:
 *                         tokens = fn(instring, tokensStart, retTokens)
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1966, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
        __pyx_t_17 = __pyx_t_5; __Pyx_INCREF(__pyx_t_17);
        __pyx_t_11 = 0;
        __pyx_t_25 = NULL;
      } else {
        __pyx_t_11 = -1; __pyx_t_17 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1966, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __pyx_t_25 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_17); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 1966, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      for (;;) {
        if (likely(!__pyx_t_25)) {
          if (likely(PyList_CheckExact(__pyx_t_17))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_17);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1966, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyList_GET_ITEM(__pyx_t_17, __pyx_t_11); __Pyx_INCREF(__pyx_t_5); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1966, __pyx_L1_error)
            #else
            __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_17, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1966, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_17);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1966, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_17, __pyx_t_11); __Pyx_INCREF(__pyx_t_5); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1966, __pyx_L1_error)
            #else
            __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_17, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1966, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          }
        } else {
          __pyx_t_5 = __pyx_t_25(__pyx_t_17);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1966, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_XDECREF_SET(__pyx_v_fn, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "cPyparsing.pyx":1967
 *             else:
 *                 for fn in self.parseAction:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                     except IndexError as parse_action_exc:
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_9, &__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_8);
          /*try:*/ {

            /* "cPyparsing.pyx":1968
 *                 for fn in self.parseAction:
 *                     try:
 *                         tokens = fn(instring, tokensStart, retTokens)             # <<<<<<<<<<<<<<
 *                     except IndexError as parse_action_exc:
 *                         exc = ParseException("exception raised in parse action")
 */
            __Pyx_INCREF(__pyx_v_fn);
            __pyx_t_6 = __pyx_v_fn; __pyx_t_16 = NULL;
            __pyx_t_20 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_6))) {
              __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_6);
              if (likely(__pyx_t_16)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
                __Pyx_INCREF(__pyx_t_16);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_6, function);
                __pyx_t_20 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[4] = {__pyx_t_16, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
              __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_20, 3+__pyx_t_20);
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1968, __pyx_L116_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            }
            __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "cPyparsing.pyx":1967
 *             else:
 *                 for fn in self.parseAction:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                     except IndexError as parse_action_exc:
 */
          }
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L123_try_end;
          __pyx_L116_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
          __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "cPyparsing.pyx":1969
 *                     try:
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                     except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                         exc = ParseException("exception raised in parse action")
 *                         exc.__cause__ = parse_action_exc
 */
          __pyx_t_20 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
          if (__pyx_t_20) {
            __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_16) < 0) __PYX_ERR(0, 1969, __pyx_L118_except_error)
            __Pyx_XGOTREF(__pyx_t_5);
            __Pyx_XGOTREF(__pyx_t_6);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_INCREF(__pyx_t_6);
            __pyx_v_parse_action_exc = __pyx_t_6;
            /*try:*/ {

              /* "cPyparsing.pyx":1970
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                     except IndexError as parse_action_exc:
 *                         exc = ParseException("exception raised in parse action")             # <<<<<<<<<<<<<<
 *                         exc.__cause__ = parse_action_exc
 *                         raise exc
 */
              __Pyx_GetModuleGlobalName(__pyx_t_18, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1970, __pyx_L129_error)
              __Pyx_GOTREF(__pyx_t_18);
              __pyx_t_1 = NULL;
              __pyx_t_20 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_18))) {
                __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_18);
                if (likely(__pyx_t_1)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
                  __Pyx_INCREF(__pyx_t_1);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_18, function);
                  __pyx_t_20 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_kp_u_exception_raised_in_parse_action};
                __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_18, __pyx_callargs+1-__pyx_t_20, 1+__pyx_t_20);
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1970, __pyx_L129_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
              }
              __pyx_v_exc = __pyx_t_4;
              __pyx_t_4 = 0;

              /* "cPyparsing.pyx":1971
 *                     except IndexError as parse_action_exc:
 *                         exc = ParseException("exception raised in parse action")
 *                         exc.__cause__ = parse_action_exc             # <<<<<<<<<<<<<<
 *                         raise exc
 * 
 */
              if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_cause, __pyx_v_parse_action_exc) < 0) __PYX_ERR(0, 1971, __pyx_L129_error)

              /* "cPyparsing.pyx":1972
 *                         exc = ParseException("exception raised in parse action")
 *                         exc.__cause__ = parse_action_exc
 *                         raise exc             # <<<<<<<<<<<<<<
 * 
 *                     if tokens is not None and tokens is not retTokens:
 */
              __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
              __PYX_ERR(0, 1972, __pyx_L129_error)
            }

            /* "cPyparsing.pyx":1969
 *                     try:
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                     except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                         exc = ParseException("exception raised in parse action")
 *                         exc.__cause__ = parse_action_exc
 */
            /*finally:*/ {
              __pyx_L129_error:;
              /*exception exit:*/{
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_22 = 0;
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_24, &__pyx_t_23, &__pyx_t_22);
                if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_27, &__pyx_t_28, &__pyx_t_29) < 0)) __Pyx_ErrFetch(&__pyx_t_27, &__pyx_t_28, &__pyx_t_29);
                __Pyx_XGOTREF(__pyx_t_27);
                __Pyx_XGOTREF(__pyx_t_28);
                __Pyx_XGOTREF(__pyx_t_29);
                __Pyx_XGOTREF(__pyx_t_24);
                __Pyx_XGOTREF(__pyx_t_23);
                __Pyx_XGOTREF(__pyx_t_22);
                __pyx_t_20 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_31 = __pyx_filename;
                {
                  __Pyx_DECREF(__pyx_v_parse_action_exc); __pyx_v_parse_action_exc = 0;
                }
                if (PY_MAJOR_VERSION >= 3) {
                  __Pyx_XGIVEREF(__pyx_t_24);
                  __Pyx_XGIVEREF(__pyx_t_23);
                  __Pyx_XGIVEREF(__pyx_t_22);
                  __Pyx_ExceptionReset(__pyx_t_24, __pyx_t_23, __pyx_t_22);
                }
                __Pyx_XGIVEREF(__pyx_t_27);
                __Pyx_XGIVEREF(__pyx_t_28);
                __Pyx_XGIVEREF(__pyx_t_29);
                __Pyx_ErrRestore(__pyx_t_27, __pyx_t_28, __pyx_t_29);
                __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_22 = 0;
                __pyx_lineno = __pyx_t_20; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_31;
                goto __pyx_L118_except_error;
              }
            }
          }
          goto __pyx_L118_except_error;

          /* "cPyparsing.pyx":1967
 *             else:
 *                 for fn in self.parseAction:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                     except IndexError as parse_action_exc:
 */
          __pyx_L118_except_error:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
          goto __pyx_L1_error;
          __pyx_L123_try_end:;
        }

        /* "cPyparsing.pyx":1974
 *                         raise exc
 * 
 *                     if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                         retTokens = ParseResults(tokens,
 *                                                   self.resultsName,
 */
        __pyx_t_3 = (__pyx_v_tokens != Py_None);
        if (__pyx_t_3) {
        } else {
          __pyx_t_2 = __pyx_t_3;
          goto __pyx_L136_bool_binop_done;
        }
        __pyx_t_3 = (__pyx_v_tokens != __pyx_v_retTokens);
        __pyx_t_2 = __pyx_t_3;
        __pyx_L136_bool_binop_done:;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":1975
 * 
 *                     if tokens is not None and tokens is not retTokens:
 *                         retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                   self.resultsName,
 *                                                   asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
          __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1975, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);

          /* "cPyparsing.pyx":1976
 *                     if tokens is not None and tokens is not retTokens:
 *                         retTokens = ParseResults(tokens,
 *                                                   self.resultsName,             # <<<<<<<<<<<<<<
 *                                                   asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                   modal=self.modalResults)
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1976, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);

          /* "cPyparsing.pyx":1975
 * 
 *                     if tokens is not None and tokens is not retTokens:
 *                         retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                   self.resultsName,
 *                                                   asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
          __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1975, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_v_tokens);
          __Pyx_GIVEREF(__pyx_v_tokens);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_tokens)) __PYX_ERR(0, 1975, __pyx_L1_error);
          __Pyx_GIVEREF(__pyx_t_6);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6)) __PYX_ERR(0, 1975, __pyx_L1_error);
          __pyx_t_6 = 0;

          /* "cPyparsing.pyx":1977
 *                         retTokens = ParseResults(tokens,
 *                                                   self.resultsName,
 *                                                   asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),             # <<<<<<<<<<<<<<
 *                                                   modal=self.modalResults)
 *         if debugging:
 */
          __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1977, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1977, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_18); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1977, __pyx_L1_error)
          if (__pyx_t_2) {
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          } else {
            __Pyx_INCREF(__pyx_t_18);
            __pyx_t_4 = __pyx_t_18;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            goto __pyx_L138_bool_binop_done;
          }
          __Pyx_GetModuleGlobalName(__pyx_t_18, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1977, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_3 = PyObject_IsInstance(__pyx_v_tokens, __pyx_t_18); 
          if (!__pyx_t_3) {
          } else {
            __pyx_t_2 = __pyx_t_3;
            goto __pyx_L140_bool_binop_done;
          }
          __pyx_t_3 = PyList_Check(__pyx_v_tokens); 
          __pyx_t_2 = __pyx_t_3;
          __pyx_L140_bool_binop_done:;
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_18 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1977, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_4 = __pyx_t_18;
          __pyx_t_18 = 0;
          __pyx_L138_bool_binop_done:;
          if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_asList, __pyx_t_4) < 0) __PYX_ERR(0, 1977, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "cPyparsing.pyx":1978
 *                                                   self.resultsName,
 *                                                   asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                   modal=self.modalResults)             # <<<<<<<<<<<<<<
 *         if debugging:
 *             # ~ print ("Matched", self, "->", retTokens.asList())
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1978, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_modal, __pyx_t_4) < 0) __PYX_ERR(0, 1977, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "cPyparsing.pyx":1975
 * 
 *                     if tokens is not None and tokens is not retTokens:
 *                         retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                   self.resultsName,
 *                                                   asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1975, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF_SET(__pyx_v_retTokens, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":1974
 *                         raise exc
 * 
 *                     if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                         retTokens = ParseResults(tokens,
 *                                                   self.resultsName,
 */
        }

        /* "cPyparsing.pyx":1966
 *                     raise
 *             else:
 *                 for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                     try:
 *                         tokens = fn(instring, tokensStart, retTokens)
 */
      }
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    }
    __pyx_L66:;

    /* "cPyparsing.pyx":1944
 * 
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *         if self.parseAction and (doActions or self.callDuringTry):             # <<<<<<<<<<<<<<
 *             if debugging:
 *                 try:
 */
  }

  /* "cPyparsing.pyx":1979
 *                                                   asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                   modal=self.modalResults)
 *         if debugging:             # <<<<<<<<<<<<<<
 *             # ~ print ("Matched", self, "->", retTokens.asList())
 *             if self.debugActions[MATCH]:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1979, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1981
 *         if debugging:
 *             # ~ print ("Matched", self, "->", retTokens.asList())
 *             if self.debugActions[MATCH]:             # <<<<<<<<<<<<<<
 *                 self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)
 * 
 */
    __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_MATCH); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_17, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1981, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1982
 *             # ~ print ("Matched", self, "->", retTokens.asList())
 *             if self.debugActions[MATCH]:
 *                 self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)             # <<<<<<<<<<<<<<
 * 
 *         return loc, retTokens
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_MATCH); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_17); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_17)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[6] = {__pyx_t_17, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_loc, __pyx_v_self, __pyx_v_retTokens};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 5+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1982, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":1981
 *         if debugging:
 *             # ~ print ("Matched", self, "->", retTokens.asList())
 *             if self.debugActions[MATCH]:             # <<<<<<<<<<<<<<
 *                 self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)
 * 
 */
    }

    /* "cPyparsing.pyx":1979
 *                                                   asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                   modal=self.modalResults)
 *         if debugging:             # <<<<<<<<<<<<<<
 *             # ~ print ("Matched", self, "->", retTokens.asList())
 *             if self.debugActions[MATCH]:
 */
  }

  /* "cPyparsing.pyx":1984
 *                 self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)
 * 
 *         return loc, retTokens             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_loc)) __PYX_ERR(0, 1984, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_retTokens);
  __Pyx_GIVEREF(__pyx_v_retTokens);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_retTokens)) __PYX_ERR(0, 1984, __pyx_L1_error);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1899
 * 
 *     #     return loc, retTokens
 *     def _parseNoCache(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] TRY, MATCH, FAIL are constants
 *         debugging = (self.debug)  # and doActions)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_debugging);
  __Pyx_XDECREF(__pyx_v_preloc);
  __Pyx_XDECREF(__pyx_v_tokensStart);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_retTokens);
  __Pyx_XDECREF(__pyx_v_fn);
  __Pyx_XDECREF(__pyx_v_parse_action_exc);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2000
 *     #     else:
 *     #         return got[0]
 *     def tryParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_39tryParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_38tryParse, "ParserElement.tryParse(self, instring, loc)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_39tryParse = {"tryParse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_39tryParse, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_38tryParse};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_39tryParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tryParse (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2000, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2000, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("tryParse", 1, 3, 3, 1); __PYX_ERR(0, 2000, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2000, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("tryParse", 1, 3, 3, 2); __PYX_ERR(0, 2000, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "tryParse") < 0)) __PYX_ERR(0, 2000, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("tryParse", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 2000, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.tryParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_38tryParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_38tryParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tryParse", 1);

  /* "cPyparsing.pyx":2001
 *     #         return got[0]
 *     def tryParse(self, instring, loc):
 *         try:             # <<<<<<<<<<<<<<
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":2002
 *     def tryParse(self, instring, loc):
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]             # <<<<<<<<<<<<<<
 *         except ParseFatalException:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2002, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2002, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_instring)) __PYX_ERR(0, 2002, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_loc);
      __Pyx_GIVEREF(__pyx_v_loc);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_loc)) __PYX_ERR(0, 2002, __pyx_L3_error);
      __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2002, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_doActions, Py_False) < 0) __PYX_ERR(0, 2002, __pyx_L3_error)
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2002, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_7, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2002, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":2001
 *     #         return got[0]
 *     def tryParse(self, instring, loc):
 *         try:             # <<<<<<<<<<<<<<
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2003
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_7, &__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseFatalException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2003, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_6, __pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_ErrRestore(__pyx_t_6, __pyx_t_7, __pyx_t_5);
    __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_5 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.tryParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_6) < 0) __PYX_ERR(0, 2003, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "cPyparsing.pyx":2004
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *     def canParseNext(self, instring, loc):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2004, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2004, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_11, __pyx_v_instring, __pyx_v_loc, __pyx_t_10, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_8, 4+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2004, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 2004, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":2001
 *     #         return got[0]
 *     def tryParse(self, instring, loc):
 *         try:             # <<<<<<<<<<<<<<
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2000
 *     #     else:
 *     #         return got[0]
 *     def tryParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.ParserElement.tryParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2006
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def canParseNext(self, instring, loc):             # <<<<<<<<<<<<<<
 *         try:
 *             self.tryParse(instring, loc)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_41canParseNext(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_40canParseNext, "ParserElement.canParseNext(self, instring, loc)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_41canParseNext = {"canParseNext", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_41canParseNext, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_40canParseNext};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_41canParseNext(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("canParseNext (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2006, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2006, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("canParseNext", 1, 3, 3, 1); __PYX_ERR(0, 2006, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2006, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("canParseNext", 1, 3, 3, 2); __PYX_ERR(0, 2006, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "canParseNext") < 0)) __PYX_ERR(0, 2006, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("canParseNext", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 2006, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.canParseNext", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_40canParseNext(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_40canParseNext(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("canParseNext", 1);

  /* "cPyparsing.pyx":2007
 * 
 *     def canParseNext(self, instring, loc):
 *         try:             # <<<<<<<<<<<<<<
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":2008
 *     def canParseNext(self, instring, loc):
 *         try:
 *             self.tryParse(instring, loc)             # <<<<<<<<<<<<<<
 *         except (ParseException, IndexError):
 *             return False
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2008, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2008, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":2007
 * 
 *     def canParseNext(self, instring, loc):
 *         try:             # <<<<<<<<<<<<<<
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):
 */
    }

    /* "cPyparsing.pyx":2012
 *             return False
 *         else:
 *             return True             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] caches are globals
 */
    /*else:*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      goto __pyx_L6_except_return;
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2009
 *         try:
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *             return False
 *         else:
 */
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2009, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_PyErr_GivenExceptionMatches2(__pyx_t_4, __pyx_t_8, __pyx_builtin_IndexError);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0;
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.canParseNext", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 2009, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "cPyparsing.pyx":2010
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):
 *             return False             # <<<<<<<<<<<<<<
 *         else:
 *             return True
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":2007
 * 
 *     def canParseNext(self, instring, loc):
 *         try:             # <<<<<<<<<<<<<<
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2006
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def canParseNext(self, instring, loc):             # <<<<<<<<<<<<<<
 *         try:
 *             self.tryParse(instring, loc)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParserElement.canParseNext", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2054
 *     #                 return value
 *     #             return value[0], value[1].copy()
 *     def _parseCache(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] HIT, MISS are constants
 *         # [CPYPARSING] include packrat_context, merge callPreParse and doActions
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_43_parseCache(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_42_parseCache, "ParserElement._parseCache(self, instring, loc, doActions=True, callPreParse=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_43_parseCache = {"_parseCache", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_43_parseCache, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_42_parseCache};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_43_parseCache(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_v_callPreParse = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_parseCache (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,&__pyx_n_s_callPreParse,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2054, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2054, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_parseCache", 0, 3, 5, 1); __PYX_ERR(0, 2054, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2054, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_parseCache", 0, 3, 5, 2); __PYX_ERR(0, 2054, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2054, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_callPreParse);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2054, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_parseCache") < 0)) __PYX_ERR(0, 2054, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
    __pyx_v_callPreParse = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_parseCache", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 2054, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_42_parseCache(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_42_parseCache(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse) {
  PyObject *__pyx_v_lookup = NULL;
  PyObject *__pyx_v_cache = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_debugging = NULL;
  PyObject *__pyx_v_preloc = NULL;
  PyObject *__pyx_v_tokensStart = NULL;
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_v_retTokens = NULL;
  PyObject *__pyx_v_fn = NULL;
  PyObject *__pyx_v_parse_action_exc = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_v_pe = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  Py_ssize_t __pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *(*__pyx_t_22)(PyObject *);
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  int __pyx_t_27;
  char const *__pyx_t_28;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  PyObject *__pyx_t_31 = NULL;
  PyObject *(*__pyx_t_32)(PyObject *);
  char const *__pyx_t_33;
  PyObject *__pyx_t_34 = NULL;
  PyObject *__pyx_t_35 = NULL;
  PyObject *__pyx_t_36 = NULL;
  char const *__pyx_t_37;
  char const *__pyx_t_38;
  char const *__pyx_t_39;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parseCache", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":2057
 *         # [CPYPARSING] HIT, MISS are constants
 *         # [CPYPARSING] include packrat_context, merge callPreParse and doActions
 *         lookup = (self, instring, loc, callPreParse | doActions << 1, ParserElement.packrat_context)             # <<<<<<<<<<<<<<
 *         with ParserElement.packrat_cache_lock:
 *             cache = ParserElement.packrat_cache
 */
  __pyx_t_1 = __Pyx_PyInt_LshiftObjC(__pyx_v_doActions, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Or(__pyx_v_callPreParse, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_packrat_context); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self)) __PYX_ERR(0, 2057, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_v_instring);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_instring)) __PYX_ERR(0, 2057, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_loc)) __PYX_ERR(0, 2057, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_2)) __PYX_ERR(0, 2057, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_t_3)) __PYX_ERR(0, 2057, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_v_lookup = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2058
 *         # [CPYPARSING] include packrat_context, merge callPreParse and doActions
 *         lookup = (self, instring, loc, callPreParse | doActions << 1, ParserElement.packrat_context)
 *         with ParserElement.packrat_cache_lock:             # <<<<<<<<<<<<<<
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)
 */
  /*with:*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_packrat_cache_lock); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_n_s_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_n_s_enter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2058, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2058, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        /*try:*/ {

          /* "cPyparsing.pyx":2059
 *         lookup = (self, instring, loc, callPreParse | doActions << 1, ParserElement.packrat_context)
 *         with ParserElement.packrat_cache_lock:
 *             cache = ParserElement.packrat_cache             # <<<<<<<<<<<<<<
 *             value = cache.get(lookup)
 *             if value is cache.not_in_cache:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2059, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_packrat_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2059, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_v_cache = __pyx_t_1;
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":2060
 *         with ParserElement.packrat_cache_lock:
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)             # <<<<<<<<<<<<<<
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2060, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = NULL;
          __pyx_t_6 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
              __pyx_t_6 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_lookup};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2060, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          }
          __pyx_v_value = __pyx_t_1;
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":2061
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)
 *             if value is cache.not_in_cache:             # <<<<<<<<<<<<<<
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_not_in_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2061, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_10 = (__pyx_v_value == __pyx_t_1);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_10) {

            /* "cPyparsing.pyx":2062
 *             value = cache.get(lookup)
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1             # <<<<<<<<<<<<<<
 *                 try:
 *                     # value = self._parseNoCache(instring, loc, doActions, callPreParse)
 */
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2062, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2062, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MISS); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2062, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2062, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2062, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely((PyObject_SetItem(__pyx_t_3, __pyx_t_1, __pyx_t_5) < 0))) __PYX_ERR(0, 2062, __pyx_L7_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

            /* "cPyparsing.pyx":2063
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:             # <<<<<<<<<<<<<<
 *                     # value = self._parseNoCache(instring, loc, doActions, callPreParse)
 *                     # [CPYPARSING] START INLINE _parseNoCache
 */
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
              __Pyx_XGOTREF(__pyx_t_11);
              __Pyx_XGOTREF(__pyx_t_12);
              __Pyx_XGOTREF(__pyx_t_13);
              /*try:*/ {

                /* "cPyparsing.pyx":2068
 * 
 *                     # [CPYPARSING] TRY, MATCH, FAIL are constants
 *                     debugging = (self.debug)  # and doActions)             # <<<<<<<<<<<<<<
 * 
 *                     if debugging or self.failAction:
 */
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2068, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_v_debugging = __pyx_t_3;
                __pyx_t_3 = 0;

                /* "cPyparsing.pyx":2070
 *                     debugging = (self.debug)  # and doActions)
 * 
 *                     if debugging or self.failAction:             # <<<<<<<<<<<<<<
 *                         # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                         if self.debugActions[TRY]:
 */
                __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2070, __pyx_L14_error)
                if (!__pyx_t_14) {
                } else {
                  __pyx_t_10 = __pyx_t_14;
                  goto __pyx_L21_bool_binop_done;
                }
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2070, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2070, __pyx_L14_error)
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __pyx_t_10 = __pyx_t_14;
                __pyx_L21_bool_binop_done:;
                if (__pyx_t_10) {

                  /* "cPyparsing.pyx":2072
 *                     if debugging or self.failAction:
 *                         # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                         if self.debugActions[TRY]:             # <<<<<<<<<<<<<<
 *                             self.debugActions[TRY](instring, loc, self)
 *                         try:
 */
                  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2072, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_TRY); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2072, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2072, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2072, __pyx_L14_error)
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                  if (__pyx_t_10) {

                    /* "cPyparsing.pyx":2073
 *                         # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                         if self.debugActions[TRY]:
 *                             self.debugActions[TRY](instring, loc, self)             # <<<<<<<<<<<<<<
 *                         try:
 *                             if callPreParse and self.callPreparse:
 */
                    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2073, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_TRY); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2073, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_3);
                    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2073, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                    __pyx_t_3 = NULL;
                    __pyx_t_6 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (unlikely(PyMethod_Check(__pyx_t_2))) {
                      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
                      if (likely(__pyx_t_3)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                        __Pyx_INCREF(__pyx_t_3);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_2, function);
                        __pyx_t_6 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc, __pyx_v_self};
                      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
                      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2073, __pyx_L14_error)
                      __Pyx_GOTREF(__pyx_t_5);
                      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                    }
                    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

                    /* "cPyparsing.pyx":2072
 *                     if debugging or self.failAction:
 *                         # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                         if self.debugActions[TRY]:             # <<<<<<<<<<<<<<
 *                             self.debugActions[TRY](instring, loc, self)
 *                         try:
 */
                  }

                  /* "cPyparsing.pyx":2074
 *                         if self.debugActions[TRY]:
 *                             self.debugActions[TRY](instring, loc, self)
 *                         try:             # <<<<<<<<<<<<<<
 *                             if callPreParse and self.callPreparse:
 *                                 preloc = self.preParse(instring, loc)
 */
                  {
                    __Pyx_PyThreadState_declare
                    __Pyx_PyThreadState_assign
                    __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
                    __Pyx_XGOTREF(__pyx_t_15);
                    __Pyx_XGOTREF(__pyx_t_16);
                    __Pyx_XGOTREF(__pyx_t_17);
                    /*try:*/ {

                      /* "cPyparsing.pyx":2075
 *                             self.debugActions[TRY](instring, loc, self)
 *                         try:
 *                             if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                                 preloc = self.preParse(instring, loc)
 *                             else:
 */
                      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_callPreParse); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2075, __pyx_L24_error)
                      if (__pyx_t_14) {
                      } else {
                        __pyx_t_10 = __pyx_t_14;
                        goto __pyx_L31_bool_binop_done;
                      }
                      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2075, __pyx_L24_error)
                      __Pyx_GOTREF(__pyx_t_5);
                      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2075, __pyx_L24_error)
                      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                      __pyx_t_10 = __pyx_t_14;
                      __pyx_L31_bool_binop_done:;
                      if (__pyx_t_10) {

                        /* "cPyparsing.pyx":2076
 *                         try:
 *                             if callPreParse and self.callPreparse:
 *                                 preloc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *                             else:
 *                                 preloc = loc
 */
                        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2076, __pyx_L24_error)
                        __Pyx_GOTREF(__pyx_t_2);
                        __pyx_t_3 = NULL;
                        __pyx_t_6 = 0;
                        #if CYTHON_UNPACK_METHODS
                        if (likely(PyMethod_Check(__pyx_t_2))) {
                          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
                          if (likely(__pyx_t_3)) {
                            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                            __Pyx_INCREF(__pyx_t_3);
                            __Pyx_INCREF(function);
                            __Pyx_DECREF_SET(__pyx_t_2, function);
                            __pyx_t_6 = 1;
                          }
                        }
                        #endif
                        {
                          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
                          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
                          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2076, __pyx_L24_error)
                          __Pyx_GOTREF(__pyx_t_5);
                          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                        }
                        __pyx_v_preloc = __pyx_t_5;
                        __pyx_t_5 = 0;

                        /* "cPyparsing.pyx":2075
 *                             self.debugActions[TRY](instring, loc, self)
 *                         try:
 *                             if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                                 preloc = self.preParse(instring, loc)
 *                             else:
 */
                        goto __pyx_L30;
                      }

                      /* "cPyparsing.pyx":2078
 *                                 preloc = self.preParse(instring, loc)
 *                             else:
 *                                 preloc = loc             # <<<<<<<<<<<<<<
 *                             tokensStart = preloc
 *                             if self.mayIndexError or preloc >= len(instring):
 */
                      /*else*/ {
                        __Pyx_INCREF(__pyx_v_loc);
                        __pyx_v_preloc = __pyx_v_loc;
                      }
                      __pyx_L30:;

                      /* "cPyparsing.pyx":2079
 *                             else:
 *                                 preloc = loc
 *                             tokensStart = preloc             # <<<<<<<<<<<<<<
 *                             if self.mayIndexError or preloc >= len(instring):
 *                                 try:
 */
                      __Pyx_INCREF(__pyx_v_preloc);
                      __pyx_v_tokensStart = __pyx_v_preloc;

                      /* "cPyparsing.pyx":2080
 *                                 preloc = loc
 *                             tokensStart = preloc
 *                             if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                                 try:
 *                                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
                      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2080, __pyx_L24_error)
                      __Pyx_GOTREF(__pyx_t_5);
                      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2080, __pyx_L24_error)
                      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                      if (!__pyx_t_14) {
                      } else {
                        __pyx_t_10 = __pyx_t_14;
                        goto __pyx_L34_bool_binop_done;
                      }
                      __pyx_t_18 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_18 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2080, __pyx_L24_error)
                      __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_18); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2080, __pyx_L24_error)
                      __Pyx_GOTREF(__pyx_t_5);
                      __pyx_t_2 = PyObject_RichCompare(__pyx_v_preloc, __pyx_t_5, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2080, __pyx_L24_error)
                      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2080, __pyx_L24_error)
                      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                      __pyx_t_10 = __pyx_t_14;
                      __pyx_L34_bool_binop_done:;
                      if (__pyx_t_10) {

                        /* "cPyparsing.pyx":2081
 *                             tokensStart = preloc
 *                             if self.mayIndexError or preloc >= len(instring):
 *                                 try:             # <<<<<<<<<<<<<<
 *                                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                                 except IndexError:
 */
                        {
                          __Pyx_PyThreadState_declare
                          __Pyx_PyThreadState_assign
                          __Pyx_ExceptionSave(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
                          __Pyx_XGOTREF(__pyx_t_19);
                          __Pyx_XGOTREF(__pyx_t_20);
                          __Pyx_XGOTREF(__pyx_t_21);
                          /*try:*/ {

                            /* "cPyparsing.pyx":2082
 *                             if self.mayIndexError or preloc >= len(instring):
 *                                 try:
 *                                     loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                                 except IndexError:
 *                                     raise ParseException(instring, len(instring), self.errmsg, self)
 */
                            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2082, __pyx_L36_error)
                            __Pyx_GOTREF(__pyx_t_5);
                            __pyx_t_3 = NULL;
                            __pyx_t_6 = 0;
                            #if CYTHON_UNPACK_METHODS
                            if (likely(PyMethod_Check(__pyx_t_5))) {
                              __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
                              if (likely(__pyx_t_3)) {
                                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                                __Pyx_INCREF(__pyx_t_3);
                                __Pyx_INCREF(function);
                                __Pyx_DECREF_SET(__pyx_t_5, function);
                                __pyx_t_6 = 1;
                              }
                            }
                            #endif
                            {
                              PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
                              __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
                              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2082, __pyx_L36_error)
                              __Pyx_GOTREF(__pyx_t_2);
                              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                            }
                            if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
                              PyObject* sequence = __pyx_t_2;
                              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                              if (unlikely(size != 2)) {
                                if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                                __PYX_ERR(0, 2082, __pyx_L36_error)
                              }
                              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                              if (likely(PyTuple_CheckExact(sequence))) {
                                __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
                                __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
                              } else {
                                __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
                                __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
                              }
                              __Pyx_INCREF(__pyx_t_5);
                              __Pyx_INCREF(__pyx_t_3);
                              #else
                              __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2082, __pyx_L36_error)
                              __Pyx_GOTREF(__pyx_t_5);
                              __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2082, __pyx_L36_error)
                              __Pyx_GOTREF(__pyx_t_3);
                              #endif
                              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                            } else {
                              Py_ssize_t index = -1;
                              __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2082, __pyx_L36_error)
                              __Pyx_GOTREF(__pyx_t_1);
                              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                              __pyx_t_22 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
                              index = 0; __pyx_t_5 = __pyx_t_22(__pyx_t_1); if (unlikely(!__pyx_t_5)) goto __pyx_L42_unpacking_failed;
                              __Pyx_GOTREF(__pyx_t_5);
                              index = 1; __pyx_t_3 = __pyx_t_22(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L42_unpacking_failed;
                              __Pyx_GOTREF(__pyx_t_3);
                              if (__Pyx_IternextUnpackEndCheck(__pyx_t_22(__pyx_t_1), 2) < 0) __PYX_ERR(0, 2082, __pyx_L36_error)
                              __pyx_t_22 = NULL;
                              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                              goto __pyx_L43_unpacking_done;
                              __pyx_L42_unpacking_failed:;
                              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                              __pyx_t_22 = NULL;
                              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                              __PYX_ERR(0, 2082, __pyx_L36_error)
                              __pyx_L43_unpacking_done:;
                            }
                            __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_5);
                            __pyx_t_5 = 0;
                            __pyx_v_tokens = __pyx_t_3;
                            __pyx_t_3 = 0;

                            /* "cPyparsing.pyx":2081
 *                             tokensStart = preloc
 *                             if self.mayIndexError or preloc >= len(instring):
 *                                 try:             # <<<<<<<<<<<<<<
 *                                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                                 except IndexError:
 */
                          }
                          __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
                          __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
                          __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
                          goto __pyx_L41_try_end;
                          __pyx_L36_error:;
                          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

                          /* "cPyparsing.pyx":2083
 *                                 try:
 *                                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                                 except IndexError:             # <<<<<<<<<<<<<<
 *                                     raise ParseException(instring, len(instring), self.errmsg, self)
 *                             else:
 */
                          __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
                          if (__pyx_t_6) {
                            __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
                            if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_5) < 0) __PYX_ERR(0, 2083, __pyx_L38_except_error)
                            __Pyx_XGOTREF(__pyx_t_2);
                            __Pyx_XGOTREF(__pyx_t_3);
                            __Pyx_XGOTREF(__pyx_t_5);

                            /* "cPyparsing.pyx":2084
 *                                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                                 except IndexError:
 *                                     raise ParseException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *                             else:
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
                            __Pyx_GetModuleGlobalName(__pyx_t_23, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2084, __pyx_L38_except_error)
                            __Pyx_GOTREF(__pyx_t_23);
                            __pyx_t_18 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_18 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2084, __pyx_L38_except_error)
                            __pyx_t_24 = PyInt_FromSsize_t(__pyx_t_18); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2084, __pyx_L38_except_error)
                            __Pyx_GOTREF(__pyx_t_24);
                            __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2084, __pyx_L38_except_error)
                            __Pyx_GOTREF(__pyx_t_25);
                            __pyx_t_26 = NULL;
                            __pyx_t_6 = 0;
                            #if CYTHON_UNPACK_METHODS
                            if (unlikely(PyMethod_Check(__pyx_t_23))) {
                              __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_23);
                              if (likely(__pyx_t_26)) {
                                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_23);
                                __Pyx_INCREF(__pyx_t_26);
                                __Pyx_INCREF(function);
                                __Pyx_DECREF_SET(__pyx_t_23, function);
                                __pyx_t_6 = 1;
                              }
                            }
                            #endif
                            {
                              PyObject *__pyx_callargs[5] = {__pyx_t_26, __pyx_v_instring, __pyx_t_24, __pyx_t_25, __pyx_v_self};
                              __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_23, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
                              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                              __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
                              __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2084, __pyx_L38_except_error)
                              __Pyx_GOTREF(__pyx_t_1);
                              __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                            }
                            __Pyx_Raise(__pyx_t_1, 0, 0, 0);
                            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                            __PYX_ERR(0, 2084, __pyx_L38_except_error)
                          }
                          goto __pyx_L38_except_error;

                          /* "cPyparsing.pyx":2081
 *                             tokensStart = preloc
 *                             if self.mayIndexError or preloc >= len(instring):
 *                                 try:             # <<<<<<<<<<<<<<
 *                                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                                 except IndexError:
 */
                          __pyx_L38_except_error:;
                          __Pyx_XGIVEREF(__pyx_t_19);
                          __Pyx_XGIVEREF(__pyx_t_20);
                          __Pyx_XGIVEREF(__pyx_t_21);
                          __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
                          goto __pyx_L24_error;
                          __pyx_L41_try_end:;
                        }

                        /* "cPyparsing.pyx":2080
 *                                 preloc = loc
 *                             tokensStart = preloc
 *                             if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                                 try:
 *                                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
                        goto __pyx_L33;
                      }

                      /* "cPyparsing.pyx":2086
 *                                     raise ParseException(instring, len(instring), self.errmsg, self)
 *                             else:
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                         except Exception as err:
 *                             # ~ print ("Exception raised:", err)
 */
                      /*else*/ {
                        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2086, __pyx_L24_error)
                        __Pyx_GOTREF(__pyx_t_3);
                        __pyx_t_2 = NULL;
                        __pyx_t_6 = 0;
                        #if CYTHON_UNPACK_METHODS
                        if (likely(PyMethod_Check(__pyx_t_3))) {
                          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
                          if (likely(__pyx_t_2)) {
                            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                            __Pyx_INCREF(__pyx_t_2);
                            __Pyx_INCREF(function);
                            __Pyx_DECREF_SET(__pyx_t_3, function);
                            __pyx_t_6 = 1;
                          }
                        }
                        #endif
                        {
                          PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
                          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
                          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2086, __pyx_L24_error)
                          __Pyx_GOTREF(__pyx_t_5);
                          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                        }
                        if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
                          PyObject* sequence = __pyx_t_5;
                          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                          if (unlikely(size != 2)) {
                            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                            __PYX_ERR(0, 2086, __pyx_L24_error)
                          }
                          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                          if (likely(PyTuple_CheckExact(sequence))) {
                            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
                            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
                          } else {
                            __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
                            __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
                          }
                          __Pyx_INCREF(__pyx_t_3);
                          __Pyx_INCREF(__pyx_t_2);
                          #else
                          __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2086, __pyx_L24_error)
                          __Pyx_GOTREF(__pyx_t_3);
                          __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2086, __pyx_L24_error)
                          __Pyx_GOTREF(__pyx_t_2);
                          #endif
                          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                        } else {
                          Py_ssize_t index = -1;
                          __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2086, __pyx_L24_error)
                          __Pyx_GOTREF(__pyx_t_1);
                          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                          __pyx_t_22 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
                          index = 0; __pyx_t_3 = __pyx_t_22(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L46_unpacking_failed;
                          __Pyx_GOTREF(__pyx_t_3);
                          index = 1; __pyx_t_2 = __pyx_t_22(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L46_unpacking_failed;
                          __Pyx_GOTREF(__pyx_t_2);
                          if (__Pyx_IternextUnpackEndCheck(__pyx_t_22(__pyx_t_1), 2) < 0) __PYX_ERR(0, 2086, __pyx_L24_error)
                          __pyx_t_22 = NULL;
                          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                          goto __pyx_L47_unpacking_done;
                          __pyx_L46_unpacking_failed:;
                          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                          __pyx_t_22 = NULL;
                          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                          __PYX_ERR(0, 2086, __pyx_L24_error)
                          __pyx_L47_unpacking_done:;
                        }
                        __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_3);
                        __pyx_t_3 = 0;
                        __pyx_v_tokens = __pyx_t_2;
                        __pyx_t_2 = 0;
                      }
                      __pyx_L33:;

                      /* "cPyparsing.pyx":2074
 *                         if self.debugActions[TRY]:
 *                             self.debugActions[TRY](instring, loc, self)
 *                         try:             # <<<<<<<<<<<<<<
 *                             if callPreParse and self.callPreparse:
 *                                 preloc = self.preParse(instring, loc)
 */
                    }
                    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                    __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                    goto __pyx_L29_try_end;
                    __pyx_L24_error:;
                    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                    __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                    __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                    __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                    __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

                    /* "cPyparsing.pyx":2087
 *                             else:
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                         except Exception as err:             # <<<<<<<<<<<<<<
 *                             # ~ print ("Exception raised:", err)
 *                             if self.debugActions[FAIL]:
 */
                    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
                    if (__pyx_t_6) {
                      __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
                      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_2, &__pyx_t_3) < 0) __PYX_ERR(0, 2087, __pyx_L26_except_error)
                      __Pyx_XGOTREF(__pyx_t_5);
                      __Pyx_XGOTREF(__pyx_t_2);
                      __Pyx_XGOTREF(__pyx_t_3);
                      __Pyx_INCREF(__pyx_t_2);
                      __pyx_v_err = __pyx_t_2;
                      /*try:*/ {

                        /* "cPyparsing.pyx":2089
 *                         except Exception as err:
 *                             # ~ print ("Exception raised:", err)
 *                             if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                                 self.debugActions[FAIL](instring, tokensStart, self, err)
 *                             if self.failAction:
 */
                        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2089, __pyx_L53_error)
                        __Pyx_GOTREF(__pyx_t_1);
                        __Pyx_GetModuleGlobalName(__pyx_t_23, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2089, __pyx_L53_error)
                        __Pyx_GOTREF(__pyx_t_23);
                        __pyx_t_25 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_23); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2089, __pyx_L53_error)
                        __Pyx_GOTREF(__pyx_t_25);
                        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                        __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2089, __pyx_L53_error)
                        __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                        if (__pyx_t_10) {

                          /* "cPyparsing.pyx":2090
 *                             # ~ print ("Exception raised:", err)
 *                             if self.debugActions[FAIL]:
 *                                 self.debugActions[FAIL](instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                             if self.failAction:
 *                                 self.failAction(instring, tokensStart, self, err)
 */
                          __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2090, __pyx_L53_error)
                          __Pyx_GOTREF(__pyx_t_23);
                          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2090, __pyx_L53_error)
                          __Pyx_GOTREF(__pyx_t_1);
                          __pyx_t_24 = __Pyx_PyObject_GetItem(__pyx_t_23, __pyx_t_1); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2090, __pyx_L53_error)
                          __Pyx_GOTREF(__pyx_t_24);
                          __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                          if (unlikely(!__pyx_v_tokensStart)) { __Pyx_RaiseUnboundLocalError("tokensStart"); __PYX_ERR(0, 2090, __pyx_L53_error) }
                          __pyx_t_1 = NULL;
                          __pyx_t_6 = 0;
                          #if CYTHON_UNPACK_METHODS
                          if (unlikely(PyMethod_Check(__pyx_t_24))) {
                            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_24);
                            if (likely(__pyx_t_1)) {
                              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_24);
                              __Pyx_INCREF(__pyx_t_1);
                              __Pyx_INCREF(function);
                              __Pyx_DECREF_SET(__pyx_t_24, function);
                              __pyx_t_6 = 1;
                            }
                          }
                          #endif
                          {
                            PyObject *__pyx_callargs[5] = {__pyx_t_1, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
                            __pyx_t_25 = __Pyx_PyObject_FastCall(__pyx_t_24, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
                            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                            if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2090, __pyx_L53_error)
                            __Pyx_GOTREF(__pyx_t_25);
                            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
                          }
                          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;

                          /* "cPyparsing.pyx":2089
 *                         except Exception as err:
 *                             # ~ print ("Exception raised:", err)
 *                             if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                                 self.debugActions[FAIL](instring, tokensStart, self, err)
 *                             if self.failAction:
 */
                        }

                        /* "cPyparsing.pyx":2091
 *                             if self.debugActions[FAIL]:
 *                                 self.debugActions[FAIL](instring, tokensStart, self, err)
 *                             if self.failAction:             # <<<<<<<<<<<<<<
 *                                 self.failAction(instring, tokensStart, self, err)
 *                             raise
 */
                        __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2091, __pyx_L53_error)
                        __Pyx_GOTREF(__pyx_t_25);
                        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2091, __pyx_L53_error)
                        __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                        if (__pyx_t_10) {

                          /* "cPyparsing.pyx":2092
 *                                 self.debugActions[FAIL](instring, tokensStart, self, err)
 *                             if self.failAction:
 *                                 self.failAction(instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                             raise
 *                     else:
 */
                          __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2092, __pyx_L53_error)
                          __Pyx_GOTREF(__pyx_t_24);
                          if (unlikely(!__pyx_v_tokensStart)) { __Pyx_RaiseUnboundLocalError("tokensStart"); __PYX_ERR(0, 2092, __pyx_L53_error) }
                          __pyx_t_1 = NULL;
                          __pyx_t_6 = 0;
                          #if CYTHON_UNPACK_METHODS
                          if (likely(PyMethod_Check(__pyx_t_24))) {
                            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_24);
                            if (likely(__pyx_t_1)) {
                              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_24);
                              __Pyx_INCREF(__pyx_t_1);
                              __Pyx_INCREF(function);
                              __Pyx_DECREF_SET(__pyx_t_24, function);
                              __pyx_t_6 = 1;
                            }
                          }
                          #endif
                          {
                            PyObject *__pyx_callargs[5] = {__pyx_t_1, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
                            __pyx_t_25 = __Pyx_PyObject_FastCall(__pyx_t_24, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
                            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                            if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2092, __pyx_L53_error)
                            __Pyx_GOTREF(__pyx_t_25);
                            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
                          }
                          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;

                          /* "cPyparsing.pyx":2091
 *                             if self.debugActions[FAIL]:
 *                                 self.debugActions[FAIL](instring, tokensStart, self, err)
 *                             if self.failAction:             # <<<<<<<<<<<<<<
 *                                 self.failAction(instring, tokensStart, self, err)
 *                             raise
 */
                        }

                        /* "cPyparsing.pyx":2093
 *                             if self.failAction:
 *                                 self.failAction(instring, tokensStart, self, err)
 *                             raise             # <<<<<<<<<<<<<<
 *                     else:
 *                         if callPreParse and self.callPreparse:
 */
                        __Pyx_GIVEREF(__pyx_t_5);
                        __Pyx_GIVEREF(__pyx_t_2);
                        __Pyx_XGIVEREF(__pyx_t_3);
                        __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_2, __pyx_t_3);
                        __pyx_t_5 = 0; __pyx_t_2 = 0; __pyx_t_3 = 0; 
                        __PYX_ERR(0, 2093, __pyx_L53_error)
                      }

                      /* "cPyparsing.pyx":2087
 *                             else:
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                         except Exception as err:             # <<<<<<<<<<<<<<
 *                             # ~ print ("Exception raised:", err)
 *                             if self.debugActions[FAIL]:
 */
                      /*finally:*/ {
                        __pyx_L53_error:;
                        /*exception exit:*/{
                          __Pyx_PyThreadState_declare
                          __Pyx_PyThreadState_assign
                          __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0;
                          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                          __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                          __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                          __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                          __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_29, &__pyx_t_30, &__pyx_t_31);
                          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
                          __Pyx_XGOTREF(__pyx_t_21);
                          __Pyx_XGOTREF(__pyx_t_20);
                          __Pyx_XGOTREF(__pyx_t_19);
                          __Pyx_XGOTREF(__pyx_t_29);
                          __Pyx_XGOTREF(__pyx_t_30);
                          __Pyx_XGOTREF(__pyx_t_31);
                          __pyx_t_6 = __pyx_lineno; __pyx_t_27 = __pyx_clineno; __pyx_t_28 = __pyx_filename;
                          {
                            __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
                          }
                          if (PY_MAJOR_VERSION >= 3) {
                            __Pyx_XGIVEREF(__pyx_t_29);
                            __Pyx_XGIVEREF(__pyx_t_30);
                            __Pyx_XGIVEREF(__pyx_t_31);
                            __Pyx_ExceptionReset(__pyx_t_29, __pyx_t_30, __pyx_t_31);
                          }
                          __Pyx_XGIVEREF(__pyx_t_21);
                          __Pyx_XGIVEREF(__pyx_t_20);
                          __Pyx_XGIVEREF(__pyx_t_19);
                          __Pyx_ErrRestore(__pyx_t_21, __pyx_t_20, __pyx_t_19);
                          __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0;
                          __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_27; __pyx_filename = __pyx_t_28;
                          goto __pyx_L26_except_error;
                        }
                      }
                    }
                    goto __pyx_L26_except_error;

                    /* "cPyparsing.pyx":2074
 *                         if self.debugActions[TRY]:
 *                             self.debugActions[TRY](instring, loc, self)
 *                         try:             # <<<<<<<<<<<<<<
 *                             if callPreParse and self.callPreparse:
 *                                 preloc = self.preParse(instring, loc)
 */
                    __pyx_L26_except_error:;
                    __Pyx_XGIVEREF(__pyx_t_15);
                    __Pyx_XGIVEREF(__pyx_t_16);
                    __Pyx_XGIVEREF(__pyx_t_17);
                    __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
                    goto __pyx_L14_error;
                    __pyx_L29_try_end:;
                  }

                  /* "cPyparsing.pyx":2070
 *                     debugging = (self.debug)  # and doActions)
 * 
 *                     if debugging or self.failAction:             # <<<<<<<<<<<<<<
 *                         # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                         if self.debugActions[TRY]:
 */
                  goto __pyx_L20;
                }

                /* "cPyparsing.pyx":2095
 *                             raise
 *                     else:
 *                         if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                             preloc = self.preParse(instring, loc)
 *                         else:
 */
                /*else*/ {
                  __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_callPreParse); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2095, __pyx_L14_error)
                  if (__pyx_t_14) {
                  } else {
                    __pyx_t_10 = __pyx_t_14;
                    goto __pyx_L62_bool_binop_done;
                  }
                  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2095, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2095, __pyx_L14_error)
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __pyx_t_10 = __pyx_t_14;
                  __pyx_L62_bool_binop_done:;
                  if (__pyx_t_10) {

                    /* "cPyparsing.pyx":2096
 *                     else:
 *                         if callPreParse and self.callPreparse:
 *                             preloc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *                         else:
 *                             preloc = loc
 */
                    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2096, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __pyx_t_5 = NULL;
                    __pyx_t_27 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (likely(PyMethod_Check(__pyx_t_2))) {
                      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
                      if (likely(__pyx_t_5)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                        __Pyx_INCREF(__pyx_t_5);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_2, function);
                        __pyx_t_27 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc};
                      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_27, 2+__pyx_t_27);
                      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2096, __pyx_L14_error)
                      __Pyx_GOTREF(__pyx_t_3);
                      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                    }
                    __pyx_v_preloc = __pyx_t_3;
                    __pyx_t_3 = 0;

                    /* "cPyparsing.pyx":2095
 *                             raise
 *                     else:
 *                         if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                             preloc = self.preParse(instring, loc)
 *                         else:
 */
                    goto __pyx_L61;
                  }

                  /* "cPyparsing.pyx":2098
 *                             preloc = self.preParse(instring, loc)
 *                         else:
 *                             preloc = loc             # <<<<<<<<<<<<<<
 *                         tokensStart = preloc
 *                         if self.mayIndexError or preloc >= len(instring):
 */
                  /*else*/ {
                    __Pyx_INCREF(__pyx_v_loc);
                    __pyx_v_preloc = __pyx_v_loc;
                  }
                  __pyx_L61:;

                  /* "cPyparsing.pyx":2099
 *                         else:
 *                             preloc = loc
 *                         tokensStart = preloc             # <<<<<<<<<<<<<<
 *                         if self.mayIndexError or preloc >= len(instring):
 *                             try:
 */
                  __Pyx_INCREF(__pyx_v_preloc);
                  __pyx_v_tokensStart = __pyx_v_preloc;

                  /* "cPyparsing.pyx":2100
 *                             preloc = loc
 *                         tokensStart = preloc
 *                         if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                             try:
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
                  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2100, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2100, __pyx_L14_error)
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  if (!__pyx_t_14) {
                  } else {
                    __pyx_t_10 = __pyx_t_14;
                    goto __pyx_L65_bool_binop_done;
                  }
                  __pyx_t_18 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_18 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2100, __pyx_L14_error)
                  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_18); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2100, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __pyx_t_2 = PyObject_RichCompare(__pyx_v_preloc, __pyx_t_3, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2100, __pyx_L14_error)
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2100, __pyx_L14_error)
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  __pyx_t_10 = __pyx_t_14;
                  __pyx_L65_bool_binop_done:;
                  if (__pyx_t_10) {

                    /* "cPyparsing.pyx":2101
 *                         tokensStart = preloc
 *                         if self.mayIndexError or preloc >= len(instring):
 *                             try:             # <<<<<<<<<<<<<<
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                             except IndexError:
 */
                    {
                      __Pyx_PyThreadState_declare
                      __Pyx_PyThreadState_assign
                      __Pyx_ExceptionSave(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
                      __Pyx_XGOTREF(__pyx_t_17);
                      __Pyx_XGOTREF(__pyx_t_16);
                      __Pyx_XGOTREF(__pyx_t_15);
                      /*try:*/ {

                        /* "cPyparsing.pyx":2102
 *                         if self.mayIndexError or preloc >= len(instring):
 *                             try:
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                             except IndexError:
 *                                 raise ParseException(instring, len(instring), self.errmsg, self)
 */
                        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2102, __pyx_L67_error)
                        __Pyx_GOTREF(__pyx_t_3);
                        __pyx_t_5 = NULL;
                        __pyx_t_27 = 0;
                        #if CYTHON_UNPACK_METHODS
                        if (likely(PyMethod_Check(__pyx_t_3))) {
                          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
                          if (likely(__pyx_t_5)) {
                            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                            __Pyx_INCREF(__pyx_t_5);
                            __Pyx_INCREF(function);
                            __Pyx_DECREF_SET(__pyx_t_3, function);
                            __pyx_t_27 = 1;
                          }
                        }
                        #endif
                        {
                          PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
                          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
                          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2102, __pyx_L67_error)
                          __Pyx_GOTREF(__pyx_t_2);
                          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                        }
                        if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
                          PyObject* sequence = __pyx_t_2;
                          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                          if (unlikely(size != 2)) {
                            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                            __PYX_ERR(0, 2102, __pyx_L67_error)
                          }
                          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                          if (likely(PyTuple_CheckExact(sequence))) {
                            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
                            __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
                          } else {
                            __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
                            __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
                          }
                          __Pyx_INCREF(__pyx_t_3);
                          __Pyx_INCREF(__pyx_t_5);
                          #else
                          __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2102, __pyx_L67_error)
                          __Pyx_GOTREF(__pyx_t_3);
                          __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2102, __pyx_L67_error)
                          __Pyx_GOTREF(__pyx_t_5);
                          #endif
                          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                        } else {
                          Py_ssize_t index = -1;
                          __pyx_t_25 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2102, __pyx_L67_error)
                          __Pyx_GOTREF(__pyx_t_25);
                          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                          __pyx_t_22 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_25);
                          index = 0; __pyx_t_3 = __pyx_t_22(__pyx_t_25); if (unlikely(!__pyx_t_3)) goto __pyx_L73_unpacking_failed;
                          __Pyx_GOTREF(__pyx_t_3);
                          index = 1; __pyx_t_5 = __pyx_t_22(__pyx_t_25); if (unlikely(!__pyx_t_5)) goto __pyx_L73_unpacking_failed;
                          __Pyx_GOTREF(__pyx_t_5);
                          if (__Pyx_IternextUnpackEndCheck(__pyx_t_22(__pyx_t_25), 2) < 0) __PYX_ERR(0, 2102, __pyx_L67_error)
                          __pyx_t_22 = NULL;
                          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                          goto __pyx_L74_unpacking_done;
                          __pyx_L73_unpacking_failed:;
                          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                          __pyx_t_22 = NULL;
                          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                          __PYX_ERR(0, 2102, __pyx_L67_error)
                          __pyx_L74_unpacking_done:;
                        }
                        __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_3);
                        __pyx_t_3 = 0;
                        __pyx_v_tokens = __pyx_t_5;
                        __pyx_t_5 = 0;

                        /* "cPyparsing.pyx":2101
 *                         tokensStart = preloc
 *                         if self.mayIndexError or preloc >= len(instring):
 *                             try:             # <<<<<<<<<<<<<<
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                             except IndexError:
 */
                      }
                      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                      goto __pyx_L72_try_end;
                      __pyx_L67_error:;
                      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                      __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                      __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                      __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                      __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

                      /* "cPyparsing.pyx":2103
 *                             try:
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                             except IndexError:             # <<<<<<<<<<<<<<
 *                                 raise ParseException(instring, len(instring), self.errmsg, self)
 *                         else:
 */
                      __pyx_t_27 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
                      if (__pyx_t_27) {
                        __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
                        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_5, &__pyx_t_3) < 0) __PYX_ERR(0, 2103, __pyx_L69_except_error)
                        __Pyx_XGOTREF(__pyx_t_2);
                        __Pyx_XGOTREF(__pyx_t_5);
                        __Pyx_XGOTREF(__pyx_t_3);

                        /* "cPyparsing.pyx":2104
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                             except IndexError:
 *                                 raise ParseException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *                         else:
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
                        __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2104, __pyx_L69_except_error)
                        __Pyx_GOTREF(__pyx_t_24);
                        __pyx_t_18 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_18 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2104, __pyx_L69_except_error)
                        __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_18); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2104, __pyx_L69_except_error)
                        __Pyx_GOTREF(__pyx_t_1);
                        __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2104, __pyx_L69_except_error)
                        __Pyx_GOTREF(__pyx_t_23);
                        __pyx_t_26 = NULL;
                        __pyx_t_27 = 0;
                        #if CYTHON_UNPACK_METHODS
                        if (unlikely(PyMethod_Check(__pyx_t_24))) {
                          __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_24);
                          if (likely(__pyx_t_26)) {
                            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_24);
                            __Pyx_INCREF(__pyx_t_26);
                            __Pyx_INCREF(function);
                            __Pyx_DECREF_SET(__pyx_t_24, function);
                            __pyx_t_27 = 1;
                          }
                        }
                        #endif
                        {
                          PyObject *__pyx_callargs[5] = {__pyx_t_26, __pyx_v_instring, __pyx_t_1, __pyx_t_23, __pyx_v_self};
                          __pyx_t_25 = __Pyx_PyObject_FastCall(__pyx_t_24, __pyx_callargs+1-__pyx_t_27, 4+__pyx_t_27);
                          __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                          __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                          if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2104, __pyx_L69_except_error)
                          __Pyx_GOTREF(__pyx_t_25);
                          __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
                        }
                        __Pyx_Raise(__pyx_t_25, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                        __PYX_ERR(0, 2104, __pyx_L69_except_error)
                      }
                      goto __pyx_L69_except_error;

                      /* "cPyparsing.pyx":2101
 *                         tokensStart = preloc
 *                         if self.mayIndexError or preloc >= len(instring):
 *                             try:             # <<<<<<<<<<<<<<
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                             except IndexError:
 */
                      __pyx_L69_except_error:;
                      __Pyx_XGIVEREF(__pyx_t_17);
                      __Pyx_XGIVEREF(__pyx_t_16);
                      __Pyx_XGIVEREF(__pyx_t_15);
                      __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
                      goto __pyx_L14_error;
                      __pyx_L72_try_end:;
                    }

                    /* "cPyparsing.pyx":2100
 *                             preloc = loc
 *                         tokensStart = preloc
 *                         if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                             try:
 *                                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
                    goto __pyx_L64;
                  }

                  /* "cPyparsing.pyx":2106
 *                                 raise ParseException(instring, len(instring), self.errmsg, self)
 *                         else:
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 * 
 *                     tokens = self.postParse(instring, loc, tokens)
 */
                  /*else*/ {
                    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2106, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_5);
                    __pyx_t_2 = NULL;
                    __pyx_t_27 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (likely(PyMethod_Check(__pyx_t_5))) {
                      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
                      if (likely(__pyx_t_2)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                        __Pyx_INCREF(__pyx_t_2);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_5, function);
                        __pyx_t_27 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
                      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
                      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2106, __pyx_L14_error)
                      __Pyx_GOTREF(__pyx_t_3);
                      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                    }
                    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
                      PyObject* sequence = __pyx_t_3;
                      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                      if (unlikely(size != 2)) {
                        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                        __PYX_ERR(0, 2106, __pyx_L14_error)
                      }
                      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                      if (likely(PyTuple_CheckExact(sequence))) {
                        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
                        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
                      } else {
                        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
                        __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
                      }
                      __Pyx_INCREF(__pyx_t_5);
                      __Pyx_INCREF(__pyx_t_2);
                      #else
                      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2106, __pyx_L14_error)
                      __Pyx_GOTREF(__pyx_t_5);
                      __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2106, __pyx_L14_error)
                      __Pyx_GOTREF(__pyx_t_2);
                      #endif
                      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                    } else {
                      Py_ssize_t index = -1;
                      __pyx_t_25 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2106, __pyx_L14_error)
                      __Pyx_GOTREF(__pyx_t_25);
                      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                      __pyx_t_22 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_25);
                      index = 0; __pyx_t_5 = __pyx_t_22(__pyx_t_25); if (unlikely(!__pyx_t_5)) goto __pyx_L77_unpacking_failed;
                      __Pyx_GOTREF(__pyx_t_5);
                      index = 1; __pyx_t_2 = __pyx_t_22(__pyx_t_25); if (unlikely(!__pyx_t_2)) goto __pyx_L77_unpacking_failed;
                      __Pyx_GOTREF(__pyx_t_2);
                      if (__Pyx_IternextUnpackEndCheck(__pyx_t_22(__pyx_t_25), 2) < 0) __PYX_ERR(0, 2106, __pyx_L14_error)
                      __pyx_t_22 = NULL;
                      __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                      goto __pyx_L78_unpacking_done;
                      __pyx_L77_unpacking_failed:;
                      __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                      __pyx_t_22 = NULL;
                      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                      __PYX_ERR(0, 2106, __pyx_L14_error)
                      __pyx_L78_unpacking_done:;
                    }
                    __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_5);
                    __pyx_t_5 = 0;
                    __pyx_v_tokens = __pyx_t_2;
                    __pyx_t_2 = 0;
                  }
                  __pyx_L64:;
                }
                __pyx_L20:;

                /* "cPyparsing.pyx":2108
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)
 * 
 *                     tokens = self.postParse(instring, loc, tokens)             # <<<<<<<<<<<<<<
 * 
 *                     retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 */
                __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_postParse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2108, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_5 = NULL;
                __pyx_t_27 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_2))) {
                  __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
                  if (likely(__pyx_t_5)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                    __Pyx_INCREF(__pyx_t_5);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_2, function);
                    __pyx_t_27 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokens};
                  __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
                  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2108, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                }
                __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_3);
                __pyx_t_3 = 0;

                /* "cPyparsing.pyx":2110
 *                     tokens = self.postParse(instring, loc, tokens)
 * 
 *                     retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)             # <<<<<<<<<<<<<<
 *                     if self.parseAction and (doActions or self.callDuringTry):
 *                         if debugging:
 */
                __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2110, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2110, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2110, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_INCREF(__pyx_v_tokens);
                __Pyx_GIVEREF(__pyx_v_tokens);
                if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_tokens)) __PYX_ERR(0, 2110, __pyx_L14_error);
                __Pyx_GIVEREF(__pyx_t_2);
                if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(0, 2110, __pyx_L14_error);
                __pyx_t_2 = 0;
                __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2110, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2110, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_25);
                if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_asList, __pyx_t_25) < 0) __PYX_ERR(0, 2110, __pyx_L14_error)
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2110, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_25);
                if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_modal, __pyx_t_25) < 0) __PYX_ERR(0, 2110, __pyx_L14_error)
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                __pyx_t_25 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2110, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_25);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __pyx_v_retTokens = __pyx_t_25;
                __pyx_t_25 = 0;

                /* "cPyparsing.pyx":2111
 * 
 *                     retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *                     if self.parseAction and (doActions or self.callDuringTry):             # <<<<<<<<<<<<<<
 *                         if debugging:
 *                             try:
 */
                __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2111, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_25);
                __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2111, __pyx_L14_error)
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                if (__pyx_t_14) {
                } else {
                  __pyx_t_10 = __pyx_t_14;
                  goto __pyx_L80_bool_binop_done;
                }
                __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_doActions); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2111, __pyx_L14_error)
                if (!__pyx_t_14) {
                } else {
                  __pyx_t_10 = __pyx_t_14;
                  goto __pyx_L80_bool_binop_done;
                }
                __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2111, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_25);
                __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 2111, __pyx_L14_error)
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                __pyx_t_10 = __pyx_t_14;
                __pyx_L80_bool_binop_done:;
                if (__pyx_t_10) {

                  /* "cPyparsing.pyx":2112
 *                     retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *                     if self.parseAction and (doActions or self.callDuringTry):
 *                         if debugging:             # <<<<<<<<<<<<<<
 *                             try:
 *                                 for fn in self.parseAction:
 */
                  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2112, __pyx_L14_error)
                  if (__pyx_t_10) {

                    /* "cPyparsing.pyx":2113
 *                     if self.parseAction and (doActions or self.callDuringTry):
 *                         if debugging:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 for fn in self.parseAction:
 *                                     try:
 */
                    {
                      __Pyx_PyThreadState_declare
                      __Pyx_PyThreadState_assign
                      __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
                      __Pyx_XGOTREF(__pyx_t_15);
                      __Pyx_XGOTREF(__pyx_t_16);
                      __Pyx_XGOTREF(__pyx_t_17);
                      /*try:*/ {

                        /* "cPyparsing.pyx":2114
 *                         if debugging:
 *                             try:
 *                                 for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                                     try:
 *                                         tokens = fn(instring, tokensStart, retTokens)
 */
                        __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2114, __pyx_L84_error)
                        __Pyx_GOTREF(__pyx_t_25);
                        if (likely(PyList_CheckExact(__pyx_t_25)) || PyTuple_CheckExact(__pyx_t_25)) {
                          __pyx_t_2 = __pyx_t_25; __Pyx_INCREF(__pyx_t_2);
                          __pyx_t_18 = 0;
                          __pyx_t_32 = NULL;
                        } else {
                          __pyx_t_18 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_25); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2114, __pyx_L84_error)
                          __Pyx_GOTREF(__pyx_t_2);
                          __pyx_t_32 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 2114, __pyx_L84_error)
                        }
                        __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                        for (;;) {
                          if (likely(!__pyx_t_32)) {
                            if (likely(PyList_CheckExact(__pyx_t_2))) {
                              {
                                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
                                #if !CYTHON_ASSUME_SAFE_MACROS
                                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2114, __pyx_L84_error)
                                #endif
                                if (__pyx_t_18 >= __pyx_temp) break;
                              }
                              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                              __pyx_t_25 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_18); __Pyx_INCREF(__pyx_t_25); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(0, 2114, __pyx_L84_error)
                              #else
                              __pyx_t_25 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2114, __pyx_L84_error)
                              __Pyx_GOTREF(__pyx_t_25);
                              #endif
                            } else {
                              {
                                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
                                #if !CYTHON_ASSUME_SAFE_MACROS
                                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2114, __pyx_L84_error)
                                #endif
                                if (__pyx_t_18 >= __pyx_temp) break;
                              }
                              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                              __pyx_t_25 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_18); __Pyx_INCREF(__pyx_t_25); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(0, 2114, __pyx_L84_error)
                              #else
                              __pyx_t_25 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2114, __pyx_L84_error)
                              __Pyx_GOTREF(__pyx_t_25);
                              #endif
                            }
                          } else {
                            __pyx_t_25 = __pyx_t_32(__pyx_t_2);
                            if (unlikely(!__pyx_t_25)) {
                              PyObject* exc_type = PyErr_Occurred();
                              if (exc_type) {
                                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                                else __PYX_ERR(0, 2114, __pyx_L84_error)
                              }
                              break;
                            }
                            __Pyx_GOTREF(__pyx_t_25);
                          }
                          __Pyx_XDECREF_SET(__pyx_v_fn, __pyx_t_25);
                          __pyx_t_25 = 0;

                          /* "cPyparsing.pyx":2115
 *                             try:
 *                                 for fn in self.parseAction:
 *                                     try:             # <<<<<<<<<<<<<<
 *                                         tokens = fn(instring, tokensStart, retTokens)
 *                                     except IndexError as parse_action_exc:
 */
                          {
                            __Pyx_PyThreadState_declare
                            __Pyx_PyThreadState_assign
                            __Pyx_ExceptionSave(&__pyx_t_31, &__pyx_t_30, &__pyx_t_29);
                            __Pyx_XGOTREF(__pyx_t_31);
                            __Pyx_XGOTREF(__pyx_t_30);
                            __Pyx_XGOTREF(__pyx_t_29);
                            /*try:*/ {

                              /* "cPyparsing.pyx":2116
 *                                 for fn in self.parseAction:
 *                                     try:
 *                                         tokens = fn(instring, tokensStart, retTokens)             # <<<<<<<<<<<<<<
 *                                     except IndexError as parse_action_exc:
 *                                         exc = ParseException("exception raised in parse action")
 */
                              __Pyx_INCREF(__pyx_v_fn);
                              __pyx_t_5 = __pyx_v_fn; __pyx_t_3 = NULL;
                              __pyx_t_27 = 0;
                              #if CYTHON_UNPACK_METHODS
                              if (unlikely(PyMethod_Check(__pyx_t_5))) {
                                __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
                                if (likely(__pyx_t_3)) {
                                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                                  __Pyx_INCREF(__pyx_t_3);
                                  __Pyx_INCREF(function);
                                  __Pyx_DECREF_SET(__pyx_t_5, function);
                                  __pyx_t_27 = 1;
                                }
                              }
                              #endif
                              {
                                PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
                                __pyx_t_25 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
                                __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                                if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2116, __pyx_L92_error)
                                __Pyx_GOTREF(__pyx_t_25);
                                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                              }
                              __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_25);
                              __pyx_t_25 = 0;

                              /* "cPyparsing.pyx":2115
 *                             try:
 *                                 for fn in self.parseAction:
 *                                     try:             # <<<<<<<<<<<<<<
 *                                         tokens = fn(instring, tokensStart, retTokens)
 *                                     except IndexError as parse_action_exc:
 */
                            }
                            __Pyx_XDECREF(__pyx_t_31); __pyx_t_31 = 0;
                            __Pyx_XDECREF(__pyx_t_30); __pyx_t_30 = 0;
                            __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
                            goto __pyx_L99_try_end;
                            __pyx_L92_error:;
                            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                            __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                            __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                            __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

                            /* "cPyparsing.pyx":2117
 *                                     try:
 *                                         tokens = fn(instring, tokensStart, retTokens)
 *                                     except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                                         exc = ParseException("exception raised in parse action")
 *                                         exc.__cause__ = parse_action_exc
 */
                            __pyx_t_27 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
                            if (__pyx_t_27) {
                              __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
                              if (__Pyx_GetException(&__pyx_t_25, &__pyx_t_5, &__pyx_t_3) < 0) __PYX_ERR(0, 2117, __pyx_L94_except_error)
                              __Pyx_XGOTREF(__pyx_t_25);
                              __Pyx_XGOTREF(__pyx_t_5);
                              __Pyx_XGOTREF(__pyx_t_3);
                              __Pyx_INCREF(__pyx_t_5);
                              __pyx_v_parse_action_exc = __pyx_t_5;
                              /*try:*/ {

                                /* "cPyparsing.pyx":2118
 *                                         tokens = fn(instring, tokensStart, retTokens)
 *                                     except IndexError as parse_action_exc:
 *                                         exc = ParseException("exception raised in parse action")             # <<<<<<<<<<<<<<
 *                                         exc.__cause__ = parse_action_exc
 *                                         raise exc
 */
                                __Pyx_GetModuleGlobalName(__pyx_t_23, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2118, __pyx_L105_error)
                                __Pyx_GOTREF(__pyx_t_23);
                                __pyx_t_1 = NULL;
                                __pyx_t_27 = 0;
                                #if CYTHON_UNPACK_METHODS
                                if (unlikely(PyMethod_Check(__pyx_t_23))) {
                                  __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_23);
                                  if (likely(__pyx_t_1)) {
                                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_23);
                                    __Pyx_INCREF(__pyx_t_1);
                                    __Pyx_INCREF(function);
                                    __Pyx_DECREF_SET(__pyx_t_23, function);
                                    __pyx_t_27 = 1;
                                  }
                                }
                                #endif
                                {
                                  PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_kp_u_exception_raised_in_parse_action};
                                  __pyx_t_24 = __Pyx_PyObject_FastCall(__pyx_t_23, __pyx_callargs+1-__pyx_t_27, 1+__pyx_t_27);
                                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                                  if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2118, __pyx_L105_error)
                                  __Pyx_GOTREF(__pyx_t_24);
                                  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                                }
                                __pyx_v_exc = __pyx_t_24;
                                __pyx_t_24 = 0;

                                /* "cPyparsing.pyx":2119
 *                                     except IndexError as parse_action_exc:
 *                                         exc = ParseException("exception raised in parse action")
 *                                         exc.__cause__ = parse_action_exc             # <<<<<<<<<<<<<<
 *                                         raise exc
 * 
 */
                                if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_cause, __pyx_v_parse_action_exc) < 0) __PYX_ERR(0, 2119, __pyx_L105_error)

                                /* "cPyparsing.pyx":2120
 *                                         exc = ParseException("exception raised in parse action")
 *                                         exc.__cause__ = parse_action_exc
 *                                         raise exc             # <<<<<<<<<<<<<<
 * 
 *                                     if tokens is not None and tokens is not retTokens:
 */
                                __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
                                __PYX_ERR(0, 2120, __pyx_L105_error)
                              }

                              /* "cPyparsing.pyx":2117
 *                                     try:
 *                                         tokens = fn(instring, tokensStart, retTokens)
 *                                     except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                                         exc = ParseException("exception raised in parse action")
 *                                         exc.__cause__ = parse_action_exc
 */
                              /*finally:*/ {
                                __pyx_L105_error:;
                                /*exception exit:*/{
                                  __Pyx_PyThreadState_declare
                                  __Pyx_PyThreadState_assign
                                  __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_34 = 0; __pyx_t_35 = 0; __pyx_t_36 = 0;
                                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                                  __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                                  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                                  __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                                  if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_34, &__pyx_t_35, &__pyx_t_36);
                                  if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
                                  __Pyx_XGOTREF(__pyx_t_19);
                                  __Pyx_XGOTREF(__pyx_t_20);
                                  __Pyx_XGOTREF(__pyx_t_21);
                                  __Pyx_XGOTREF(__pyx_t_34);
                                  __Pyx_XGOTREF(__pyx_t_35);
                                  __Pyx_XGOTREF(__pyx_t_36);
                                  __pyx_t_27 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_33 = __pyx_filename;
                                  {
                                    __Pyx_DECREF(__pyx_v_parse_action_exc); __pyx_v_parse_action_exc = 0;
                                  }
                                  if (PY_MAJOR_VERSION >= 3) {
                                    __Pyx_XGIVEREF(__pyx_t_34);
                                    __Pyx_XGIVEREF(__pyx_t_35);
                                    __Pyx_XGIVEREF(__pyx_t_36);
                                    __Pyx_ExceptionReset(__pyx_t_34, __pyx_t_35, __pyx_t_36);
                                  }
                                  __Pyx_XGIVEREF(__pyx_t_19);
                                  __Pyx_XGIVEREF(__pyx_t_20);
                                  __Pyx_XGIVEREF(__pyx_t_21);
                                  __Pyx_ErrRestore(__pyx_t_19, __pyx_t_20, __pyx_t_21);
                                  __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_34 = 0; __pyx_t_35 = 0; __pyx_t_36 = 0;
                                  __pyx_lineno = __pyx_t_27; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_33;
                                  goto __pyx_L94_except_error;
                                }
                              }
                            }
                            goto __pyx_L94_except_error;

                            /* "cPyparsing.pyx":2115
 *                             try:
 *                                 for fn in self.parseAction:
 *                                     try:             # <<<<<<<<<<<<<<
 *                                         tokens = fn(instring, tokensStart, retTokens)
 *                                     except IndexError as parse_action_exc:
 */
                            __pyx_L94_except_error:;
                            __Pyx_XGIVEREF(__pyx_t_31);
                            __Pyx_XGIVEREF(__pyx_t_30);
                            __Pyx_XGIVEREF(__pyx_t_29);
                            __Pyx_ExceptionReset(__pyx_t_31, __pyx_t_30, __pyx_t_29);
                            goto __pyx_L84_error;
                            __pyx_L99_try_end:;
                          }

                          /* "cPyparsing.pyx":2122
 *                                         raise exc
 * 
 *                                     if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                                         retTokens = ParseResults(tokens,
 *                                                                 self.resultsName,
 */
                          __pyx_t_14 = (__pyx_v_tokens != Py_None);
                          if (__pyx_t_14) {
                          } else {
                            __pyx_t_10 = __pyx_t_14;
                            goto __pyx_L112_bool_binop_done;
                          }
                          __pyx_t_14 = (__pyx_v_tokens != __pyx_v_retTokens);
                          __pyx_t_10 = __pyx_t_14;
                          __pyx_L112_bool_binop_done:;
                          if (__pyx_t_10) {

                            /* "cPyparsing.pyx":2123
 * 
 *                                     if tokens is not None and tokens is not retTokens:
 *                                         retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                                 self.resultsName,
 *                                                                 asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                            __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2123, __pyx_L84_error)
                            __Pyx_GOTREF(__pyx_t_3);

                            /* "cPyparsing.pyx":2124
 *                                     if tokens is not None and tokens is not retTokens:
 *                                         retTokens = ParseResults(tokens,
 *                                                                 self.resultsName,             # <<<<<<<<<<<<<<
 *                                                                 asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                                 modal=self.modalResults)
 */
                            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2124, __pyx_L84_error)
                            __Pyx_GOTREF(__pyx_t_5);

                            /* "cPyparsing.pyx":2123
 * 
 *                                     if tokens is not None and tokens is not retTokens:
 *                                         retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                                 self.resultsName,
 *                                                                 asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                            __pyx_t_25 = PyTuple_New(2); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2123, __pyx_L84_error)
                            __Pyx_GOTREF(__pyx_t_25);
                            __Pyx_INCREF(__pyx_v_tokens);
                            __Pyx_GIVEREF(__pyx_v_tokens);
                            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_25, 0, __pyx_v_tokens)) __PYX_ERR(0, 2123, __pyx_L84_error);
                            __Pyx_GIVEREF(__pyx_t_5);
                            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_25, 1, __pyx_t_5)) __PYX_ERR(0, 2123, __pyx_L84_error);
                            __pyx_t_5 = 0;

                            /* "cPyparsing.pyx":2125
 *                                         retTokens = ParseResults(tokens,
 *                                                                 self.resultsName,
 *                                                                 asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),             # <<<<<<<<<<<<<<
 *                                                                 modal=self.modalResults)
 *                             except Exception as err:
 */
                            __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2125, __pyx_L84_error)
                            __Pyx_GOTREF(__pyx_t_5);
                            __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2125, __pyx_L84_error)
                            __Pyx_GOTREF(__pyx_t_23);
                            __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_23); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2125, __pyx_L84_error)
                            if (__pyx_t_10) {
                              __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                            } else {
                              __Pyx_INCREF(__pyx_t_23);
                              __pyx_t_24 = __pyx_t_23;
                              __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                              goto __pyx_L114_bool_binop_done;
                            }
                            __Pyx_GetModuleGlobalName(__pyx_t_23, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2125, __pyx_L84_error)
                            __Pyx_GOTREF(__pyx_t_23);
                            __pyx_t_14 = PyObject_IsInstance(__pyx_v_tokens, __pyx_t_23); 
                            if (!__pyx_t_14) {
                            } else {
                              __pyx_t_10 = __pyx_t_14;
                              goto __pyx_L116_bool_binop_done;
                            }
                            __pyx_t_14 = PyList_Check(__pyx_v_tokens); 
                            __pyx_t_10 = __pyx_t_14;
                            __pyx_L116_bool_binop_done:;
                            __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                            __pyx_t_23 = __Pyx_PyBool_FromLong(__pyx_t_10); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2125, __pyx_L84_error)
                            __Pyx_GOTREF(__pyx_t_23);
                            __pyx_t_24 = __pyx_t_23;
                            __pyx_t_23 = 0;
                            __pyx_L114_bool_binop_done:;
                            if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_asList, __pyx_t_24) < 0) __PYX_ERR(0, 2125, __pyx_L84_error)
                            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;

                            /* "cPyparsing.pyx":2126
 *                                                                 self.resultsName,
 *                                                                 asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                                 modal=self.modalResults)             # <<<<<<<<<<<<<<
 *                             except Exception as err:
 *                                 # ~ print "Exception raised in user parse action:", err
 */
                            __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2126, __pyx_L84_error)
                            __Pyx_GOTREF(__pyx_t_24);
                            if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_modal, __pyx_t_24) < 0) __PYX_ERR(0, 2125, __pyx_L84_error)
                            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;

                            /* "cPyparsing.pyx":2123
 * 
 *                                     if tokens is not None and tokens is not retTokens:
 *                                         retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                                 self.resultsName,
 *                                                                 asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                            __pyx_t_24 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_25, __pyx_t_5); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2123, __pyx_L84_error)
                            __Pyx_GOTREF(__pyx_t_24);
                            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                            __Pyx_DECREF_SET(__pyx_v_retTokens, __pyx_t_24);
                            __pyx_t_24 = 0;

                            /* "cPyparsing.pyx":2122
 *                                         raise exc
 * 
 *                                     if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                                         retTokens = ParseResults(tokens,
 *                                                                 self.resultsName,
 */
                          }

                          /* "cPyparsing.pyx":2114
 *                         if debugging:
 *                             try:
 *                                 for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                                     try:
 *                                         tokens = fn(instring, tokensStart, retTokens)
 */
                        }
                        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                        /* "cPyparsing.pyx":2113
 *                     if self.parseAction and (doActions or self.callDuringTry):
 *                         if debugging:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 for fn in self.parseAction:
 *                                     try:
 */
                      }
                      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                      goto __pyx_L89_try_end;
                      __pyx_L84_error:;
                      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                      __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                      __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                      __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                      __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

                      /* "cPyparsing.pyx":2127
 *                                                                 asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                                 modal=self.modalResults)
 *                             except Exception as err:             # <<<<<<<<<<<<<<
 *                                 # ~ print "Exception raised in user parse action:", err
 *                                 if self.debugActions[FAIL]:
 */
                      __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
                      if (__pyx_t_6) {
                        __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
                        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_24, &__pyx_t_5) < 0) __PYX_ERR(0, 2127, __pyx_L86_except_error)
                        __Pyx_XGOTREF(__pyx_t_2);
                        __Pyx_XGOTREF(__pyx_t_24);
                        __Pyx_XGOTREF(__pyx_t_5);
                        __Pyx_INCREF(__pyx_t_24);
                        __pyx_v_err = __pyx_t_24;
                        /*try:*/ {

                          /* "cPyparsing.pyx":2129
 *                             except Exception as err:
 *                                 # ~ print "Exception raised in user parse action:", err
 *                                 if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                                     self.debugActions[FAIL](instring, tokensStart, self, err)
 *                                 raise
 */
                          __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2129, __pyx_L124_error)
                          __Pyx_GOTREF(__pyx_t_25);
                          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2129, __pyx_L124_error)
                          __Pyx_GOTREF(__pyx_t_3);
                          __pyx_t_23 = __Pyx_PyObject_GetItem(__pyx_t_25, __pyx_t_3); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2129, __pyx_L124_error)
                          __Pyx_GOTREF(__pyx_t_23);
                          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_23); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2129, __pyx_L124_error)
                          __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                          if (__pyx_t_10) {

                            /* "cPyparsing.pyx":2130
 *                                 # ~ print "Exception raised in user parse action:", err
 *                                 if self.debugActions[FAIL]:
 *                                     self.debugActions[FAIL](instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                                 raise
 *                         else:
 */
                            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2130, __pyx_L124_error)
                            __Pyx_GOTREF(__pyx_t_3);
                            __Pyx_GetModuleGlobalName(__pyx_t_25, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2130, __pyx_L124_error)
                            __Pyx_GOTREF(__pyx_t_25);
                            __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_25); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2130, __pyx_L124_error)
                            __Pyx_GOTREF(__pyx_t_1);
                            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                            __pyx_t_25 = NULL;
                            __pyx_t_6 = 0;
                            #if CYTHON_UNPACK_METHODS
                            if (unlikely(PyMethod_Check(__pyx_t_1))) {
                              __pyx_t_25 = PyMethod_GET_SELF(__pyx_t_1);
                              if (likely(__pyx_t_25)) {
                                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                                __Pyx_INCREF(__pyx_t_25);
                                __Pyx_INCREF(function);
                                __Pyx_DECREF_SET(__pyx_t_1, function);
                                __pyx_t_6 = 1;
                              }
                            }
                            #endif
                            {
                              PyObject *__pyx_callargs[5] = {__pyx_t_25, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
                              __pyx_t_23 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
                              __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                              if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2130, __pyx_L124_error)
                              __Pyx_GOTREF(__pyx_t_23);
                              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                            }
                            __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;

                            /* "cPyparsing.pyx":2129
 *                             except Exception as err:
 *                                 # ~ print "Exception raised in user parse action:", err
 *                                 if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                                     self.debugActions[FAIL](instring, tokensStart, self, err)
 *                                 raise
 */
                          }

                          /* "cPyparsing.pyx":2131
 *                                 if self.debugActions[FAIL]:
 *                                     self.debugActions[FAIL](instring, tokensStart, self, err)
 *                                 raise             # <<<<<<<<<<<<<<
 *                         else:
 *                             for fn in self.parseAction:
 */
                          __Pyx_GIVEREF(__pyx_t_2);
                          __Pyx_GIVEREF(__pyx_t_24);
                          __Pyx_XGIVEREF(__pyx_t_5);
                          __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_24, __pyx_t_5);
                          __pyx_t_2 = 0; __pyx_t_24 = 0; __pyx_t_5 = 0; 
                          __PYX_ERR(0, 2131, __pyx_L124_error)
                        }

                        /* "cPyparsing.pyx":2127
 *                                                                 asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                                 modal=self.modalResults)
 *                             except Exception as err:             # <<<<<<<<<<<<<<
 *                                 # ~ print "Exception raised in user parse action:", err
 *                                 if self.debugActions[FAIL]:
 */
                        /*finally:*/ {
                          __pyx_L124_error:;
                          /*exception exit:*/{
                            __Pyx_PyThreadState_declare
                            __Pyx_PyThreadState_assign
                            __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0; __pyx_t_36 = 0; __pyx_t_35 = 0; __pyx_t_34 = 0;
                            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                            __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                            __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_36, &__pyx_t_35, &__pyx_t_34);
                            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_29, &__pyx_t_30, &__pyx_t_31) < 0)) __Pyx_ErrFetch(&__pyx_t_29, &__pyx_t_30, &__pyx_t_31);
                            __Pyx_XGOTREF(__pyx_t_29);
                            __Pyx_XGOTREF(__pyx_t_30);
                            __Pyx_XGOTREF(__pyx_t_31);
                            __Pyx_XGOTREF(__pyx_t_36);
                            __Pyx_XGOTREF(__pyx_t_35);
                            __Pyx_XGOTREF(__pyx_t_34);
                            __pyx_t_6 = __pyx_lineno; __pyx_t_27 = __pyx_clineno; __pyx_t_37 = __pyx_filename;
                            {
                              __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
                            }
                            if (PY_MAJOR_VERSION >= 3) {
                              __Pyx_XGIVEREF(__pyx_t_36);
                              __Pyx_XGIVEREF(__pyx_t_35);
                              __Pyx_XGIVEREF(__pyx_t_34);
                              __Pyx_ExceptionReset(__pyx_t_36, __pyx_t_35, __pyx_t_34);
                            }
                            __Pyx_XGIVEREF(__pyx_t_29);
                            __Pyx_XGIVEREF(__pyx_t_30);
                            __Pyx_XGIVEREF(__pyx_t_31);
                            __Pyx_ErrRestore(__pyx_t_29, __pyx_t_30, __pyx_t_31);
                            __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0; __pyx_t_36 = 0; __pyx_t_35 = 0; __pyx_t_34 = 0;
                            __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_27; __pyx_filename = __pyx_t_37;
                            goto __pyx_L86_except_error;
                          }
                        }
                      }
                      goto __pyx_L86_except_error;

                      /* "cPyparsing.pyx":2113
 *                     if self.parseAction and (doActions or self.callDuringTry):
 *                         if debugging:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 for fn in self.parseAction:
 *                                     try:
 */
                      __pyx_L86_except_error:;
                      __Pyx_XGIVEREF(__pyx_t_15);
                      __Pyx_XGIVEREF(__pyx_t_16);
                      __Pyx_XGIVEREF(__pyx_t_17);
                      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
                      goto __pyx_L14_error;
                      __pyx_L89_try_end:;
                    }

                    /* "cPyparsing.pyx":2112
 *                     retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *                     if self.parseAction and (doActions or self.callDuringTry):
 *                         if debugging:             # <<<<<<<<<<<<<<
 *                             try:
 *                                 for fn in self.parseAction:
 */
                    goto __pyx_L83;
                  }

                  /* "cPyparsing.pyx":2133
 *                                 raise
 *                         else:
 *                             for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                                 try:
 *                                     tokens = fn(instring, tokensStart, retTokens)
 */
                  /*else*/ {
                    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2133, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_5);
                    if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
                      __pyx_t_24 = __pyx_t_5; __Pyx_INCREF(__pyx_t_24);
                      __pyx_t_18 = 0;
                      __pyx_t_32 = NULL;
                    } else {
                      __pyx_t_18 = -1; __pyx_t_24 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2133, __pyx_L14_error)
                      __Pyx_GOTREF(__pyx_t_24);
                      __pyx_t_32 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_24); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 2133, __pyx_L14_error)
                    }
                    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                    for (;;) {
                      if (likely(!__pyx_t_32)) {
                        if (likely(PyList_CheckExact(__pyx_t_24))) {
                          {
                            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_24);
                            #if !CYTHON_ASSUME_SAFE_MACROS
                            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2133, __pyx_L14_error)
                            #endif
                            if (__pyx_t_18 >= __pyx_temp) break;
                          }
                          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_24, __pyx_t_18); __Pyx_INCREF(__pyx_t_5); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(0, 2133, __pyx_L14_error)
                          #else
                          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_24, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2133, __pyx_L14_error)
                          __Pyx_GOTREF(__pyx_t_5);
                          #endif
                        } else {
                          {
                            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_24);
                            #if !CYTHON_ASSUME_SAFE_MACROS
                            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2133, __pyx_L14_error)
                            #endif
                            if (__pyx_t_18 >= __pyx_temp) break;
                          }
                          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_24, __pyx_t_18); __Pyx_INCREF(__pyx_t_5); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(0, 2133, __pyx_L14_error)
                          #else
                          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_24, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2133, __pyx_L14_error)
                          __Pyx_GOTREF(__pyx_t_5);
                          #endif
                        }
                      } else {
                        __pyx_t_5 = __pyx_t_32(__pyx_t_24);
                        if (unlikely(!__pyx_t_5)) {
                          PyObject* exc_type = PyErr_Occurred();
                          if (exc_type) {
                            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                            else __PYX_ERR(0, 2133, __pyx_L14_error)
                          }
                          break;
                        }
                        __Pyx_GOTREF(__pyx_t_5);
                      }
                      __Pyx_XDECREF_SET(__pyx_v_fn, __pyx_t_5);
                      __pyx_t_5 = 0;

                      /* "cPyparsing.pyx":2134
 *                         else:
 *                             for fn in self.parseAction:
 *                                 try:             # <<<<<<<<<<<<<<
 *                                     tokens = fn(instring, tokensStart, retTokens)
 *                                 except IndexError as parse_action_exc:
 */
                      {
                        __Pyx_PyThreadState_declare
                        __Pyx_PyThreadState_assign
                        __Pyx_ExceptionSave(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
                        __Pyx_XGOTREF(__pyx_t_17);
                        __Pyx_XGOTREF(__pyx_t_16);
                        __Pyx_XGOTREF(__pyx_t_15);
                        /*try:*/ {

                          /* "cPyparsing.pyx":2135
 *                             for fn in self.parseAction:
 *                                 try:
 *                                     tokens = fn(instring, tokensStart, retTokens)             # <<<<<<<<<<<<<<
 *                                 except IndexError as parse_action_exc:
 *                                     exc = ParseException("exception raised in parse action")
 */
                          __Pyx_INCREF(__pyx_v_fn);
                          __pyx_t_2 = __pyx_v_fn; __pyx_t_23 = NULL;
                          __pyx_t_27 = 0;
                          #if CYTHON_UNPACK_METHODS
                          if (unlikely(PyMethod_Check(__pyx_t_2))) {
                            __pyx_t_23 = PyMethod_GET_SELF(__pyx_t_2);
                            if (likely(__pyx_t_23)) {
                              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                              __Pyx_INCREF(__pyx_t_23);
                              __Pyx_INCREF(function);
                              __Pyx_DECREF_SET(__pyx_t_2, function);
                              __pyx_t_27 = 1;
                            }
                          }
                          #endif
                          {
                            PyObject *__pyx_callargs[4] = {__pyx_t_23, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
                            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
                            __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2135, __pyx_L133_error)
                            __Pyx_GOTREF(__pyx_t_5);
                            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                          }
                          __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_5);
                          __pyx_t_5 = 0;

                          /* "cPyparsing.pyx":2134
 *                         else:
 *                             for fn in self.parseAction:
 *                                 try:             # <<<<<<<<<<<<<<
 *                                     tokens = fn(instring, tokensStart, retTokens)
 *                                 except IndexError as parse_action_exc:
 */
                        }
                        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                        goto __pyx_L140_try_end;
                        __pyx_L133_error:;
                        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                        __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                        __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                        __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

                        /* "cPyparsing.pyx":2136
 *                                 try:
 *                                     tokens = fn(instring, tokensStart, retTokens)
 *                                 except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                                     exc = ParseException("exception raised in parse action")
 *                                     exc.__cause__ = parse_action_exc
 */
                        __pyx_t_27 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
                        if (__pyx_t_27) {
                          __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
                          if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_2, &__pyx_t_23) < 0) __PYX_ERR(0, 2136, __pyx_L135_except_error)
                          __Pyx_XGOTREF(__pyx_t_5);
                          __Pyx_XGOTREF(__pyx_t_2);
                          __Pyx_XGOTREF(__pyx_t_23);
                          __Pyx_INCREF(__pyx_t_2);
                          __pyx_v_parse_action_exc = __pyx_t_2;
                          /*try:*/ {

                            /* "cPyparsing.pyx":2137
 *                                     tokens = fn(instring, tokensStart, retTokens)
 *                                 except IndexError as parse_action_exc:
 *                                     exc = ParseException("exception raised in parse action")             # <<<<<<<<<<<<<<
 *                                     exc.__cause__ = parse_action_exc
 *                                     raise exc
 */
                            __Pyx_GetModuleGlobalName(__pyx_t_25, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2137, __pyx_L146_error)
                            __Pyx_GOTREF(__pyx_t_25);
                            __pyx_t_3 = NULL;
                            __pyx_t_27 = 0;
                            #if CYTHON_UNPACK_METHODS
                            if (unlikely(PyMethod_Check(__pyx_t_25))) {
                              __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_25);
                              if (likely(__pyx_t_3)) {
                                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_25);
                                __Pyx_INCREF(__pyx_t_3);
                                __Pyx_INCREF(function);
                                __Pyx_DECREF_SET(__pyx_t_25, function);
                                __pyx_t_27 = 1;
                              }
                            }
                            #endif
                            {
                              PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_exception_raised_in_parse_action};
                              __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_25, __pyx_callargs+1-__pyx_t_27, 1+__pyx_t_27);
                              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2137, __pyx_L146_error)
                              __Pyx_GOTREF(__pyx_t_1);
                              __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                            }
                            __pyx_v_exc = __pyx_t_1;
                            __pyx_t_1 = 0;

                            /* "cPyparsing.pyx":2138
 *                                 except IndexError as parse_action_exc:
 *                                     exc = ParseException("exception raised in parse action")
 *                                     exc.__cause__ = parse_action_exc             # <<<<<<<<<<<<<<
 *                                     raise exc
 * 
 */
                            if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_cause, __pyx_v_parse_action_exc) < 0) __PYX_ERR(0, 2138, __pyx_L146_error)

                            /* "cPyparsing.pyx":2139
 *                                     exc = ParseException("exception raised in parse action")
 *                                     exc.__cause__ = parse_action_exc
 *                                     raise exc             # <<<<<<<<<<<<<<
 * 
 *                                 if tokens is not None and tokens is not retTokens:
 */
                            __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
                            __PYX_ERR(0, 2139, __pyx_L146_error)
                          }

                          /* "cPyparsing.pyx":2136
 *                                 try:
 *                                     tokens = fn(instring, tokensStart, retTokens)
 *                                 except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                                     exc = ParseException("exception raised in parse action")
 *                                     exc.__cause__ = parse_action_exc
 */
                          /*finally:*/ {
                            __pyx_L146_error:;
                            /*exception exit:*/{
                              __Pyx_PyThreadState_declare
                              __Pyx_PyThreadState_assign
                              __pyx_t_34 = 0; __pyx_t_35 = 0; __pyx_t_36 = 0; __pyx_t_31 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0;
                              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                              __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_31, &__pyx_t_30, &__pyx_t_29);
                              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_34, &__pyx_t_35, &__pyx_t_36) < 0)) __Pyx_ErrFetch(&__pyx_t_34, &__pyx_t_35, &__pyx_t_36);
                              __Pyx_XGOTREF(__pyx_t_34);
                              __Pyx_XGOTREF(__pyx_t_35);
                              __Pyx_XGOTREF(__pyx_t_36);
                              __Pyx_XGOTREF(__pyx_t_31);
                              __Pyx_XGOTREF(__pyx_t_30);
                              __Pyx_XGOTREF(__pyx_t_29);
                              __pyx_t_27 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_38 = __pyx_filename;
                              {
                                __Pyx_DECREF(__pyx_v_parse_action_exc); __pyx_v_parse_action_exc = 0;
                              }
                              if (PY_MAJOR_VERSION >= 3) {
                                __Pyx_XGIVEREF(__pyx_t_31);
                                __Pyx_XGIVEREF(__pyx_t_30);
                                __Pyx_XGIVEREF(__pyx_t_29);
                                __Pyx_ExceptionReset(__pyx_t_31, __pyx_t_30, __pyx_t_29);
                              }
                              __Pyx_XGIVEREF(__pyx_t_34);
                              __Pyx_XGIVEREF(__pyx_t_35);
                              __Pyx_XGIVEREF(__pyx_t_36);
                              __Pyx_ErrRestore(__pyx_t_34, __pyx_t_35, __pyx_t_36);
                              __pyx_t_34 = 0; __pyx_t_35 = 0; __pyx_t_36 = 0; __pyx_t_31 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0;
                              __pyx_lineno = __pyx_t_27; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_38;
                              goto __pyx_L135_except_error;
                            }
                          }
                        }
                        goto __pyx_L135_except_error;

                        /* "cPyparsing.pyx":2134
 *                         else:
 *                             for fn in self.parseAction:
 *                                 try:             # <<<<<<<<<<<<<<
 *                                     tokens = fn(instring, tokensStart, retTokens)
 *                                 except IndexError as parse_action_exc:
 */
                        __pyx_L135_except_error:;
                        __Pyx_XGIVEREF(__pyx_t_17);
                        __Pyx_XGIVEREF(__pyx_t_16);
                        __Pyx_XGIVEREF(__pyx_t_15);
                        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
                        goto __pyx_L14_error;
                        __pyx_L140_try_end:;
                      }

                      /* "cPyparsing.pyx":2141
 *                                     raise exc
 * 
 *                                 if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                                     retTokens = ParseResults(tokens,
 *                                                             self.resultsName,
 */
                      __pyx_t_14 = (__pyx_v_tokens != Py_None);
                      if (__pyx_t_14) {
                      } else {
                        __pyx_t_10 = __pyx_t_14;
                        goto __pyx_L153_bool_binop_done;
                      }
                      __pyx_t_14 = (__pyx_v_tokens != __pyx_v_retTokens);
                      __pyx_t_10 = __pyx_t_14;
                      __pyx_L153_bool_binop_done:;
                      if (__pyx_t_10) {

                        /* "cPyparsing.pyx":2142
 * 
 *                                 if tokens is not None and tokens is not retTokens:
 *                                     retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                             self.resultsName,
 *                                                             asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                        __Pyx_GetModuleGlobalName(__pyx_t_23, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2142, __pyx_L14_error)
                        __Pyx_GOTREF(__pyx_t_23);

                        /* "cPyparsing.pyx":2143
 *                                 if tokens is not None and tokens is not retTokens:
 *                                     retTokens = ParseResults(tokens,
 *                                                             self.resultsName,             # <<<<<<<<<<<<<<
 *                                                             asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                             modal=self.modalResults)
 */
                        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2143, __pyx_L14_error)
                        __Pyx_GOTREF(__pyx_t_2);

                        /* "cPyparsing.pyx":2142
 * 
 *                                 if tokens is not None and tokens is not retTokens:
 *                                     retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                             self.resultsName,
 *                                                             asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2142, __pyx_L14_error)
                        __Pyx_GOTREF(__pyx_t_5);
                        __Pyx_INCREF(__pyx_v_tokens);
                        __Pyx_GIVEREF(__pyx_v_tokens);
                        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_tokens)) __PYX_ERR(0, 2142, __pyx_L14_error);
                        __Pyx_GIVEREF(__pyx_t_2);
                        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(0, 2142, __pyx_L14_error);
                        __pyx_t_2 = 0;

                        /* "cPyparsing.pyx":2144
 *                                     retTokens = ParseResults(tokens,
 *                                                             self.resultsName,
 *                                                             asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),             # <<<<<<<<<<<<<<
 *                                                             modal=self.modalResults)
 *                     if debugging:
 */
                        __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2144, __pyx_L14_error)
                        __Pyx_GOTREF(__pyx_t_2);
                        __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2144, __pyx_L14_error)
                        __Pyx_GOTREF(__pyx_t_25);
                        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2144, __pyx_L14_error)
                        if (__pyx_t_10) {
                          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                        } else {
                          __Pyx_INCREF(__pyx_t_25);
                          __pyx_t_1 = __pyx_t_25;
                          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                          goto __pyx_L155_bool_binop_done;
                        }
                        __Pyx_GetModuleGlobalName(__pyx_t_25, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2144, __pyx_L14_error)
                        __Pyx_GOTREF(__pyx_t_25);
                        __pyx_t_14 = PyObject_IsInstance(__pyx_v_tokens, __pyx_t_25); 
                        if (!__pyx_t_14) {
                        } else {
                          __pyx_t_10 = __pyx_t_14;
                          goto __pyx_L157_bool_binop_done;
                        }
                        __pyx_t_14 = PyList_Check(__pyx_v_tokens); 
                        __pyx_t_10 = __pyx_t_14;
                        __pyx_L157_bool_binop_done:;
                        __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                        __pyx_t_25 = __Pyx_PyBool_FromLong(__pyx_t_10); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2144, __pyx_L14_error)
                        __Pyx_GOTREF(__pyx_t_25);
                        __pyx_t_1 = __pyx_t_25;
                        __pyx_t_25 = 0;
                        __pyx_L155_bool_binop_done:;
                        if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_asList, __pyx_t_1) < 0) __PYX_ERR(0, 2144, __pyx_L14_error)
                        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

                        /* "cPyparsing.pyx":2145
 *                                                             self.resultsName,
 *                                                             asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                             modal=self.modalResults)             # <<<<<<<<<<<<<<
 *                     if debugging:
 *                         # ~ print ("Matched", self, "->", retTokens.asList())
 */
                        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2145, __pyx_L14_error)
                        __Pyx_GOTREF(__pyx_t_1);
                        if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_modal, __pyx_t_1) < 0) __PYX_ERR(0, 2144, __pyx_L14_error)
                        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

                        /* "cPyparsing.pyx":2142
 * 
 *                                 if tokens is not None and tokens is not retTokens:
 *                                     retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                             self.resultsName,
 *                                                             asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_23, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2142, __pyx_L14_error)
                        __Pyx_GOTREF(__pyx_t_1);
                        __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                        __Pyx_DECREF_SET(__pyx_v_retTokens, __pyx_t_1);
                        __pyx_t_1 = 0;

                        /* "cPyparsing.pyx":2141
 *                                     raise exc
 * 
 *                                 if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                                     retTokens = ParseResults(tokens,
 *                                                             self.resultsName,
 */
                      }

                      /* "cPyparsing.pyx":2133
 *                                 raise
 *                         else:
 *                             for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                                 try:
 *                                     tokens = fn(instring, tokensStart, retTokens)
 */
                    }
                    __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
                  }
                  __pyx_L83:;

                  /* "cPyparsing.pyx":2111
 * 
 *                     retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *                     if self.parseAction and (doActions or self.callDuringTry):             # <<<<<<<<<<<<<<
 *                         if debugging:
 *                             try:
 */
                }

                /* "cPyparsing.pyx":2146
 *                                                             asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                             modal=self.modalResults)
 *                     if debugging:             # <<<<<<<<<<<<<<
 *                         # ~ print ("Matched", self, "->", retTokens.asList())
 *                         if self.debugActions[MATCH]:
 */
                __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2146, __pyx_L14_error)
                if (__pyx_t_10) {

                  /* "cPyparsing.pyx":2148
 *                     if debugging:
 *                         # ~ print ("Matched", self, "->", retTokens.asList())
 *                         if self.debugActions[MATCH]:             # <<<<<<<<<<<<<<
 *                             self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)
 * 
 */
                  __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2148, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_24);
                  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MATCH); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2148, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_24, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2148, __pyx_L14_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2148, __pyx_L14_error)
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  if (__pyx_t_10) {

                    /* "cPyparsing.pyx":2149
 *                         # ~ print ("Matched", self, "->", retTokens.asList())
 *                         if self.debugActions[MATCH]:
 *                             self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)             # <<<<<<<<<<<<<<
 * 
 *                     # return loc, retTokens
 */
                    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2149, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_n_s_MATCH); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2149, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_24);
                    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_24); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2149, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_5);
                    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                    __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
                    __pyx_t_24 = NULL;
                    __pyx_t_6 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (unlikely(PyMethod_Check(__pyx_t_5))) {
                      __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_5);
                      if (likely(__pyx_t_24)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                        __Pyx_INCREF(__pyx_t_24);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_5, function);
                        __pyx_t_6 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[6] = {__pyx_t_24, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_loc, __pyx_v_self, __pyx_v_retTokens};
                      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 5+__pyx_t_6);
                      __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2149, __pyx_L14_error)
                      __Pyx_GOTREF(__pyx_t_2);
                      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                    }
                    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                    /* "cPyparsing.pyx":2148
 *                     if debugging:
 *                         # ~ print ("Matched", self, "->", retTokens.asList())
 *                         if self.debugActions[MATCH]:             # <<<<<<<<<<<<<<
 *                             self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)
 * 
 */
                  }

                  /* "cPyparsing.pyx":2146
 *                                                             asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                             modal=self.modalResults)
 *                     if debugging:             # <<<<<<<<<<<<<<
 *                         # ~ print ("Matched", self, "->", retTokens.asList())
 *                         if self.debugActions[MATCH]:
 */
                }

                /* "cPyparsing.pyx":2154
 * 
 *                     # [CPYPARSING] END INLINE _parseNoCache
 *                     value = loc, retTokens             # <<<<<<<<<<<<<<
 *                 except ParseBaseException as pe:
 *                     # cache a copy of the exception, without the traceback
 */
                __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2154, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_INCREF(__pyx_v_loc);
                __Pyx_GIVEREF(__pyx_v_loc);
                if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_loc)) __PYX_ERR(0, 2154, __pyx_L14_error);
                __Pyx_INCREF(__pyx_v_retTokens);
                __Pyx_GIVEREF(__pyx_v_retTokens);
                if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_retTokens)) __PYX_ERR(0, 2154, __pyx_L14_error);
                __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_2);
                __pyx_t_2 = 0;

                /* "cPyparsing.pyx":2063
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:             # <<<<<<<<<<<<<<
 *                     # value = self._parseNoCache(instring, loc, doActions, callPreParse)
 *                     # [CPYPARSING] START INLINE _parseNoCache
 */
              }

              /* "cPyparsing.pyx":2160
 *                     raise
 *                 else:
 *                     cache.set(lookup, (value[0], value[1].copy()))             # <<<<<<<<<<<<<<
 *                     return value
 *             else:
 */
              /*else:*/ {
                __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_set); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2160, __pyx_L16_except_error)
                __Pyx_GOTREF(__pyx_t_5);
                __pyx_t_24 = __Pyx_GetItemInt(__pyx_v_value, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2160, __pyx_L16_except_error)
                __Pyx_GOTREF(__pyx_t_24);
                __pyx_t_23 = __Pyx_GetItemInt(__pyx_v_value, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2160, __pyx_L16_except_error)
                __Pyx_GOTREF(__pyx_t_23);
                __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_23, __pyx_n_s_copy); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2160, __pyx_L16_except_error)
                __Pyx_GOTREF(__pyx_t_25);
                __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                __pyx_t_23 = NULL;
                __pyx_t_6 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_25))) {
                  __pyx_t_23 = PyMethod_GET_SELF(__pyx_t_25);
                  if (likely(__pyx_t_23)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_25);
                    __Pyx_INCREF(__pyx_t_23);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_25, function);
                    __pyx_t_6 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_23, NULL};
                  __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_25, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
                  __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2160, __pyx_L16_except_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                }
                __pyx_t_25 = PyTuple_New(2); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2160, __pyx_L16_except_error)
                __Pyx_GOTREF(__pyx_t_25);
                __Pyx_GIVEREF(__pyx_t_24);
                if (__Pyx_PyTuple_SET_ITEM(__pyx_t_25, 0, __pyx_t_24)) __PYX_ERR(0, 2160, __pyx_L16_except_error);
                __Pyx_GIVEREF(__pyx_t_1);
                if (__Pyx_PyTuple_SET_ITEM(__pyx_t_25, 1, __pyx_t_1)) __PYX_ERR(0, 2160, __pyx_L16_except_error);
                __pyx_t_24 = 0;
                __pyx_t_1 = 0;
                __pyx_t_1 = NULL;
                __pyx_t_6 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_5))) {
                  __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
                  if (likely(__pyx_t_1)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                    __Pyx_INCREF(__pyx_t_1);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_5, function);
                    __pyx_t_6 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_lookup, __pyx_t_25};
                  __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2160, __pyx_L16_except_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                }
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                /* "cPyparsing.pyx":2161
 *                 else:
 *                     cache.set(lookup, (value[0], value[1].copy()))
 *                     return value             # <<<<<<<<<<<<<<
 *             else:
 *                 ParserElement.packrat_cache_stats[HIT] += 1
 */
                __Pyx_XDECREF(__pyx_r);
                __Pyx_INCREF(__pyx_v_value);
                __pyx_r = __pyx_v_value;
                goto __pyx_L17_except_return;
              }
              __pyx_L14_error:;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
              __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
              __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

              /* "cPyparsing.pyx":2155
 *                     # [CPYPARSING] END INLINE _parseNoCache
 *                     value = loc, retTokens
 *                 except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                     # cache a copy of the exception, without the traceback
 *                     cache.set(lookup, pe.__class__(*pe.args))
 */
              __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_5, &__pyx_t_25);
              __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2155, __pyx_L16_except_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_6 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_1);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_ErrRestore(__pyx_t_2, __pyx_t_5, __pyx_t_25);
              __pyx_t_2 = 0; __pyx_t_5 = 0; __pyx_t_25 = 0;
              if (__pyx_t_6) {
                __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_25, &__pyx_t_5, &__pyx_t_2) < 0) __PYX_ERR(0, 2155, __pyx_L16_except_error)
                __Pyx_XGOTREF(__pyx_t_25);
                __Pyx_XGOTREF(__pyx_t_5);
                __Pyx_XGOTREF(__pyx_t_2);
                __Pyx_INCREF(__pyx_t_5);
                __pyx_v_pe = __pyx_t_5;
                /*try:*/ {

                  /* "cPyparsing.pyx":2157
 *                 except ParseBaseException as pe:
 *                     # cache a copy of the exception, without the traceback
 *                     cache.set(lookup, pe.__class__(*pe.args))             # <<<<<<<<<<<<<<
 *                     raise
 *                 else:
 */
                  __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_set); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 2157, __pyx_L167_error)
                  __Pyx_GOTREF(__pyx_t_24);
                  __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_class); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 2157, __pyx_L167_error)
                  __Pyx_GOTREF(__pyx_t_23);
                  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2157, __pyx_L167_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __pyx_t_26 = __Pyx_PySequence_Tuple(__pyx_t_3); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 2157, __pyx_L167_error)
                  __Pyx_GOTREF(__pyx_t_26);
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_23, __pyx_t_26, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2157, __pyx_L167_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                  __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
                  __pyx_t_26 = NULL;
                  __pyx_t_6 = 0;
                  #if CYTHON_UNPACK_METHODS
                  if (likely(PyMethod_Check(__pyx_t_24))) {
                    __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_24);
                    if (likely(__pyx_t_26)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_24);
                      __Pyx_INCREF(__pyx_t_26);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_24, function);
                      __pyx_t_6 = 1;
                    }
                  }
                  #endif
                  {
                    PyObject *__pyx_callargs[3] = {__pyx_t_26, __pyx_v_lookup, __pyx_t_3};
                    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_24, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
                    __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2157, __pyx_L167_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
                  }
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

                  /* "cPyparsing.pyx":2158
 *                     # cache a copy of the exception, without the traceback
 *                     cache.set(lookup, pe.__class__(*pe.args))
 *                     raise             # <<<<<<<<<<<<<<
 *                 else:
 *                     cache.set(lookup, (value[0], value[1].copy()))
 */
                  __Pyx_GIVEREF(__pyx_t_25);
                  __Pyx_GIVEREF(__pyx_t_5);
                  __Pyx_XGIVEREF(__pyx_t_2);
                  __Pyx_ErrRestoreWithState(__pyx_t_25, __pyx_t_5, __pyx_t_2);
                  __pyx_t_25 = 0; __pyx_t_5 = 0; __pyx_t_2 = 0; 
                  __PYX_ERR(0, 2158, __pyx_L167_error)
                }

                /* "cPyparsing.pyx":2155
 *                     # [CPYPARSING] END INLINE _parseNoCache
 *                     value = loc, retTokens
 *                 except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                     # cache a copy of the exception, without the traceback
 *                     cache.set(lookup, pe.__class__(*pe.args))
 */
                /*finally:*/ {
                  __pyx_L167_error:;
                  /*exception exit:*/{
                    __Pyx_PyThreadState_declare
                    __Pyx_PyThreadState_assign
                    __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0;
                    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                    __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                    __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                    __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                    if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_29, &__pyx_t_30, &__pyx_t_31);
                    if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
                    __Pyx_XGOTREF(__pyx_t_15);
                    __Pyx_XGOTREF(__pyx_t_16);
                    __Pyx_XGOTREF(__pyx_t_17);
                    __Pyx_XGOTREF(__pyx_t_29);
                    __Pyx_XGOTREF(__pyx_t_30);
                    __Pyx_XGOTREF(__pyx_t_31);
                    __pyx_t_6 = __pyx_lineno; __pyx_t_27 = __pyx_clineno; __pyx_t_39 = __pyx_filename;
                    {
                      __Pyx_DECREF(__pyx_v_pe); __pyx_v_pe = 0;
                    }
                    if (PY_MAJOR_VERSION >= 3) {
                      __Pyx_XGIVEREF(__pyx_t_29);
                      __Pyx_XGIVEREF(__pyx_t_30);
                      __Pyx_XGIVEREF(__pyx_t_31);
                      __Pyx_ExceptionReset(__pyx_t_29, __pyx_t_30, __pyx_t_31);
                    }
                    __Pyx_XGIVEREF(__pyx_t_15);
                    __Pyx_XGIVEREF(__pyx_t_16);
                    __Pyx_XGIVEREF(__pyx_t_17);
                    __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
                    __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0;
                    __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_27; __pyx_filename = __pyx_t_39;
                    goto __pyx_L16_except_error;
                  }
                }
              }
              goto __pyx_L16_except_error;

              /* "cPyparsing.pyx":2063
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:             # <<<<<<<<<<<<<<
 *                     # value = self._parseNoCache(instring, loc, doActions, callPreParse)
 *                     # [CPYPARSING] START INLINE _parseNoCache
 */
              __pyx_L16_except_error:;
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
              goto __pyx_L7_error;
              __pyx_L17_except_return:;
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
              goto __pyx_L11_try_return;
            }

            /* "cPyparsing.pyx":2061
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)
 *             if value is cache.not_in_cache:             # <<<<<<<<<<<<<<
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:
 */
          }

          /* "cPyparsing.pyx":2163
 *                     return value
 *             else:
 *                 ParserElement.packrat_cache_stats[HIT] += 1             # <<<<<<<<<<<<<<
 *                 if isinstance(value, Exception):
 *                     raise value
 */
          /*else*/ {
            __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2163, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2163, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_HIT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2163, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_25 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2163, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_25);
            __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_25, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2163, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            if (unlikely((PyObject_SetItem(__pyx_t_5, __pyx_t_2, __pyx_t_1) < 0))) __PYX_ERR(0, 2163, __pyx_L7_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "cPyparsing.pyx":2164
 *             else:
 *                 ParserElement.packrat_cache_stats[HIT] += 1
 *                 if isinstance(value, Exception):             # <<<<<<<<<<<<<<
 *                     raise value
 *                 return value[0], value[1].copy()
 */
            __pyx_t_10 = __Pyx_PyException_Check(__pyx_v_value); 
            if (unlikely(__pyx_t_10)) {

              /* "cPyparsing.pyx":2165
 *                 ParserElement.packrat_cache_stats[HIT] += 1
 *                 if isinstance(value, Exception):
 *                     raise value             # <<<<<<<<<<<<<<
 *                 return value[0], value[1].copy()
 * 
 */
              __Pyx_Raise(__pyx_v_value, 0, 0, 0);
              __PYX_ERR(0, 2165, __pyx_L7_error)

              /* "cPyparsing.pyx":2164
 *             else:
 *                 ParserElement.packrat_cache_stats[HIT] += 1
 *                 if isinstance(value, Exception):             # <<<<<<<<<<<<<<
 *                     raise value
 *                 return value[0], value[1].copy()
 */
            }

            /* "cPyparsing.pyx":2166
 *                 if isinstance(value, Exception):
 *                     raise value
 *                 return value[0], value[1].copy()             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] add _update_furthest_loc_for_regex
 */
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_value, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2166, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_value, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2166, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_copy); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2166, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_25);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = NULL;
            __pyx_t_27 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_25))) {
              __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_25);
              if (likely(__pyx_t_1)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_25);
                __Pyx_INCREF(__pyx_t_1);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_25, function);
                __pyx_t_27 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
              __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_25, __pyx_callargs+1-__pyx_t_27, 0+__pyx_t_27);
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2166, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            }
            __pyx_t_25 = PyTuple_New(2); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2166, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_25);
            __Pyx_GIVEREF(__pyx_t_5);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_25, 0, __pyx_t_5)) __PYX_ERR(0, 2166, __pyx_L7_error);
            __Pyx_GIVEREF(__pyx_t_2);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_25, 1, __pyx_t_2)) __PYX_ERR(0, 2166, __pyx_L7_error);
            __pyx_t_5 = 0;
            __pyx_t_2 = 0;
            __pyx_r = __pyx_t_25;
            __pyx_t_25 = 0;
            goto __pyx_L11_try_return;
          }

          /* "cPyparsing.pyx":2058
 *         # [CPYPARSING] include packrat_context, merge callPreParse and doActions
 *         lookup = (self, instring, loc, callPreParse | doActions << 1, ParserElement.packrat_context)
 *         with ParserElement.packrat_cache_lock:             # <<<<<<<<<<<<<<
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)
 */
        }
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
        __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
        __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
        __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_25, &__pyx_t_2, &__pyx_t_5) < 0) __PYX_ERR(0, 2058, __pyx_L9_except_error)
          __Pyx_XGOTREF(__pyx_t_25);
          __Pyx_XGOTREF(__pyx_t_2);
          __Pyx_XGOTREF(__pyx_t_5);
          __pyx_t_1 = PyTuple_Pack(3, __pyx_t_25, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2058, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_1, NULL);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2058, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (__pyx_t_10 < 0) __PYX_ERR(0, 2058, __pyx_L9_except_error)
          __pyx_t_14 = (!__pyx_t_10);
          if (unlikely(__pyx_t_14)) {
            __Pyx_GIVEREF(__pyx_t_25);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_XGIVEREF(__pyx_t_5);
            __Pyx_ErrRestoreWithState(__pyx_t_25, __pyx_t_2, __pyx_t_5);
            __pyx_t_25 = 0; __pyx_t_2 = 0; __pyx_t_5 = 0; 
            __PYX_ERR(0, 2058, __pyx_L9_except_error)
          }
          __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
        goto __pyx_L1_error;
        __pyx_L11_try_return:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
        goto __pyx_L4_return;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_4) {
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__46, NULL);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2058, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L4_return: {
        __pyx_t_9 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_4) {
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__46, NULL);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2058, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_r = __pyx_t_9;
        __pyx_t_9 = 0;
        goto __pyx_L0;
      }
      __pyx_L6:;
    }
    goto __pyx_L177;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L1_error;
    __pyx_L177:;
  }

  /* "cPyparsing.pyx":2054
 *     #                 return value
 *     #             return value[0], value[1].copy()
 *     def _parseCache(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] HIT, MISS are constants
 *         # [CPYPARSING] include packrat_context, merge callPreParse and doActions
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lookup);
  __Pyx_XDECREF(__pyx_v_cache);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_debugging);
  __Pyx_XDECREF(__pyx_v_preloc);
  __Pyx_XDECREF(__pyx_v_tokensStart);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_retTokens);
  __Pyx_XDECREF(__pyx_v_fn);
  __Pyx_XDECREF(__pyx_v_parse_action_exc);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_pe);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2169
 * 
 *     # [CPYPARSING] add _update_furthest_loc_for_regex
 *     def _update_furthest_loc_for_regex(self, instring, loc, flags=0):             # <<<<<<<<<<<<<<
 *         if ParserElement._incrementalEnabled:
 *             if flags & re.MULTILINE:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_45_update_furthest_loc_for_regex(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_44_update_furthest_loc_for_regex, "ParserElement._update_furthest_loc_for_regex(self, instring, loc, flags=0)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_45_update_furthest_loc_for_regex = {"_update_furthest_loc_for_regex", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_45_update_furthest_loc_for_regex, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_44_update_furthest_loc_for_regex};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_45_update_furthest_loc_for_regex(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_flags = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_update_furthest_loc_for_regex (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_flags,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2169, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2169, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_update_furthest_loc_for_regex", 0, 3, 4, 1); __PYX_ERR(0, 2169, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2169, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_update_furthest_loc_for_regex", 0, 3, 4, 2); __PYX_ERR(0, 2169, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_flags);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2169, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_update_furthest_loc_for_regex") < 0)) __PYX_ERR(0, 2169, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_flags = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_update_furthest_loc_for_regex", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 2169, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement._update_furthest_loc_for_regex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_44_update_furthest_loc_for_regex(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_flags);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_44_update_furthest_loc_for_regex(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_flags) {
  PyObject *__pyx_v_next_linebreak_loc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_update_furthest_loc_for_regex", 1);

  /* "cPyparsing.pyx":2170
 *     # [CPYPARSING] add _update_furthest_loc_for_regex
 *     def _update_furthest_loc_for_regex(self, instring, loc, flags=0):
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             if flags & re.MULTILINE:
 *                 if __diag__.warn_on_incremental_multiline_regex:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_incrementalEnabled); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":2171
 *     def _update_furthest_loc_for_regex(self, instring, loc, flags=0):
 *         if ParserElement._incrementalEnabled:
 *             if flags & re.MULTILINE:             # <<<<<<<<<<<<<<
 *                 if __diag__.warn_on_incremental_multiline_regex:
 *                     warnings.warn("found multiline regex during incremental parsing; will hurt performance: " + repr(self), SyntaxWarning, stacklevel=1)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_MULTILINE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_And(__pyx_v_flags, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2171, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":2172
 *         if ParserElement._incrementalEnabled:
 *             if flags & re.MULTILINE:
 *                 if __diag__.warn_on_incremental_multiline_regex:             # <<<<<<<<<<<<<<
 *                     warnings.warn("found multiline regex during incremental parsing; will hurt performance: " + repr(self), SyntaxWarning, stacklevel=1)
 *                 ParserElement._furthest_locs[instring] = len(instring) - 1
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_diag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warn_on_incremental_multiline_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2172, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":2173
 *             if flags & re.MULTILINE:
 *                 if __diag__.warn_on_incremental_multiline_regex:
 *                     warnings.warn("found multiline regex during incremental parsing; will hurt performance: " + repr(self), SyntaxWarning, stacklevel=1)             # <<<<<<<<<<<<<<
 *                 ParserElement._furthest_locs[instring] = len(instring) - 1
 *             else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_repr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_self};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2173, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_t_4 = PyNumber_Add(__pyx_kp_u_found_multiline_regex_during_inc, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_4);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4)) __PYX_ERR(0, 2173, __pyx_L1_error);
        __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
        __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2173, __pyx_L1_error);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_stacklevel, __pyx_int_1) < 0) __PYX_ERR(0, 2173, __pyx_L1_error)
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "cPyparsing.pyx":2172
 *         if ParserElement._incrementalEnabled:
 *             if flags & re.MULTILINE:
 *                 if __diag__.warn_on_incremental_multiline_regex:             # <<<<<<<<<<<<<<
 *                     warnings.warn("found multiline regex during incremental parsing; will hurt performance: " + repr(self), SyntaxWarning, stacklevel=1)
 *                 ParserElement._furthest_locs[instring] = len(instring) - 1
 */
      }

      /* "cPyparsing.pyx":2174
 *                 if __diag__.warn_on_incremental_multiline_regex:
 *                     warnings.warn("found multiline regex during incremental parsing; will hurt performance: " + repr(self), SyntaxWarning, stacklevel=1)
 *                 ParserElement._furthest_locs[instring] = len(instring) - 1             # <<<<<<<<<<<<<<
 *             else:
 *                 next_linebreak_loc = instring.find("\n", loc)
 */
      __pyx_t_6 = 0;
      __pyx_t_7 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2174, __pyx_L1_error)
      __pyx_t_8 = __Pyx_sub_const_Py_ssize_t_checking_overflow(__pyx_t_7, 1, &__pyx_t_6);
      if (unlikely(__pyx_t_6)) {
        PyErr_SetString(PyExc_OverflowError, "value too large");
        __PYX_ERR(0, 2174, __pyx_L1_error)
      }
      __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_instring, __pyx_t_5) < 0))) __PYX_ERR(0, 2174, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":2171
 *     def _update_furthest_loc_for_regex(self, instring, loc, flags=0):
 *         if ParserElement._incrementalEnabled:
 *             if flags & re.MULTILINE:             # <<<<<<<<<<<<<<
 *                 if __diag__.warn_on_incremental_multiline_regex:
 *                     warnings.warn("found multiline regex during incremental parsing; will hurt performance: " + repr(self), SyntaxWarning, stacklevel=1)
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":2176
 *                 ParserElement._furthest_locs[instring] = len(instring) - 1
 *             else:
 *                 next_linebreak_loc = instring.find("\n", loc)             # <<<<<<<<<<<<<<
 *                 if next_linebreak_loc < 0:
 *                     next_linebreak_loc = len(instring) - 1
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_instring, __pyx_n_s_find); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_kp_u__19, __pyx_v_loc};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2176, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_v_next_linebreak_loc = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":2177
 *             else:
 *                 next_linebreak_loc = instring.find("\n", loc)
 *                 if next_linebreak_loc < 0:             # <<<<<<<<<<<<<<
 *                     next_linebreak_loc = len(instring) - 1
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], next_linebreak_loc)
 */
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_next_linebreak_loc, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2177, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2177, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":2178
 *                 next_linebreak_loc = instring.find("\n", loc)
 *                 if next_linebreak_loc < 0:
 *                     next_linebreak_loc = len(instring) - 1             # <<<<<<<<<<<<<<
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], next_linebreak_loc)
 * 
 */
        __pyx_t_6 = 0;
        __pyx_t_8 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2178, __pyx_L1_error)
        __pyx_t_7 = __Pyx_sub_const_Py_ssize_t_checking_overflow(__pyx_t_8, 1, &__pyx_t_6);
        if (unlikely(__pyx_t_6)) {
          PyErr_SetString(PyExc_OverflowError, "value too large");
          __PYX_ERR(0, 2178, __pyx_L1_error)
        }
        __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2178, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_next_linebreak_loc, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "cPyparsing.pyx":2177
 *             else:
 *                 next_linebreak_loc = instring.find("\n", loc)
 *                 if next_linebreak_loc < 0:             # <<<<<<<<<<<<<<
 *                     next_linebreak_loc = len(instring) - 1
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], next_linebreak_loc)
 */
      }

      /* "cPyparsing.pyx":2179
 *                 if next_linebreak_loc < 0:
 *                     next_linebreak_loc = len(instring) - 1
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], next_linebreak_loc)             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] add _parseIncremental
 */
      __Pyx_INCREF(__pyx_v_next_linebreak_loc);
      __pyx_t_5 = __pyx_v_next_linebreak_loc;
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_instring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = PyObject_RichCompare(__pyx_t_5, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2179, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2179, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_3) {
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_4 = __pyx_t_5;
      } else {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __pyx_t_4;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_instring, __pyx_t_5) < 0))) __PYX_ERR(0, 2179, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":2170
 *     # [CPYPARSING] add _update_furthest_loc_for_regex
 *     def _update_furthest_loc_for_regex(self, instring, loc, flags=0):
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             if flags & re.MULTILINE:
 *                 if __diag__.warn_on_incremental_multiline_regex:
 */
  }

  /* "cPyparsing.pyx":2169
 * 
 *     # [CPYPARSING] add _update_furthest_loc_for_regex
 *     def _update_furthest_loc_for_regex(self, instring, loc, flags=0):             # <<<<<<<<<<<<<<
 *         if ParserElement._incrementalEnabled:
 *             if flags & re.MULTILINE:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement._update_furthest_loc_for_regex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_next_linebreak_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2183
 *     # [CPYPARSING] add _parseIncremental
 *     _incremental_parent_usefullness_obj = [False]  # caches at start loc can't be reused, so start usefullness at False
 *     def _parseIncremental(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         """Version of ParserElement._parseCache that can reuse caches from common prefix/suffix parses.
 *         Note that unlike _parseCache, _parseIncremental is not thread-safe."""
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_47_parseIncremental(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_46_parseIncremental, "ParserElement._parseIncremental(self, instring, loc, doActions=True, callPreParse=True)\nVersion of ParserElement._parseCache that can reuse caches from common prefix/suffix parses.\n        Note that unlike _parseCache, _parseIncremental is not thread-safe.");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_47_parseIncremental = {"_parseIncremental", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_47_parseIncremental, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_46_parseIncremental};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_47_parseIncremental(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_v_callPreParse = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_parseIncremental (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,&__pyx_n_s_callPreParse,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2183, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2183, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_parseIncremental", 0, 3, 5, 1); __PYX_ERR(0, 2183, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2183, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_parseIncremental", 0, 3, 5, 2); __PYX_ERR(0, 2183, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2183, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_callPreParse);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2183, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_parseIncremental") < 0)) __PYX_ERR(0, 2183, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
    __pyx_v_callPreParse = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_parseIncremental", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 2183, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_46_parseIncremental(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2200
 *                     prefixes_and_suffixes.append((other_instring, common_prefix_len, common_suffix_len))
 *             # sort the strings with the largest common prefixes/suffixes to the front so we check them first
 *             prefixes_and_suffixes.sort(key=lambda s_pl_sl: sum(s_pl_sl[1:]), reverse=True)             # <<<<<<<<<<<<<<
 *             ParserElement._instring_prefixes_and_suffixes[instring] = prefixes_and_suffixes
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_17_parseIncremental_lambda14(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_17_parseIncremental_lambda14 = {"lambda14", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_17_parseIncremental_lambda14, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_17_parseIncremental_lambda14(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s_pl_sl = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda14 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s_pl_sl,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s_pl_sl)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2200, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda14") < 0)) __PYX_ERR(0, 2200, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_s_pl_sl = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda14", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2200, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental.lambda14", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda14(__pyx_self, __pyx_v_s_pl_sl);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda14(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s_pl_sl) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda14", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_s_pl_sl, 1, 0, NULL, NULL, &__pyx_slice_, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental.lambda14", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2183
 *     # [CPYPARSING] add _parseIncremental
 *     _incremental_parent_usefullness_obj = [False]  # caches at start loc can't be reused, so start usefullness at False
 *     def _parseIncremental(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         """Version of ParserElement._parseCache that can reuse caches from common prefix/suffix parses.
 *         Note that unlike _parseCache, _parseIncremental is not thread-safe."""
 */

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_46_parseIncremental(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse) {
  PyObject *__pyx_v_prefixes_and_suffixes = NULL;
  PyObject *__pyx_v_reversed_instring = NULL;
  PyObject *__pyx_v_other_instring = NULL;
  Py_ssize_t __pyx_v_common_prefix_len;
  Py_ssize_t __pyx_v_common_suffix_len;
  PyObject *__pyx_v_lookup_bools = NULL;
  PyObject *__pyx_v_cache = NULL;
  PyObject *__pyx_v_hit = NULL;
  PyObject *__pyx_v_prefix_len = NULL;
  PyObject *__pyx_v_suffix_len = NULL;
  PyObject *__pyx_v_is_instring = NULL;
  PyObject *__pyx_v_prefix_lookup = NULL;
  PyObject *__pyx_v_cache_result = NULL;
  PyObject *__pyx_v_cache_furthest_loc = NULL;
  PyObject *__pyx_v_cache_item = NULL;
  PyObject *__pyx_v_cache_usefullness_obj = NULL;
  PyObject *__pyx_v_loc_in_suffix = NULL;
  PyObject *__pyx_v_suffix_lookup = NULL;
  PyObject *__pyx_v_lookup = NULL;
  PyObject *__pyx_v_outer_parent_usefullness_obj = NULL;
  PyObject *__pyx_v_debugging = NULL;
  PyObject *__pyx_v_preloc = NULL;
  PyObject *__pyx_v_tokensStart = NULL;
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_v_retTokens = NULL;
  PyObject *__pyx_v_fn = NULL;
  PyObject *__pyx_v_parse_action_exc = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_v_new_loc = NULL;
  PyObject *__pyx_v_ret_toks = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  int __pyx_t_27;
  char const *__pyx_t_28;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  PyObject *__pyx_t_31 = NULL;
  char const *__pyx_t_32;
  PyObject *__pyx_t_33 = NULL;
  PyObject *__pyx_t_34 = NULL;
  PyObject *__pyx_t_35 = NULL;
  char const *__pyx_t_36;
  char const *__pyx_t_37;
  char const *__pyx_t_38;
  char const *__pyx_t_39;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parseIncremental", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":2187
 *         Note that unlike _parseCache, _parseIncremental is not thread-safe."""
 *         # determine the prefixes and suffixes to check for caches
 *         prefixes_and_suffixes = ParserElement._instring_prefixes_and_suffixes.get(instring)             # <<<<<<<<<<<<<<
 *         if prefixes_and_suffixes is None:  # this should only happen once per instring
 *             prefixes_and_suffixes = [
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_instring_prefixes_and_suffixes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_prefixes_and_suffixes = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2188
 *         # determine the prefixes and suffixes to check for caches
 *         prefixes_and_suffixes = ParserElement._instring_prefixes_and_suffixes.get(instring)
 *         if prefixes_and_suffixes is None:  # this should only happen once per instring             # <<<<<<<<<<<<<<
 *             prefixes_and_suffixes = [
 *                 # instring, common prefix len, common suffix len
 */
  __pyx_t_5 = (__pyx_v_prefixes_and_suffixes == Py_None);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2191
 *             prefixes_and_suffixes = [
 *                 # instring, common prefix len, common suffix len
 *                 (instring, len(instring), len(instring)),             # <<<<<<<<<<<<<<
 *             ]
 *             reversed_instring = instring[::-1]
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2191, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2191, __pyx_L1_error)
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_instring)) __PYX_ERR(0, 2191, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(0, 2191, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(0, 2191, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2189
 *         prefixes_and_suffixes = ParserElement._instring_prefixes_and_suffixes.get(instring)
 *         if prefixes_and_suffixes is None:  # this should only happen once per instring
 *             prefixes_and_suffixes = [             # <<<<<<<<<<<<<<
 *                 # instring, common prefix len, common suffix len
 *                 (instring, len(instring), len(instring)),
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 2189, __pyx_L1_error);
    __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_prefixes_and_suffixes, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2193
 *                 (instring, len(instring), len(instring)),
 *             ]
 *             reversed_instring = instring[::-1]             # <<<<<<<<<<<<<<
 *             for other_instring in ParserElement._instring_prefixes_and_suffixes:
 *                 common_prefix_len = len(commonprefix([instring, other_instring]))
 */
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_slice__21); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_reversed_instring = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2194
 *             ]
 *             reversed_instring = instring[::-1]
 *             for other_instring in ParserElement._instring_prefixes_and_suffixes:             # <<<<<<<<<<<<<<
 *                 common_prefix_len = len(commonprefix([instring, other_instring]))
 *                 common_suffix_len = len(commonprefix([reversed_instring, other_instring[::-1]]))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_instring_prefixes_and_suffixes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2194, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2194, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2194, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 2194, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2194, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2194, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 2194, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2194, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_7(__pyx_t_2);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 2194, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_other_instring, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2195
 *             reversed_instring = instring[::-1]
 *             for other_instring in ParserElement._instring_prefixes_and_suffixes:
 *                 common_prefix_len = len(commonprefix([instring, other_instring]))             # <<<<<<<<<<<<<<
 *                 common_suffix_len = len(commonprefix([reversed_instring, other_instring[::-1]]))
 *                 if common_prefix_len or common_suffix_len:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_commonprefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2195, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2195, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_v_instring)) __PYX_ERR(0, 2195, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_other_instring);
      __Pyx_GIVEREF(__pyx_v_other_instring);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 1, __pyx_v_other_instring)) __PYX_ERR(0, 2195, __pyx_L1_error);
      __pyx_t_9 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2195, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_10 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2195, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_common_prefix_len = __pyx_t_10;

      /* "cPyparsing.pyx":2196
 *             for other_instring in ParserElement._instring_prefixes_and_suffixes:
 *                 common_prefix_len = len(commonprefix([instring, other_instring]))
 *                 common_suffix_len = len(commonprefix([reversed_instring, other_instring[::-1]]))             # <<<<<<<<<<<<<<
 *                 if common_prefix_len or common_suffix_len:
 *                     prefixes_and_suffixes.append((other_instring, common_prefix_len, common_suffix_len))
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_commonprefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2196, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_other_instring, __pyx_slice__21); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2196, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = PyList_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2196, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_v_reversed_instring);
      __Pyx_GIVEREF(__pyx_v_reversed_instring);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_v_reversed_instring)) __PYX_ERR(0, 2196, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_8);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 1, __pyx_t_8)) __PYX_ERR(0, 2196, __pyx_L1_error);
      __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_9};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2196, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_10 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2196, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_common_suffix_len = __pyx_t_10;

      /* "cPyparsing.pyx":2197
 *                 common_prefix_len = len(commonprefix([instring, other_instring]))
 *                 common_suffix_len = len(commonprefix([reversed_instring, other_instring[::-1]]))
 *                 if common_prefix_len or common_suffix_len:             # <<<<<<<<<<<<<<
 *                     prefixes_and_suffixes.append((other_instring, common_prefix_len, common_suffix_len))
 *             # sort the strings with the largest common prefixes/suffixes to the front so we check them first
 */
      __pyx_t_11 = (__pyx_v_common_prefix_len != 0);
      if (!__pyx_t_11) {
      } else {
        __pyx_t_5 = __pyx_t_11;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_11 = (__pyx_v_common_suffix_len != 0);
      __pyx_t_5 = __pyx_t_11;
      __pyx_L7_bool_binop_done:;
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":2198
 *                 common_suffix_len = len(commonprefix([reversed_instring, other_instring[::-1]]))
 *                 if common_prefix_len or common_suffix_len:
 *                     prefixes_and_suffixes.append((other_instring, common_prefix_len, common_suffix_len))             # <<<<<<<<<<<<<<
 *             # sort the strings with the largest common prefixes/suffixes to the front so we check them first
 *             prefixes_and_suffixes.sort(key=lambda s_pl_sl: sum(s_pl_sl[1:]), reverse=True)
 */
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_common_prefix_len); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2198, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_common_suffix_len); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2198, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2198, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_v_other_instring);
        __Pyx_GIVEREF(__pyx_v_other_instring);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_other_instring)) __PYX_ERR(0, 2198, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_3)) __PYX_ERR(0, 2198, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_1)) __PYX_ERR(0, 2198, __pyx_L1_error);
        __pyx_t_3 = 0;
        __pyx_t_1 = 0;
        __pyx_t_12 = __Pyx_PyObject_Append(__pyx_v_prefixes_and_suffixes, __pyx_t_9); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 2198, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "cPyparsing.pyx":2197
 *                 common_prefix_len = len(commonprefix([instring, other_instring]))
 *                 common_suffix_len = len(commonprefix([reversed_instring, other_instring[::-1]]))
 *                 if common_prefix_len or common_suffix_len:             # <<<<<<<<<<<<<<
 *                     prefixes_and_suffixes.append((other_instring, common_prefix_len, common_suffix_len))
 *             # sort the strings with the largest common prefixes/suffixes to the front so we check them first
 */
      }

      /* "cPyparsing.pyx":2194
 *             ]
 *             reversed_instring = instring[::-1]
 *             for other_instring in ParserElement._instring_prefixes_and_suffixes:             # <<<<<<<<<<<<<<
 *                 common_prefix_len = len(commonprefix([instring, other_instring]))
 *                 common_suffix_len = len(commonprefix([reversed_instring, other_instring[::-1]]))
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2200
 *                     prefixes_and_suffixes.append((other_instring, common_prefix_len, common_suffix_len))
 *             # sort the strings with the largest common prefixes/suffixes to the front so we check them first
 *             prefixes_and_suffixes.sort(key=lambda s_pl_sl: sum(s_pl_sl[1:]), reverse=True)             # <<<<<<<<<<<<<<
 *             ParserElement._instring_prefixes_and_suffixes[instring] = prefixes_and_suffixes
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_prefixes_and_suffixes, __pyx_n_s_sort); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_17_parseIncremental_lambda14, 0, __pyx_n_s_ParserElement__parseIncremental, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_key, __pyx_t_1) < 0) __PYX_ERR(0, 2200, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_reverse, Py_True) < 0) __PYX_ERR(0, 2200, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2201
 *             # sort the strings with the largest common prefixes/suffixes to the front so we check them first
 *             prefixes_and_suffixes.sort(key=lambda s_pl_sl: sum(s_pl_sl[1:]), reverse=True)
 *             ParserElement._instring_prefixes_and_suffixes[instring] = prefixes_and_suffixes             # <<<<<<<<<<<<<<
 * 
 *         lookup_bools = callPreParse | doActions << 1
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_instring_prefixes_and_suffixes); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyObject_SetItem(__pyx_t_9, __pyx_v_instring, __pyx_v_prefixes_and_suffixes) < 0))) __PYX_ERR(0, 2201, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":2188
 *         # determine the prefixes and suffixes to check for caches
 *         prefixes_and_suffixes = ParserElement._instring_prefixes_and_suffixes.get(instring)
 *         if prefixes_and_suffixes is None:  # this should only happen once per instring             # <<<<<<<<<<<<<<
 *             prefixes_and_suffixes = [
 *                 # instring, common prefix len, common suffix len
 */
  }

  /* "cPyparsing.pyx":2203
 *             ParserElement._instring_prefixes_and_suffixes[instring] = prefixes_and_suffixes
 * 
 *         lookup_bools = callPreParse | doActions << 1             # <<<<<<<<<<<<<<
 *         # with ParserElement.packrat_cache_lock:
 * 
 */
  __pyx_t_9 = __Pyx_PyInt_LshiftObjC(__pyx_v_doActions, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_1 = PyNumber_Or(__pyx_v_callPreParse, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_v_lookup_bools = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2207
 * 
 *         # update furthest_loc
 *         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc)             # <<<<<<<<<<<<<<
 * 
 *         cache = ParserElement.packrat_cache
 */
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_t_1 = __pyx_v_loc;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_instring); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_9, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2207, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = __pyx_t_1;
  } else {
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_2 = __pyx_t_9;
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely((PyObject_SetItem(__pyx_t_9, __pyx_v_instring, __pyx_t_1) < 0))) __PYX_ERR(0, 2207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2209
 *         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc)
 * 
 *         cache = ParserElement.packrat_cache             # <<<<<<<<<<<<<<
 * 
 *         # try to find a hit
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_packrat_cache); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cache = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "cPyparsing.pyx":2212
 * 
 *         # try to find a hit
 *         hit = None             # <<<<<<<<<<<<<<
 *         for other_instring, prefix_len, suffix_len in prefixes_and_suffixes:
 *             is_instring = prefix_len == len(instring)
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_hit = Py_None;

  /* "cPyparsing.pyx":2213
 *         # try to find a hit
 *         hit = None
 *         for other_instring, prefix_len, suffix_len in prefixes_and_suffixes:             # <<<<<<<<<<<<<<
 *             is_instring = prefix_len == len(instring)
 * 
 */
  if (likely(PyList_CheckExact(__pyx_v_prefixes_and_suffixes)) || PyTuple_CheckExact(__pyx_v_prefixes_and_suffixes)) {
    __pyx_t_9 = __pyx_v_prefixes_and_suffixes; __Pyx_INCREF(__pyx_t_9);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_9 = PyObject_GetIter(__pyx_v_prefixes_and_suffixes); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2213, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_9))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_9);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2213, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_9, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 2213, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_9, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2213, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_9);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2213, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_9, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 2213, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_9, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2213, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_9);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2213, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 2213, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_8 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      #else
      __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_13 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_13);
      index = 0; __pyx_t_2 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_2)) goto __pyx_L12_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      index = 1; __pyx_t_3 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_3)) goto __pyx_L12_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 2; __pyx_t_8 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_8)) goto __pyx_L12_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_13), 3) < 0) __PYX_ERR(0, 2213, __pyx_L1_error)
      __pyx_t_14 = NULL;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L13_unpacking_done;
      __pyx_L12_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_14 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 2213, __pyx_L1_error)
      __pyx_L13_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_other_instring, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_prefix_len, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_suffix_len, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2214
 *         hit = None
 *         for other_instring, prefix_len, suffix_len in prefixes_and_suffixes:
 *             is_instring = prefix_len == len(instring)             # <<<<<<<<<<<<<<
 * 
 *             # look for prefix hit
 */
    __pyx_t_10 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2214, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = PyObject_RichCompare(__pyx_v_prefix_len, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2214, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_is_instring, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2219
 *             if (
 *                 # always check instring itself here
 *                 is_instring             # <<<<<<<<<<<<<<
 *                 # or if we're in the common prefix (and not at the end of it)
 *                 or loc < prefix_len - 1
 */
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_is_instring); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 2219, __pyx_L1_error)
    if (!__pyx_t_11) {
    } else {
      __pyx_t_5 = __pyx_t_11;
      goto __pyx_L15_bool_binop_done;
    }

    /* "cPyparsing.pyx":2221
 *                 is_instring
 *                 # or if we're in the common prefix (and not at the end of it)
 *                 or loc < prefix_len - 1             # <<<<<<<<<<<<<<
 *             ):
 *                 prefix_lookup = (self, other_instring, loc, lookup_bools, ParserElement.packrat_context)
 */
    __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_v_prefix_len, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_8, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2221, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 2221, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __pyx_t_11;
    __pyx_L15_bool_binop_done:;

    /* "cPyparsing.pyx":2217
 * 
 *             # look for prefix hit
 *             if (             # <<<<<<<<<<<<<<
 *                 # always check instring itself here
 *                 is_instring
 */
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":2223
 *                 or loc < prefix_len - 1
 *             ):
 *                 prefix_lookup = (self, other_instring, loc, lookup_bools, ParserElement.packrat_context)             # <<<<<<<<<<<<<<
 *                 cache_result = cache.get(prefix_lookup)
 *                 if cache_result is not cache.not_in_cache:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_packrat_context); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self)) __PYX_ERR(0, 2223, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_other_instring);
      __Pyx_GIVEREF(__pyx_v_other_instring);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_other_instring)) __PYX_ERR(0, 2223, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_loc);
      __Pyx_GIVEREF(__pyx_v_loc);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_loc)) __PYX_ERR(0, 2223, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_lookup_bools);
      __Pyx_GIVEREF(__pyx_v_lookup_bools);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_lookup_bools)) __PYX_ERR(0, 2223, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_8);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_t_8)) __PYX_ERR(0, 2223, __pyx_L1_error);
      __pyx_t_8 = 0;
      __Pyx_XDECREF_SET(__pyx_v_prefix_lookup, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":2224
 *             ):
 *                 prefix_lookup = (self, other_instring, loc, lookup_bools, ParserElement.packrat_context)
 *                 cache_result = cache.get(prefix_lookup)             # <<<<<<<<<<<<<<
 *                 if cache_result is not cache.not_in_cache:
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_get); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_prefix_lookup};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2224, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_cache_result, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":2225
 *                 prefix_lookup = (self, other_instring, loc, lookup_bools, ParserElement.packrat_context)
 *                 cache_result = cache.get(prefix_lookup)
 *                 if cache_result is not cache.not_in_cache:             # <<<<<<<<<<<<<<
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result
 *                     if (
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_not_in_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = (__pyx_v_cache_result != __pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":2226
 *                 cache_result = cache.get(prefix_lookup)
 *                 if cache_result is not cache.not_in_cache:
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result             # <<<<<<<<<<<<<<
 *                     if (
 *                         # if other_instring is instring
 */
        if ((likely(PyTuple_CheckExact(__pyx_v_cache_result))) || (PyList_CheckExact(__pyx_v_cache_result))) {
          PyObject* sequence = __pyx_v_cache_result;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 3)) {
            if (size > 3) __Pyx_RaiseTooManyValuesError(3);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 2226, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2); 
          } else {
            __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
            __pyx_t_3 = PyList_GET_ITEM(sequence, 2); 
          }
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_3);
          #else
          __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2226, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2226, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_3 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2226, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          Py_ssize_t index = -1;
          __pyx_t_2 = PyObject_GetIter(__pyx_v_cache_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2226, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
          index = 0; __pyx_t_1 = __pyx_t_14(__pyx_t_2); if (unlikely(!__pyx_t_1)) goto __pyx_L18_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          index = 1; __pyx_t_8 = __pyx_t_14(__pyx_t_2); if (unlikely(!__pyx_t_8)) goto __pyx_L18_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_8);
          index = 2; __pyx_t_3 = __pyx_t_14(__pyx_t_2); if (unlikely(!__pyx_t_3)) goto __pyx_L18_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_3);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_2), 3) < 0) __PYX_ERR(0, 2226, __pyx_L1_error)
          __pyx_t_14 = NULL;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L19_unpacking_done;
          __pyx_L18_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_14 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 2226, __pyx_L1_error)
          __pyx_L19_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_cache_furthest_loc, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_cache_item, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_cache_usefullness_obj, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "cPyparsing.pyx":2229
 *                     if (
 *                         # if other_instring is instring
 *                         is_instring             # <<<<<<<<<<<<<<
 *                         # or we never looked past the end of the prefix
 *                         or cache_furthest_loc < prefix_len - 1
 */
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_is_instring); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 2229, __pyx_L1_error)
        if (!__pyx_t_11) {
        } else {
          __pyx_t_5 = __pyx_t_11;
          goto __pyx_L21_bool_binop_done;
        }

        /* "cPyparsing.pyx":2231
 *                         is_instring
 *                         # or we never looked past the end of the prefix
 *                         or cache_furthest_loc < prefix_len - 1             # <<<<<<<<<<<<<<
 *                         # then we can use this result
 *                     ):
 */
        __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_prefix_len, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2231, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = PyObject_RichCompare(__pyx_v_cache_furthest_loc, __pyx_t_3, Py_LT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2231, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 2231, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_5 = __pyx_t_11;
        __pyx_L21_bool_binop_done:;

        /* "cPyparsing.pyx":2227
 *                 if cache_result is not cache.not_in_cache:
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result
 *                     if (             # <<<<<<<<<<<<<<
 *                         # if other_instring is instring
 *                         is_instring
 */
        if (__pyx_t_5) {

          /* "cPyparsing.pyx":2235
 *                     ):
 *                         # we just used this cache item, so it's definitely useful
 *                         cache_usefullness_obj[0] = True             # <<<<<<<<<<<<<<
 *                         hit = cache_item
 *                         break
 */
          if (unlikely((__Pyx_SetItemInt(__pyx_v_cache_usefullness_obj, 0, Py_True, long, 1, __Pyx_PyInt_From_long, 0, 0, 1) < 0))) __PYX_ERR(0, 2235, __pyx_L1_error)

          /* "cPyparsing.pyx":2236
 *                         # we just used this cache item, so it's definitely useful
 *                         cache_usefullness_obj[0] = True
 *                         hit = cache_item             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
          __Pyx_INCREF(__pyx_v_cache_item);
          __Pyx_DECREF_SET(__pyx_v_hit, __pyx_v_cache_item);

          /* "cPyparsing.pyx":2237
 *                         cache_usefullness_obj[0] = True
 *                         hit = cache_item
 *                         break             # <<<<<<<<<<<<<<
 * 
 *             # otherwise look for suffix hit
 */
          goto __pyx_L11_break;

          /* "cPyparsing.pyx":2227
 *                 if cache_result is not cache.not_in_cache:
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result
 *                     if (             # <<<<<<<<<<<<<<
 *                         # if other_instring is instring
 *                         is_instring
 */
        }

        /* "cPyparsing.pyx":2225
 *                 prefix_lookup = (self, other_instring, loc, lookup_bools, ParserElement.packrat_context)
 *                 cache_result = cache.get(prefix_lookup)
 *                 if cache_result is not cache.not_in_cache:             # <<<<<<<<<<<<<<
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result
 *                     if (
 */
      }

      /* "cPyparsing.pyx":2217
 * 
 *             # look for prefix hit
 *             if (             # <<<<<<<<<<<<<<
 *                 # always check instring itself here
 *                 is_instring
 */
    }

    /* "cPyparsing.pyx":2242
 *             if (
 *                 # don't recheck instring itself
 *                 not is_instring             # <<<<<<<<<<<<<<
 *                 # only check if we're in the common suffix (and not at the start of it)
 *                 and loc > len(instring) - suffix_len
 */
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_is_instring); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 2242, __pyx_L1_error)
    __pyx_t_15 = (!__pyx_t_11);
    if (__pyx_t_15) {
    } else {
      __pyx_t_5 = __pyx_t_15;
      goto __pyx_L24_bool_binop_done;
    }

    /* "cPyparsing.pyx":2244
 *                 not is_instring
 *                 # only check if we're in the common suffix (and not at the start of it)
 *                 and loc > len(instring) - suffix_len             # <<<<<<<<<<<<<<
 *             ):
 *                 loc_in_suffix = len(other_instring) - (len(instring) - loc)
 */
    __pyx_t_10 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2244, __pyx_L1_error)
    __pyx_t_8 = PyInt_FromSsize_t(__pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = PyNumber_Subtract(__pyx_t_8, __pyx_v_suffix_len); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2244, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2244, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_5 = __pyx_t_15;
    __pyx_L24_bool_binop_done:;

    /* "cPyparsing.pyx":2240
 * 
 *             # otherwise look for suffix hit
 *             if (             # <<<<<<<<<<<<<<
 *                 # don't recheck instring itself
 *                 not is_instring
 */
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":2246
 *                 and loc > len(instring) - suffix_len
 *             ):
 *                 loc_in_suffix = len(other_instring) - (len(instring) - loc)             # <<<<<<<<<<<<<<
 *                 suffix_lookup = (self, other_instring, loc_in_suffix, lookup_bools, ParserElement.packrat_context)
 *                 cache_result = cache.get(suffix_lookup)
 */
      __pyx_t_10 = PyObject_Length(__pyx_v_other_instring); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2246, __pyx_L1_error)
      __pyx_t_8 = PyInt_FromSsize_t(__pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2246, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2246, __pyx_L1_error)
      __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2246, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = PyNumber_Subtract(__pyx_t_3, __pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2246, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Subtract(__pyx_t_8, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2246, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_loc_in_suffix, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2247
 *             ):
 *                 loc_in_suffix = len(other_instring) - (len(instring) - loc)
 *                 suffix_lookup = (self, other_instring, loc_in_suffix, lookup_bools, ParserElement.packrat_context)             # <<<<<<<<<<<<<<
 *                 cache_result = cache.get(suffix_lookup)
 *                 if cache_result is not cache.not_in_cache:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_packrat_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self)) __PYX_ERR(0, 2247, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_other_instring);
      __Pyx_GIVEREF(__pyx_v_other_instring);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_other_instring)) __PYX_ERR(0, 2247, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_loc_in_suffix);
      __Pyx_GIVEREF(__pyx_v_loc_in_suffix);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_loc_in_suffix)) __PYX_ERR(0, 2247, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_lookup_bools);
      __Pyx_GIVEREF(__pyx_v_lookup_bools);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_lookup_bools)) __PYX_ERR(0, 2247, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_t_1)) __PYX_ERR(0, 2247, __pyx_L1_error);
      __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_suffix_lookup, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2248
 *                 loc_in_suffix = len(other_instring) - (len(instring) - loc)
 *                 suffix_lookup = (self, other_instring, loc_in_suffix, lookup_bools, ParserElement.packrat_context)
 *                 cache_result = cache.get(suffix_lookup)             # <<<<<<<<<<<<<<
 *                 if cache_result is not cache.not_in_cache:
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_suffix_lookup};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2248, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_cache_result, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2249
 *                 suffix_lookup = (self, other_instring, loc_in_suffix, lookup_bools, ParserElement.packrat_context)
 *                 cache_result = cache.get(suffix_lookup)
 *                 if cache_result is not cache.not_in_cache:             # <<<<<<<<<<<<<<
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result
 *                     # we just used this cache item, so it's definitely useful
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_not_in_cache); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2249, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = (__pyx_v_cache_result != __pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":2250
 *                 cache_result = cache.get(suffix_lookup)
 *                 if cache_result is not cache.not_in_cache:
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result             # <<<<<<<<<<<<<<
 *                     # we just used this cache item, so it's definitely useful
 *                     cache_usefullness_obj[0] = True
 */
        if ((likely(PyTuple_CheckExact(__pyx_v_cache_result))) || (PyList_CheckExact(__pyx_v_cache_result))) {
          PyObject* sequence = __pyx_v_cache_result;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 3)) {
            if (size > 3) __Pyx_RaiseTooManyValuesError(3);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 2250, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
            __pyx_t_8 = PyTuple_GET_ITEM(sequence, 2); 
          } else {
            __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
            __pyx_t_8 = PyList_GET_ITEM(sequence, 2); 
          }
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_8);
          #else
          __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2250, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2250, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_8 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2250, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          #endif
        } else {
          Py_ssize_t index = -1;
          __pyx_t_2 = PyObject_GetIter(__pyx_v_cache_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2250, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
          index = 0; __pyx_t_3 = __pyx_t_14(__pyx_t_2); if (unlikely(!__pyx_t_3)) goto __pyx_L27_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_3);
          index = 1; __pyx_t_1 = __pyx_t_14(__pyx_t_2); if (unlikely(!__pyx_t_1)) goto __pyx_L27_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          index = 2; __pyx_t_8 = __pyx_t_14(__pyx_t_2); if (unlikely(!__pyx_t_8)) goto __pyx_L27_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_8);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_2), 3) < 0) __PYX_ERR(0, 2250, __pyx_L1_error)
          __pyx_t_14 = NULL;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L28_unpacking_done;
          __pyx_L27_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_14 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 2250, __pyx_L1_error)
          __pyx_L28_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_cache_furthest_loc, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_XDECREF_SET(__pyx_v_cache_item, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_cache_usefullness_obj, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "cPyparsing.pyx":2252
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result
 *                     # we just used this cache item, so it's definitely useful
 *                     cache_usefullness_obj[0] = True             # <<<<<<<<<<<<<<
 *                     # the conditions above ensure that if we've gotten here,
 *                     #  we can always use this result
 */
        if (unlikely((__Pyx_SetItemInt(__pyx_v_cache_usefullness_obj, 0, Py_True, long, 1, __Pyx_PyInt_From_long, 0, 0, 1) < 0))) __PYX_ERR(0, 2252, __pyx_L1_error)

        /* "cPyparsing.pyx":2255
 *                     # the conditions above ensure that if we've gotten here,
 *                     #  we can always use this result
 *                     hit = cache_item             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
        __Pyx_INCREF(__pyx_v_cache_item);
        __Pyx_DECREF_SET(__pyx_v_hit, __pyx_v_cache_item);

        /* "cPyparsing.pyx":2256
 *                     #  we can always use this result
 *                     hit = cache_item
 *                     break             # <<<<<<<<<<<<<<
 * 
 *         # handle the hit if we got one
 */
        goto __pyx_L11_break;

        /* "cPyparsing.pyx":2249
 *                 suffix_lookup = (self, other_instring, loc_in_suffix, lookup_bools, ParserElement.packrat_context)
 *                 cache_result = cache.get(suffix_lookup)
 *                 if cache_result is not cache.not_in_cache:             # <<<<<<<<<<<<<<
 *                     cache_furthest_loc, cache_item, cache_usefullness_obj = cache_result
 *                     # we just used this cache item, so it's definitely useful
 */
      }

      /* "cPyparsing.pyx":2240
 * 
 *             # otherwise look for suffix hit
 *             if (             # <<<<<<<<<<<<<<
 *                 # don't recheck instring itself
 *                 not is_instring
 */
    }

    /* "cPyparsing.pyx":2213
 *         # try to find a hit
 *         hit = None
 *         for other_instring, prefix_len, suffix_len in prefixes_and_suffixes:             # <<<<<<<<<<<<<<
 *             is_instring = prefix_len == len(instring)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  goto __pyx_L29_for_end;
  __pyx_L11_break:;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  goto __pyx_L29_for_end;
  __pyx_L29_for_end:;

  /* "cPyparsing.pyx":2259
 * 
 *         # handle the hit if we got one
 *         if hit is not None:             # <<<<<<<<<<<<<<
 *             ParserElement.packrat_cache_stats[HIT] += 1
 *             # defer handling success until later so we can inline
 */
  __pyx_t_5 = (__pyx_v_hit != Py_None);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2260
 *         # handle the hit if we got one
 *         if hit is not None:
 *             ParserElement.packrat_cache_stats[HIT] += 1             # <<<<<<<<<<<<<<
 *             # defer handling success until later so we can inline
 *             # if hit is True:  # success
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_HIT); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyObject_SetItem(__pyx_t_8, __pyx_t_9, __pyx_t_3) < 0))) __PYX_ERR(0, 2260, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2267
 *             #     #  actions that need to actually be called in this parse
 *             #     return self._parseNoCache(instring, loc, doActions, callPreParse)
 *             if hit is not True:  # failure; hit is exception loc             # <<<<<<<<<<<<<<
 *                 # unlike _parseCache, we don't cache the full exception,
 *                 #  so we need to rebuild it here, which can make exceptions a bit wonky
 */
    __pyx_t_5 = (__pyx_v_hit != Py_True);
    if (unlikely(__pyx_t_5)) {

      /* "cPyparsing.pyx":2270
 *                 # unlike _parseCache, we don't cache the full exception,
 *                 #  so we need to rebuild it here, which can make exceptions a bit wonky
 *                 raise ParseException(instring, hit, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         if hit is not True:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_1, __pyx_v_instring, __pyx_v_hit, __pyx_t_3, __pyx_v_self};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2270, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(0, 2270, __pyx_L1_error)

      /* "cPyparsing.pyx":2267
 *             #     #  actions that need to actually be called in this parse
 *             #     return self._parseNoCache(instring, loc, doActions, callPreParse)
 *             if hit is not True:  # failure; hit is exception loc             # <<<<<<<<<<<<<<
 *                 # unlike _parseCache, we don't cache the full exception,
 *                 #  so we need to rebuild it here, which can make exceptions a bit wonky
 */
    }

    /* "cPyparsing.pyx":2259
 * 
 *         # handle the hit if we got one
 *         if hit is not None:             # <<<<<<<<<<<<<<
 *             ParserElement.packrat_cache_stats[HIT] += 1
 *             # defer handling success until later so we can inline
 */
  }

  /* "cPyparsing.pyx":2272
 *                 raise ParseException(instring, hit, self.errmsg, self)
 * 
 *         if hit is not True:             # <<<<<<<<<<<<<<
 *             # otherwise do miss behavior
 *             ParserElement.packrat_cache_stats[MISS] += 1
 */
  __pyx_t_5 = (__pyx_v_hit != Py_True);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2274
 *         if hit is not True:
 *             # otherwise do miss behavior
 *             ParserElement.packrat_cache_stats[MISS] += 1             # <<<<<<<<<<<<<<
 *             lookup = (self, instring, loc, lookup_bools, ParserElement.packrat_context)
 *         # by default, assume inner caches are useful, so they don't get cleared inside this parse
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_MISS); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely((PyObject_SetItem(__pyx_t_9, __pyx_t_8, __pyx_t_1) < 0))) __PYX_ERR(0, 2274, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":2275
 *             # otherwise do miss behavior
 *             ParserElement.packrat_cache_stats[MISS] += 1
 *             lookup = (self, instring, loc, lookup_bools, ParserElement.packrat_context)             # <<<<<<<<<<<<<<
 *         # by default, assume inner caches are useful, so they don't get cleared inside this parse
 *         outer_parent_usefullness_obj, ParserElement._incremental_parent_usefullness_obj = ParserElement._incremental_parent_usefullness_obj, [True]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_packrat_context); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyTuple_New(5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_self)) __PYX_ERR(0, 2275, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_instring)) __PYX_ERR(0, 2275, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_loc);
    __Pyx_GIVEREF(__pyx_v_loc);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_v_loc)) __PYX_ERR(0, 2275, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_lookup_bools);
    __Pyx_GIVEREF(__pyx_v_lookup_bools);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_v_lookup_bools)) __PYX_ERR(0, 2275, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_8)) __PYX_ERR(0, 2275, __pyx_L1_error);
    __pyx_t_8 = 0;
    __pyx_v_lookup = ((PyObject*)__pyx_t_9);
    __pyx_t_9 = 0;

    /* "cPyparsing.pyx":2272
 *                 raise ParseException(instring, hit, self.errmsg, self)
 * 
 *         if hit is not True:             # <<<<<<<<<<<<<<
 *             # otherwise do miss behavior
 *             ParserElement.packrat_cache_stats[MISS] += 1
 */
  }

  /* "cPyparsing.pyx":2277
 *             lookup = (self, instring, loc, lookup_bools, ParserElement.packrat_context)
 *         # by default, assume inner caches are useful, so they don't get cleared inside this parse
 *         outer_parent_usefullness_obj, ParserElement._incremental_parent_usefullness_obj = ParserElement._incremental_parent_usefullness_obj, [True]             # <<<<<<<<<<<<<<
 *         try:
 *             # loc, ret_toks = self._parseNoCache(instring, loc, doActions, callPreParse)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_incremental_parent_usefullness); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, Py_True)) __PYX_ERR(0, 2277, __pyx_L1_error);
  __pyx_v_outer_parent_usefullness_obj = __pyx_t_8;
  __pyx_t_8 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_incremental_parent_usefullness, __pyx_t_9) < 0) __PYX_ERR(0, 2277, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2278
 *         # by default, assume inner caches are useful, so they don't get cleared inside this parse
 *         outer_parent_usefullness_obj, ParserElement._incremental_parent_usefullness_obj = ParserElement._incremental_parent_usefullness_obj, [True]
 *         try:             # <<<<<<<<<<<<<<
 *             # loc, ret_toks = self._parseNoCache(instring, loc, doActions, callPreParse)
 *             # [CPYPARSING] START INLINE _parseNoCache
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_18);
      /*try:*/ {

        /* "cPyparsing.pyx":2283
 * 
 *             # [CPYPARSING] TRY, MATCH, FAIL are constants
 *             debugging = (self.debug)  # and doActions)             # <<<<<<<<<<<<<<
 * 
 *             if debugging or self.failAction:
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debug); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2283, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_v_debugging = __pyx_t_8;
        __pyx_t_8 = 0;

        /* "cPyparsing.pyx":2285
 *             debugging = (self.debug)  # and doActions)
 * 
 *             if debugging or self.failAction:             # <<<<<<<<<<<<<<
 *                 # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                 if self.debugActions[TRY]:
 */
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2285, __pyx_L36_error)
        if (!__pyx_t_15) {
        } else {
          __pyx_t_5 = __pyx_t_15;
          goto __pyx_L43_bool_binop_done;
        }
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2285, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2285, __pyx_L36_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_5 = __pyx_t_15;
        __pyx_L43_bool_binop_done:;
        if (__pyx_t_5) {

          /* "cPyparsing.pyx":2287
 *             if debugging or self.failAction:
 *                 # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                 if self.debugActions[TRY]:             # <<<<<<<<<<<<<<
 *                     self.debugActions[TRY](instring, loc, self)
 *                 try:
 */
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2287, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_TRY); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2287, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2287, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2287, __pyx_L36_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_5) {

            /* "cPyparsing.pyx":2288
 *                 # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                 if self.debugActions[TRY]:
 *                     self.debugActions[TRY](instring, loc, self)             # <<<<<<<<<<<<<<
 *                 try:
 *                     if callPreParse and self.callPreparse:
 */
            __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2288, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_TRY); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2288, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2288, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __pyx_t_8 = NULL;
            __pyx_t_4 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
                __pyx_t_4 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_v_instring, __pyx_v_loc, __pyx_v_self};
              __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2288, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "cPyparsing.pyx":2287
 *             if debugging or self.failAction:
 *                 # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                 if self.debugActions[TRY]:             # <<<<<<<<<<<<<<
 *                     self.debugActions[TRY](instring, loc, self)
 *                 try:
 */
          }

          /* "cPyparsing.pyx":2289
 *                 if self.debugActions[TRY]:
 *                     self.debugActions[TRY](instring, loc, self)
 *                 try:             # <<<<<<<<<<<<<<
 *                     if callPreParse and self.callPreparse:
 *                         preloc = self.preParse(instring, loc)
 */
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            /*try:*/ {

              /* "cPyparsing.pyx":2290
 *                     self.debugActions[TRY](instring, loc, self)
 *                 try:
 *                     if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                         preloc = self.preParse(instring, loc)
 *                     else:
 */
              __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_callPreParse); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2290, __pyx_L46_error)
              if (__pyx_t_15) {
              } else {
                __pyx_t_5 = __pyx_t_15;
                goto __pyx_L53_bool_binop_done;
              }
              __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2290, __pyx_L46_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2290, __pyx_L46_error)
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_t_5 = __pyx_t_15;
              __pyx_L53_bool_binop_done:;
              if (__pyx_t_5) {

                /* "cPyparsing.pyx":2291
 *                 try:
 *                     if callPreParse and self.callPreparse:
 *                         preloc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *                     else:
 *                         preloc = loc
 */
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2291, __pyx_L46_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_8 = NULL;
                __pyx_t_4 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_3))) {
                  __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
                  if (likely(__pyx_t_8)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                    __Pyx_INCREF(__pyx_t_8);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_3, function);
                    __pyx_t_4 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_instring, __pyx_v_loc};
                  __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
                  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2291, __pyx_L46_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                }
                __pyx_v_preloc = __pyx_t_1;
                __pyx_t_1 = 0;

                /* "cPyparsing.pyx":2290
 *                     self.debugActions[TRY](instring, loc, self)
 *                 try:
 *                     if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                         preloc = self.preParse(instring, loc)
 *                     else:
 */
                goto __pyx_L52;
              }

              /* "cPyparsing.pyx":2293
 *                         preloc = self.preParse(instring, loc)
 *                     else:
 *                         preloc = loc             # <<<<<<<<<<<<<<
 *                     tokensStart = preloc
 *                     if self.mayIndexError or preloc >= len(instring):
 */
              /*else*/ {
                __Pyx_INCREF(__pyx_v_loc);
                __pyx_v_preloc = __pyx_v_loc;
              }
              __pyx_L52:;

              /* "cPyparsing.pyx":2294
 *                     else:
 *                         preloc = loc
 *                     tokensStart = preloc             # <<<<<<<<<<<<<<
 *                     if self.mayIndexError or preloc >= len(instring):
 *                         try:
 */
              __Pyx_INCREF(__pyx_v_preloc);
              __pyx_v_tokensStart = __pyx_v_preloc;

              /* "cPyparsing.pyx":2295
 *                         preloc = loc
 *                     tokensStart = preloc
 *                     if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                         try:
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
              __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2295, __pyx_L46_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2295, __pyx_L46_error)
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (!__pyx_t_15) {
              } else {
                __pyx_t_5 = __pyx_t_15;
                goto __pyx_L56_bool_binop_done;
              }
              __pyx_t_6 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2295, __pyx_L46_error)
              __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2295, __pyx_L46_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_3 = PyObject_RichCompare(__pyx_v_preloc, __pyx_t_1, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2295, __pyx_L46_error)
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2295, __pyx_L46_error)
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __pyx_t_5 = __pyx_t_15;
              __pyx_L56_bool_binop_done:;
              if (__pyx_t_5) {

                /* "cPyparsing.pyx":2296
 *                     tokensStart = preloc
 *                     if self.mayIndexError or preloc >= len(instring):
 *                         try:             # <<<<<<<<<<<<<<
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                         except IndexError:
 */
                {
                  __Pyx_PyThreadState_declare
                  __Pyx_PyThreadState_assign
                  __Pyx_ExceptionSave(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
                  __Pyx_XGOTREF(__pyx_t_22);
                  __Pyx_XGOTREF(__pyx_t_23);
                  __Pyx_XGOTREF(__pyx_t_24);
                  /*try:*/ {

                    /* "cPyparsing.pyx":2297
 *                     if self.mayIndexError or preloc >= len(instring):
 *                         try:
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                         except IndexError:
 *                             raise ParseException(instring, len(instring), self.errmsg, self)
 */
                    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2297, __pyx_L58_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    __pyx_t_8 = NULL;
                    __pyx_t_4 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (likely(PyMethod_Check(__pyx_t_1))) {
                      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
                      if (likely(__pyx_t_8)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                        __Pyx_INCREF(__pyx_t_8);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_1, function);
                        __pyx_t_4 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
                      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
                      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2297, __pyx_L58_error)
                      __Pyx_GOTREF(__pyx_t_3);
                      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                    }
                    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
                      PyObject* sequence = __pyx_t_3;
                      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                      if (unlikely(size != 2)) {
                        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                        __PYX_ERR(0, 2297, __pyx_L58_error)
                      }
                      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                      if (likely(PyTuple_CheckExact(sequence))) {
                        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
                        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
                      } else {
                        __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
                        __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
                      }
                      __Pyx_INCREF(__pyx_t_1);
                      __Pyx_INCREF(__pyx_t_8);
                      #else
                      __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2297, __pyx_L58_error)
                      __Pyx_GOTREF(__pyx_t_1);
                      __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2297, __pyx_L58_error)
                      __Pyx_GOTREF(__pyx_t_8);
                      #endif
                      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                    } else {
                      Py_ssize_t index = -1;
                      __pyx_t_9 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2297, __pyx_L58_error)
                      __Pyx_GOTREF(__pyx_t_9);
                      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                      __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
                      index = 0; __pyx_t_1 = __pyx_t_14(__pyx_t_9); if (unlikely(!__pyx_t_1)) goto __pyx_L64_unpacking_failed;
                      __Pyx_GOTREF(__pyx_t_1);
                      index = 1; __pyx_t_8 = __pyx_t_14(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L64_unpacking_failed;
                      __Pyx_GOTREF(__pyx_t_8);
                      if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_9), 2) < 0) __PYX_ERR(0, 2297, __pyx_L58_error)
                      __pyx_t_14 = NULL;
                      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                      goto __pyx_L65_unpacking_done;
                      __pyx_L64_unpacking_failed:;
                      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                      __pyx_t_14 = NULL;
                      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                      __PYX_ERR(0, 2297, __pyx_L58_error)
                      __pyx_L65_unpacking_done:;
                    }
                    __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
                    __pyx_t_1 = 0;
                    __pyx_v_tokens = __pyx_t_8;
                    __pyx_t_8 = 0;

                    /* "cPyparsing.pyx":2296
 *                     tokensStart = preloc
 *                     if self.mayIndexError or preloc >= len(instring):
 *                         try:             # <<<<<<<<<<<<<<
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                         except IndexError:
 */
                  }
                  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
                  __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                  goto __pyx_L63_try_end;
                  __pyx_L58_error:;
                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

                  /* "cPyparsing.pyx":2298
 *                         try:
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                         except IndexError:             # <<<<<<<<<<<<<<
 *                             raise ParseException(instring, len(instring), self.errmsg, self)
 *                     else:
 */
                  __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
                  if (__pyx_t_4) {
                    __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
                    if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(0, 2298, __pyx_L60_except_error)
                    __Pyx_XGOTREF(__pyx_t_3);
                    __Pyx_XGOTREF(__pyx_t_8);
                    __Pyx_XGOTREF(__pyx_t_1);

                    /* "cPyparsing.pyx":2299
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                         except IndexError:
 *                             raise ParseException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *                     else:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
                    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2299, __pyx_L60_except_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __pyx_t_6 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2299, __pyx_L60_except_error)
                    __pyx_t_13 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2299, __pyx_L60_except_error)
                    __Pyx_GOTREF(__pyx_t_13);
                    __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2299, __pyx_L60_except_error)
                    __Pyx_GOTREF(__pyx_t_25);
                    __pyx_t_26 = NULL;
                    __pyx_t_4 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (unlikely(PyMethod_Check(__pyx_t_2))) {
                      __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_2);
                      if (likely(__pyx_t_26)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                        __Pyx_INCREF(__pyx_t_26);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_2, function);
                        __pyx_t_4 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[5] = {__pyx_t_26, __pyx_v_instring, __pyx_t_13, __pyx_t_25, __pyx_v_self};
                      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
                      __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                      __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2299, __pyx_L60_except_error)
                      __Pyx_GOTREF(__pyx_t_9);
                      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                    }
                    __Pyx_Raise(__pyx_t_9, 0, 0, 0);
                    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                    __PYX_ERR(0, 2299, __pyx_L60_except_error)
                  }
                  goto __pyx_L60_except_error;

                  /* "cPyparsing.pyx":2296
 *                     tokensStart = preloc
 *                     if self.mayIndexError or preloc >= len(instring):
 *                         try:             # <<<<<<<<<<<<<<
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                         except IndexError:
 */
                  __pyx_L60_except_error:;
                  __Pyx_XGIVEREF(__pyx_t_22);
                  __Pyx_XGIVEREF(__pyx_t_23);
                  __Pyx_XGIVEREF(__pyx_t_24);
                  __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
                  goto __pyx_L46_error;
                  __pyx_L63_try_end:;
                }

                /* "cPyparsing.pyx":2295
 *                         preloc = loc
 *                     tokensStart = preloc
 *                     if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                         try:
 *                             loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
                goto __pyx_L55;
              }

              /* "cPyparsing.pyx":2301
 *                             raise ParseException(instring, len(instring), self.errmsg, self)
 *                     else:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                 except Exception as err:
 *                     # ~ print ("Exception raised:", err)
 */
              /*else*/ {
                __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2301, __pyx_L46_error)
                __Pyx_GOTREF(__pyx_t_8);
                __pyx_t_3 = NULL;
                __pyx_t_4 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_8))) {
                  __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
                  if (likely(__pyx_t_3)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                    __Pyx_INCREF(__pyx_t_3);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_8, function);
                    __pyx_t_4 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
                  __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
                  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2301, __pyx_L46_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                }
                if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
                  PyObject* sequence = __pyx_t_1;
                  Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                  if (unlikely(size != 2)) {
                    if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                    else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                    __PYX_ERR(0, 2301, __pyx_L46_error)
                  }
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  if (likely(PyTuple_CheckExact(sequence))) {
                    __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
                    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
                  } else {
                    __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
                    __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
                  }
                  __Pyx_INCREF(__pyx_t_8);
                  __Pyx_INCREF(__pyx_t_3);
                  #else
                  __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2301, __pyx_L46_error)
                  __Pyx_GOTREF(__pyx_t_8);
                  __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2301, __pyx_L46_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  #endif
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                } else {
                  Py_ssize_t index = -1;
                  __pyx_t_9 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2301, __pyx_L46_error)
                  __Pyx_GOTREF(__pyx_t_9);
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
                  index = 0; __pyx_t_8 = __pyx_t_14(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L68_unpacking_failed;
                  __Pyx_GOTREF(__pyx_t_8);
                  index = 1; __pyx_t_3 = __pyx_t_14(__pyx_t_9); if (unlikely(!__pyx_t_3)) goto __pyx_L68_unpacking_failed;
                  __Pyx_GOTREF(__pyx_t_3);
                  if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_9), 2) < 0) __PYX_ERR(0, 2301, __pyx_L46_error)
                  __pyx_t_14 = NULL;
                  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                  goto __pyx_L69_unpacking_done;
                  __pyx_L68_unpacking_failed:;
                  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                  __pyx_t_14 = NULL;
                  if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                  __PYX_ERR(0, 2301, __pyx_L46_error)
                  __pyx_L69_unpacking_done:;
                }
                __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_8);
                __pyx_t_8 = 0;
                __pyx_v_tokens = __pyx_t_3;
                __pyx_t_3 = 0;
              }
              __pyx_L55:;

              /* "cPyparsing.pyx":2289
 *                 if self.debugActions[TRY]:
 *                     self.debugActions[TRY](instring, loc, self)
 *                 try:             # <<<<<<<<<<<<<<
 *                     if callPreParse and self.callPreparse:
 *                         preloc = self.preParse(instring, loc)
 */
            }
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
            __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
            goto __pyx_L51_try_end;
            __pyx_L46_error:;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

            /* "cPyparsing.pyx":2302
 *                     else:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except Exception as err:             # <<<<<<<<<<<<<<
 *                     # ~ print ("Exception raised:", err)
 *                     if self.debugActions[FAIL]:
 */
            __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
            if (__pyx_t_4) {
              __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_8) < 0) __PYX_ERR(0, 2302, __pyx_L48_except_error)
              __Pyx_XGOTREF(__pyx_t_1);
              __Pyx_XGOTREF(__pyx_t_3);
              __Pyx_XGOTREF(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_3);
              __pyx_v_err = __pyx_t_3;
              /*try:*/ {

                /* "cPyparsing.pyx":2304
 *                 except Exception as err:
 *                     # ~ print ("Exception raised:", err)
 *                     if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)
 *                     if self.failAction:
 */
                __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2304, __pyx_L75_error)
                __Pyx_GOTREF(__pyx_t_9);
                __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2304, __pyx_L75_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_25 = __Pyx_PyObject_GetItem(__pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2304, __pyx_L75_error)
                __Pyx_GOTREF(__pyx_t_25);
                __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2304, __pyx_L75_error)
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                if (__pyx_t_5) {

                  /* "cPyparsing.pyx":2305
 *                     # ~ print ("Exception raised:", err)
 *                     if self.debugActions[FAIL]:
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                     if self.failAction:
 *                         self.failAction(instring, tokensStart, self, err)
 */
                  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2305, __pyx_L75_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2305, __pyx_L75_error)
                  __Pyx_GOTREF(__pyx_t_9);
                  __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2305, __pyx_L75_error)
                  __Pyx_GOTREF(__pyx_t_13);
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                  if (unlikely(!__pyx_v_tokensStart)) { __Pyx_RaiseUnboundLocalError("tokensStart"); __PYX_ERR(0, 2305, __pyx_L75_error) }
                  __pyx_t_9 = NULL;
                  __pyx_t_4 = 0;
                  #if CYTHON_UNPACK_METHODS
                  if (unlikely(PyMethod_Check(__pyx_t_13))) {
                    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
                    if (likely(__pyx_t_9)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                      __Pyx_INCREF(__pyx_t_9);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_13, function);
                      __pyx_t_4 = 1;
                    }
                  }
                  #endif
                  {
                    PyObject *__pyx_callargs[5] = {__pyx_t_9, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
                    __pyx_t_25 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
                    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                    if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2305, __pyx_L75_error)
                    __Pyx_GOTREF(__pyx_t_25);
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                  }
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;

                  /* "cPyparsing.pyx":2304
 *                 except Exception as err:
 *                     # ~ print ("Exception raised:", err)
 *                     if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)
 *                     if self.failAction:
 */
                }

                /* "cPyparsing.pyx":2306
 *                     if self.debugActions[FAIL]:
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)
 *                     if self.failAction:             # <<<<<<<<<<<<<<
 *                         self.failAction(instring, tokensStart, self, err)
 *                     raise
 */
                __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2306, __pyx_L75_error)
                __Pyx_GOTREF(__pyx_t_25);
                __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2306, __pyx_L75_error)
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                if (__pyx_t_5) {

                  /* "cPyparsing.pyx":2307
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)
 *                     if self.failAction:
 *                         self.failAction(instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                     raise
 *             else:
 */
                  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2307, __pyx_L75_error)
                  __Pyx_GOTREF(__pyx_t_13);
                  if (unlikely(!__pyx_v_tokensStart)) { __Pyx_RaiseUnboundLocalError("tokensStart"); __PYX_ERR(0, 2307, __pyx_L75_error) }
                  __pyx_t_9 = NULL;
                  __pyx_t_4 = 0;
                  #if CYTHON_UNPACK_METHODS
                  if (likely(PyMethod_Check(__pyx_t_13))) {
                    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
                    if (likely(__pyx_t_9)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                      __Pyx_INCREF(__pyx_t_9);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_13, function);
                      __pyx_t_4 = 1;
                    }
                  }
                  #endif
                  {
                    PyObject *__pyx_callargs[5] = {__pyx_t_9, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
                    __pyx_t_25 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
                    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                    if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2307, __pyx_L75_error)
                    __Pyx_GOTREF(__pyx_t_25);
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                  }
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;

                  /* "cPyparsing.pyx":2306
 *                     if self.debugActions[FAIL]:
 *                         self.debugActions[FAIL](instring, tokensStart, self, err)
 *                     if self.failAction:             # <<<<<<<<<<<<<<
 *                         self.failAction(instring, tokensStart, self, err)
 *                     raise
 */
                }

                /* "cPyparsing.pyx":2308
 *                     if self.failAction:
 *                         self.failAction(instring, tokensStart, self, err)
 *                     raise             # <<<<<<<<<<<<<<
 *             else:
 *                 if callPreParse and self.callPreparse:
 */
                __Pyx_GIVEREF(__pyx_t_1);
                __Pyx_GIVEREF(__pyx_t_3);
                __Pyx_XGIVEREF(__pyx_t_8);
                __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_3, __pyx_t_8);
                __pyx_t_1 = 0; __pyx_t_3 = 0; __pyx_t_8 = 0; 
                __PYX_ERR(0, 2308, __pyx_L75_error)
              }

              /* "cPyparsing.pyx":2302
 *                     else:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except Exception as err:             # <<<<<<<<<<<<<<
 *                     # ~ print ("Exception raised:", err)
 *                     if self.debugActions[FAIL]:
 */
              /*finally:*/ {
                __pyx_L75_error:;
                /*exception exit:*/{
                  __Pyx_PyThreadState_declare
                  __Pyx_PyThreadState_assign
                  __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_22 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0;
                  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                  __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                  __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                  if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_29, &__pyx_t_30, &__pyx_t_31);
                  if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_24, &__pyx_t_23, &__pyx_t_22) < 0)) __Pyx_ErrFetch(&__pyx_t_24, &__pyx_t_23, &__pyx_t_22);
                  __Pyx_XGOTREF(__pyx_t_24);
                  __Pyx_XGOTREF(__pyx_t_23);
                  __Pyx_XGOTREF(__pyx_t_22);
                  __Pyx_XGOTREF(__pyx_t_29);
                  __Pyx_XGOTREF(__pyx_t_30);
                  __Pyx_XGOTREF(__pyx_t_31);
                  __pyx_t_4 = __pyx_lineno; __pyx_t_27 = __pyx_clineno; __pyx_t_28 = __pyx_filename;
                  {
                    __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
                  }
                  if (PY_MAJOR_VERSION >= 3) {
                    __Pyx_XGIVEREF(__pyx_t_29);
                    __Pyx_XGIVEREF(__pyx_t_30);
                    __Pyx_XGIVEREF(__pyx_t_31);
                    __Pyx_ExceptionReset(__pyx_t_29, __pyx_t_30, __pyx_t_31);
                  }
                  __Pyx_XGIVEREF(__pyx_t_24);
                  __Pyx_XGIVEREF(__pyx_t_23);
                  __Pyx_XGIVEREF(__pyx_t_22);
                  __Pyx_ErrRestore(__pyx_t_24, __pyx_t_23, __pyx_t_22);
                  __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_22 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0;
                  __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_27; __pyx_filename = __pyx_t_28;
                  goto __pyx_L48_except_error;
                }
              }
            }
            goto __pyx_L48_except_error;

            /* "cPyparsing.pyx":2289
 *                 if self.debugActions[TRY]:
 *                     self.debugActions[TRY](instring, loc, self)
 *                 try:             # <<<<<<<<<<<<<<
 *                     if callPreParse and self.callPreparse:
 *                         preloc = self.preParse(instring, loc)
 */
            __pyx_L48_except_error:;
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
            goto __pyx_L36_error;
            __pyx_L51_try_end:;
          }

          /* "cPyparsing.pyx":2285
 *             debugging = (self.debug)  # and doActions)
 * 
 *             if debugging or self.failAction:             # <<<<<<<<<<<<<<
 *                 # ~ print ("Match", self, "at loc", loc, "(%d, %d)" % (lineno(loc, instring), col(loc, instring)))
 *                 if self.debugActions[TRY]:
 */
          goto __pyx_L42;
        }

        /* "cPyparsing.pyx":2310
 *                     raise
 *             else:
 *                 if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                     preloc = self.preParse(instring, loc)
 *                 else:
 */
        /*else*/ {
          __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_callPreParse); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2310, __pyx_L36_error)
          if (__pyx_t_15) {
          } else {
            __pyx_t_5 = __pyx_t_15;
            goto __pyx_L84_bool_binop_done;
          }
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2310, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2310, __pyx_L36_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_5 = __pyx_t_15;
          __pyx_L84_bool_binop_done:;
          if (__pyx_t_5) {

            /* "cPyparsing.pyx":2311
 *             else:
 *                 if callPreParse and self.callPreparse:
 *                     preloc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *                 else:
 *                     preloc = loc
 */
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2311, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_1 = NULL;
            __pyx_t_27 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_1)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_1);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
                __pyx_t_27 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc};
              __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_27, 2+__pyx_t_27);
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2311, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            }
            __pyx_v_preloc = __pyx_t_8;
            __pyx_t_8 = 0;

            /* "cPyparsing.pyx":2310
 *                     raise
 *             else:
 *                 if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                     preloc = self.preParse(instring, loc)
 *                 else:
 */
            goto __pyx_L83;
          }

          /* "cPyparsing.pyx":2313
 *                     preloc = self.preParse(instring, loc)
 *                 else:
 *                     preloc = loc             # <<<<<<<<<<<<<<
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):
 */
          /*else*/ {
            __Pyx_INCREF(__pyx_v_loc);
            __pyx_v_preloc = __pyx_v_loc;
          }
          __pyx_L83:;

          /* "cPyparsing.pyx":2314
 *                 else:
 *                     preloc = loc
 *                 tokensStart = preloc             # <<<<<<<<<<<<<<
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:
 */
          __Pyx_INCREF(__pyx_v_preloc);
          __pyx_v_tokensStart = __pyx_v_preloc;

          /* "cPyparsing.pyx":2315
 *                     preloc = loc
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                     try:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2315, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2315, __pyx_L36_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (!__pyx_t_15) {
          } else {
            __pyx_t_5 = __pyx_t_15;
            goto __pyx_L87_bool_binop_done;
          }
          __pyx_t_6 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2315, __pyx_L36_error)
          __pyx_t_8 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2315, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_3 = PyObject_RichCompare(__pyx_v_preloc, __pyx_t_8, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2315, __pyx_L36_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2315, __pyx_L36_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_5 = __pyx_t_15;
          __pyx_L87_bool_binop_done:;
          if (__pyx_t_5) {

            /* "cPyparsing.pyx":2316
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:             # <<<<<<<<<<<<<<
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:
 */
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_19);
              /*try:*/ {

                /* "cPyparsing.pyx":2317
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                     except IndexError:
 *                         raise ParseException(instring, len(instring), self.errmsg, self)
 */
                __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2317, __pyx_L89_error)
                __Pyx_GOTREF(__pyx_t_8);
                __pyx_t_1 = NULL;
                __pyx_t_27 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_8))) {
                  __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
                  if (likely(__pyx_t_1)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                    __Pyx_INCREF(__pyx_t_1);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_8, function);
                    __pyx_t_27 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
                  __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2317, __pyx_L89_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                }
                if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
                  PyObject* sequence = __pyx_t_3;
                  Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                  if (unlikely(size != 2)) {
                    if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                    else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                    __PYX_ERR(0, 2317, __pyx_L89_error)
                  }
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  if (likely(PyTuple_CheckExact(sequence))) {
                    __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
                    __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
                  } else {
                    __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
                    __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
                  }
                  __Pyx_INCREF(__pyx_t_8);
                  __Pyx_INCREF(__pyx_t_1);
                  #else
                  __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2317, __pyx_L89_error)
                  __Pyx_GOTREF(__pyx_t_8);
                  __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2317, __pyx_L89_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  #endif
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                } else {
                  Py_ssize_t index = -1;
                  __pyx_t_25 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2317, __pyx_L89_error)
                  __Pyx_GOTREF(__pyx_t_25);
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_25);
                  index = 0; __pyx_t_8 = __pyx_t_14(__pyx_t_25); if (unlikely(!__pyx_t_8)) goto __pyx_L95_unpacking_failed;
                  __Pyx_GOTREF(__pyx_t_8);
                  index = 1; __pyx_t_1 = __pyx_t_14(__pyx_t_25); if (unlikely(!__pyx_t_1)) goto __pyx_L95_unpacking_failed;
                  __Pyx_GOTREF(__pyx_t_1);
                  if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_25), 2) < 0) __PYX_ERR(0, 2317, __pyx_L89_error)
                  __pyx_t_14 = NULL;
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                  goto __pyx_L96_unpacking_done;
                  __pyx_L95_unpacking_failed:;
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                  __pyx_t_14 = NULL;
                  if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                  __PYX_ERR(0, 2317, __pyx_L89_error)
                  __pyx_L96_unpacking_done:;
                }
                __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_8);
                __pyx_t_8 = 0;
                __pyx_v_tokens = __pyx_t_1;
                __pyx_t_1 = 0;

                /* "cPyparsing.pyx":2316
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:             # <<<<<<<<<<<<<<
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:
 */
              }
              __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
              __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              goto __pyx_L94_try_end;
              __pyx_L89_error:;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

              /* "cPyparsing.pyx":2318
 *                     try:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:             # <<<<<<<<<<<<<<
 *                         raise ParseException(instring, len(instring), self.errmsg, self)
 *                 else:
 */
              __pyx_t_27 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
              if (__pyx_t_27) {
                __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_8) < 0) __PYX_ERR(0, 2318, __pyx_L91_except_error)
                __Pyx_XGOTREF(__pyx_t_3);
                __Pyx_XGOTREF(__pyx_t_1);
                __Pyx_XGOTREF(__pyx_t_8);

                /* "cPyparsing.pyx":2319
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:
 *                         raise ParseException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *                 else:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
                __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2319, __pyx_L91_except_error)
                __Pyx_GOTREF(__pyx_t_13);
                __pyx_t_6 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2319, __pyx_L91_except_error)
                __pyx_t_9 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2319, __pyx_L91_except_error)
                __Pyx_GOTREF(__pyx_t_9);
                __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2319, __pyx_L91_except_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_26 = NULL;
                __pyx_t_27 = 0;
                #if CYTHON_UNPACK_METHODS
                if (unlikely(PyMethod_Check(__pyx_t_13))) {
                  __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_13);
                  if (likely(__pyx_t_26)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                    __Pyx_INCREF(__pyx_t_26);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_13, function);
                    __pyx_t_27 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[5] = {__pyx_t_26, __pyx_v_instring, __pyx_t_9, __pyx_t_2, __pyx_v_self};
                  __pyx_t_25 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_27, 4+__pyx_t_27);
                  __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2319, __pyx_L91_except_error)
                  __Pyx_GOTREF(__pyx_t_25);
                  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                }
                __Pyx_Raise(__pyx_t_25, 0, 0, 0);
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                __PYX_ERR(0, 2319, __pyx_L91_except_error)
              }
              goto __pyx_L91_except_error;

              /* "cPyparsing.pyx":2316
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):
 *                     try:             # <<<<<<<<<<<<<<
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                     except IndexError:
 */
              __pyx_L91_except_error:;
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
              goto __pyx_L36_error;
              __pyx_L94_try_end:;
            }

            /* "cPyparsing.pyx":2315
 *                     preloc = loc
 *                 tokensStart = preloc
 *                 if self.mayIndexError or preloc >= len(instring):             # <<<<<<<<<<<<<<
 *                     try:
 *                         loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
            goto __pyx_L86;
          }

          /* "cPyparsing.pyx":2321
 *                         raise ParseException(instring, len(instring), self.errmsg, self)
 *                 else:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 * 
 *             tokens = self.postParse(instring, loc, tokens)
 */
          /*else*/ {
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2321, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_3 = NULL;
            __pyx_t_27 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_3)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_3);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_27 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
              __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2321, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            }
            if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
              PyObject* sequence = __pyx_t_8;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 2)) {
                if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 2321, __pyx_L36_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
              } else {
                __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
              }
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_3);
              #else
              __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2321, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2321, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_3);
              #endif
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else {
              Py_ssize_t index = -1;
              __pyx_t_25 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2321, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_25);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_25);
              index = 0; __pyx_t_1 = __pyx_t_14(__pyx_t_25); if (unlikely(!__pyx_t_1)) goto __pyx_L99_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_1);
              index = 1; __pyx_t_3 = __pyx_t_14(__pyx_t_25); if (unlikely(!__pyx_t_3)) goto __pyx_L99_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_3);
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_25), 2) < 0) __PYX_ERR(0, 2321, __pyx_L36_error)
              __pyx_t_14 = NULL;
              __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
              goto __pyx_L100_unpacking_done;
              __pyx_L99_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
              __pyx_t_14 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 2321, __pyx_L36_error)
              __pyx_L100_unpacking_done:;
            }
            __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
            __pyx_t_1 = 0;
            __pyx_v_tokens = __pyx_t_3;
            __pyx_t_3 = 0;
          }
          __pyx_L86:;
        }
        __pyx_L42:;

        /* "cPyparsing.pyx":2323
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 * 
 *             tokens = self.postParse(instring, loc, tokens)             # <<<<<<<<<<<<<<
 * 
 *             retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_postParse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2323, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = NULL;
        __pyx_t_27 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_27 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokens};
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2323, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "cPyparsing.pyx":2325
 *             tokens = self.postParse(instring, loc, tokens)
 * 
 *             retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)             # <<<<<<<<<<<<<<
 *             if self.parseAction and (doActions or self.callDuringTry):
 *                 if debugging:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2325, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2325, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2325, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_tokens);
        __Pyx_GIVEREF(__pyx_v_tokens);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_tokens)) __PYX_ERR(0, 2325, __pyx_L36_error);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(0, 2325, __pyx_L36_error);
        __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2325, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2325, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_25);
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_asList, __pyx_t_25) < 0) __PYX_ERR(0, 2325, __pyx_L36_error)
        __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
        __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2325, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_25);
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_modal, __pyx_t_25) < 0) __PYX_ERR(0, 2325, __pyx_L36_error)
        __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
        __pyx_t_25 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2325, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_25);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_retTokens = __pyx_t_25;
        __pyx_t_25 = 0;

        /* "cPyparsing.pyx":2326
 * 
 *             retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *             if self.parseAction and (doActions or self.callDuringTry):             # <<<<<<<<<<<<<<
 *                 if debugging:
 *                     try:
 */
        __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2326, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_25);
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2326, __pyx_L36_error)
        __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
        if (__pyx_t_15) {
        } else {
          __pyx_t_5 = __pyx_t_15;
          goto __pyx_L102_bool_binop_done;
        }
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_doActions); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2326, __pyx_L36_error)
        if (!__pyx_t_15) {
        } else {
          __pyx_t_5 = __pyx_t_15;
          goto __pyx_L102_bool_binop_done;
        }
        __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2326, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_25);
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2326, __pyx_L36_error)
        __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
        __pyx_t_5 = __pyx_t_15;
        __pyx_L102_bool_binop_done:;
        if (__pyx_t_5) {

          /* "cPyparsing.pyx":2327
 *             retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *             if self.parseAction and (doActions or self.callDuringTry):
 *                 if debugging:             # <<<<<<<<<<<<<<
 *                     try:
 *                         for fn in self.parseAction:
 */
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2327, __pyx_L36_error)
          if (__pyx_t_5) {

            /* "cPyparsing.pyx":2328
 *             if self.parseAction and (doActions or self.callDuringTry):
 *                 if debugging:
 *                     try:             # <<<<<<<<<<<<<<
 *                         for fn in self.parseAction:
 *                             try:
 */
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_21);
              /*try:*/ {

                /* "cPyparsing.pyx":2329
 *                 if debugging:
 *                     try:
 *                         for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                             try:
 *                                 tokens = fn(instring, tokensStart, retTokens)
 */
                __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2329, __pyx_L106_error)
                __Pyx_GOTREF(__pyx_t_25);
                if (likely(PyList_CheckExact(__pyx_t_25)) || PyTuple_CheckExact(__pyx_t_25)) {
                  __pyx_t_3 = __pyx_t_25; __Pyx_INCREF(__pyx_t_3);
                  __pyx_t_6 = 0;
                  __pyx_t_7 = NULL;
                } else {
                  __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_25); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2329, __pyx_L106_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2329, __pyx_L106_error)
                }
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                for (;;) {
                  if (likely(!__pyx_t_7)) {
                    if (likely(PyList_CheckExact(__pyx_t_3))) {
                      {
                        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
                        #if !CYTHON_ASSUME_SAFE_MACROS
                        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2329, __pyx_L106_error)
                        #endif
                        if (__pyx_t_6 >= __pyx_temp) break;
                      }
                      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                      __pyx_t_25 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_25); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 2329, __pyx_L106_error)
                      #else
                      __pyx_t_25 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2329, __pyx_L106_error)
                      __Pyx_GOTREF(__pyx_t_25);
                      #endif
                    } else {
                      {
                        Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
                        #if !CYTHON_ASSUME_SAFE_MACROS
                        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2329, __pyx_L106_error)
                        #endif
                        if (__pyx_t_6 >= __pyx_temp) break;
                      }
                      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                      __pyx_t_25 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_25); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 2329, __pyx_L106_error)
                      #else
                      __pyx_t_25 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2329, __pyx_L106_error)
                      __Pyx_GOTREF(__pyx_t_25);
                      #endif
                    }
                  } else {
                    __pyx_t_25 = __pyx_t_7(__pyx_t_3);
                    if (unlikely(!__pyx_t_25)) {
                      PyObject* exc_type = PyErr_Occurred();
                      if (exc_type) {
                        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                        else __PYX_ERR(0, 2329, __pyx_L106_error)
                      }
                      break;
                    }
                    __Pyx_GOTREF(__pyx_t_25);
                  }
                  __Pyx_XDECREF_SET(__pyx_v_fn, __pyx_t_25);
                  __pyx_t_25 = 0;

                  /* "cPyparsing.pyx":2330
 *                     try:
 *                         for fn in self.parseAction:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 tokens = fn(instring, tokensStart, retTokens)
 *                             except IndexError as parse_action_exc:
 */
                  {
                    __Pyx_PyThreadState_declare
                    __Pyx_PyThreadState_assign
                    __Pyx_ExceptionSave(&__pyx_t_31, &__pyx_t_30, &__pyx_t_29);
                    __Pyx_XGOTREF(__pyx_t_31);
                    __Pyx_XGOTREF(__pyx_t_30);
                    __Pyx_XGOTREF(__pyx_t_29);
                    /*try:*/ {

                      /* "cPyparsing.pyx":2331
 *                         for fn in self.parseAction:
 *                             try:
 *                                 tokens = fn(instring, tokensStart, retTokens)             # <<<<<<<<<<<<<<
 *                             except IndexError as parse_action_exc:
 *                                 exc = ParseException("exception raised in parse action")
 */
                      __Pyx_INCREF(__pyx_v_fn);
                      __pyx_t_1 = __pyx_v_fn; __pyx_t_8 = NULL;
                      __pyx_t_27 = 0;
                      #if CYTHON_UNPACK_METHODS
                      if (unlikely(PyMethod_Check(__pyx_t_1))) {
                        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
                        if (likely(__pyx_t_8)) {
                          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                          __Pyx_INCREF(__pyx_t_8);
                          __Pyx_INCREF(function);
                          __Pyx_DECREF_SET(__pyx_t_1, function);
                          __pyx_t_27 = 1;
                        }
                      }
                      #endif
                      {
                        PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
                        __pyx_t_25 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
                        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                        if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2331, __pyx_L114_error)
                        __Pyx_GOTREF(__pyx_t_25);
                        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                      }
                      __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_25);
                      __pyx_t_25 = 0;

                      /* "cPyparsing.pyx":2330
 *                     try:
 *                         for fn in self.parseAction:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 tokens = fn(instring, tokensStart, retTokens)
 *                             except IndexError as parse_action_exc:
 */
                    }
                    __Pyx_XDECREF(__pyx_t_31); __pyx_t_31 = 0;
                    __Pyx_XDECREF(__pyx_t_30); __pyx_t_30 = 0;
                    __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
                    goto __pyx_L121_try_end;
                    __pyx_L114_error:;
                    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                    __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                    __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

                    /* "cPyparsing.pyx":2332
 *                             try:
 *                                 tokens = fn(instring, tokensStart, retTokens)
 *                             except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                                 exc = ParseException("exception raised in parse action")
 *                                 exc.__cause__ = parse_action_exc
 */
                    __pyx_t_27 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
                    if (__pyx_t_27) {
                      __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
                      if (__Pyx_GetException(&__pyx_t_25, &__pyx_t_1, &__pyx_t_8) < 0) __PYX_ERR(0, 2332, __pyx_L116_except_error)
                      __Pyx_XGOTREF(__pyx_t_25);
                      __Pyx_XGOTREF(__pyx_t_1);
                      __Pyx_XGOTREF(__pyx_t_8);
                      __Pyx_INCREF(__pyx_t_1);
                      __pyx_v_parse_action_exc = __pyx_t_1;
                      /*try:*/ {

                        /* "cPyparsing.pyx":2333
 *                                 tokens = fn(instring, tokensStart, retTokens)
 *                             except IndexError as parse_action_exc:
 *                                 exc = ParseException("exception raised in parse action")             # <<<<<<<<<<<<<<
 *                                 exc.__cause__ = parse_action_exc
 *                                 raise exc
 */
                        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2333, __pyx_L127_error)
                        __Pyx_GOTREF(__pyx_t_2);
                        __pyx_t_9 = NULL;
                        __pyx_t_27 = 0;
                        #if CYTHON_UNPACK_METHODS
                        if (unlikely(PyMethod_Check(__pyx_t_2))) {
                          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
                          if (likely(__pyx_t_9)) {
                            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                            __Pyx_INCREF(__pyx_t_9);
                            __Pyx_INCREF(function);
                            __Pyx_DECREF_SET(__pyx_t_2, function);
                            __pyx_t_27 = 1;
                          }
                        }
                        #endif
                        {
                          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_kp_u_exception_raised_in_parse_action};
                          __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_27, 1+__pyx_t_27);
                          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2333, __pyx_L127_error)
                          __Pyx_GOTREF(__pyx_t_13);
                          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                        }
                        __pyx_v_exc = __pyx_t_13;
                        __pyx_t_13 = 0;

                        /* "cPyparsing.pyx":2334
 *                             except IndexError as parse_action_exc:
 *                                 exc = ParseException("exception raised in parse action")
 *                                 exc.__cause__ = parse_action_exc             # <<<<<<<<<<<<<<
 *                                 raise exc
 * 
 */
                        if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_cause, __pyx_v_parse_action_exc) < 0) __PYX_ERR(0, 2334, __pyx_L127_error)

                        /* "cPyparsing.pyx":2335
 *                                 exc = ParseException("exception raised in parse action")
 *                                 exc.__cause__ = parse_action_exc
 *                                 raise exc             # <<<<<<<<<<<<<<
 * 
 *                             if tokens is not None and tokens is not retTokens:
 */
                        __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
                        __PYX_ERR(0, 2335, __pyx_L127_error)
                      }

                      /* "cPyparsing.pyx":2332
 *                             try:
 *                                 tokens = fn(instring, tokensStart, retTokens)
 *                             except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                                 exc = ParseException("exception raised in parse action")
 *                                 exc.__cause__ = parse_action_exc
 */
                      /*finally:*/ {
                        __pyx_L127_error:;
                        /*exception exit:*/{
                          __Pyx_PyThreadState_declare
                          __Pyx_PyThreadState_assign
                          __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_33 = 0; __pyx_t_34 = 0; __pyx_t_35 = 0;
                          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                          __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_33, &__pyx_t_34, &__pyx_t_35);
                          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
                          __Pyx_XGOTREF(__pyx_t_22);
                          __Pyx_XGOTREF(__pyx_t_23);
                          __Pyx_XGOTREF(__pyx_t_24);
                          __Pyx_XGOTREF(__pyx_t_33);
                          __Pyx_XGOTREF(__pyx_t_34);
                          __Pyx_XGOTREF(__pyx_t_35);
                          __pyx_t_27 = __pyx_lineno; __pyx_t_4 = __pyx_clineno; __pyx_t_32 = __pyx_filename;
                          {
                            __Pyx_DECREF(__pyx_v_parse_action_exc); __pyx_v_parse_action_exc = 0;
                          }
                          if (PY_MAJOR_VERSION >= 3) {
                            __Pyx_XGIVEREF(__pyx_t_33);
                            __Pyx_XGIVEREF(__pyx_t_34);
                            __Pyx_XGIVEREF(__pyx_t_35);
                            __Pyx_ExceptionReset(__pyx_t_33, __pyx_t_34, __pyx_t_35);
                          }
                          __Pyx_XGIVEREF(__pyx_t_22);
                          __Pyx_XGIVEREF(__pyx_t_23);
                          __Pyx_XGIVEREF(__pyx_t_24);
                          __Pyx_ErrRestore(__pyx_t_22, __pyx_t_23, __pyx_t_24);
                          __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_33 = 0; __pyx_t_34 = 0; __pyx_t_35 = 0;
                          __pyx_lineno = __pyx_t_27; __pyx_clineno = __pyx_t_4; __pyx_filename = __pyx_t_32;
                          goto __pyx_L116_except_error;
                        }
                      }
                    }
                    goto __pyx_L116_except_error;

                    /* "cPyparsing.pyx":2330
 *                     try:
 *                         for fn in self.parseAction:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 tokens = fn(instring, tokensStart, retTokens)
 *                             except IndexError as parse_action_exc:
 */
                    __pyx_L116_except_error:;
                    __Pyx_XGIVEREF(__pyx_t_31);
                    __Pyx_XGIVEREF(__pyx_t_30);
                    __Pyx_XGIVEREF(__pyx_t_29);
                    __Pyx_ExceptionReset(__pyx_t_31, __pyx_t_30, __pyx_t_29);
                    goto __pyx_L106_error;
                    __pyx_L121_try_end:;
                  }

                  /* "cPyparsing.pyx":2337
 *                                 raise exc
 * 
 *                             if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                                 retTokens = ParseResults(tokens,
 *                                                         self.resultsName,
 */
                  __pyx_t_15 = (__pyx_v_tokens != Py_None);
                  if (__pyx_t_15) {
                  } else {
                    __pyx_t_5 = __pyx_t_15;
                    goto __pyx_L134_bool_binop_done;
                  }
                  __pyx_t_15 = (__pyx_v_tokens != __pyx_v_retTokens);
                  __pyx_t_5 = __pyx_t_15;
                  __pyx_L134_bool_binop_done:;
                  if (__pyx_t_5) {

                    /* "cPyparsing.pyx":2338
 * 
 *                             if tokens is not None and tokens is not retTokens:
 *                                 retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                         self.resultsName,
 *                                                         asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2338, __pyx_L106_error)
                    __Pyx_GOTREF(__pyx_t_8);

                    /* "cPyparsing.pyx":2339
 *                             if tokens is not None and tokens is not retTokens:
 *                                 retTokens = ParseResults(tokens,
 *                                                         self.resultsName,             # <<<<<<<<<<<<<<
 *                                                         asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                         modal=self.modalResults)
 */
                    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2339, __pyx_L106_error)
                    __Pyx_GOTREF(__pyx_t_1);

                    /* "cPyparsing.pyx":2338
 * 
 *                             if tokens is not None and tokens is not retTokens:
 *                                 retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                         self.resultsName,
 *                                                         asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                    __pyx_t_25 = PyTuple_New(2); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2338, __pyx_L106_error)
                    __Pyx_GOTREF(__pyx_t_25);
                    __Pyx_INCREF(__pyx_v_tokens);
                    __Pyx_GIVEREF(__pyx_v_tokens);
                    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_25, 0, __pyx_v_tokens)) __PYX_ERR(0, 2338, __pyx_L106_error);
                    __Pyx_GIVEREF(__pyx_t_1);
                    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_25, 1, __pyx_t_1)) __PYX_ERR(0, 2338, __pyx_L106_error);
                    __pyx_t_1 = 0;

                    /* "cPyparsing.pyx":2340
 *                                 retTokens = ParseResults(tokens,
 *                                                         self.resultsName,
 *                                                         asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),             # <<<<<<<<<<<<<<
 *                                                         modal=self.modalResults)
 *                     except Exception as err:
 */
                    __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2340, __pyx_L106_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2340, __pyx_L106_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2340, __pyx_L106_error)
                    if (__pyx_t_5) {
                      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                    } else {
                      __Pyx_INCREF(__pyx_t_2);
                      __pyx_t_13 = __pyx_t_2;
                      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                      goto __pyx_L136_bool_binop_done;
                    }
                    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2340, __pyx_L106_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __pyx_t_15 = PyObject_IsInstance(__pyx_v_tokens, __pyx_t_2); 
                    if (!__pyx_t_15) {
                    } else {
                      __pyx_t_5 = __pyx_t_15;
                      goto __pyx_L138_bool_binop_done;
                    }
                    __pyx_t_15 = PyList_Check(__pyx_v_tokens); 
                    __pyx_t_5 = __pyx_t_15;
                    __pyx_L138_bool_binop_done:;
                    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                    __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2340, __pyx_L106_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __pyx_t_13 = __pyx_t_2;
                    __pyx_t_2 = 0;
                    __pyx_L136_bool_binop_done:;
                    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_asList, __pyx_t_13) < 0) __PYX_ERR(0, 2340, __pyx_L106_error)
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

                    /* "cPyparsing.pyx":2341
 *                                                         self.resultsName,
 *                                                         asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                         modal=self.modalResults)             # <<<<<<<<<<<<<<
 *                     except Exception as err:
 *                         # ~ print "Exception raised in user parse action:", err
 */
                    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2341, __pyx_L106_error)
                    __Pyx_GOTREF(__pyx_t_13);
                    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_modal, __pyx_t_13) < 0) __PYX_ERR(0, 2340, __pyx_L106_error)
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

                    /* "cPyparsing.pyx":2338
 * 
 *                             if tokens is not None and tokens is not retTokens:
 *                                 retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                         self.resultsName,
 *                                                         asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_25, __pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2338, __pyx_L106_error)
                    __Pyx_GOTREF(__pyx_t_13);
                    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                    __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                    __Pyx_DECREF_SET(__pyx_v_retTokens, __pyx_t_13);
                    __pyx_t_13 = 0;

                    /* "cPyparsing.pyx":2337
 *                                 raise exc
 * 
 *                             if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                                 retTokens = ParseResults(tokens,
 *                                                         self.resultsName,
 */
                  }

                  /* "cPyparsing.pyx":2329
 *                 if debugging:
 *                     try:
 *                         for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                             try:
 *                                 tokens = fn(instring, tokensStart, retTokens)
 */
                }
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

                /* "cPyparsing.pyx":2328
 *             if self.parseAction and (doActions or self.callDuringTry):
 *                 if debugging:
 *                     try:             # <<<<<<<<<<<<<<
 *                         for fn in self.parseAction:
 *                             try:
 */
              }
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
              __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
              goto __pyx_L111_try_end;
              __pyx_L106_error:;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

              /* "cPyparsing.pyx":2342
 *                                                         asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                         modal=self.modalResults)
 *                     except Exception as err:             # <<<<<<<<<<<<<<
 *                         # ~ print "Exception raised in user parse action:", err
 *                         if self.debugActions[FAIL]:
 */
              __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
              if (__pyx_t_4) {
                __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_13, &__pyx_t_1) < 0) __PYX_ERR(0, 2342, __pyx_L108_except_error)
                __Pyx_XGOTREF(__pyx_t_3);
                __Pyx_XGOTREF(__pyx_t_13);
                __Pyx_XGOTREF(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_13);
                __pyx_v_err = __pyx_t_13;
                /*try:*/ {

                  /* "cPyparsing.pyx":2344
 *                     except Exception as err:
 *                         # ~ print "Exception raised in user parse action:", err
 *                         if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                             self.debugActions[FAIL](instring, tokensStart, self, err)
 *                         raise
 */
                  __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2344, __pyx_L146_error)
                  __Pyx_GOTREF(__pyx_t_25);
                  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2344, __pyx_L146_error)
                  __Pyx_GOTREF(__pyx_t_8);
                  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_25, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2344, __pyx_L146_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2344, __pyx_L146_error)
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  if (__pyx_t_5) {

                    /* "cPyparsing.pyx":2345
 *                         # ~ print "Exception raised in user parse action:", err
 *                         if self.debugActions[FAIL]:
 *                             self.debugActions[FAIL](instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                         raise
 *                 else:
 */
                    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2345, __pyx_L146_error)
                    __Pyx_GOTREF(__pyx_t_8);
                    __Pyx_GetModuleGlobalName(__pyx_t_25, __pyx_n_s_FAIL); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2345, __pyx_L146_error)
                    __Pyx_GOTREF(__pyx_t_25);
                    __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_t_25); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2345, __pyx_L146_error)
                    __Pyx_GOTREF(__pyx_t_9);
                    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                    __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                    __pyx_t_25 = NULL;
                    __pyx_t_4 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (unlikely(PyMethod_Check(__pyx_t_9))) {
                      __pyx_t_25 = PyMethod_GET_SELF(__pyx_t_9);
                      if (likely(__pyx_t_25)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
                        __Pyx_INCREF(__pyx_t_25);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_9, function);
                        __pyx_t_4 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[5] = {__pyx_t_25, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
                      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
                      __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2345, __pyx_L146_error)
                      __Pyx_GOTREF(__pyx_t_2);
                      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                    }
                    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                    /* "cPyparsing.pyx":2344
 *                     except Exception as err:
 *                         # ~ print "Exception raised in user parse action:", err
 *                         if self.debugActions[FAIL]:             # <<<<<<<<<<<<<<
 *                             self.debugActions[FAIL](instring, tokensStart, self, err)
 *                         raise
 */
                  }

                  /* "cPyparsing.pyx":2346
 *                         if self.debugActions[FAIL]:
 *                             self.debugActions[FAIL](instring, tokensStart, self, err)
 *                         raise             # <<<<<<<<<<<<<<
 *                 else:
 *                     for fn in self.parseAction:
 */
                  __Pyx_GIVEREF(__pyx_t_3);
                  __Pyx_GIVEREF(__pyx_t_13);
                  __Pyx_XGIVEREF(__pyx_t_1);
                  __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_13, __pyx_t_1);
                  __pyx_t_3 = 0; __pyx_t_13 = 0; __pyx_t_1 = 0; 
                  __PYX_ERR(0, 2346, __pyx_L146_error)
                }

                /* "cPyparsing.pyx":2342
 *                                                         asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                         modal=self.modalResults)
 *                     except Exception as err:             # <<<<<<<<<<<<<<
 *                         # ~ print "Exception raised in user parse action:", err
 *                         if self.debugActions[FAIL]:
 */
                /*finally:*/ {
                  __pyx_L146_error:;
                  /*exception exit:*/{
                    __Pyx_PyThreadState_declare
                    __Pyx_PyThreadState_assign
                    __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0; __pyx_t_35 = 0; __pyx_t_34 = 0; __pyx_t_33 = 0;
                    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                    __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                    __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                    if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_35, &__pyx_t_34, &__pyx_t_33);
                    if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_29, &__pyx_t_30, &__pyx_t_31) < 0)) __Pyx_ErrFetch(&__pyx_t_29, &__pyx_t_30, &__pyx_t_31);
                    __Pyx_XGOTREF(__pyx_t_29);
                    __Pyx_XGOTREF(__pyx_t_30);
                    __Pyx_XGOTREF(__pyx_t_31);
                    __Pyx_XGOTREF(__pyx_t_35);
                    __Pyx_XGOTREF(__pyx_t_34);
                    __Pyx_XGOTREF(__pyx_t_33);
                    __pyx_t_4 = __pyx_lineno; __pyx_t_27 = __pyx_clineno; __pyx_t_36 = __pyx_filename;
                    {
                      __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
                    }
                    if (PY_MAJOR_VERSION >= 3) {
                      __Pyx_XGIVEREF(__pyx_t_35);
                      __Pyx_XGIVEREF(__pyx_t_34);
                      __Pyx_XGIVEREF(__pyx_t_33);
                      __Pyx_ExceptionReset(__pyx_t_35, __pyx_t_34, __pyx_t_33);
                    }
                    __Pyx_XGIVEREF(__pyx_t_29);
                    __Pyx_XGIVEREF(__pyx_t_30);
                    __Pyx_XGIVEREF(__pyx_t_31);
                    __Pyx_ErrRestore(__pyx_t_29, __pyx_t_30, __pyx_t_31);
                    __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0; __pyx_t_35 = 0; __pyx_t_34 = 0; __pyx_t_33 = 0;
                    __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_27; __pyx_filename = __pyx_t_36;
                    goto __pyx_L108_except_error;
                  }
                }
              }
              goto __pyx_L108_except_error;

              /* "cPyparsing.pyx":2328
 *             if self.parseAction and (doActions or self.callDuringTry):
 *                 if debugging:
 *                     try:             # <<<<<<<<<<<<<<
 *                         for fn in self.parseAction:
 *                             try:
 */
              __pyx_L108_except_error:;
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
              goto __pyx_L36_error;
              __pyx_L111_try_end:;
            }

            /* "cPyparsing.pyx":2327
 *             retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *             if self.parseAction and (doActions or self.callDuringTry):
 *                 if debugging:             # <<<<<<<<<<<<<<
 *                     try:
 *                         for fn in self.parseAction:
 */
            goto __pyx_L105;
          }

          /* "cPyparsing.pyx":2348
 *                         raise
 *                 else:
 *                     for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)
 */
          /*else*/ {
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2348, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
              __pyx_t_13 = __pyx_t_1; __Pyx_INCREF(__pyx_t_13);
              __pyx_t_6 = 0;
              __pyx_t_7 = NULL;
            } else {
              __pyx_t_6 = -1; __pyx_t_13 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2348, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2348, __pyx_L36_error)
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            for (;;) {
              if (likely(!__pyx_t_7)) {
                if (likely(PyList_CheckExact(__pyx_t_13))) {
                  {
                    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_13);
                    #if !CYTHON_ASSUME_SAFE_MACROS
                    if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2348, __pyx_L36_error)
                    #endif
                    if (__pyx_t_6 >= __pyx_temp) break;
                  }
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_1 = PyList_GET_ITEM(__pyx_t_13, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 2348, __pyx_L36_error)
                  #else
                  __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2348, __pyx_L36_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  #endif
                } else {
                  {
                    Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_13);
                    #if !CYTHON_ASSUME_SAFE_MACROS
                    if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2348, __pyx_L36_error)
                    #endif
                    if (__pyx_t_6 >= __pyx_temp) break;
                  }
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_13, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 2348, __pyx_L36_error)
                  #else
                  __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2348, __pyx_L36_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  #endif
                }
              } else {
                __pyx_t_1 = __pyx_t_7(__pyx_t_13);
                if (unlikely(!__pyx_t_1)) {
                  PyObject* exc_type = PyErr_Occurred();
                  if (exc_type) {
                    if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                    else __PYX_ERR(0, 2348, __pyx_L36_error)
                  }
                  break;
                }
                __Pyx_GOTREF(__pyx_t_1);
              }
              __Pyx_XDECREF_SET(__pyx_v_fn, __pyx_t_1);
              __pyx_t_1 = 0;

              /* "cPyparsing.pyx":2349
 *                 else:
 *                     for fn in self.parseAction:
 *                         try:             # <<<<<<<<<<<<<<
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:
 */
              {
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __Pyx_ExceptionSave(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
                __Pyx_XGOTREF(__pyx_t_21);
                __Pyx_XGOTREF(__pyx_t_20);
                __Pyx_XGOTREF(__pyx_t_19);
                /*try:*/ {

                  /* "cPyparsing.pyx":2350
 *                     for fn in self.parseAction:
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)             # <<<<<<<<<<<<<<
 *                         except IndexError as parse_action_exc:
 *                             exc = ParseException("exception raised in parse action")
 */
                  __Pyx_INCREF(__pyx_v_fn);
                  __pyx_t_3 = __pyx_v_fn; __pyx_t_2 = NULL;
                  __pyx_t_27 = 0;
                  #if CYTHON_UNPACK_METHODS
                  if (unlikely(PyMethod_Check(__pyx_t_3))) {
                    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
                    if (likely(__pyx_t_2)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                      __Pyx_INCREF(__pyx_t_2);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_3, function);
                      __pyx_t_27 = 1;
                    }
                  }
                  #endif
                  {
                    PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
                    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_27, 3+__pyx_t_27);
                    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2350, __pyx_L155_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  }
                  __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_1);
                  __pyx_t_1 = 0;

                  /* "cPyparsing.pyx":2349
 *                 else:
 *                     for fn in self.parseAction:
 *                         try:             # <<<<<<<<<<<<<<
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:
 */
                }
                __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
                __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
                __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
                goto __pyx_L162_try_end;
                __pyx_L155_error:;
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

                /* "cPyparsing.pyx":2351
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                             exc = ParseException("exception raised in parse action")
 *                             exc.__cause__ = parse_action_exc
 */
                __pyx_t_27 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
                if (__pyx_t_27) {
                  __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
                  if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 2351, __pyx_L157_except_error)
                  __Pyx_XGOTREF(__pyx_t_1);
                  __Pyx_XGOTREF(__pyx_t_3);
                  __Pyx_XGOTREF(__pyx_t_2);
                  __Pyx_INCREF(__pyx_t_3);
                  __pyx_v_parse_action_exc = __pyx_t_3;
                  /*try:*/ {

                    /* "cPyparsing.pyx":2352
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:
 *                             exc = ParseException("exception raised in parse action")             # <<<<<<<<<<<<<<
 *                             exc.__cause__ = parse_action_exc
 *                             raise exc
 */
                    __Pyx_GetModuleGlobalName(__pyx_t_25, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2352, __pyx_L168_error)
                    __Pyx_GOTREF(__pyx_t_25);
                    __pyx_t_8 = NULL;
                    __pyx_t_27 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (unlikely(PyMethod_Check(__pyx_t_25))) {
                      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_25);
                      if (likely(__pyx_t_8)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_25);
                        __Pyx_INCREF(__pyx_t_8);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_25, function);
                        __pyx_t_27 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_kp_u_exception_raised_in_parse_action};
                      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_25, __pyx_callargs+1-__pyx_t_27, 1+__pyx_t_27);
                      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2352, __pyx_L168_error)
                      __Pyx_GOTREF(__pyx_t_9);
                      __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                    }
                    __pyx_v_exc = __pyx_t_9;
                    __pyx_t_9 = 0;

                    /* "cPyparsing.pyx":2353
 *                         except IndexError as parse_action_exc:
 *                             exc = ParseException("exception raised in parse action")
 *                             exc.__cause__ = parse_action_exc             # <<<<<<<<<<<<<<
 *                             raise exc
 * 
 */
                    if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_cause, __pyx_v_parse_action_exc) < 0) __PYX_ERR(0, 2353, __pyx_L168_error)

                    /* "cPyparsing.pyx":2354
 *                             exc = ParseException("exception raised in parse action")
 *                             exc.__cause__ = parse_action_exc
 *                             raise exc             # <<<<<<<<<<<<<<
 * 
 *                         if tokens is not None and tokens is not retTokens:
 */
                    __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
                    __PYX_ERR(0, 2354, __pyx_L168_error)
                  }

                  /* "cPyparsing.pyx":2351
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:             # <<<<<<<<<<<<<<
 *                             exc = ParseException("exception raised in parse action")
 *                             exc.__cause__ = parse_action_exc
 */
                  /*finally:*/ {
                    __pyx_L168_error:;
                    /*exception exit:*/{
                      __Pyx_PyThreadState_declare
                      __Pyx_PyThreadState_assign
                      __pyx_t_33 = 0; __pyx_t_34 = 0; __pyx_t_35 = 0; __pyx_t_31 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0;
                      __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                      __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
                      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_31, &__pyx_t_30, &__pyx_t_29);
                      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_33, &__pyx_t_34, &__pyx_t_35) < 0)) __Pyx_ErrFetch(&__pyx_t_33, &__pyx_t_34, &__pyx_t_35);
                      __Pyx_XGOTREF(__pyx_t_33);
                      __Pyx_XGOTREF(__pyx_t_34);
                      __Pyx_XGOTREF(__pyx_t_35);
                      __Pyx_XGOTREF(__pyx_t_31);
                      __Pyx_XGOTREF(__pyx_t_30);
                      __Pyx_XGOTREF(__pyx_t_29);
                      __pyx_t_27 = __pyx_lineno; __pyx_t_4 = __pyx_clineno; __pyx_t_37 = __pyx_filename;
                      {
                        __Pyx_DECREF(__pyx_v_parse_action_exc); __pyx_v_parse_action_exc = 0;
                      }
                      if (PY_MAJOR_VERSION >= 3) {
                        __Pyx_XGIVEREF(__pyx_t_31);
                        __Pyx_XGIVEREF(__pyx_t_30);
                        __Pyx_XGIVEREF(__pyx_t_29);
                        __Pyx_ExceptionReset(__pyx_t_31, __pyx_t_30, __pyx_t_29);
                      }
                      __Pyx_XGIVEREF(__pyx_t_33);
                      __Pyx_XGIVEREF(__pyx_t_34);
                      __Pyx_XGIVEREF(__pyx_t_35);
                      __Pyx_ErrRestore(__pyx_t_33, __pyx_t_34, __pyx_t_35);
                      __pyx_t_33 = 0; __pyx_t_34 = 0; __pyx_t_35 = 0; __pyx_t_31 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0;
                      __pyx_lineno = __pyx_t_27; __pyx_clineno = __pyx_t_4; __pyx_filename = __pyx_t_37;
                      goto __pyx_L157_except_error;
                    }
                  }
                }
                goto __pyx_L157_except_error;

                /* "cPyparsing.pyx":2349
 *                 else:
 *                     for fn in self.parseAction:
 *                         try:             # <<<<<<<<<<<<<<
 *                             tokens = fn(instring, tokensStart, retTokens)
 *                         except IndexError as parse_action_exc:
 */
                __pyx_L157_except_error:;
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
                goto __pyx_L36_error;
                __pyx_L162_try_end:;
              }

              /* "cPyparsing.pyx":2356
 *                             raise exc
 * 
 *                         if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                             retTokens = ParseResults(tokens,
 *                                                     self.resultsName,
 */
              __pyx_t_15 = (__pyx_v_tokens != Py_None);
              if (__pyx_t_15) {
              } else {
                __pyx_t_5 = __pyx_t_15;
                goto __pyx_L175_bool_binop_done;
              }
              __pyx_t_15 = (__pyx_v_tokens != __pyx_v_retTokens);
              __pyx_t_5 = __pyx_t_15;
              __pyx_L175_bool_binop_done:;
              if (__pyx_t_5) {

                /* "cPyparsing.pyx":2357
 * 
 *                         if tokens is not None and tokens is not retTokens:
 *                             retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                     self.resultsName,
 *                                                     asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2357, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_2);

                /* "cPyparsing.pyx":2358
 *                         if tokens is not None and tokens is not retTokens:
 *                             retTokens = ParseResults(tokens,
 *                                                     self.resultsName,             # <<<<<<<<<<<<<<
 *                                                     asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                     modal=self.modalResults)
 */
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2358, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_3);

                /* "cPyparsing.pyx":2357
 * 
 *                         if tokens is not None and tokens is not retTokens:
 *                             retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                     self.resultsName,
 *                                                     asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2357, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_INCREF(__pyx_v_tokens);
                __Pyx_GIVEREF(__pyx_v_tokens);
                if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_tokens)) __PYX_ERR(0, 2357, __pyx_L36_error);
                __Pyx_GIVEREF(__pyx_t_3);
                if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(0, 2357, __pyx_L36_error);
                __pyx_t_3 = 0;

                /* "cPyparsing.pyx":2359
 *                             retTokens = ParseResults(tokens,
 *                                                     self.resultsName,
 *                                                     asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),             # <<<<<<<<<<<<<<
 *                                                     modal=self.modalResults)
 *             if debugging:
 */
                __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2359, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2359, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_25);
                __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_25); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2359, __pyx_L36_error)
                if (__pyx_t_5) {
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                } else {
                  __Pyx_INCREF(__pyx_t_25);
                  __pyx_t_9 = __pyx_t_25;
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                  goto __pyx_L177_bool_binop_done;
                }
                __Pyx_GetModuleGlobalName(__pyx_t_25, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2359, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_25);
                __pyx_t_15 = PyObject_IsInstance(__pyx_v_tokens, __pyx_t_25); 
                if (!__pyx_t_15) {
                } else {
                  __pyx_t_5 = __pyx_t_15;
                  goto __pyx_L179_bool_binop_done;
                }
                __pyx_t_15 = PyList_Check(__pyx_v_tokens); 
                __pyx_t_5 = __pyx_t_15;
                __pyx_L179_bool_binop_done:;
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                __pyx_t_25 = __Pyx_PyBool_FromLong(__pyx_t_5); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2359, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_25);
                __pyx_t_9 = __pyx_t_25;
                __pyx_t_25 = 0;
                __pyx_L177_bool_binop_done:;
                if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_asList, __pyx_t_9) < 0) __PYX_ERR(0, 2359, __pyx_L36_error)
                __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

                /* "cPyparsing.pyx":2360
 *                                                     self.resultsName,
 *                                                     asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                     modal=self.modalResults)             # <<<<<<<<<<<<<<
 *             if debugging:
 *                 # ~ print ("Matched", self, "->", retTokens.asList())
 */
                __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2360, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_9);
                if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_modal, __pyx_t_9) < 0) __PYX_ERR(0, 2359, __pyx_L36_error)
                __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

                /* "cPyparsing.pyx":2357
 * 
 *                         if tokens is not None and tokens is not retTokens:
 *                             retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                     self.resultsName,
 *                                                     asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
                __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2357, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_9);
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_DECREF_SET(__pyx_v_retTokens, __pyx_t_9);
                __pyx_t_9 = 0;

                /* "cPyparsing.pyx":2356
 *                             raise exc
 * 
 *                         if tokens is not None and tokens is not retTokens:             # <<<<<<<<<<<<<<
 *                             retTokens = ParseResults(tokens,
 *                                                     self.resultsName,
 */
              }

              /* "cPyparsing.pyx":2348
 *                         raise
 *                 else:
 *                     for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                         try:
 *                             tokens = fn(instring, tokensStart, retTokens)
 */
            }
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
          __pyx_L105:;

          /* "cPyparsing.pyx":2326
 * 
 *             retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *             if self.parseAction and (doActions or self.callDuringTry):             # <<<<<<<<<<<<<<
 *                 if debugging:
 *                     try:
 */
        }

        /* "cPyparsing.pyx":2361
 *                                                     asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                     modal=self.modalResults)
 *             if debugging:             # <<<<<<<<<<<<<<
 *                 # ~ print ("Matched", self, "->", retTokens.asList())
 *                 if self.debugActions[MATCH]:
 */
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2361, __pyx_L36_error)
        if (__pyx_t_5) {

          /* "cPyparsing.pyx":2363
 *             if debugging:
 *                 # ~ print ("Matched", self, "->", retTokens.asList())
 *                 if self.debugActions[MATCH]:             # <<<<<<<<<<<<<<
 *                     self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)
 * 
 */
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2363, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_MATCH); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2363, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2363, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2363, __pyx_L36_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (__pyx_t_5) {

            /* "cPyparsing.pyx":2364
 *                 # ~ print ("Matched", self, "->", retTokens.asList())
 *                 if self.debugActions[MATCH]:
 *                     self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)             # <<<<<<<<<<<<<<
 * 
 *             # return loc, retTokens
 */
            __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2364, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_MATCH); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2364, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2364, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_13 = NULL;
            __pyx_t_4 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_13)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_13);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_4 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[6] = {__pyx_t_13, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_loc, __pyx_v_self, __pyx_v_retTokens};
              __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 5+__pyx_t_4);
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2364, __pyx_L36_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            }
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

            /* "cPyparsing.pyx":2363
 *             if debugging:
 *                 # ~ print ("Matched", self, "->", retTokens.asList())
 *                 if self.debugActions[MATCH]:             # <<<<<<<<<<<<<<
 *                     self.debugActions[MATCH](instring, tokensStart, loc, self, retTokens)
 * 
 */
          }

          /* "cPyparsing.pyx":2361
 *                                                     asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                     modal=self.modalResults)
 *             if debugging:             # <<<<<<<<<<<<<<
 *                 # ~ print ("Matched", self, "->", retTokens.asList())
 *                 if self.debugActions[MATCH]:
 */
        }

        /* "cPyparsing.pyx":2369
 * 
 *             # [CPYPARSING] END INLINE _parseNoCache
 *             new_loc, ret_toks = loc, retTokens             # <<<<<<<<<<<<<<
 * 
 *         # _parseIncremental only caches the minimum necessary information to limit
 */
        __pyx_t_3 = __pyx_v_loc;
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_1 = __pyx_v_retTokens;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_new_loc = __pyx_t_3;
        __pyx_t_3 = 0;
        __pyx_v_ret_toks = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":2278
 *         # by default, assume inner caches are useful, so they don't get cleared inside this parse
 *         outer_parent_usefullness_obj, ParserElement._incremental_parent_usefullness_obj = ParserElement._incremental_parent_usefullness_obj, [True]
 *         try:             # <<<<<<<<<<<<<<
 *             # loc, ret_toks = self._parseNoCache(instring, loc, doActions, callPreParse)
 *             # [CPYPARSING] START INLINE _parseNoCache
 */
      }

      /* "cPyparsing.pyx":2385
 *             # but if we're caching a success for the outer parse, then we will need inner cache items to reparse
 *             # ParserElement._incremental_parent_usefullness_obj[0] = True  # not necessary because it's our default assumption
 *             if hit is not True:             # <<<<<<<<<<<<<<
 *                 # update furthest_loc
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], new_loc)
 */
      /*else:*/ {
        __pyx_t_5 = (__pyx_v_hit != Py_True);
        if (__pyx_t_5) {

          /* "cPyparsing.pyx":2387
 *             if hit is not True:
 *                 # update furthest_loc
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], new_loc)             # <<<<<<<<<<<<<<
 *                 # since we just recompute the parse action anyway on a success, we don't have to cache them
 *                 if ParserElement._should_cache_incremental_success:
 */
          __Pyx_INCREF(__pyx_v_new_loc);
          __pyx_t_1 = __pyx_v_new_loc;
          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2387, __pyx_L38_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2387, __pyx_L38_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_13, __pyx_v_instring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2387, __pyx_L38_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_9 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2387, __pyx_L38_except_error)
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2387, __pyx_L38_except_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (__pyx_t_5) {
            __Pyx_INCREF(__pyx_t_1);
            __pyx_t_13 = __pyx_t_1;
          } else {
            __Pyx_INCREF(__pyx_t_3);
            __pyx_t_13 = __pyx_t_3;
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = __pyx_t_13;
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2387, __pyx_L38_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2387, __pyx_L38_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely((PyObject_SetItem(__pyx_t_3, __pyx_v_instring, __pyx_t_1) < 0))) __PYX_ERR(0, 2387, __pyx_L38_except_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "cPyparsing.pyx":2389
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], new_loc)
 *                 # since we just recompute the parse action anyway on a success, we don't have to cache them
 *                 if ParserElement._should_cache_incremental_success:             # <<<<<<<<<<<<<<
 *                     # on success, cache (furthest loc, True)
 *                     cache.set(lookup, (ParserElement._furthest_locs[instring], True, outer_parent_usefullness_obj))
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2389, __pyx_L38_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_should_cache_incremental_succes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2389, __pyx_L38_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2389, __pyx_L38_except_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (__pyx_t_5) {

            /* "cPyparsing.pyx":2391
 *                 if ParserElement._should_cache_incremental_success:
 *                     # on success, cache (furthest loc, True)
 *                     cache.set(lookup, (ParserElement._furthest_locs[instring], True, outer_parent_usefullness_obj))             # <<<<<<<<<<<<<<
 *             return new_loc, ret_toks
 *         finally:
 */
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_set); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2391, __pyx_L38_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (unlikely(!__pyx_v_lookup)) { __Pyx_RaiseUnboundLocalError("lookup"); __PYX_ERR(0, 2391, __pyx_L38_except_error) }
            __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2391, __pyx_L38_except_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2391, __pyx_L38_except_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_t_9, __pyx_v_instring); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2391, __pyx_L38_except_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2391, __pyx_L38_except_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_13);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_13)) __PYX_ERR(0, 2391, __pyx_L38_except_error);
            __Pyx_INCREF(Py_True);
            __Pyx_GIVEREF(Py_True);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, Py_True)) __PYX_ERR(0, 2391, __pyx_L38_except_error);
            __Pyx_INCREF(__pyx_v_outer_parent_usefullness_obj);
            __Pyx_GIVEREF(__pyx_v_outer_parent_usefullness_obj);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_v_outer_parent_usefullness_obj)) __PYX_ERR(0, 2391, __pyx_L38_except_error);
            __pyx_t_13 = 0;
            __pyx_t_13 = NULL;
            __pyx_t_4 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_13)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_13);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_4 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_v_lookup, __pyx_t_9};
              __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2391, __pyx_L38_except_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            }
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

            /* "cPyparsing.pyx":2389
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], new_loc)
 *                 # since we just recompute the parse action anyway on a success, we don't have to cache them
 *                 if ParserElement._should_cache_incremental_success:             # <<<<<<<<<<<<<<
 *                     # on success, cache (furthest loc, True)
 *                     cache.set(lookup, (ParserElement._furthest_locs[instring], True, outer_parent_usefullness_obj))
 */
          }

          /* "cPyparsing.pyx":2385
 *             # but if we're caching a success for the outer parse, then we will need inner cache items to reparse
 *             # ParserElement._incremental_parent_usefullness_obj[0] = True  # not necessary because it's our default assumption
 *             if hit is not True:             # <<<<<<<<<<<<<<
 *                 # update furthest_loc
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], new_loc)
 */
        }

        /* "cPyparsing.pyx":2392
 *                     # on success, cache (furthest loc, True)
 *                     cache.set(lookup, (ParserElement._furthest_locs[instring], True, outer_parent_usefullness_obj))
 *             return new_loc, ret_toks             # <<<<<<<<<<<<<<
 *         finally:
 *             ParserElement._incremental_parent_usefullness_obj = outer_parent_usefullness_obj
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2392, __pyx_L38_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_v_new_loc);
        __Pyx_GIVEREF(__pyx_v_new_loc);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_new_loc)) __PYX_ERR(0, 2392, __pyx_L38_except_error);
        __Pyx_INCREF(__pyx_v_ret_toks);
        __Pyx_GIVEREF(__pyx_v_ret_toks);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_ret_toks)) __PYX_ERR(0, 2392, __pyx_L38_except_error);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L39_except_return;
      }
      __pyx_L36_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
      __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "cPyparsing.pyx":2373
 *         # _parseIncremental only caches the minimum necessary information to limit
 *         #  the memory footprint of very large caches
 *         except ParseBaseException as err:             # <<<<<<<<<<<<<<
 *             # if we're caching a failure for the outer parse, then any inner cache items probably won't be needed
 *             ParserElement._incremental_parent_usefullness_obj[0] = False
 */
      __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_1, &__pyx_t_9);
      __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2373, __pyx_L38_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_4 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_3, __pyx_t_13);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_ErrRestore(__pyx_t_3, __pyx_t_1, __pyx_t_9);
      __pyx_t_3 = 0; __pyx_t_1 = 0; __pyx_t_9 = 0;
      if (__pyx_t_4) {
        __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_1, &__pyx_t_3) < 0) __PYX_ERR(0, 2373, __pyx_L38_except_error)
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_err, __pyx_t_1);
        /*try:*/ {

          /* "cPyparsing.pyx":2375
 *         except ParseBaseException as err:
 *             # if we're caching a failure for the outer parse, then any inner cache items probably won't be needed
 *             ParserElement._incremental_parent_usefullness_obj[0] = False             # <<<<<<<<<<<<<<
 *             if hit is not True:
 *                 # update furthest_loc
 */
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2375, __pyx_L191_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_incremental_parent_usefullness); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2375, __pyx_L191_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely((__Pyx_SetItemInt(__pyx_t_2, 0, Py_False, long, 1, __Pyx_PyInt_From_long, 0, 0, 1) < 0))) __PYX_ERR(0, 2375, __pyx_L191_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "cPyparsing.pyx":2376
 *             # if we're caching a failure for the outer parse, then any inner cache items probably won't be needed
 *             ParserElement._incremental_parent_usefullness_obj[0] = False
 *             if hit is not True:             # <<<<<<<<<<<<<<
 *                 # update furthest_loc
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], err.loc)
 */
          __pyx_t_5 = (__pyx_v_hit != Py_True);
          if (__pyx_t_5) {

            /* "cPyparsing.pyx":2378
 *             if hit is not True:
 *                 # update furthest_loc
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], err.loc)             # <<<<<<<<<<<<<<
 *                 # on failure, cache (furthest loc, exception loc)
 *                 cache.set(lookup, (ParserElement._furthest_locs[instring], err.loc, outer_parent_usefullness_obj))
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2378, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2378, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2378, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_25);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_t_25, __pyx_v_instring); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2378, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            __pyx_t_8 = PyObject_RichCompare(__pyx_t_2, __pyx_t_13, Py_GT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2378, __pyx_L191_error)
            __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2378, __pyx_L191_error)
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (__pyx_t_5) {
              __Pyx_INCREF(__pyx_t_2);
              __pyx_t_25 = __pyx_t_2;
            } else {
              __Pyx_INCREF(__pyx_t_13);
              __pyx_t_25 = __pyx_t_13;
            }
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_2 = __pyx_t_25;
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            __Pyx_GetModuleGlobalName(__pyx_t_25, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2378, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_25);
            __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_25, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2378, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            if (unlikely((PyObject_SetItem(__pyx_t_13, __pyx_v_instring, __pyx_t_2) < 0))) __PYX_ERR(0, 2378, __pyx_L191_error)
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "cPyparsing.pyx":2380
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], err.loc)
 *                 # on failure, cache (furthest loc, exception loc)
 *                 cache.set(lookup, (ParserElement._furthest_locs[instring], err.loc, outer_parent_usefullness_obj))             # <<<<<<<<<<<<<<
 *             raise
 *         else:
 */
            __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_set); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2380, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_13);
            if (unlikely(!__pyx_v_lookup)) { __Pyx_RaiseUnboundLocalError("lookup"); __PYX_ERR(0, 2380, __pyx_L191_error) }
            __Pyx_GetModuleGlobalName(__pyx_t_25, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2380, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_25);
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_25, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2380, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            __pyx_t_25 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_v_instring); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 2380, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_25);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2380, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_26 = PyTuple_New(3); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 2380, __pyx_L191_error)
            __Pyx_GOTREF(__pyx_t_26);
            __Pyx_GIVEREF(__pyx_t_25);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_26, 0, __pyx_t_25)) __PYX_ERR(0, 2380, __pyx_L191_error);
            __Pyx_GIVEREF(__pyx_t_8);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_26, 1, __pyx_t_8)) __PYX_ERR(0, 2380, __pyx_L191_error);
            __Pyx_INCREF(__pyx_v_outer_parent_usefullness_obj);
            __Pyx_GIVEREF(__pyx_v_outer_parent_usefullness_obj);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_26, 2, __pyx_v_outer_parent_usefullness_obj)) __PYX_ERR(0, 2380, __pyx_L191_error);
            __pyx_t_25 = 0;
            __pyx_t_8 = 0;
            __pyx_t_8 = NULL;
            __pyx_t_4 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_13))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_13);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_13, function);
                __pyx_t_4 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_lookup, __pyx_t_26};
              __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2380, __pyx_L191_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "cPyparsing.pyx":2376
 *             # if we're caching a failure for the outer parse, then any inner cache items probably won't be needed
 *             ParserElement._incremental_parent_usefullness_obj[0] = False
 *             if hit is not True:             # <<<<<<<<<<<<<<
 *                 # update furthest_loc
 *                 ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], err.loc)
 */
          }

          /* "cPyparsing.pyx":2381
 *                 # on failure, cache (furthest loc, exception loc)
 *                 cache.set(lookup, (ParserElement._furthest_locs[instring], err.loc, outer_parent_usefullness_obj))
 *             raise             # <<<<<<<<<<<<<<
 *         else:
 *             # but if we're caching a success for the outer parse, then we will need inner cache items to reparse
 */
          __Pyx_GIVEREF(__pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_1);
          __Pyx_XGIVEREF(__pyx_t_3);
          __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_1, __pyx_t_3);
          __pyx_t_9 = 0; __pyx_t_1 = 0; __pyx_t_3 = 0; 
          __PYX_ERR(0, 2381, __pyx_L191_error)
        }

        /* "cPyparsing.pyx":2373
 *         # _parseIncremental only caches the minimum necessary information to limit
 *         #  the memory footprint of very large caches
 *         except ParseBaseException as err:             # <<<<<<<<<<<<<<
 *             # if we're caching a failure for the outer parse, then any inner cache items probably won't be needed
 *             ParserElement._incremental_parent_usefullness_obj[0] = False
 */
        /*finally:*/ {
          __pyx_L191_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_29, &__pyx_t_30, &__pyx_t_31);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_29);
            __Pyx_XGOTREF(__pyx_t_30);
            __Pyx_XGOTREF(__pyx_t_31);
            __pyx_t_4 = __pyx_lineno; __pyx_t_27 = __pyx_clineno; __pyx_t_38 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_29);
              __Pyx_XGIVEREF(__pyx_t_30);
              __Pyx_XGIVEREF(__pyx_t_31);
              __Pyx_ExceptionReset(__pyx_t_29, __pyx_t_30, __pyx_t_31);
            }
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ErrRestore(__pyx_t_19, __pyx_t_20, __pyx_t_21);
            __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_31 = 0;
            __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_27; __pyx_filename = __pyx_t_38;
            goto __pyx_L38_except_error;
          }
        }
      }
      goto __pyx_L38_except_error;

      /* "cPyparsing.pyx":2278
 *         # by default, assume inner caches are useful, so they don't get cleared inside this parse
 *         outer_parent_usefullness_obj, ParserElement._incremental_parent_usefullness_obj = ParserElement._incremental_parent_usefullness_obj, [True]
 *         try:             # <<<<<<<<<<<<<<
 *             # loc, ret_toks = self._parseNoCache(instring, loc, doActions, callPreParse)
 *             # [CPYPARSING] START INLINE _parseNoCache
 */
      __pyx_L38_except_error:;
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      goto __pyx_L34_error;
      __pyx_L39_except_return:;
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      goto __pyx_L33_return;
    }
  }

  /* "cPyparsing.pyx":2394
 *             return new_loc, ret_toks
 *         finally:
 *             ParserElement._incremental_parent_usefullness_obj = outer_parent_usefullness_obj             # <<<<<<<<<<<<<<
 * 
 *     _parse = _parseNoCache
 */
  /*finally:*/ {
    __pyx_L34_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_31 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
      __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_31, &__pyx_t_30, &__pyx_t_29);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_17, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_17, &__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_31);
      __Pyx_XGOTREF(__pyx_t_30);
      __Pyx_XGOTREF(__pyx_t_29);
      __pyx_t_27 = __pyx_lineno; __pyx_t_4 = __pyx_clineno; __pyx_t_39 = __pyx_filename;
      {
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2394, __pyx_L199_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_PyObject_SetAttrStr(__pyx_t_3, __pyx_n_s_incremental_parent_usefullness, __pyx_v_outer_parent_usefullness_obj) < 0) __PYX_ERR(0, 2394, __pyx_L199_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_31);
        __Pyx_XGIVEREF(__pyx_t_30);
        __Pyx_XGIVEREF(__pyx_t_29);
        __Pyx_ExceptionReset(__pyx_t_31, __pyx_t_30, __pyx_t_29);
      }
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ErrRestore(__pyx_t_18, __pyx_t_17, __pyx_t_16);
      __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_31 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0;
      __pyx_lineno = __pyx_t_27; __pyx_clineno = __pyx_t_4; __pyx_filename = __pyx_t_39;
      goto __pyx_L1_error;
      __pyx_L199_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_31);
        __Pyx_XGIVEREF(__pyx_t_30);
        __Pyx_XGIVEREF(__pyx_t_29);
        __Pyx_ExceptionReset(__pyx_t_31, __pyx_t_30, __pyx_t_29);
      }
      __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_31 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L33_return: {
      __pyx_t_29 = __pyx_r;
      __pyx_r = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2394, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_PyObject_SetAttrStr(__pyx_t_3, __pyx_n_s_incremental_parent_usefullness, __pyx_v_outer_parent_usefullness_obj) < 0) __PYX_ERR(0, 2394, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_29;
      __pyx_t_29 = 0;
      goto __pyx_L0;
    }
  }

  /* "cPyparsing.pyx":2183
 *     # [CPYPARSING] add _parseIncremental
 *     _incremental_parent_usefullness_obj = [False]  # caches at start loc can't be reused, so start usefullness at False
 *     def _parseIncremental(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         """Version of ParserElement._parseCache that can reuse caches from common prefix/suffix parses.
 *         Note that unlike _parseCache, _parseIncremental is not thread-safe."""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_prefixes_and_suffixes);
  __Pyx_XDECREF(__pyx_v_reversed_instring);
  __Pyx_XDECREF(__pyx_v_other_instring);
  __Pyx_XDECREF(__pyx_v_lookup_bools);
  __Pyx_XDECREF(__pyx_v_cache);
  __Pyx_XDECREF(__pyx_v_hit);
  __Pyx_XDECREF(__pyx_v_prefix_len);
  __Pyx_XDECREF(__pyx_v_suffix_len);
  __Pyx_XDECREF(__pyx_v_is_instring);
  __Pyx_XDECREF(__pyx_v_prefix_lookup);
  __Pyx_XDECREF(__pyx_v_cache_result);
  __Pyx_XDECREF(__pyx_v_cache_furthest_loc);
  __Pyx_XDECREF(__pyx_v_cache_item);
  __Pyx_XDECREF(__pyx_v_cache_usefullness_obj);
  __Pyx_XDECREF(__pyx_v_loc_in_suffix);
  __Pyx_XDECREF(__pyx_v_suffix_lookup);
  __Pyx_XDECREF(__pyx_v_lookup);
  __Pyx_XDECREF(__pyx_v_outer_parent_usefullness_obj);
  __Pyx_XDECREF(__pyx_v_debugging);
  __Pyx_XDECREF(__pyx_v_preloc);
  __Pyx_XDECREF(__pyx_v_tokensStart);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_retTokens);
  __Pyx_XDECREF(__pyx_v_fn);
  __Pyx_XDECREF(__pyx_v_parse_action_exc);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_new_loc);
  __Pyx_XDECREF(__pyx_v_ret_toks);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2398
 *     _parse = _parseNoCache
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def resetCache():
 *         # [CPYPARSING] don't reset in incremental mode
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_49resetCache(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_48resetCache, "ParserElement.resetCache()");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_49resetCache = {"resetCache", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_49resetCache, METH_NOARGS, __pyx_doc_10cPyparsing_13ParserElement_48resetCache};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_49resetCache(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resetCache (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_48resetCache(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_48resetCache(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resetCache", 1);

  /* "cPyparsing.pyx":2401
 *     def resetCache():
 *         # [CPYPARSING] don't reset in incremental mode
 *         if ParserElement._incrementalEnabled and not ParserElement._incrementalWithResets:             # <<<<<<<<<<<<<<
 *             return
 *         ParserElement.packrat_cache.clear()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_incrementalEnabled); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_incrementalWithResets); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (!__pyx_t_4);
  __pyx_t_1 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2402
 *         # [CPYPARSING] don't reset in incremental mode
 *         if ParserElement._incrementalEnabled and not ParserElement._incrementalWithResets:
 *             return             # <<<<<<<<<<<<<<
 *         ParserElement.packrat_cache.clear()
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2401
 *     def resetCache():
 *         # [CPYPARSING] don't reset in incremental mode
 *         if ParserElement._incrementalEnabled and not ParserElement._incrementalWithResets:             # <<<<<<<<<<<<<<
 *             return
 *         ParserElement.packrat_cache.clear()
 */
  }

  /* "cPyparsing.pyx":2403
 *         if ParserElement._incrementalEnabled and not ParserElement._incrementalWithResets:
 *             return
 *         ParserElement.packrat_cache.clear()             # <<<<<<<<<<<<<<
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 *         # [CPYPARSING] reset incremental attributes
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_packrat_cache); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_clear); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2404
 *             return
 *         ParserElement.packrat_cache.clear()
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] reset incremental attributes
 *         if ParserElement._incrementalEnabled:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyList_New(1 * ((__pyx_t_8<0) ? 0:__pyx_t_8)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  { Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < __pyx_t_8; __pyx_temp++) {
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_3, __pyx_temp, __pyx_int_0)) __PYX_ERR(0, 2404, __pyx_L1_error);
    }
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetSlice(__pyx_t_6, __pyx_t_3, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1) < 0) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2406
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 *         # [CPYPARSING] reset incremental attributes
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._instring_prefixes_and_suffixes = {}
 *             ParserElement._furthest_locs = defaultdict(int)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_incrementalEnabled); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2407
 *         # [CPYPARSING] reset incremental attributes
 *         if ParserElement._incrementalEnabled:
 *             ParserElement._instring_prefixes_and_suffixes = {}             # <<<<<<<<<<<<<<
 *             ParserElement._furthest_locs = defaultdict(int)
 * 
 */
    __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_3, __pyx_n_s_instring_prefixes_and_suffixes, __pyx_t_6) < 0) __PYX_ERR(0, 2407, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2408
 *         if ParserElement._incrementalEnabled:
 *             ParserElement._instring_prefixes_and_suffixes = {}
 *             ParserElement._furthest_locs = defaultdict(int)             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] add enableIncremental
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_defaultdict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)(&PyInt_Type))};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2408, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_6, __pyx_n_s_furthest_locs, __pyx_t_3) < 0) __PYX_ERR(0, 2408, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2406
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 *         # [CPYPARSING] reset incremental attributes
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._instring_prefixes_and_suffixes = {}
 *             ParserElement._furthest_locs = defaultdict(int)
 */
  }

  /* "cPyparsing.pyx":2398
 *     _parse = _parseNoCache
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def resetCache():
 *         # [CPYPARSING] don't reset in incremental mode
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.resetCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2413
 *     _incrementalEnabled = False
 *     _incrementalWithResets = False
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enableIncremental(
 *         cache_size_limit=None,
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_51enableIncremental(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_50enableIncremental, "ParserElement.enableIncremental(cache_size_limit=None, still_reset_cache=False, cache_successes=True)\nEnable incremental parsing mode where caches from common prefix/suffix parses are reused.\n\n        Note that incremental mode does not fully preserve parse exception error messages.");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_51enableIncremental = {"enableIncremental", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_51enableIncremental, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_50enableIncremental};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_51enableIncremental(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cache_size_limit = 0;
  PyObject *__pyx_v_still_reset_cache = 0;
  PyObject *__pyx_v_cache_successes = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enableIncremental (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cache_size_limit,&__pyx_n_s_still_reset_cache,&__pyx_n_s_cache_successes,0};

    /* "cPyparsing.pyx":2415
 *     @staticmethod
 *     def enableIncremental(
 *         cache_size_limit=None,             # <<<<<<<<<<<<<<
 *         still_reset_cache=False,
 *         cache_successes=True,  # experimentally determined
 */
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "cPyparsing.pyx":2416
 *     def enableIncremental(
 *         cache_size_limit=None,
 *         still_reset_cache=False,             # <<<<<<<<<<<<<<
 *         cache_successes=True,  # experimentally determined
 *     ):
 */
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));

    /* "cPyparsing.pyx":2417
 *         cache_size_limit=None,
 *         still_reset_cache=False,
 *         cache_successes=True,  # experimentally determined             # <<<<<<<<<<<<<<
 *     ):
 *         """Enable incremental parsing mode where caches from common prefix/suffix parses are reused.
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cache_size_limit);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2413, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_still_reset_cache);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2413, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cache_successes);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2413, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "enableIncremental") < 0)) __PYX_ERR(0, 2413, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cache_size_limit = values[0];
    __pyx_v_still_reset_cache = values[1];
    __pyx_v_cache_successes = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("enableIncremental", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 2413, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.enableIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_50enableIncremental(__pyx_self, __pyx_v_cache_size_limit, __pyx_v_still_reset_cache, __pyx_v_cache_successes);

  /* "cPyparsing.pyx":2413
 *     _incrementalEnabled = False
 *     _incrementalWithResets = False
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enableIncremental(
 *         cache_size_limit=None,
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_50enableIncremental(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cache_size_limit, PyObject *__pyx_v_still_reset_cache, PyObject *__pyx_v_cache_successes) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enableIncremental", 1);

  /* "cPyparsing.pyx":2422
 * 
 *         Note that incremental mode does not fully preserve parse exception error messages."""
 *         if not ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._incrementalEnabled = True
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_incrementalEnabled); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2422, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":2423
 *         Note that incremental mode does not fully preserve parse exception error messages."""
 *         if not ParserElement._incrementalEnabled:
 *             ParserElement._incrementalEnabled = True             # <<<<<<<<<<<<<<
 * 
 *             # force reenable packrat to clear the cache and ensure we're using the correct cache_size_limit
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_incrementalEnabled, Py_True) < 0) __PYX_ERR(0, 2423, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2426
 * 
 *             # force reenable packrat to clear the cache and ensure we're using the correct cache_size_limit
 *             ParserElement._packratEnabled = False             # <<<<<<<<<<<<<<
 *             ParserElement.enablePackrat(cache_size_limit=cache_size_limit)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_packratEnabled, Py_False) < 0) __PYX_ERR(0, 2426, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2427
 *             # force reenable packrat to clear the cache and ensure we're using the correct cache_size_limit
 *             ParserElement._packratEnabled = False
 *             ParserElement.enablePackrat(cache_size_limit=cache_size_limit)             # <<<<<<<<<<<<<<
 * 
 *             # forcibly reset the cache for incremental mode
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_enablePackrat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_cache_size_limit, __pyx_v_cache_size_limit) < 0) __PYX_ERR(0, 2427, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":2430
 * 
 *             # forcibly reset the cache for incremental mode
 *             ParserElement._incrementalWithResets = True             # <<<<<<<<<<<<<<
 *             ParserElement.resetCache()
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_5, __pyx_n_s_incrementalWithResets, Py_True) < 0) __PYX_ERR(0, 2430, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":2431
 *             # forcibly reset the cache for incremental mode
 *             ParserElement._incrementalWithResets = True
 *             ParserElement.resetCache()             # <<<<<<<<<<<<<<
 * 
 *             ParserElement._parse = ParserElement._parseIncremental
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2431, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_resetCache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2431, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2431, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":2433
 *             ParserElement.resetCache()
 * 
 *             ParserElement._parse = ParserElement._parseIncremental             # <<<<<<<<<<<<<<
 * 
 *         ParserElement._incrementalWithResets = still_reset_cache
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_parseIncremental); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_5, __pyx_n_s_parse, __pyx_t_1) < 0) __PYX_ERR(0, 2433, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":2422
 * 
 *         Note that incremental mode does not fully preserve parse exception error messages."""
 *         if not ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._incrementalEnabled = True
 * 
 */
  }

  /* "cPyparsing.pyx":2435
 *             ParserElement._parse = ParserElement._parseIncremental
 * 
 *         ParserElement._incrementalWithResets = still_reset_cache             # <<<<<<<<<<<<<<
 *         ParserElement._should_cache_incremental_success = cache_successes
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_5, __pyx_n_s_incrementalWithResets, __pyx_v_still_reset_cache) < 0) __PYX_ERR(0, 2435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":2436
 * 
 *         ParserElement._incrementalWithResets = still_reset_cache
 *         ParserElement._should_cache_incremental_success = cache_successes             # <<<<<<<<<<<<<<
 * 
 *     _packratEnabled = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_5, __pyx_n_s_should_cache_incremental_succes, __pyx_v_cache_successes) < 0) __PYX_ERR(0, 2436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":2413
 *     _incrementalEnabled = False
 *     _incrementalWithResets = False
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enableIncremental(
 *         cache_size_limit=None,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.enableIncremental", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2439
 * 
 *     _packratEnabled = False
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enablePackrat(cache_size_limit=128):
 *         """Enables "packrat" parsing, which adds memoizing to the parsing logic.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_53enablePackrat(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_52enablePackrat, "ParserElement.enablePackrat(cache_size_limit=128)\nEnables \"packrat\" parsing, which adds memoizing to the parsing logic.\n           Repeated parse attempts at the same string location (which happens\n           often in many complex grammars) can immediately return a cached value,\n           instead of re-executing parsing/validating code.  Memoizing is done of\n           both valid results and parsing exceptions.\n\n           Parameters:\n\n           - cache_size_limit - (default= ``128``) - if an integer value is provided\n             will limit the size of the packrat cache; if None is passed, then\n             the cache size will be unbounded; if 0 is passed, the cache will\n             be effectively disabled.\n\n           This speedup may break existing programs that use parse actions that\n           have side-effects.  For this reason, packrat parsing is disabled when\n           you first import pyparsing.  To activate the packrat feature, your\n           program must call the class method :class:`ParserElement.enablePackrat`.\n           For best results, call ``enablePackrat()`` immediately after\n           importing pyparsing.\n\n           Example::\n\n               import pyparsing\n               pyparsing.ParserElement.enablePackrat()\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_53enablePackrat = {"enablePackrat", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_53enablePackrat, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_52enablePackrat};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_53enablePackrat(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cache_size_limit = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enablePackrat (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cache_size_limit,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_128)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cache_size_limit);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2439, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "enablePackrat") < 0)) __PYX_ERR(0, 2439, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cache_size_limit = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("enablePackrat", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 2439, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.enablePackrat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_52enablePackrat(__pyx_self, __pyx_v_cache_size_limit);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_52enablePackrat(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cache_size_limit) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enablePackrat", 1);

  /* "cPyparsing.pyx":2466
 *                pyparsing.ParserElement.enablePackrat()
 *         """
 *         if not ParserElement._packratEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_packratEnabled); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2466, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":2467
 *         """
 *         if not ParserElement._packratEnabled:
 *             ParserElement._packratEnabled = True             # <<<<<<<<<<<<<<
 *             if cache_size_limit is None:
 *                 ParserElement.packrat_cache = _UnboundedCache()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_packratEnabled, Py_True) < 0) __PYX_ERR(0, 2467, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2468
 *         if not ParserElement._packratEnabled:
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:             # <<<<<<<<<<<<<<
 *                 ParserElement.packrat_cache = _UnboundedCache()
 *             else:
 */
    __pyx_t_4 = (__pyx_v_cache_size_limit == Py_None);
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":2469
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:
 *                 ParserElement.packrat_cache = _UnboundedCache()             # <<<<<<<<<<<<<<
 *             else:
 *                 ParserElement.packrat_cache = _FifoCache(cache_size_limit)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_UnboundedCache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2469, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2469, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2469, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_packrat_cache, __pyx_t_2) < 0) __PYX_ERR(0, 2469, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":2468
 *         if not ParserElement._packratEnabled:
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:             # <<<<<<<<<<<<<<
 *                 ParserElement.packrat_cache = _UnboundedCache()
 *             else:
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":2471
 *                 ParserElement.packrat_cache = _UnboundedCache()
 *             else:
 *                 ParserElement.packrat_cache = _FifoCache(cache_size_limit)             # <<<<<<<<<<<<<<
 *             ParserElement._parse = ParserElement._parseCache
 * 
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_FifoCache); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2471, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_cache_size_limit};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2471, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2471, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_packrat_cache, __pyx_t_1) < 0) __PYX_ERR(0, 2471, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":2472
 *             else:
 *                 ParserElement.packrat_cache = _FifoCache(cache_size_limit)
 *             ParserElement._parse = ParserElement._parseCache             # <<<<<<<<<<<<<<
 * 
 *     def parseString(self, instring, parseAll=False):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_parseCache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_parse, __pyx_t_1) < 0) __PYX_ERR(0, 2472, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2466
 *                pyparsing.ParserElement.enablePackrat()
 *         """
 *         if not ParserElement._packratEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:
 */
  }

  /* "cPyparsing.pyx":2439
 * 
 *     _packratEnabled = False
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enablePackrat(cache_size_limit=128):
 *         """Enables "packrat" parsing, which adds memoizing to the parsing logic.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.enablePackrat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2474
 *             ParserElement._parse = ParserElement._parseCache
 * 
 *     def parseString(self, instring, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression with the given string.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_55parseString(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_54parseString, "ParserElement.parseString(self, instring, parseAll=False)\n\n        Execute the parse expression with the given string.\n        This is the main interface to the client code, once the complete\n        expression has been built.\n\n        Returns the parsed data as a :class:`ParseResults` object, which may be\n        accessed as a list, or as a dict or object with attributes if the given parser\n        includes results names.\n\n        If you want the grammar to require that the entire input string be\n        successfully parsed, then set ``parseAll`` to True (equivalent to ending\n        the grammar with ``StringEnd()``).\n\n        Note: ``parseString`` implicitly calls ``expandtabs()`` on the input string,\n        in order to report proper column numbers in parse actions.\n        If the input string contains tabs and\n        the grammar uses parse actions that use the ``loc`` argument to index into the\n        string being parsed, you can ensure you have a consistent view of the input\n        string by:\n\n        - calling ``parseWithTabs`` on your grammar before calling ``parseString``\n          (see :class:`parseWithTabs`)\n        - define your parse action using the full ``(s, loc, toks)`` signature, and\n          reference the input string using the parse action's ``s`` argument\n        - explictly expand the tabs in your input string before calling\n          ``parseString``\n\n        Example::\n\n            Word('a').parseString('aaaaabaaa')  # -> ['aaaaa']\n            Word('a').parseString('aaaaabaaa', parseAll=True)  # -> Exception: Expected end of text\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_55parseString = {"parseString", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_55parseString, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_54parseString};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_55parseString(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_parseAll = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseString (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_parseAll,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2474, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2474, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseString", 0, 2, 3, 1); __PYX_ERR(0, 2474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseAll);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2474, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseString") < 0)) __PYX_ERR(0, 2474, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_parseAll = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseString", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 2474, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_54parseString(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_parseAll);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_54parseString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_parseAll) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_loc = NULL;
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_v_se = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  char const *__pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseString", 0);
  __Pyx_INCREF(__pyx_v_instring);

  /* "cPyparsing.pyx":2507
 *             Word('a').parseString('aaaaabaaa', parseAll=True)  # -> Exception: Expected end of text
 *         """
 *         ParserElement.resetCache()             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamline()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_resetCache); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2508
 *         """
 *         ParserElement.resetCache()
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamline()
 *             # ~ self.saveAsList = True
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_streamlined); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2508, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":2509
 *         ParserElement.resetCache()
 *         if not self.streamlined:
 *             self.streamline()             # <<<<<<<<<<<<<<
 *             # ~ self.saveAsList = True
 *         for e in self.ignoreExprs:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2509, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2508
 *         """
 *         ParserElement.resetCache()
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamline()
 *             # ~ self.saveAsList = True
 */
  }

  /* "cPyparsing.pyx":2511
 *             self.streamline()
 *             # ~ self.saveAsList = True
 *         for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 *         if not self.keepTabs:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2511, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2511, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2511, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2511, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2511, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2511, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2511, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_8(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2511, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2512
 *             # ~ self.saveAsList = True
 *         for e in self.ignoreExprs:
 *             e.streamline()             # <<<<<<<<<<<<<<
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_streamline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2511
 *             self.streamline()
 *             # ~ self.saveAsList = True
 *         for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 *         if not self.keepTabs:
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2513
 *         for e in self.ignoreExprs:
 *             e.streamline()
 *         if not self.keepTabs:             # <<<<<<<<<<<<<<
 *             instring = instring.expandtabs()
 *         try:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_keepTabs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = (!__pyx_t_6);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2514
 *             e.streamline()
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self._parse(instring, 0)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_instring, __pyx_n_s_expandtabs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2514, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_instring, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2513
 *         for e in self.ignoreExprs:
 *             e.streamline()
 *         if not self.keepTabs:             # <<<<<<<<<<<<<<
 *             instring = instring.expandtabs()
 *         try:
 */
  }

  /* "cPyparsing.pyx":2515
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_12);
    /*try:*/ {

      /* "cPyparsing.pyx":2516
 *             instring = instring.expandtabs()
 *         try:
 *             loc, tokens = self._parse(instring, 0)             # <<<<<<<<<<<<<<
 *             if parseAll:
 *                 loc = self.preParse(instring, loc)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2516, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_instring, __pyx_int_0};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2516, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
        PyObject* sequence = __pyx_t_3;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 2516, __pyx_L8_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        #else
        __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2516, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2516, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2516, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
        index = 0; __pyx_t_1 = __pyx_t_13(__pyx_t_9); if (unlikely(!__pyx_t_1)) goto __pyx_L14_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        index = 1; __pyx_t_2 = __pyx_t_13(__pyx_t_9); if (unlikely(!__pyx_t_2)) goto __pyx_L14_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_9), 2) < 0) __PYX_ERR(0, 2516, __pyx_L8_error)
        __pyx_t_13 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L15_unpacking_done;
        __pyx_L14_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_13 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 2516, __pyx_L8_error)
        __pyx_L15_unpacking_done:;
      }
      __pyx_v_loc = __pyx_t_1;
      __pyx_t_1 = 0;
      __pyx_v_tokens = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":2517
 *         try:
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:             # <<<<<<<<<<<<<<
 *                 loc = self.preParse(instring, loc)
 *                 se = Empty() + StringEnd()
 */
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_parseAll); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2517, __pyx_L8_error)
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":2518
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:
 *                 loc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *                 se = Empty() + StringEnd()
 *                 se._parse(instring, loc)
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2518, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2518, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "cPyparsing.pyx":2519
 *             if parseAll:
 *                 loc = self.preParse(instring, loc)
 *                 se = Empty() + StringEnd()             # <<<<<<<<<<<<<<
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2519, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2519, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_StringEnd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2519, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_9 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2519, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2519, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_v_se = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":2520
 *                 loc = self.preParse(instring, loc)
 *                 se = Empty() + StringEnd()
 *                 se._parse(instring, loc)             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_se, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2520, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2520, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":2517
 *         try:
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:             # <<<<<<<<<<<<<<
 *                 loc = self.preParse(instring, loc)
 *                 se = Empty() + StringEnd()
 */
      }

      /* "cPyparsing.pyx":2515
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:
 */
    }

    /* "cPyparsing.pyx":2530
 *                 raise exc
 *         else:
 *             return tokens             # <<<<<<<<<<<<<<
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):
 */
    /*else:*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_tokens);
      __pyx_r = __pyx_v_tokens;
      goto __pyx_L11_except_return;
    }
    __pyx_L8_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":2521
 *                 se = Empty() + StringEnd()
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2521, __pyx_L10_except_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_4 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_ErrRestore(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_t_1 = 0; __pyx_t_2 = 0; __pyx_t_3 = 0;
    if (__pyx_t_4) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.parseString", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1) < 0) __PYX_ERR(0, 2521, __pyx_L10_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_v_exc = __pyx_t_2;
      /*try:*/ {

        /* "cPyparsing.pyx":2522
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2522, __pyx_L22_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2522, __pyx_L22_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2522, __pyx_L22_error)
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(__pyx_t_5)) {

          /* "cPyparsing.pyx":2523
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_3);
          __Pyx_GIVEREF(__pyx_t_2);
          __Pyx_XGIVEREF(__pyx_t_1);
          __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_2, __pyx_t_1);
          __pyx_t_3 = 0; __pyx_t_2 = 0; __pyx_t_1 = 0; 
          __PYX_ERR(0, 2523, __pyx_L22_error)

          /* "cPyparsing.pyx":2522
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":2526
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
        /*else*/ {
          __pyx_t_14 = __Pyx_GetAttr3(__pyx_v_exc, __pyx_n_u_traceback, Py_None); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2526, __pyx_L22_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_5 = (__pyx_t_14 != Py_None);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (__pyx_t_5) {

            /* "cPyparsing.pyx":2527
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)             # <<<<<<<<<<<<<<
 *                 raise exc
 *         else:
 */
            __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_trim_traceback); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2527, __pyx_L22_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_traceback); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2527, __pyx_L22_error)
            __Pyx_GOTREF(__pyx_t_15);
            __pyx_t_16 = NULL;
            __pyx_t_4 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_9))) {
              __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_9);
              if (likely(__pyx_t_16)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
                __Pyx_INCREF(__pyx_t_16);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_9, function);
                __pyx_t_4 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_t_15};
              __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2527, __pyx_L22_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_traceback, __pyx_t_14) < 0) __PYX_ERR(0, 2527, __pyx_L22_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

            /* "cPyparsing.pyx":2526
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
          }

          /* "cPyparsing.pyx":2528
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc             # <<<<<<<<<<<<<<
 *         else:
 *             return tokens
 */
          __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 2528, __pyx_L22_error)
        }
      }

      /* "cPyparsing.pyx":2521
 *                 se = Empty() + StringEnd()
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        __pyx_L22_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          __pyx_t_4 = __pyx_lineno; __pyx_t_17 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc); __pyx_v_exc = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_24);
            __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
          }
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_ErrRestore(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_17; __pyx_filename = __pyx_t_18;
          goto __pyx_L10_except_error;
        }
      }
    }
    goto __pyx_L10_except_error;

    /* "cPyparsing.pyx":2515
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:
 */
    __pyx_L10_except_error:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
    goto __pyx_L1_error;
    __pyx_L11_except_return:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2474
 *             ParserElement._parse = ParserElement._parseCache
 * 
 *     def parseString(self, instring, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression with the given string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_se);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_instring);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_13ParserElement_58generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":2532
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */

static PyObject *__pyx_pf_10cPyparsing_93__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_maxMatches);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_maxMatches);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_maxMatches)) __PYX_ERR(0, 2532, __pyx_L1_error);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)Py_False))) __PYX_ERR(0, 2532, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 2532, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 2532, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_57scanString(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_56scanString, "ParserElement.scanString(self, instring, maxMatches=_MAX_INT, overlap=False)\n\n        Scan the input string for expression matches.  Each match will return the\n        matching tokens, start location, and end location.  May be called with optional\n        ``maxMatches`` argument, to clip scanning after 'n' matches are found.  If\n        ``overlap`` is specified, then overlapping matches will be reported.\n\n        Note that the start and end locations are reported relative to the string\n        being parsed.  See :class:`parseString` for more information on parsing\n        strings with embedded tabs.\n\n        Example::\n\n            source = \"sldjf123lsdjjkf345sldkjf879lkjsfd987\"\n            print(source)\n            for tokens, start, end in Word(alphas).scanString(source):\n                print(' '*start + '^'*(end-start))\n                print(' '*start + tokens[0])\n\n        prints::\n\n            sldjf123lsdjjkf345sldkjf879lkjsfd987\n            ^^^^^\n            sldjf\n                    ^^^^^^^\n                    lsdjjkf\n                              ^^^^^^\n                              sldkjf\n                                       ^^^^^^\n                                       lkjsfd\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_57scanString = {"scanString", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_57scanString, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_56scanString};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_57scanString(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_maxMatches = 0;
  PyObject *__pyx_v_overlap = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scanString (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_maxMatches,&__pyx_n_s_overlap,0};
    __pyx_defaults2 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_maxMatches);
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("scanString", 0, 2, 4, 1); __PYX_ERR(0, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_maxMatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_overlap);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "scanString") < 0)) __PYX_ERR(0, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_maxMatches = values[2];
    __pyx_v_overlap = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("scanString", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_56scanString(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_maxMatches, __pyx_v_overlap);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_56scanString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxMatches, PyObject *__pyx_v_overlap) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("scanString", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_19_scanString(__pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2532, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_instring = __pyx_v_instring;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
  __pyx_cur_scope->__pyx_v_maxMatches = __pyx_v_maxMatches;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_maxMatches);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_maxMatches);
  __pyx_cur_scope->__pyx_v_overlap = __pyx_v_overlap;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_overlap);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_overlap);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_13ParserElement_58generator, __pyx_codeobj__52, (PyObject *) __pyx_cur_scope, __pyx_n_s_scanString, __pyx_n_s_ParserElement_scanString, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 2532, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_13ParserElement_58generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *(*__pyx_t_16)(PyObject *);
  long __pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_t_21;
  char const *__pyx_t_22;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scanString", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L30_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2532, __pyx_L1_error)

  /* "cPyparsing.pyx":2563
 *                                        lkjsfd
 *         """
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamline()
 *         for e in self.ignoreExprs:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_streamlined); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2563, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":2564
 *         """
 *         if not self.streamlined:
 *             self.streamline()             # <<<<<<<<<<<<<<
 *         for e in self.ignoreExprs:
 *             e.streamline()
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_streamline); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2563
 *                                        lkjsfd
 *         """
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamline()
 *         for e in self.ignoreExprs:
 */
  }

  /* "cPyparsing.pyx":2565
 *         if not self.streamlined:
 *             self.streamline()
 *         for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4);
    __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2565, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2565, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2565, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2565, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2565, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2565, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2565, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_8(__pyx_t_4);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2565, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2566
 *             self.streamline()
 *         for e in self.ignoreExprs:
 *             e.streamline()             # <<<<<<<<<<<<<<
 * 
 *         if not self.keepTabs:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_streamline); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2566, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2565
 *         if not self.streamlined:
 *             self.streamline()
 *         for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":2568
 *             e.streamline()
 * 
 *         if not self.keepTabs:             # <<<<<<<<<<<<<<
 *             instring = _ustr(instring).expandtabs()
 *         instrlen = len(instring)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_keepTabs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = (!__pyx_t_3);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2569
 * 
 *         if not self.keepTabs:
 *             instring = _ustr(instring).expandtabs()             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         loc = 0
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_cur_scope->__pyx_v_instring};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_expandtabs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_instring);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_instring, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2568
 *             e.streamline()
 * 
 *         if not self.keepTabs:             # <<<<<<<<<<<<<<
 *             instring = _ustr(instring).expandtabs()
 *         instrlen = len(instring)
 */
  }

  /* "cPyparsing.pyx":2570
 *         if not self.keepTabs:
 *             instring = _ustr(instring).expandtabs()
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         loc = 0
 *         preparseFn = self.preParse
 */
  __pyx_t_7 = PyObject_Length(__pyx_cur_scope->__pyx_v_instring); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2570, __pyx_L1_error)
  __pyx_cur_scope->__pyx_v_instrlen = __pyx_t_7;

  /* "cPyparsing.pyx":2571
 *             instring = _ustr(instring).expandtabs()
 *         instrlen = len(instring)
 *         loc = 0             # <<<<<<<<<<<<<<
 *         preparseFn = self.preParse
 *         parseFn = self._parse
 */
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __pyx_cur_scope->__pyx_v_loc = __pyx_int_0;

  /* "cPyparsing.pyx":2572
 *         instrlen = len(instring)
 *         loc = 0
 *         preparseFn = self.preParse             # <<<<<<<<<<<<<<
 *         parseFn = self._parse
 *         ParserElement.resetCache()
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_preparseFn = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":2573
 *         loc = 0
 *         preparseFn = self.preParse
 *         parseFn = self._parse             # <<<<<<<<<<<<<<
 *         ParserElement.resetCache()
 *         matches = 0
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_parseFn = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":2574
 *         preparseFn = self.preParse
 *         parseFn = self._parse
 *         ParserElement.resetCache()             # <<<<<<<<<<<<<<
 *         matches = 0
 *         try:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_resetCache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":2575
 *         parseFn = self._parse
 *         ParserElement.resetCache()
 *         matches = 0             # <<<<<<<<<<<<<<
 *         try:
 *             while loc <= instrlen and matches < maxMatches:
 */
  __pyx_cur_scope->__pyx_v_matches = 0;

  /* "cPyparsing.pyx":2576
 *         ParserElement.resetCache()
 *         matches = 0
 *         try:             # <<<<<<<<<<<<<<
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_12);
    /*try:*/ {

      /* "cPyparsing.pyx":2577
 *         matches = 0
 *         try:
 *             while loc <= instrlen and matches < maxMatches:             # <<<<<<<<<<<<<<
 *                 try:
 *                     preloc = preparseFn(instring, loc)
 */
      while (1) {
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_cur_scope->__pyx_v_instrlen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2577, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_loc, __pyx_t_4, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2577, __pyx_L9_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2577, __pyx_L9_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_3) {
        } else {
          __pyx_t_2 = __pyx_t_3;
          goto __pyx_L17_bool_binop_done;
        }
        __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_cur_scope->__pyx_v_matches); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2577, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_cur_scope->__pyx_v_maxMatches, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2577, __pyx_L9_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2577, __pyx_L9_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __pyx_t_3;
        __pyx_L17_bool_binop_done:;
        if (!__pyx_t_2) break;

        /* "cPyparsing.pyx":2578
 *         try:
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:             # <<<<<<<<<<<<<<
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 */
        {
          __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          /*try:*/ {

            /* "cPyparsing.pyx":2579
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:
 *                     preloc = preparseFn(instring, loc)             # <<<<<<<<<<<<<<
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 *                 except ParseException:
 */
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_preparseFn);
            __pyx_t_1 = __pyx_cur_scope->__pyx_v_preparseFn; __pyx_t_5 = NULL;
            __pyx_t_6 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_6 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_instring, __pyx_cur_scope->__pyx_v_loc};
              __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2579, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            }
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_preloc);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_preloc, __pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_4);
            __pyx_t_4 = 0;

            /* "cPyparsing.pyx":2580
 *                 try:
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)             # <<<<<<<<<<<<<<
 *                 except ParseException:
 *                     loc = preloc + 1
 */
            __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2580, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_cur_scope->__pyx_v_instring)) __PYX_ERR(0, 2580, __pyx_L19_error);
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_preloc);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_preloc);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_cur_scope->__pyx_v_preloc)) __PYX_ERR(0, 2580, __pyx_L19_error);
            __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2580, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 2580, __pyx_L19_error)
            __pyx_t_5 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_parseFn, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2580, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
              PyObject* sequence = __pyx_t_5;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 2)) {
                if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 2580, __pyx_L19_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
              } else {
                __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
              }
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_4);
              #else
              __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2580, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2580, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            } else {
              Py_ssize_t index = -1;
              __pyx_t_9 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2580, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __pyx_t_16 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
              index = 0; __pyx_t_1 = __pyx_t_16(__pyx_t_9); if (unlikely(!__pyx_t_1)) goto __pyx_L27_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_1);
              index = 1; __pyx_t_4 = __pyx_t_16(__pyx_t_9); if (unlikely(!__pyx_t_4)) goto __pyx_L27_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_4);
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_9), 2) < 0) __PYX_ERR(0, 2580, __pyx_L19_error)
              __pyx_t_16 = NULL;
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              goto __pyx_L28_unpacking_done;
              __pyx_L27_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __pyx_t_16 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 2580, __pyx_L19_error)
              __pyx_L28_unpacking_done:;
            }
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_nextLoc);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_nextLoc, __pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_1);
            __pyx_t_1 = 0;
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_tokens);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_tokens, __pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_4);
            __pyx_t_4 = 0;

            /* "cPyparsing.pyx":2578
 *         try:
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:             # <<<<<<<<<<<<<<
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 */
          }

          /* "cPyparsing.pyx":2584
 *                     loc = preloc + 1
 *                 else:
 *                     if nextLoc > loc:             # <<<<<<<<<<<<<<
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc
 */
          /*else:*/ {
            __pyx_t_5 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_nextLoc, __pyx_cur_scope->__pyx_v_loc, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2584, __pyx_L21_except_error)
            __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2584, __pyx_L21_except_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (__pyx_t_2) {

              /* "cPyparsing.pyx":2585
 *                 else:
 *                     if nextLoc > loc:
 *                         matches += 1             # <<<<<<<<<<<<<<
 *                         yield tokens, preloc, nextLoc
 *                         if overlap:
 */
              __pyx_t_6 = 0;
              __pyx_t_17 = __Pyx_add_const_long_checking_overflow(__pyx_cur_scope->__pyx_v_matches, 1, &__pyx_t_6);
              if (unlikely(__pyx_t_6)) {
                PyErr_SetString(PyExc_OverflowError, "value too large");
                __PYX_ERR(0, 2585, __pyx_L21_except_error)
              }
              __pyx_cur_scope->__pyx_v_matches = __pyx_t_17;

              /* "cPyparsing.pyx":2586
 *                     if nextLoc > loc:
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc             # <<<<<<<<<<<<<<
 *                         if overlap:
 *                             nextloc = preparseFn(instring, loc)
 */
              __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2586, __pyx_L21_except_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_tokens);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_tokens);
              if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_cur_scope->__pyx_v_tokens)) __PYX_ERR(0, 2586, __pyx_L21_except_error);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_preloc);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_preloc);
              if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_cur_scope->__pyx_v_preloc)) __PYX_ERR(0, 2586, __pyx_L21_except_error);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_nextLoc);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_nextLoc);
              if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_cur_scope->__pyx_v_nextLoc)) __PYX_ERR(0, 2586, __pyx_L21_except_error);
              __pyx_r = __pyx_t_5;
              __pyx_t_5 = 0;
              __Pyx_XGIVEREF(__pyx_t_10);
              __pyx_cur_scope->__pyx_t_0 = __pyx_t_10;
              __Pyx_XGIVEREF(__pyx_t_11);
              __pyx_cur_scope->__pyx_t_1 = __pyx_t_11;
              __Pyx_XGIVEREF(__pyx_t_12);
              __pyx_cur_scope->__pyx_t_2 = __pyx_t_12;
              __Pyx_XGIVEREF(__pyx_t_13);
              __pyx_cur_scope->__pyx_t_3 = __pyx_t_13;
              __Pyx_XGIVEREF(__pyx_t_14);
              __pyx_cur_scope->__pyx_t_4 = __pyx_t_14;
              __Pyx_XGIVEREF(__pyx_t_15);
              __pyx_cur_scope->__pyx_t_5 = __pyx_t_15;
              __Pyx_XGIVEREF(__pyx_r);
              __Pyx_RefNannyFinishContext();
              __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
              /* return from generator, yielding value */
              __pyx_generator->resume_label = 1;
              return __pyx_r;
              __pyx_L30_resume_from_yield:;
              __pyx_t_10 = __pyx_cur_scope->__pyx_t_0;
              __pyx_cur_scope->__pyx_t_0 = 0;
              __Pyx_XGOTREF(__pyx_t_10);
              __pyx_t_11 = __pyx_cur_scope->__pyx_t_1;
              __pyx_cur_scope->__pyx_t_1 = 0;
              __Pyx_XGOTREF(__pyx_t_11);
              __pyx_t_12 = __pyx_cur_scope->__pyx_t_2;
              __pyx_cur_scope->__pyx_t_2 = 0;
              __Pyx_XGOTREF(__pyx_t_12);
              __pyx_t_13 = __pyx_cur_scope->__pyx_t_3;
              __pyx_cur_scope->__pyx_t_3 = 0;
              __Pyx_XGOTREF(__pyx_t_13);
              __pyx_t_14 = __pyx_cur_scope->__pyx_t_4;
              __pyx_cur_scope->__pyx_t_4 = 0;
              __Pyx_XGOTREF(__pyx_t_14);
              __pyx_t_15 = __pyx_cur_scope->__pyx_t_5;
              __pyx_cur_scope->__pyx_t_5 = 0;
              __Pyx_XGOTREF(__pyx_t_15);
              if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2586, __pyx_L21_except_error)

              /* "cPyparsing.pyx":2587
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc
 *                         if overlap:             # <<<<<<<<<<<<<<
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:
 */
              __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_overlap); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2587, __pyx_L21_except_error)
              if (__pyx_t_2) {

                /* "cPyparsing.pyx":2588
 *                         yield tokens, preloc, nextLoc
 *                         if overlap:
 *                             nextloc = preparseFn(instring, loc)             # <<<<<<<<<<<<<<
 *                             if nextloc > loc:
 *                                 loc = nextLoc
 */
                __Pyx_INCREF(__pyx_cur_scope->__pyx_v_preparseFn);
                __pyx_t_4 = __pyx_cur_scope->__pyx_v_preparseFn; __pyx_t_1 = NULL;
                __pyx_t_6 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_4))) {
                  __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
                  if (likely(__pyx_t_1)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                    __Pyx_INCREF(__pyx_t_1);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_4, function);
                    __pyx_t_6 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_cur_scope->__pyx_v_instring, __pyx_cur_scope->__pyx_v_loc};
                  __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2588, __pyx_L21_except_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                }
                __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_nextloc);
                __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_nextloc, __pyx_t_5);
                __Pyx_GIVEREF(__pyx_t_5);
                __pyx_t_5 = 0;

                /* "cPyparsing.pyx":2589
 *                         if overlap:
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:             # <<<<<<<<<<<<<<
 *                                 loc = nextLoc
 *                             else:
 */
                __pyx_t_5 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_nextloc, __pyx_cur_scope->__pyx_v_loc, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2589, __pyx_L21_except_error)
                __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2589, __pyx_L21_except_error)
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                if (__pyx_t_2) {

                  /* "cPyparsing.pyx":2590
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:
 *                                 loc = nextLoc             # <<<<<<<<<<<<<<
 *                             else:
 *                                 loc += 1
 */
                  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_nextLoc);
                  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
                  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_cur_scope->__pyx_v_nextLoc);
                  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_nextLoc);

                  /* "cPyparsing.pyx":2589
 *                         if overlap:
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:             # <<<<<<<<<<<<<<
 *                                 loc = nextLoc
 *                             else:
 */
                  goto __pyx_L32;
                }

                /* "cPyparsing.pyx":2592
 *                                 loc = nextLoc
 *                             else:
 *                                 loc += 1             # <<<<<<<<<<<<<<
 *                         else:
 *                             loc = nextLoc
 */
                /*else*/ {
                  __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_cur_scope->__pyx_v_loc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2592, __pyx_L21_except_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
                  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_t_5);
                  __Pyx_GIVEREF(__pyx_t_5);
                  __pyx_t_5 = 0;
                }
                __pyx_L32:;

                /* "cPyparsing.pyx":2587
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc
 *                         if overlap:             # <<<<<<<<<<<<<<
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:
 */
                goto __pyx_L31;
              }

              /* "cPyparsing.pyx":2594
 *                                 loc += 1
 *                         else:
 *                             loc = nextLoc             # <<<<<<<<<<<<<<
 *                     else:
 *                         loc = preloc + 1
 */
              /*else*/ {
                __Pyx_INCREF(__pyx_cur_scope->__pyx_v_nextLoc);
                __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
                __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_cur_scope->__pyx_v_nextLoc);
                __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_nextLoc);
              }
              __pyx_L31:;

              /* "cPyparsing.pyx":2584
 *                     loc = preloc + 1
 *                 else:
 *                     if nextLoc > loc:             # <<<<<<<<<<<<<<
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc
 */
              goto __pyx_L29;
            }

            /* "cPyparsing.pyx":2596
 *                             loc = nextLoc
 *                     else:
 *                         loc = preloc + 1             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
            /*else*/ {
              __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_cur_scope->__pyx_v_preloc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2596, __pyx_L21_except_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
              __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_t_5);
              __Pyx_GIVEREF(__pyx_t_5);
              __pyx_t_5 = 0;
            }
            __pyx_L29:;
          }
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          goto __pyx_L26_try_end;
          __pyx_L19_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":2581
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 *                 except ParseException:             # <<<<<<<<<<<<<<
 *                     loc = preloc + 1
 *                 else:
 */
          __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_4, &__pyx_t_1);
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2581, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_6 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_5, __pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_ErrRestore(__pyx_t_5, __pyx_t_4, __pyx_t_1);
          __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_1 = 0;
          if (__pyx_t_6) {
            __Pyx_AddTraceback("cPyparsing.ParserElement.scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 2581, __pyx_L21_except_error)
            __Pyx_XGOTREF(__pyx_t_1);
            __Pyx_XGOTREF(__pyx_t_4);
            __Pyx_XGOTREF(__pyx_t_5);

            /* "cPyparsing.pyx":2582
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 *                 except ParseException:
 *                     loc = preloc + 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     if nextLoc > loc:
 */
            if (unlikely(!__pyx_cur_scope->__pyx_v_preloc)) { __Pyx_RaiseUnboundLocalError("preloc"); __PYX_ERR(0, 2582, __pyx_L21_except_error) }
            __pyx_t_9 = __Pyx_PyInt_AddObjC(__pyx_cur_scope->__pyx_v_preloc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2582, __pyx_L21_except_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
            __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_9);
            __pyx_t_9 = 0;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            goto __pyx_L20_exception_handled;
          }
          goto __pyx_L21_except_error;

          /* "cPyparsing.pyx":2578
 *         try:
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:             # <<<<<<<<<<<<<<
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 */
          __pyx_L21_except_error:;
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          goto __pyx_L9_error;
          __pyx_L20_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          __pyx_L26_try_end:;
        }
      }

      /* "cPyparsing.pyx":2576
 *         ParserElement.resetCache()
 *         matches = 0
 *         try:             # <<<<<<<<<<<<<<
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:
 */
    }
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    goto __pyx_L14_try_end;
    __pyx_L9_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":2597
 *                     else:
 *                         loc = preloc + 1
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_4, &__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2597, __pyx_L11_except_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_6 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_5, __pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_ErrRestore(__pyx_t_5, __pyx_t_4, __pyx_t_1);
    __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_1 = 0;
    if (__pyx_t_6) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 2597, __pyx_L11_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_cur_scope->__pyx_v_exc = __pyx_t_4;
      /*try:*/ {

        /* "cPyparsing.pyx":2598
 *                         loc = preloc + 1
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2598, __pyx_L40_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2598, __pyx_L40_error)
        __Pyx_GOTREF(__pyx_t_18);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_18); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2598, __pyx_L40_error)
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
        if (unlikely(__pyx_t_2)) {

          /* "cPyparsing.pyx":2599
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_XGIVEREF(__pyx_t_5);
          __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_4, __pyx_t_5);
          __pyx_t_1 = 0; __pyx_t_4 = 0; __pyx_t_5 = 0; 
          __PYX_ERR(0, 2599, __pyx_L40_error)

          /* "cPyparsing.pyx":2598
 *                         loc = preloc + 1
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":2602
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
        /*else*/ {
          __pyx_t_18 = __Pyx_GetAttr3(__pyx_cur_scope->__pyx_v_exc, __pyx_n_u_traceback, Py_None); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2602, __pyx_L40_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_2 = (__pyx_t_18 != Py_None);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":2603
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)             # <<<<<<<<<<<<<<
 *                 raise exc
 * 
 */
            __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_trim_traceback); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2603, __pyx_L40_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_exc, __pyx_n_s_traceback); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2603, __pyx_L40_error)
            __Pyx_GOTREF(__pyx_t_19);
            __pyx_t_20 = NULL;
            __pyx_t_6 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_9))) {
              __pyx_t_20 = PyMethod_GET_SELF(__pyx_t_9);
              if (likely(__pyx_t_20)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
                __Pyx_INCREF(__pyx_t_20);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_9, function);
                __pyx_t_6 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_20, __pyx_t_19};
              __pyx_t_18 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
              __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
              __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
              if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2603, __pyx_L40_error)
              __Pyx_GOTREF(__pyx_t_18);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
            if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_exc, __pyx_n_s_traceback, __pyx_t_18) < 0) __PYX_ERR(0, 2603, __pyx_L40_error)
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

            /* "cPyparsing.pyx":2602
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
          }

          /* "cPyparsing.pyx":2604
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *     def transformString(self, instring):
 */
          __Pyx_Raise(__pyx_cur_scope->__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 2604, __pyx_L40_error)
        }
      }

      /* "cPyparsing.pyx":2597
 *                     else:
 *                         loc = preloc + 1
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        __pyx_L40_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_assign
          __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
          __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
          __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          __Pyx_XGOTREF(__pyx_t_25);
          __pyx_t_6 = __pyx_lineno; __pyx_t_21 = __pyx_clineno; __pyx_t_22 = __pyx_filename;
          {
            __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exc);
            __Pyx_DECREF(__pyx_cur_scope->__pyx_v_exc); __pyx_cur_scope->__pyx_v_exc = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_24);
            __Pyx_XGIVEREF(__pyx_t_25);
            __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
          }
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_14, __pyx_t_13);
          __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
          __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_21; __pyx_filename = __pyx_t_22;
          goto __pyx_L11_except_error;
        }
      }
    }
    goto __pyx_L11_except_error;

    /* "cPyparsing.pyx":2576
 *         ParserElement.resetCache()
 *         matches = 0
 *         try:             # <<<<<<<<<<<<<<
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:
 */
    __pyx_L11_except_error:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
    goto __pyx_L1_error;
    __pyx_L14_try_end:;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":2532
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_AddTraceback("scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2606
 *                 raise exc
 * 
 *     def transformString(self, instring):             # <<<<<<<<<<<<<<
 *         """
 *         Extension to :class:`scanString`, to modify matching text with modified tokens that may
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_60transformString(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_59transformString, "ParserElement.transformString(self, instring)\n\n        Extension to :class:`scanString`, to modify matching text with modified tokens that may\n        be returned from a parse action.  To use ``transformString``, define a grammar and\n        attach a parse action to it that modifies the returned token list.\n        Invoking ``transformString()`` on a target string will then scan for matches,\n        and replace the matched text patterns according to the logic in the parse\n        action.  ``transformString()`` returns the resulting transformed string.\n\n        Example::\n\n            wd = Word(alphas)\n            wd.setParseAction(lambda toks: toks[0].title())\n\n            print(wd.transformString(\"now is the winter of our discontent made glorious summer by this sun of york.\"))\n\n        prints::\n\n            Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_60transformString = {"transformString", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_60transformString, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_59transformString};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_60transformString(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transformString (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2606, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2606, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("transformString", 1, 2, 2, 1); __PYX_ERR(0, 2606, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "transformString") < 0)) __PYX_ERR(0, 2606, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("transformString", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2606, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.transformString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_59transformString(__pyx_self, __pyx_v_self, __pyx_v_instring);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_59transformString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring) {
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_lastE = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_9genexpr17__pyx_v_o = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  int __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  char const *__pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("transformString", 1);

  /* "cPyparsing.pyx":2626
 *             Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York.
 *         """
 *         out = []             # <<<<<<<<<<<<<<
 *         lastE = 0
 *         # force preservation of <TAB>s, to minimize unwanted transformation of string, and to
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2627
 *         """
 *         out = []
 *         lastE = 0             # <<<<<<<<<<<<<<
 *         # force preservation of <TAB>s, to minimize unwanted transformation of string, and to
 *         # keep string locs straight between transformString and scanString
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_lastE = __pyx_int_0;

  /* "cPyparsing.pyx":2630
 *         # force preservation of <TAB>s, to minimize unwanted transformation of string, and to
 *         # keep string locs straight between transformString and scanString
 *         self.keepTabs = True             # <<<<<<<<<<<<<<
 *         try:
 *             for t, s, e in self.scanString(instring):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_keepTabs, Py_True) < 0) __PYX_ERR(0, 2630, __pyx_L1_error)

  /* "cPyparsing.pyx":2631
 *         # keep string locs straight between transformString and scanString
 *         self.keepTabs = True
 *         try:             # <<<<<<<<<<<<<<
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "cPyparsing.pyx":2632
 *         self.keepTabs = True
 *         try:
 *             for t, s, e in self.scanString(instring):             # <<<<<<<<<<<<<<
 *                 out.append(instring[lastE:s])
 *                 if t:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_scanString); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2632, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_instring};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2632, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_5 = __pyx_t_1; __Pyx_INCREF(__pyx_t_5);
        __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2632, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2632, __pyx_L3_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_9)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2632, __pyx_L3_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 2632, __pyx_L3_error)
            #else
            __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2632, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2632, __pyx_L3_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 2632, __pyx_L3_error)
            #else
            __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2632, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_9(__pyx_t_5);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 2632, __pyx_L3_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 3)) {
            if (size > 3) __Pyx_RaiseTooManyValuesError(3);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 2632, __pyx_L3_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1); 
            __pyx_t_11 = PyTuple_GET_ITEM(sequence, 2); 
          } else {
            __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_10 = PyList_GET_ITEM(sequence, 1); 
            __pyx_t_11 = PyList_GET_ITEM(sequence, 2); 
          }
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          #else
          __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2632, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_10 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2632, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2632, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_11);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_12 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2632, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_12);
          index = 0; __pyx_t_6 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_6)) goto __pyx_L11_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_6);
          index = 1; __pyx_t_10 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_10)) goto __pyx_L11_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_10);
          index = 2; __pyx_t_11 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_11)) goto __pyx_L11_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_11);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_12), 3) < 0) __PYX_ERR(0, 2632, __pyx_L3_error)
          __pyx_t_13 = NULL;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          goto __pyx_L12_unpacking_done;
          __pyx_L11_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_13 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 2632, __pyx_L3_error)
          __pyx_L12_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_6);
        __pyx_t_6 = 0;
        __Pyx_XDECREF_SET(__pyx_v_s, __pyx_t_10);
        __pyx_t_10 = 0;
        __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_11);
        __pyx_t_11 = 0;

        /* "cPyparsing.pyx":2633
 *         try:
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])             # <<<<<<<<<<<<<<
 *                 if t:
 *                     if isinstance(t, ParseResults):
 */
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_lastE, &__pyx_v_s, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2633, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_t_1); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 2633, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":2634
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 *                 if t:             # <<<<<<<<<<<<<<
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()
 */
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2634, __pyx_L3_error)
        if (__pyx_t_15) {

          /* "cPyparsing.pyx":2635
 *                 out.append(instring[lastE:s])
 *                 if t:
 *                     if isinstance(t, ParseResults):             # <<<<<<<<<<<<<<
 *                         out += t.asList()
 *                     elif isinstance(t, list):
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2635, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_15 = PyObject_IsInstance(__pyx_v_t, __pyx_t_1); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 2635, __pyx_L3_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_15) {

            /* "cPyparsing.pyx":2636
 *                 if t:
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()             # <<<<<<<<<<<<<<
 *                     elif isinstance(t, list):
 *                         out += t
 */
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_asList); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2636, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_10 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_11))) {
              __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
              if (likely(__pyx_t_10)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
                __Pyx_INCREF(__pyx_t_10);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_11, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
              __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2636, __pyx_L3_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            }
            __pyx_t_11 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2636, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_11);
            __pyx_t_11 = 0;

            /* "cPyparsing.pyx":2635
 *                 out.append(instring[lastE:s])
 *                 if t:
 *                     if isinstance(t, ParseResults):             # <<<<<<<<<<<<<<
 *                         out += t.asList()
 *                     elif isinstance(t, list):
 */
            goto __pyx_L14;
          }

          /* "cPyparsing.pyx":2637
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()
 *                     elif isinstance(t, list):             # <<<<<<<<<<<<<<
 *                         out += t
 *                     else:
 */
          __pyx_t_15 = PyList_Check(__pyx_v_t); 
          if (__pyx_t_15) {

            /* "cPyparsing.pyx":2638
 *                         out += t.asList()
 *                     elif isinstance(t, list):
 *                         out += t             # <<<<<<<<<<<<<<
 *                     else:
 *                         out.append(t)
 */
            __pyx_t_11 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_v_t); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2638, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_11);
            __pyx_t_11 = 0;

            /* "cPyparsing.pyx":2637
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()
 *                     elif isinstance(t, list):             # <<<<<<<<<<<<<<
 *                         out += t
 *                     else:
 */
            goto __pyx_L14;
          }

          /* "cPyparsing.pyx":2640
 *                         out += t
 *                     else:
 *                         out.append(t)             # <<<<<<<<<<<<<<
 *                 lastE = e
 *             out.append(instring[lastE:])
 */
          /*else*/ {
            __pyx_t_14 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_v_t); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 2640, __pyx_L3_error)
          }
          __pyx_L14:;

          /* "cPyparsing.pyx":2634
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 *                 if t:             # <<<<<<<<<<<<<<
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()
 */
        }

        /* "cPyparsing.pyx":2641
 *                     else:
 *                         out.append(t)
 *                 lastE = e             # <<<<<<<<<<<<<<
 *             out.append(instring[lastE:])
 *             out = [o for o in out if o]
 */
        __Pyx_INCREF(__pyx_v_e);
        __Pyx_DECREF_SET(__pyx_v_lastE, __pyx_v_e);

        /* "cPyparsing.pyx":2632
 *         self.keepTabs = True
 *         try:
 *             for t, s, e in self.scanString(instring):             # <<<<<<<<<<<<<<
 *                 out.append(instring[lastE:s])
 *                 if t:
 */
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":2642
 *                         out.append(t)
 *                 lastE = e
 *             out.append(instring[lastE:])             # <<<<<<<<<<<<<<
 *             out = [o for o in out if o]
 *             return "".join(map(_ustr, _flatten(out)))
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_lastE, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2642, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 2642, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":2643
 *                 lastE = e
 *             out.append(instring[lastE:])
 *             out = [o for o in out if o]             # <<<<<<<<<<<<<<
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:
 */
      { /* enter inner scope */
        __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2643, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (likely(PyList_CheckExact(__pyx_v_out)) || PyTuple_CheckExact(__pyx_v_out)) {
          __pyx_t_11 = __pyx_v_out; __Pyx_INCREF(__pyx_t_11);
          __pyx_t_8 = 0;
          __pyx_t_9 = NULL;
        } else {
          __pyx_t_8 = -1; __pyx_t_11 = PyObject_GetIter(__pyx_v_out); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2643, __pyx_L18_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2643, __pyx_L18_error)
        }
        for (;;) {
          if (likely(!__pyx_t_9)) {
            if (likely(PyList_CheckExact(__pyx_t_11))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_11);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2643, __pyx_L18_error)
                #endif
                if (__pyx_t_8 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = PyList_GET_ITEM(__pyx_t_11, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 2643, __pyx_L18_error)
              #else
              __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_11, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2643, __pyx_L18_error)
              __Pyx_GOTREF(__pyx_t_1);
              #endif
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_11);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2643, __pyx_L18_error)
                #endif
                if (__pyx_t_8 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_11, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 2643, __pyx_L18_error)
              #else
              __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_11, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2643, __pyx_L18_error)
              __Pyx_GOTREF(__pyx_t_1);
              #endif
            }
          } else {
            __pyx_t_1 = __pyx_t_9(__pyx_t_11);
            if (unlikely(!__pyx_t_1)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 2643, __pyx_L18_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_XDECREF_SET(__pyx_9genexpr17__pyx_v_o, __pyx_t_1);
          __pyx_t_1 = 0;
          __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_9genexpr17__pyx_v_o); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2643, __pyx_L18_error)
          if (__pyx_t_15) {
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_5, (PyObject*)__pyx_9genexpr17__pyx_v_o))) __PYX_ERR(0, 2643, __pyx_L18_error)
          }
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_9genexpr17__pyx_v_o); __pyx_9genexpr17__pyx_v_o = 0;
        goto __pyx_L23_exit_scope;
        __pyx_L18_error:;
        __Pyx_XDECREF(__pyx_9genexpr17__pyx_v_o); __pyx_9genexpr17__pyx_v_o = 0;
        goto __pyx_L3_error;
        __pyx_L23_exit_scope:;
      } /* exit inner scope */
      __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":2644
 *             out.append(instring[lastE:])
 *             out = [o for o in out if o]
 *             return "".join(map(_ustr, _flatten(out)))             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_flatten); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_out};
        __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2644, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5)) __PYX_ERR(0, 2644, __pyx_L3_error);
      __Pyx_GIVEREF(__pyx_t_11);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_11)) __PYX_ERR(0, 2644, __pyx_L3_error);
      __pyx_t_5 = 0;
      __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_1, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":2631
 *         # keep string locs straight between transformString and scanString
 *         self.keepTabs = True
 *         try:             # <<<<<<<<<<<<<<
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2645
 *             out = [o for o in out if o]
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_11, &__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2645, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_7 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_10);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_ErrRestore(__pyx_t_1, __pyx_t_11, __pyx_t_5);
    __pyx_t_1 = 0; __pyx_t_11 = 0; __pyx_t_5 = 0;
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.transformString", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_11, &__pyx_t_1) < 0) __PYX_ERR(0, 2645, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_11);
      __pyx_v_exc = __pyx_t_11;
      /*try:*/ {

        /* "cPyparsing.pyx":2646
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2646, __pyx_L29_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2646, __pyx_L29_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 2646, __pyx_L29_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(__pyx_t_15)) {

          /* "cPyparsing.pyx":2647
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_1);
          __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_11, __pyx_t_1);
          __pyx_t_5 = 0; __pyx_t_11 = 0; __pyx_t_1 = 0; 
          __PYX_ERR(0, 2647, __pyx_L29_error)

          /* "cPyparsing.pyx":2646
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":2650
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
        /*else*/ {
          __pyx_t_6 = __Pyx_GetAttr3(__pyx_v_exc, __pyx_n_u_traceback, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2650, __pyx_L29_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_15 = (__pyx_t_6 != Py_None);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (__pyx_t_15) {

            /* "cPyparsing.pyx":2651
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)             # <<<<<<<<<<<<<<
 *                 raise exc
 * 
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_trim_traceback); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2651, __pyx_L29_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_traceback); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2651, __pyx_L29_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_16 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_16)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_16);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_t_12};
              __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2651, __pyx_L29_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_traceback, __pyx_t_6) < 0) __PYX_ERR(0, 2651, __pyx_L29_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "cPyparsing.pyx":2650
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
          }

          /* "cPyparsing.pyx":2652
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):
 */
          __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 2652, __pyx_L29_error)
        }
      }

      /* "cPyparsing.pyx":2645
 *             out = [o for o in out if o]
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        __pyx_L29_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          __pyx_t_7 = __pyx_lineno; __pyx_t_17 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc); __pyx_v_exc = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_24);
            __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
          }
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_ErrRestore(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_17; __pyx_filename = __pyx_t_18;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":2631
 *         # keep string locs straight between transformString and scanString
 *         self.keepTabs = True
 *         try:             # <<<<<<<<<<<<<<
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2606
 *                 raise exc
 * 
 *     def transformString(self, instring):             # <<<<<<<<<<<<<<
 *         """
 *         Extension to :class:`scanString`, to modify matching text with modified tokens that may
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("cPyparsing.ParserElement.transformString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_lastE);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_9genexpr17__pyx_v_o);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2654
 *                 raise exc
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):             # <<<<<<<<<<<<<<
 *         """
 *         Another extension to :class:`scanString`, simplifying the access to the tokens found
 */

static PyObject *__pyx_pf_10cPyparsing_95__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_maxMatches);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_maxMatches);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_maxMatches)) __PYX_ERR(0, 2654, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 2654, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 2654, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_62searchString(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_61searchString, "ParserElement.searchString(self, instring, maxMatches=_MAX_INT)\n\n        Another extension to :class:`scanString`, simplifying the access to the tokens found\n        to match the given parse expression.  May be called with optional\n        ``maxMatches`` argument, to clip searching after 'n' matches are found.\n\n        Example::\n\n            # a capitalized word starts with an uppercase letter, followed by zero or more lowercase letters\n            cap_word = Word(alphas.upper(), alphas.lower())\n\n            print(cap_word.searchString(\"More than Iron, more than Lead, more than Gold I need Electricity\"))\n\n            # the sum() builtin can be used to merge results into a single ParseResults object\n            print(sum(cap_word.searchString(\"More than Iron, more than Lead, more than Gold I need Electricity\")))\n\n        prints::\n\n            [['More'], ['Iron'], ['Lead'], ['Gold'], ['I'], ['Electricity']]\n            ['More', 'Iron', 'Lead', 'Gold', 'I', 'Electricity']\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_62searchString = {"searchString", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_62searchString, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_61searchString};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_62searchString(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_maxMatches = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("searchString (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_maxMatches,0};
    __pyx_defaults3 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_maxMatches);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2654, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2654, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("searchString", 0, 2, 3, 1); __PYX_ERR(0, 2654, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_maxMatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2654, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "searchString") < 0)) __PYX_ERR(0, 2654, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_maxMatches = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("searchString", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 2654, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.searchString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_61searchString(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_maxMatches);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_61searchString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxMatches) {
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_9genexpr18__pyx_v_t = NULL;
  CYTHON_UNUSED PyObject *__pyx_9genexpr18__pyx_v_s = NULL;
  CYTHON_UNUSED PyObject *__pyx_9genexpr18__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *(*__pyx_t_16)(PyObject *);
  int __pyx_t_17;
  int __pyx_t_18;
  char const *__pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("searchString", 1);

  /* "cPyparsing.pyx":2675
 *             ['More', 'Iron', 'Lead', 'Gold', 'I', 'Electricity']
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":2676
 *         """
 *         try:
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2676, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      { /* enter inner scope */
        __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2676, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_scanString); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2676, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_v_instring, __pyx_v_maxMatches};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2676, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
          __pyx_t_8 = __pyx_t_7; __Pyx_INCREF(__pyx_t_8);
          __pyx_t_11 = 0;
          __pyx_t_12 = NULL;
        } else {
          __pyx_t_11 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2676, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_8); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2676, __pyx_L11_error)
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        for (;;) {
          if (likely(!__pyx_t_12)) {
            if (likely(PyList_CheckExact(__pyx_t_8))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_8);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2676, __pyx_L11_error)
                #endif
                if (__pyx_t_11 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_7 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_11); __Pyx_INCREF(__pyx_t_7); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 2676, __pyx_L11_error)
              #else
              __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_8, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2676, __pyx_L11_error)
              __Pyx_GOTREF(__pyx_t_7);
              #endif
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_8);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2676, __pyx_L11_error)
                #endif
                if (__pyx_t_11 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_11); __Pyx_INCREF(__pyx_t_7); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 2676, __pyx_L11_error)
              #else
              __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_8, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2676, __pyx_L11_error)
              __Pyx_GOTREF(__pyx_t_7);
              #endif
            }
          } else {
            __pyx_t_7 = __pyx_t_12(__pyx_t_8);
            if (unlikely(!__pyx_t_7)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 2676, __pyx_L11_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_7);
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
            PyObject* sequence = __pyx_t_7;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 3)) {
              if (size > 3) __Pyx_RaiseTooManyValuesError(3);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 2676, __pyx_L11_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_13 = PyTuple_GET_ITEM(sequence, 1); 
              __pyx_t_14 = PyTuple_GET_ITEM(sequence, 2); 
            } else {
              __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_13 = PyList_GET_ITEM(sequence, 1); 
              __pyx_t_14 = PyList_GET_ITEM(sequence, 2); 
            }
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_14);
            #else
            __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2676, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_13 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2676, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_14 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2676, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_14);
            #endif
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_15 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2676, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_15);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __pyx_t_16 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_15);
            index = 0; __pyx_t_9 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_9)) goto __pyx_L14_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_9);
            index = 1; __pyx_t_13 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_13)) goto __pyx_L14_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_13);
            index = 2; __pyx_t_14 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_14)) goto __pyx_L14_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_14);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_15), 3) < 0) __PYX_ERR(0, 2676, __pyx_L11_error)
            __pyx_t_16 = NULL;
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            goto __pyx_L15_unpacking_done;
            __pyx_L14_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            __pyx_t_16 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 2676, __pyx_L11_error)
            __pyx_L15_unpacking_done:;
          }
          __Pyx_XDECREF_SET(__pyx_9genexpr18__pyx_v_t, __pyx_t_9);
          __pyx_t_9 = 0;
          __Pyx_XDECREF_SET(__pyx_9genexpr18__pyx_v_s, __pyx_t_13);
          __pyx_t_13 = 0;
          __Pyx_XDECREF_SET(__pyx_9genexpr18__pyx_v_e, __pyx_t_14);
          __pyx_t_14 = 0;
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_6, (PyObject*)__pyx_9genexpr18__pyx_v_t))) __PYX_ERR(0, 2676, __pyx_L11_error)
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_e); __pyx_9genexpr18__pyx_v_e = 0;
        __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_s); __pyx_9genexpr18__pyx_v_s = 0;
        __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_t); __pyx_9genexpr18__pyx_v_t = 0;
        goto __pyx_L17_exit_scope;
        __pyx_L11_error:;
        __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_e); __pyx_9genexpr18__pyx_v_e = 0;
        __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_s); __pyx_9genexpr18__pyx_v_s = 0;
        __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_t); __pyx_9genexpr18__pyx_v_t = 0;
        goto __pyx_L3_error;
        __pyx_L17_exit_scope:;
      } /* exit inner scope */
      __pyx_t_8 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_6};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2676, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":2675
 *             ['More', 'Iron', 'Lead', 'Gold', 'I', 'Electricity']
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":2677
 *         try:
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2677, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0;
    if (__pyx_t_10) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.searchString", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 2677, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_v_exc = __pyx_t_5;
      /*try:*/ {

        /* "cPyparsing.pyx":2678
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2678, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2678, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_17 < 0))) __PYX_ERR(0, 2678, __pyx_L23_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(__pyx_t_17)) {

          /* "cPyparsing.pyx":2679
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_4);
          __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_5, __pyx_t_4);
          __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; 
          __PYX_ERR(0, 2679, __pyx_L23_error)

          /* "cPyparsing.pyx":2678
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":2682
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
        /*else*/ {
          __pyx_t_7 = __Pyx_GetAttr3(__pyx_v_exc, __pyx_n_u_traceback, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2682, __pyx_L23_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_17 = (__pyx_t_7 != Py_None);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (__pyx_t_17) {

            /* "cPyparsing.pyx":2683
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)             # <<<<<<<<<<<<<<
 *                 raise exc
 * 
 */
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_trim_traceback); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2683, __pyx_L23_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_traceback); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2683, __pyx_L23_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_13 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_13)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_13);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_14};
              __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2683, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_traceback, __pyx_t_7) < 0) __PYX_ERR(0, 2683, __pyx_L23_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "cPyparsing.pyx":2682
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
          }

          /* "cPyparsing.pyx":2684
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):
 */
          __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 2684, __pyx_L23_error)
        }
      }

      /* "cPyparsing.pyx":2677
 *         try:
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        __pyx_L23_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          __Pyx_XGOTREF(__pyx_t_25);
          __pyx_t_10 = __pyx_lineno; __pyx_t_18 = __pyx_clineno; __pyx_t_19 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc); __pyx_v_exc = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_24);
            __Pyx_XGIVEREF(__pyx_t_25);
            __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
          }
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_22);
          __Pyx_ErrRestore(__pyx_t_20, __pyx_t_21, __pyx_t_22);
          __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
          __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_18; __pyx_filename = __pyx_t_19;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":2675
 *             ['More', 'Iron', 'Lead', 'Gold', 'I', 'Electricity']
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2654
 *                 raise exc
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):             # <<<<<<<<<<<<<<
 *         """
 *         Another extension to :class:`scanString`, simplifying the access to the tokens found
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("cPyparsing.ParserElement.searchString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_t);
  __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_s);
  __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_13ParserElement_65generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":2686
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */

static PyObject *__pyx_pf_10cPyparsing_97__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_maxsplit);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_maxsplit);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_maxsplit)) __PYX_ERR(0, 2686, __pyx_L1_error);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)Py_False))) __PYX_ERR(0, 2686, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 2686, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 2686, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_64split(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_63split, "ParserElement.split(self, instring, maxsplit=_MAX_INT, includeSeparators=False)\n\n        Generator method to split a string using the given expression as a separator.\n        May be called with optional ``maxsplit`` argument, to limit the number of splits;\n        and the optional ``includeSeparators`` argument (default= ``False``), if the separating\n        matching text should be included in the split results.\n\n        Example::\n\n            punc = oneOf(list(\".,;:/-!?\"))\n            print(list(punc.split(\"This, this?, this sentence, is badly punctuated!\")))\n\n        prints::\n\n            ['This', ' this', '', ' this sentence', ' is badly punctuated', '']\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_64split = {"split", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_64split, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_63split};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_64split(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_maxsplit = 0;
  PyObject *__pyx_v_includeSeparators = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("split (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_maxsplit,&__pyx_n_s_includeSeparators,0};
    __pyx_defaults4 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_maxsplit);
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2686, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2686, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("split", 0, 2, 4, 1); __PYX_ERR(0, 2686, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_maxsplit);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2686, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_includeSeparators);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2686, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "split") < 0)) __PYX_ERR(0, 2686, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_maxsplit = values[2];
    __pyx_v_includeSeparators = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("split", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 2686, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_63split(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_maxsplit, __pyx_v_includeSeparators);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_63split(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxsplit, PyObject *__pyx_v_includeSeparators) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("split", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_20_split(__pyx_ptype_10cPyparsing___pyx_scope_struct_20_split, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2686, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_instring = __pyx_v_instring;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
  __pyx_cur_scope->__pyx_v_maxsplit = __pyx_v_maxsplit;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_maxsplit);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_maxsplit);
  __pyx_cur_scope->__pyx_v_includeSeparators = __pyx_v_includeSeparators;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_includeSeparators);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_includeSeparators);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_13ParserElement_65generator1, __pyx_codeobj__53, (PyObject *) __pyx_cur_scope, __pyx_n_s_split, __pyx_n_s_ParserElement_split, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 2686, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_13ParserElement_65generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("split", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L8_resume_from_yield;
    case 2: goto __pyx_L10_resume_from_yield;
    case 3: goto __pyx_L12_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2686, __pyx_L1_error)

  /* "cPyparsing.pyx":2702
 *             ['This', ' this', '', ' this sentence', ' is badly punctuated', '']
 *         """
 *         splits = 0             # <<<<<<<<<<<<<<
 *         last = 0
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 */
  __pyx_cur_scope->__pyx_v_splits = 0;

  /* "cPyparsing.pyx":2703
 *         """
 *         splits = 0
 *         last = 0             # <<<<<<<<<<<<<<
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 *             yield instring[last:s]
 */
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __pyx_cur_scope->__pyx_v_last = __pyx_int_0;

  /* "cPyparsing.pyx":2704
 *         splits = 0
 *         last = 0
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):             # <<<<<<<<<<<<<<
 *             yield instring[last:s]
 *             if includeSeparators:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_scanString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_cur_scope->__pyx_v_instring)) __PYX_ERR(0, 2704, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_maxMatches, __pyx_cur_scope->__pyx_v_maxsplit) < 0) __PYX_ERR(0, 2704, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2704, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2704, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 2704, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2704, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2704, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 2704, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2704, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_3);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2704, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 2704, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
      index = 0; __pyx_t_2 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      index = 1; __pyx_t_1 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_1)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      index = 2; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 3) < 0) __PYX_ERR(0, 2704, __pyx_L1_error)
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 2704, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_s);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_s, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2705
 *         last = 0
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 *             yield instring[last:s]             # <<<<<<<<<<<<<<
 *             if includeSeparators:
 *                 yield t[0]
 */
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_instring, 0, 0, &__pyx_cur_scope->__pyx_v_last, &__pyx_cur_scope->__pyx_v_s, NULL, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_3);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_3;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_5;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_6;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L8_resume_from_yield:;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_3);
    __pyx_t_5 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_6 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2705, __pyx_L1_error)

    /* "cPyparsing.pyx":2706
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 *             yield instring[last:s]
 *             if includeSeparators:             # <<<<<<<<<<<<<<
 *                 yield t[0]
 *             last = e
 */
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_includeSeparators); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2706, __pyx_L1_error)
    if (__pyx_t_10) {

      /* "cPyparsing.pyx":2707
 *             yield instring[last:s]
 *             if includeSeparators:
 *                 yield t[0]             # <<<<<<<<<<<<<<
 *             last = e
 *         yield instring[last:]
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2707, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      __Pyx_XGIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_3;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_5;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_6;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 2;
      return __pyx_r;
      __pyx_L10_resume_from_yield:;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_3);
      __pyx_t_5 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_6 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2707, __pyx_L1_error)

      /* "cPyparsing.pyx":2706
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 *             yield instring[last:s]
 *             if includeSeparators:             # <<<<<<<<<<<<<<
 *                 yield t[0]
 *             last = e
 */
    }

    /* "cPyparsing.pyx":2708
 *             if includeSeparators:
 *                 yield t[0]
 *             last = e             # <<<<<<<<<<<<<<
 *         yield instring[last:]
 * 
 */
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_last);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_last, __pyx_cur_scope->__pyx_v_e);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_e);

    /* "cPyparsing.pyx":2704
 *         splits = 0
 *         last = 0
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):             # <<<<<<<<<<<<<<
 *             yield instring[last:s]
 *             if includeSeparators:
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2709
 *                 yield t[0]
 *             last = e
 *         yield instring[last:]             # <<<<<<<<<<<<<<
 * 
 *     def __add__(self, other):
 */
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_instring, 0, 0, &__pyx_cur_scope->__pyx_v_last, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  /* return from generator, yielding value */
  __pyx_generator->resume_label = 3;
  return __pyx_r;
  __pyx_L12_resume_from_yield:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2709, __pyx_L1_error)
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":2686
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2711
 *         yield instring[last:]
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator - returns :class:`And`. Adding strings to a ParserElement
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_67__add__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_66__add__, "ParserElement.__add__(self, other)\n\n        Implementation of + operator - returns :class:`And`. Adding strings to a ParserElement\n        converts them to :class:`Literal`s by default.\n\n        Example::\n\n            greet = Word(alphas) + \",\" + Word(alphas) + \"!\"\n            hello = \"Hello, World!\"\n            print (hello, \"->\", greet.parseString(hello))\n\n        prints::\n\n            Hello, World! -> ['Hello', ',', 'World', '!']\n\n        ``...`` may be used as a parse expression as a short form of :class:`SkipTo`.\n\n            Literal('start') + ... + Literal('end')\n\n        is equivalent to:\n\n            Literal('start') + SkipTo('end')(\"_skipped*\") + Literal('end')\n\n        Note that the skipped text is returned with '_skipped' as a results name,\n        and to support having multiple skips in the same parser, the value returned is\n        a list of all skipped text.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_67__add__ = {"__add__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_67__add__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_66__add__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_67__add__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__add__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2711, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2711, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, 1); __PYX_ERR(0, 2711, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__add__") < 0)) __PYX_ERR(0, 2711, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2711, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_66__add__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_66__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__add__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2738
 *         a list of all skipped text.
 *         """
 *         if other is Ellipsis:             # <<<<<<<<<<<<<<
 *             return _PendingSkip(self)
 * 
 */
  __pyx_t_1 = (__pyx_v_other == __pyx_builtin_Ellipsis);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2739
 *         """
 *         if other is Ellipsis:
 *             return _PendingSkip(self)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(other, basestring):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PendingSkip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2739, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2739, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2738
 *         a list of all skipped text.
 *         """
 *         if other is Ellipsis:             # <<<<<<<<<<<<<<
 *             return _PendingSkip(self)
 * 
 */
  }

  /* "cPyparsing.pyx":2741
 *             return _PendingSkip(self)
 * 
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_basestring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_other, __pyx_t_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 2741, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2742
 * 
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2742, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2741
 *             return _PendingSkip(self)
 * 
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2743
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_other, __pyx_t_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 2743, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (!__pyx_t_1);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":2744
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "cPyparsing.pyx":2745
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return And([self, other])
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 2744, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2744, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2745, __pyx_L1_error)

    /* "cPyparsing.pyx":2744
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2746
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return And([self, other])
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2743
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2747
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return And([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __radd__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_And); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyList_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_self)) __PYX_ERR(0, 2747, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 1, __pyx_v_other)) __PYX_ERR(0, 2747, __pyx_L1_error);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2711
 *         yield instring[last:]
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator - returns :class:`And`. Adding strings to a ParserElement
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2749
 *         return And([self, other])
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator when left operand is not a :class:`ParserElement`
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_69__radd__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_68__radd__, "ParserElement.__radd__(self, other)\n\n        Implementation of + operator when left operand is not a :class:`ParserElement`\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_69__radd__ = {"__radd__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_69__radd__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_68__radd__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_69__radd__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__radd__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2749, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2749, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__radd__", 1, 2, 2, 1); __PYX_ERR(0, 2749, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__radd__") < 0)) __PYX_ERR(0, 2749, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__radd__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2749, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_68__radd__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_68__radd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__radd__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2753
 *         Implementation of + operator when left operand is not a :class:`ParserElement`
 *         """
 *         if other is Ellipsis:             # <<<<<<<<<<<<<<
 *             return SkipTo(self)("_skipped*") + self
 * 
 */
  __pyx_t_1 = (__pyx_v_other == __pyx_builtin_Ellipsis);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2754
 *         """
 *         if other is Ellipsis:
 *             return SkipTo(self)("_skipped*") + self             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(other, basestring):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_SkipTo); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_self};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2754, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_skipped};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2754, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2753
 *         Implementation of + operator when left operand is not a :class:`ParserElement`
 *         """
 *         if other is Ellipsis:             # <<<<<<<<<<<<<<
 *             return SkipTo(self)("_skipped*") + self
 * 
 */
  }

  /* "cPyparsing.pyx":2756
 *             return SkipTo(self)("_skipped*") + self
 * 
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_basestring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_other, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 2756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2757
 * 
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2756
 *             return SkipTo(self)("_skipped*") + self
 * 
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2758
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_other, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 2758, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = (!__pyx_t_1);
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":2759
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_warnings); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_warn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "cPyparsing.pyx":2760
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other + self
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(0, 2759, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2759, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2760, __pyx_L1_error)

    /* "cPyparsing.pyx":2759
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":2761
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other + self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2758
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2762
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other + self             # <<<<<<<<<<<<<<
 * 
 *     def __sub__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyNumber_Add(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2749
 *         return And([self, other])
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator when left operand is not a :class:`ParserElement`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2764
 *         return other + self
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator, returns :class:`And` with error stop
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_71__sub__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_70__sub__, "ParserElement.__sub__(self, other)\n\n        Implementation of - operator, returns :class:`And` with error stop\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_71__sub__ = {"__sub__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_71__sub__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_70__sub__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_71__sub__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__sub__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2764, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2764, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__sub__", 1, 2, 2, 1); __PYX_ERR(0, 2764, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__sub__") < 0)) __PYX_ERR(0, 2764, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__sub__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2764, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__sub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_70__sub__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_70__sub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__sub__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2768
 *         Implementation of - operator, returns :class:`And` with error stop
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2768, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2769
 *         """
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2769, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2768
 *         Implementation of - operator, returns :class:`And` with error stop
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2770
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_2);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":2771
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":2772
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return self + And._ErrorStop() + other
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 2771, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2771, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2772, __pyx_L1_error)

    /* "cPyparsing.pyx":2771
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2773
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return self + And._ErrorStop() + other
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2770
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2774
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return self + And._ErrorStop() + other             # <<<<<<<<<<<<<<
 * 
 *     def __rsub__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_And); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ErrorStop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2774, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = PyNumber_Add(__pyx_v_self, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_4, __pyx_v_other); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2764
 *         return other + self
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator, returns :class:`And` with error stop
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__sub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2776
 *         return self + And._ErrorStop() + other
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator when left operand is not a :class:`ParserElement`
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_73__rsub__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_72__rsub__, "ParserElement.__rsub__(self, other)\n\n        Implementation of - operator when left operand is not a :class:`ParserElement`\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_73__rsub__ = {"__rsub__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_73__rsub__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_72__rsub__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_73__rsub__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rsub__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2776, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2776, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__rsub__", 1, 2, 2, 1); __PYX_ERR(0, 2776, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__rsub__") < 0)) __PYX_ERR(0, 2776, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rsub__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2776, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rsub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_72__rsub__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_72__rsub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rsub__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2780
 *         Implementation of - operator when left operand is not a :class:`ParserElement`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2780, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2781
 *         """
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2781, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2781, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2780
 *         Implementation of - operator when left operand is not a :class:`ParserElement`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2782
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2782, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_2);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":2783
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":2784
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other - self
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 2783, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2783, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2784, __pyx_L1_error)

    /* "cPyparsing.pyx":2783
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2785
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other - self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2782
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2786
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other - self             # <<<<<<<<<<<<<<
 * 
 *     def __mul__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = PyNumber_Subtract(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2776
 *         return self + And._ErrorStop() + other
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator when left operand is not a :class:`ParserElement`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rsub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2788
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of ``expr * 3`` in place of
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_75__mul__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_74__mul__, "ParserElement.__mul__(self, other)\n\n        Implementation of * operator, allows use of ``expr * 3`` in place of\n        ``expr + expr + expr``.  Expressions may also me multiplied by a 2-integer\n        tuple, similar to ``{min, max}`` multipliers in regular expressions.  Tuples\n        may also include ``None`` as in:\n         - ``expr*(n, None)`` or ``expr*(n, )`` is equivalent\n              to ``expr*n + ZeroOrMore(expr)``\n              (read as \"at least n instances of ``expr``\")\n         - ``expr*(None, n)`` is equivalent to ``expr*(0, n)``\n              (read as \"0 to n instances of ``expr``\")\n         - ``expr*(None, None)`` is equivalent to ``ZeroOrMore(expr)``\n         - ``expr*(1, None)`` is equivalent to ``OneOrMore(expr)``\n\n        Note that ``expr*(None, n)`` does not raise an exception if\n        more than n exprs exist in the input stream; that is,\n        ``expr*(None, n)`` does not enforce a maximum number of expr\n        occurrences.  If this behavior is desired, then write\n        ``expr*(None, n) + ~expr``\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_75__mul__ = {"__mul__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_75__mul__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_74__mul__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_75__mul__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__mul__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2788, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2788, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__mul__", 1, 2, 2, 1); __PYX_ERR(0, 2788, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__mul__") < 0)) __PYX_ERR(0, 2788, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__mul__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2788, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_74__mul__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2843
 * 
 *         if optElements:
 *             def makeOptionalList(n):             # <<<<<<<<<<<<<<
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_7__mul___1makeOptionalList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_7__mul___1makeOptionalList = {"makeOptionalList", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_7__mul___1makeOptionalList, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_7__mul___1makeOptionalList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_n = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makeOptionalList (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2843, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "makeOptionalList") < 0)) __PYX_ERR(0, 2843, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_n = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("makeOptionalList", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2843, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__mul__.makeOptionalList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_self, __pyx_v_n);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(PyObject *__pyx_self, PyObject *__pyx_v_n) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("makeOptionalList", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":2844
 *         if optElements:
 *             def makeOptionalList(n):
 *                 if n > 1:             # <<<<<<<<<<<<<<
 *                     return Optional(self + makeOptionalList(n - 1))
 *                 else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_n, __pyx_int_1, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2844, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2844, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2845
 *             def makeOptionalList(n):
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))             # <<<<<<<<<<<<<<
 *                 else:
 *                     return Optional(self)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Optional); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 2845, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_n, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(!__pyx_cur_scope->__pyx_v_makeOptionalList)) { __Pyx_RaiseClosureNameError("makeOptionalList"); __PYX_ERR(0, 2845, __pyx_L1_error) }
    __pyx_t_5 = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_cur_scope->__pyx_v_makeOptionalList, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_cur_scope->__pyx_v_self, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2845, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2844
 *         if optElements:
 *             def makeOptionalList(n):
 *                 if n > 1:             # <<<<<<<<<<<<<<
 *                     return Optional(self + makeOptionalList(n - 1))
 *                 else:
 */
  }

  /* "cPyparsing.pyx":2847
 *                     return Optional(self + makeOptionalList(n - 1))
 *                 else:
 *                     return Optional(self)             # <<<<<<<<<<<<<<
 *             if minElements:
 *                 if minElements == 1:
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Optional); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2847, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 2847, __pyx_L1_error) }
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_cur_scope->__pyx_v_self};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2847, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2843
 * 
 *         if optElements:
 *             def makeOptionalList(n):             # <<<<<<<<<<<<<<
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__mul__.makeOptionalList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_13ParserElement_7__mul___4generator15(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":2816
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):
 *             other = tuple(o if o is not Ellipsis else None for o in other)             # <<<<<<<<<<<<<<
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:
 */

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_7__mul___2genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_22_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2816, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_13ParserElement_7__mul___4generator15, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParserElement___mul___locals_gen, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 2816, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__mul__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_13ParserElement_7__mul___4generator15(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2816, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 2816, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2816, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2816, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2816, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 2816, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2816, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2816, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 2816, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2816, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2816, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_o);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_o, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_5 = (__pyx_cur_scope->__pyx_v_o != __pyx_builtin_Ellipsis);
    if (__pyx_t_5) {
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_o);
      __pyx_t_4 = __pyx_cur_scope->__pyx_v_o;
    } else {
      __Pyx_INCREF(Py_None);
      __pyx_t_4 = Py_None;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2816, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2788
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of ``expr * 3`` in place of
 */

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_74__mul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *__pyx_cur_scope;
  PyObject *__pyx_v_minElements = NULL;
  PyObject *__pyx_v_optElements = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_gb_10cPyparsing_13ParserElement_7__mul___4generator15 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__mul__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_21___mul__(__pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2788, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2808
 *         ``expr*(None, n) + ~expr``
 *         """
 *         if other is Ellipsis:             # <<<<<<<<<<<<<<
 *             other = (0, None)
 *         elif isinstance(other, tuple) and other[:1] == (Ellipsis,):
 */
  __pyx_t_1 = (__pyx_v_other == __pyx_builtin_Ellipsis);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2809
 *         """
 *         if other is Ellipsis:
 *             other = (0, None)             # <<<<<<<<<<<<<<
 *         elif isinstance(other, tuple) and other[:1] == (Ellipsis,):
 *             other = ((0, ) + other[1:] + (None,))[:2]
 */
    __Pyx_INCREF(__pyx_tuple__54);
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_tuple__54);

    /* "cPyparsing.pyx":2808
 *         ``expr*(None, n) + ~expr``
 *         """
 *         if other is Ellipsis:             # <<<<<<<<<<<<<<
 *             other = (0, None)
 *         elif isinstance(other, tuple) and other[:1] == (Ellipsis,):
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":2810
 *         if other is Ellipsis:
 *             other = (0, None)
 *         elif isinstance(other, tuple) and other[:1] == (Ellipsis,):             # <<<<<<<<<<<<<<
 *             other = ((0, ) + other[1:] + (None,))[:2]
 * 
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_other); 
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_other, 0, 1, NULL, NULL, &__pyx_slice__55, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_tuple__56, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2811
 *             other = (0, None)
 *         elif isinstance(other, tuple) and other[:1] == (Ellipsis,):
 *             other = ((0, ) + other[1:] + (None,))[:2]             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(other, int):
 */
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_other, 1, 0, NULL, NULL, &__pyx_slice_, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Add(__pyx_tuple__41, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_tuple__57); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 2, NULL, NULL, &__pyx_slice__37, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2810
 *         if other is Ellipsis:
 *             other = (0, None)
 *         elif isinstance(other, tuple) and other[:1] == (Ellipsis,):             # <<<<<<<<<<<<<<
 *             other = ((0, ) + other[1:] + (None,))[:2]
 * 
 */
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":2813
 *             other = ((0, ) + other[1:] + (None,))[:2]
 * 
 *         if isinstance(other, int):             # <<<<<<<<<<<<<<
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):
 */
  __pyx_t_1 = PyInt_Check(__pyx_v_other); 
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2814
 * 
 *         if isinstance(other, int):
 *             minElements, optElements = other, 0             # <<<<<<<<<<<<<<
 *         elif isinstance(other, tuple):
 *             other = tuple(o if o is not Ellipsis else None for o in other)
 */
    __pyx_t_3 = __pyx_v_other;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = __pyx_int_0;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_v_minElements = __pyx_t_3;
    __pyx_t_3 = 0;
    __pyx_v_optElements = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2813
 *             other = ((0, ) + other[1:] + (None,))[:2]
 * 
 *         if isinstance(other, int):             # <<<<<<<<<<<<<<
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):
 */
    goto __pyx_L6;
  }

  /* "cPyparsing.pyx":2815
 *         if isinstance(other, int):
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):             # <<<<<<<<<<<<<<
 *             other = tuple(o if o is not Ellipsis else None for o in other)
 *             other = (other + (None, None))[:2]
 */
  __pyx_t_1 = PyTuple_Check(__pyx_v_other); 
  if (likely(__pyx_t_1)) {

    /* "cPyparsing.pyx":2816
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):
 *             other = tuple(o if o is not Ellipsis else None for o in other)             # <<<<<<<<<<<<<<
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:
 */
    __pyx_t_4 = __pyx_pf_10cPyparsing_13ParserElement_7__mul___2genexpr(NULL, __pyx_v_other); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2816, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2816, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2817
 *         elif isinstance(other, tuple):
 *             other = tuple(o if o is not Ellipsis else None for o in other)
 *             other = (other + (None, None))[:2]             # <<<<<<<<<<<<<<
 *             if other[0] is None:
 *                 other = (0, other[1])
 */
    __pyx_t_3 = PyNumber_Add(__pyx_v_other, __pyx_tuple__58); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_3, 0, 2, NULL, NULL, &__pyx_slice__37, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2818
 *             other = tuple(o if o is not Ellipsis else None for o in other)
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:             # <<<<<<<<<<<<<<
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:
 */
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2818, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = (__pyx_t_4 == Py_None);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":2819
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:
 *                 other = (0, other[1])             # <<<<<<<<<<<<<<
 *             if isinstance(other[0], int) and other[1] is None:
 *                 if other[0] == 0:
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_other, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_int_0)) __PYX_ERR(0, 2819, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4)) __PYX_ERR(0, 2819, __pyx_L1_error);
      __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2818
 *             other = tuple(o if o is not Ellipsis else None for o in other)
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:             # <<<<<<<<<<<<<<
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:
 */
    }

    /* "cPyparsing.pyx":2820
 *             if other[0] is None:
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:             # <<<<<<<<<<<<<<
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyInt_Check(__pyx_t_3); 
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_other, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = (__pyx_t_3 == Py_None);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_2;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":2821
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:
 *                 if other[0] == 0:             # <<<<<<<<<<<<<<
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2821, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2821, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_1) {

        /* "cPyparsing.pyx":2822
 *             if isinstance(other[0], int) and other[1] is None:
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)             # <<<<<<<<<<<<<<
 *                 if other[0] == 1:
 *                     return OneOrMore(self)
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_self};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2822, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "cPyparsing.pyx":2821
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:
 *                 if other[0] == 0:             # <<<<<<<<<<<<<<
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:
 */
      }

      /* "cPyparsing.pyx":2823
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:             # <<<<<<<<<<<<<<
 *                     return OneOrMore(self)
 *                 else:
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2823, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2823, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_1) {

        /* "cPyparsing.pyx":2824
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:
 *                     return OneOrMore(self)             # <<<<<<<<<<<<<<
 *                 else:
 *                     return self * other[0] + ZeroOrMore(self)
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_self};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2824, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "cPyparsing.pyx":2823
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:             # <<<<<<<<<<<<<<
 *                     return OneOrMore(self)
 *                 else:
 */
      }

      /* "cPyparsing.pyx":2826
 *                     return OneOrMore(self)
 *                 else:
 *                     return self * other[0] + ZeroOrMore(self)             # <<<<<<<<<<<<<<
 *             elif isinstance(other[0], int) and isinstance(other[1], int):
 *                 minElements, optElements = other
 */
      /*else*/ {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyNumber_Multiply(__pyx_cur_scope->__pyx_v_self, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_self};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2826, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_5;
        __pyx_t_5 = 0;
        goto __pyx_L0;
      }

      /* "cPyparsing.pyx":2820
 *             if other[0] is None:
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:             # <<<<<<<<<<<<<<
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)
 */
    }

    /* "cPyparsing.pyx":2827
 *                 else:
 *                     return self * other[0] + ZeroOrMore(self)
 *             elif isinstance(other[0], int) and isinstance(other[1], int):             # <<<<<<<<<<<<<<
 *                 minElements, optElements = other
 *                 optElements -= minElements
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyInt_Check(__pyx_t_5); 
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_other, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyInt_Check(__pyx_t_5); 
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = __pyx_t_2;
    __pyx_L13_bool_binop_done:;
    if (likely(__pyx_t_1)) {

      /* "cPyparsing.pyx":2828
 *                     return self * other[0] + ZeroOrMore(self)
 *             elif isinstance(other[0], int) and isinstance(other[1], int):
 *                 minElements, optElements = other             # <<<<<<<<<<<<<<
 *                 optElements -= minElements
 *             else:
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_other))) || (PyList_CheckExact(__pyx_v_other))) {
        PyObject* sequence = __pyx_v_other;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 2828, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_3);
        #else
        __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2828, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2828, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_4 = PyObject_GetIter(__pyx_v_other); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2828, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
        index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_5)) goto __pyx_L15_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 1; __pyx_t_3 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L15_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_4), 2) < 0) __PYX_ERR(0, 2828, __pyx_L1_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L16_unpacking_done;
        __pyx_L15_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 2828, __pyx_L1_error)
        __pyx_L16_unpacking_done:;
      }
      __pyx_v_minElements = __pyx_t_5;
      __pyx_t_5 = 0;
      __pyx_v_optElements = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2829
 *             elif isinstance(other[0], int) and isinstance(other[1], int):
 *                 minElements, optElements = other
 *                 optElements -= minElements             # <<<<<<<<<<<<<<
 *             else:
 *                 raise TypeError("cannot multiply 'ParserElement' and ('%s', '%s') objects", type(other[0]), type(other[1]))
 */
      __pyx_t_3 = PyNumber_InPlaceSubtract(__pyx_v_optElements, __pyx_v_minElements); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2829, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_optElements, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2827
 *                 else:
 *                     return self * other[0] + ZeroOrMore(self)
 *             elif isinstance(other[0], int) and isinstance(other[1], int):             # <<<<<<<<<<<<<<
 *                 minElements, optElements = other
 *                 optElements -= minElements
 */
      goto __pyx_L8;
    }

    /* "cPyparsing.pyx":2831
 *                 optElements -= minElements
 *             else:
 *                 raise TypeError("cannot multiply 'ParserElement' and ('%s', '%s') objects", type(other[0]), type(other[1]))             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError("cannot multiply 'ParserElement' and '%s' objects", type(other))
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_other, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_kp_u_cannot_multiply_ParserElement_an);
      __Pyx_GIVEREF(__pyx_kp_u_cannot_multiply_ParserElement_an);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u_cannot_multiply_ParserElement_an)) __PYX_ERR(0, 2831, __pyx_L1_error);
      __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_t_3)));
      __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_t_3)));
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, ((PyObject *)Py_TYPE(__pyx_t_3)))) __PYX_ERR(0, 2831, __pyx_L1_error);
      __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_t_5)));
      __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_t_5)));
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, ((PyObject *)Py_TYPE(__pyx_t_5)))) __PYX_ERR(0, 2831, __pyx_L1_error);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 2831, __pyx_L1_error)
    }
    __pyx_L8:;

    /* "cPyparsing.pyx":2815
 *         if isinstance(other, int):
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):             # <<<<<<<<<<<<<<
 *             other = tuple(o if o is not Ellipsis else None for o in other)
 *             other = (other + (None, None))[:2]
 */
    goto __pyx_L6;
  }

  /* "cPyparsing.pyx":2833
 *                 raise TypeError("cannot multiply 'ParserElement' and ('%s', '%s') objects", type(other[0]), type(other[1]))
 *         else:
 *             raise TypeError("cannot multiply 'ParserElement' and '%s' objects", type(other))             # <<<<<<<<<<<<<<
 * 
 *         if minElements < 0:
 */
  /*else*/ {
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_u_cannot_multiply_ParserElement_an_2);
    __Pyx_GIVEREF(__pyx_kp_u_cannot_multiply_ParserElement_an_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_cannot_multiply_ParserElement_an_2)) __PYX_ERR(0, 2833, __pyx_L1_error);
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_other)));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_v_other)));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)Py_TYPE(__pyx_v_other)))) __PYX_ERR(0, 2833, __pyx_L1_error);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 2833, __pyx_L1_error)
  }
  __pyx_L6:;

  /* "cPyparsing.pyx":2835
 *             raise TypeError("cannot multiply 'ParserElement' and '%s' objects", type(other))
 * 
 *         if minElements < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_minElements, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2835, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2835, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(__pyx_t_1)) {

    /* "cPyparsing.pyx":2836
 * 
 *         if minElements < 0:
 *             raise ValueError("cannot multiply ParserElement by negative value")             # <<<<<<<<<<<<<<
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 2836, __pyx_L1_error)

    /* "cPyparsing.pyx":2835
 *             raise TypeError("cannot multiply 'ParserElement' and '%s' objects", type(other))
 * 
 *         if minElements < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:
 */
  }

  /* "cPyparsing.pyx":2837
 *         if minElements < 0:
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_optElements, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2837, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2837, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(__pyx_t_1)) {

    /* "cPyparsing.pyx":2838
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")             # <<<<<<<<<<<<<<
 *         if minElements == optElements == 0:
 *             raise ValueError("cannot multiply ParserElement by 0 or (0, 0)")
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__60, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2838, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 2838, __pyx_L1_error)

    /* "cPyparsing.pyx":2837
 *         if minElements < 0:
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:
 */
  }

  /* "cPyparsing.pyx":2839
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot multiply ParserElement by 0 or (0, 0)")
 * 
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_minElements, __pyx_v_optElements, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2839, __pyx_L1_error)
  if (__Pyx_PyObject_IsTrue(__pyx_t_4)) {
    __Pyx_DECREF(__pyx_t_4);
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_optElements, __pyx_int_0, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2839, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(__pyx_t_1)) {

    /* "cPyparsing.pyx":2840
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:
 *             raise ValueError("cannot multiply ParserElement by 0 or (0, 0)")             # <<<<<<<<<<<<<<
 * 
 *         if optElements:
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__61, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2840, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 2840, __pyx_L1_error)

    /* "cPyparsing.pyx":2839
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot multiply ParserElement by 0 or (0, 0)")
 * 
 */
  }

  /* "cPyparsing.pyx":2842
 *             raise ValueError("cannot multiply ParserElement by 0 or (0, 0)")
 * 
 *         if optElements:             # <<<<<<<<<<<<<<
 *             def makeOptionalList(n):
 *                 if n > 1:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_optElements); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2842, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2843
 * 
 *         if optElements:
 *             def makeOptionalList(n):             # <<<<<<<<<<<<<<
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))
 */
    __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_7__mul___1makeOptionalList, 0, __pyx_n_s_ParserElement___mul___locals_mak, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_cur_scope->__pyx_v_makeOptionalList = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2848
 *                 else:
 *                     return Optional(self)
 *             if minElements:             # <<<<<<<<<<<<<<
 *                 if minElements == 1:
 *                     ret = self + makeOptionalList(optElements)
 */
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_minElements); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2848, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":2849
 *                     return Optional(self)
 *             if minElements:
 *                 if minElements == 1:             # <<<<<<<<<<<<<<
 *                     ret = self + makeOptionalList(optElements)
 *                 else:
 */
      __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_minElements, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2849, __pyx_L1_error)
      if (__pyx_t_1) {

        /* "cPyparsing.pyx":2850
 *             if minElements:
 *                 if minElements == 1:
 *                     ret = self + makeOptionalList(optElements)             # <<<<<<<<<<<<<<
 *                 else:
 *                     ret = And([self] * minElements) + makeOptionalList(optElements)
 */
        __pyx_t_4 = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_cur_scope->__pyx_v_makeOptionalList, __pyx_v_optElements); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2850, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyNumber_Add(__pyx_cur_scope->__pyx_v_self, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2850, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_v_ret = __pyx_t_5;
        __pyx_t_5 = 0;

        /* "cPyparsing.pyx":2849
 *                     return Optional(self)
 *             if minElements:
 *                 if minElements == 1:             # <<<<<<<<<<<<<<
 *                     ret = self + makeOptionalList(optElements)
 *                 else:
 */
        goto __pyx_L22;
      }

      /* "cPyparsing.pyx":2852
 *                     ret = self + makeOptionalList(optElements)
 *                 else:
 *                     ret = And([self] * minElements) + makeOptionalList(optElements)             # <<<<<<<<<<<<<<
 *             else:
 *                 ret = makeOptionalList(optElements)
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_And); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2852, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2852, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_cur_scope->__pyx_v_self)) __PYX_ERR(0, 2852, __pyx_L1_error);
        { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_3, __pyx_v_minElements); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 2852, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_temp);
          __Pyx_DECREF(__pyx_t_3);
          __pyx_t_3 = __pyx_temp;
        }
        __pyx_t_7 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2852, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_t_4 = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_cur_scope->__pyx_v_makeOptionalList, __pyx_v_optElements); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2852, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = PyNumber_Add(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2852, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_v_ret = __pyx_t_3;
        __pyx_t_3 = 0;
      }
      __pyx_L22:;

      /* "cPyparsing.pyx":2848
 *                 else:
 *                     return Optional(self)
 *             if minElements:             # <<<<<<<<<<<<<<
 *                 if minElements == 1:
 *                     ret = self + makeOptionalList(optElements)
 */
      goto __pyx_L21;
    }

    /* "cPyparsing.pyx":2854
 *                     ret = And([self] * minElements) + makeOptionalList(optElements)
 *             else:
 *                 ret = makeOptionalList(optElements)             # <<<<<<<<<<<<<<
 *         else:
 *             if minElements == 1:
 */
    /*else*/ {
      __pyx_t_3 = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_cur_scope->__pyx_v_makeOptionalList, __pyx_v_optElements); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_ret = __pyx_t_3;
      __pyx_t_3 = 0;
    }
    __pyx_L21:;

    /* "cPyparsing.pyx":2842
 *             raise ValueError("cannot multiply ParserElement by 0 or (0, 0)")
 * 
 *         if optElements:             # <<<<<<<<<<<<<<
 *             def makeOptionalList(n):
 *                 if n > 1:
 */
    goto __pyx_L20;
  }

  /* "cPyparsing.pyx":2856
 *                 ret = makeOptionalList(optElements)
 *         else:
 *             if minElements == 1:             # <<<<<<<<<<<<<<
 *                 ret = self
 *             else:
 */
  /*else*/ {
    __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_minElements, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2856, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":2857
 *         else:
 *             if minElements == 1:
 *                 ret = self             # <<<<<<<<<<<<<<
 *             else:
 *                 ret = And([self] * minElements)
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
      __pyx_v_ret = __pyx_cur_scope->__pyx_v_self;

      /* "cPyparsing.pyx":2856
 *                 ret = makeOptionalList(optElements)
 *         else:
 *             if minElements == 1:             # <<<<<<<<<<<<<<
 *                 ret = self
 *             else:
 */
      goto __pyx_L23;
    }

    /* "cPyparsing.pyx":2859
 *                 ret = self
 *             else:
 *                 ret = And([self] * minElements)             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_And); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 0, __pyx_cur_scope->__pyx_v_self)) __PYX_ERR(0, 2859, __pyx_L1_error);
      { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_5, __pyx_v_minElements); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 2859, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_temp);
        __Pyx_DECREF(__pyx_t_5);
        __pyx_t_5 = __pyx_temp;
      }
      __pyx_t_7 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2859, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_v_ret = __pyx_t_3;
      __pyx_t_3 = 0;
    }
    __pyx_L23:;
  }
  __pyx_L20:;

  /* "cPyparsing.pyx":2860
 *             else:
 *                 ret = And([self] * minElements)
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def __rmul__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2788
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of ``expr * 3`` in place of
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_minElements);
  __Pyx_XDECREF(__pyx_v_optElements);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_13ParserElement_7__mul___4generator15);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2862
 *         return ret
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_77__rmul__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_76__rmul__, "ParserElement.__rmul__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_77__rmul__ = {"__rmul__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_77__rmul__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_76__rmul__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_77__rmul__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rmul__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2862, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2862, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__rmul__", 1, 2, 2, 1); __PYX_ERR(0, 2862, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__rmul__") < 0)) __PYX_ERR(0, 2862, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rmul__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2862, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rmul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_76__rmul__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_76__rmul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rmul__", 1);

  /* "cPyparsing.pyx":2863
 * 
 *     def __rmul__(self, other):
 *         return self.__mul__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __or__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mul); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2862
 *         return ret
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rmul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2865
 *         return self.__mul__(other)
 * 
 *     def __or__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator - returns :class:`MatchFirst`
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_79__or__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_78__or__, "ParserElement.__or__(self, other)\n\n        Implementation of | operator - returns :class:`MatchFirst`\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_79__or__ = {"__or__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_79__or__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_78__or__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_79__or__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__or__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2865, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2865, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__or__", 1, 2, 2, 1); __PYX_ERR(0, 2865, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__or__") < 0)) __PYX_ERR(0, 2865, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__or__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2865, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__or__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_78__or__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_78__or__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__or__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2869
 *         Implementation of | operator - returns :class:`MatchFirst`
 *         """
 *         if other is Ellipsis:             # <<<<<<<<<<<<<<
 *             return _PendingSkip(self, must_skip=True)
 * 
 */
  __pyx_t_1 = (__pyx_v_other == __pyx_builtin_Ellipsis);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2870
 *         """
 *         if other is Ellipsis:
 *             return _PendingSkip(self, must_skip=True)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(other, basestring):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PendingSkip); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self)) __PYX_ERR(0, 2870, __pyx_L1_error);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_must_skip, Py_True) < 0) __PYX_ERR(0, 2870, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2869
 *         Implementation of | operator - returns :class:`MatchFirst`
 *         """
 *         if other is Ellipsis:             # <<<<<<<<<<<<<<
 *             return _PendingSkip(self, must_skip=True)
 * 
 */
  }

  /* "cPyparsing.pyx":2872
 *             return _PendingSkip(self, must_skip=True)
 * 
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_basestring); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_other, __pyx_t_5); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 2872, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2873
 * 
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2873, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":2872
 *             return _PendingSkip(self, must_skip=True)
 * 
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2874
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_other, __pyx_t_5); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 2874, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = (!__pyx_t_1);
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":2875
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_warnings); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_warn); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "cPyparsing.pyx":2876
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return MatchFirst([self, other])
 */
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5)) __PYX_ERR(0, 2875, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2875, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2876, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2876, __pyx_L1_error)

    /* "cPyparsing.pyx":2875
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2877
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return MatchFirst([self, other])
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2874
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2878
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return MatchFirst([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __ror__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_MatchFirst); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_self)) __PYX_ERR(0, 2878, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_v_other)) __PYX_ERR(0, 2878, __pyx_L1_error);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2878, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2865
 *         return self.__mul__(other)
 * 
 *     def __or__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator - returns :class:`MatchFirst`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__or__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2880
 *         return MatchFirst([self, other])
 * 
 *     def __ror__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator when left operand is not a :class:`ParserElement`
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_81__ror__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_80__ror__, "ParserElement.__ror__(self, other)\n\n        Implementation of | operator when left operand is not a :class:`ParserElement`\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_81__ror__ = {"__ror__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_81__ror__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_80__ror__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_81__ror__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ror__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2880, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2880, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__ror__", 1, 2, 2, 1); __PYX_ERR(0, 2880, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__ror__") < 0)) __PYX_ERR(0, 2880, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ror__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2880, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__ror__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_80__ror__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_80__ror__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ror__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2884
 *         Implementation of | operator when left operand is not a :class:`ParserElement`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2884, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2885
 *         """
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2884
 *         Implementation of | operator when left operand is not a :class:`ParserElement`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2886
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_2);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":2887
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":2888
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other | self
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 2887, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2887, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2888, __pyx_L1_error)

    /* "cPyparsing.pyx":2887
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2889
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other | self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2886
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2890
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other | self             # <<<<<<<<<<<<<<
 * 
 *     def __xor__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = PyNumber_Or(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2880
 *         return MatchFirst([self, other])
 * 
 *     def __ror__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator when left operand is not a :class:`ParserElement`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__ror__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2892
 *         return other | self
 * 
 *     def __xor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator - returns :class:`Or`
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_83__xor__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_82__xor__, "ParserElement.__xor__(self, other)\n\n        Implementation of ^ operator - returns :class:`Or`\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_83__xor__ = {"__xor__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_83__xor__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_82__xor__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_83__xor__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__xor__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2892, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2892, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__xor__", 1, 2, 2, 1); __PYX_ERR(0, 2892, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__xor__") < 0)) __PYX_ERR(0, 2892, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__xor__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2892, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__xor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_82__xor__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_82__xor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__xor__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2896
 *         Implementation of ^ operator - returns :class:`Or`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2896, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2897
 *         """
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2896
 *         Implementation of ^ operator - returns :class:`Or`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2898
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_2);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":2899
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":2900
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return Or([self, other])
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 2899, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2899, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2900, __pyx_L1_error)

    /* "cPyparsing.pyx":2899
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2901
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return Or([self, other])
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2898
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2902
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return Or([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __rxor__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Or); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyList_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_self)) __PYX_ERR(0, 2902, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 1, __pyx_v_other)) __PYX_ERR(0, 2902, __pyx_L1_error);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2902, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2892
 *         return other | self
 * 
 *     def __xor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator - returns :class:`Or`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__xor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2904
 *         return Or([self, other])
 * 
 *     def __rxor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator when left operand is not a :class:`ParserElement`
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_85__rxor__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_84__rxor__, "ParserElement.__rxor__(self, other)\n\n        Implementation of ^ operator when left operand is not a :class:`ParserElement`\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_85__rxor__ = {"__rxor__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_85__rxor__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_84__rxor__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_85__rxor__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rxor__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2904, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2904, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__rxor__", 1, 2, 2, 1); __PYX_ERR(0, 2904, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__rxor__") < 0)) __PYX_ERR(0, 2904, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rxor__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2904, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rxor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_84__rxor__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_84__rxor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rxor__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2908
 *         Implementation of ^ operator when left operand is not a :class:`ParserElement`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2908, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2909
 *         """
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2908
 *         Implementation of ^ operator when left operand is not a :class:`ParserElement`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2910
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2910, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_2);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":2911
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":2912
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other ^ self
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 2911, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2911, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2912, __pyx_L1_error)

    /* "cPyparsing.pyx":2911
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2913
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other ^ self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2910
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2914
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other ^ self             # <<<<<<<<<<<<<<
 * 
 *     def __and__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = PyNumber_Xor(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2904
 *         return Or([self, other])
 * 
 *     def __rxor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator when left operand is not a :class:`ParserElement`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rxor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2916
 *         return other ^ self
 * 
 *     def __and__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator - returns :class:`Each`
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_87__and__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_86__and__, "ParserElement.__and__(self, other)\n\n        Implementation of & operator - returns :class:`Each`\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_87__and__ = {"__and__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_87__and__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_86__and__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_87__and__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__and__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2916, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2916, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__and__", 1, 2, 2, 1); __PYX_ERR(0, 2916, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__and__") < 0)) __PYX_ERR(0, 2916, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__and__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2916, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__and__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_86__and__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_86__and__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__and__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2920
 *         Implementation of & operator - returns :class:`Each`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2920, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2921
 *         """
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2921, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2921, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2920
 *         Implementation of & operator - returns :class:`Each`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2922
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2922, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_2);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":2923
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":2924
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return Each([self, other])
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 2923, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2923, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2924, __pyx_L1_error)

    /* "cPyparsing.pyx":2923
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2925
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return Each([self, other])
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2922
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2926
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return Each([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __rand__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Each); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyList_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_self)) __PYX_ERR(0, 2926, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 1, __pyx_v_other)) __PYX_ERR(0, 2926, __pyx_L1_error);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2916
 *         return other ^ self
 * 
 *     def __and__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator - returns :class:`Each`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__and__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2928
 *         return Each([self, other])
 * 
 *     def __rand__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator when left operand is not a :class:`ParserElement`
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_89__rand__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_88__rand__, "ParserElement.__rand__(self, other)\n\n        Implementation of & operator when left operand is not a :class:`ParserElement`\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_89__rand__ = {"__rand__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_89__rand__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_88__rand__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_89__rand__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rand__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2928, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2928, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__rand__", 1, 2, 2, 1); __PYX_ERR(0, 2928, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__rand__") < 0)) __PYX_ERR(0, 2928, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rand__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2928, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rand__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_88__rand__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_88__rand__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rand__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2932
 *         Implementation of & operator when left operand is not a :class:`ParserElement`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2933
 *         """
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2933, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2933, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2932
 *         Implementation of & operator when left operand is not a :class:`ParserElement`
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2934
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_2);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":2935
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":2936
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other & self
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 2935, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 2935, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2936, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2936, __pyx_L1_error)

    /* "cPyparsing.pyx":2935
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":2937
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other & self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":2934
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2938
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other & self             # <<<<<<<<<<<<<<
 * 
 *     def __invert__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = PyNumber_And(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2928
 *         return Each([self, other])
 * 
 *     def __rand__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator when left operand is not a :class:`ParserElement`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rand__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2940
 *         return other & self
 * 
 *     def __invert__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ~ operator - returns :class:`NotAny`
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_91__invert__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_90__invert__, "ParserElement.__invert__(self)\n\n        Implementation of ~ operator - returns :class:`NotAny`\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_91__invert__ = {"__invert__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_91__invert__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_90__invert__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_91__invert__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__invert__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2940, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__invert__") < 0)) __PYX_ERR(0, 2940, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__invert__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2940, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__invert__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_90__invert__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_90__invert__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__invert__", 1);

  /* "cPyparsing.pyx":2944
 *         Implementation of ~ operator - returns :class:`NotAny`
 *         """
 *         return NotAny(self)             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_NotAny); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2940
 *         return other & self
 * 
 *     def __invert__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ~ operator - returns :class:`NotAny`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__invert__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2946
 *         return NotAny(self)
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         # must implement __iter__ to override legacy use of sequential access to __getitem__ to
 *         # iterate over a sequence
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_93__iter__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_92__iter__, "ParserElement.__iter__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_93__iter__ = {"__iter__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_93__iter__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_92__iter__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_93__iter__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2946, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__iter__") < 0)) __PYX_ERR(0, 2946, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__iter__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2946, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_92__iter__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_92__iter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iter__", 1);

  /* "cPyparsing.pyx":2949
 *         # must implement __iter__ to override legacy use of sequential access to __getitem__ to
 *         # iterate over a sequence
 *         raise TypeError('%r object is not iterable' % self.__class__.__name__)             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, key):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_r_object_is_not_iterable, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(0, 2949, __pyx_L1_error)

  /* "cPyparsing.pyx":2946
 *         return NotAny(self)
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         # must implement __iter__ to override legacy use of sequential access to __getitem__ to
 *         # iterate over a sequence
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2951
 *         raise TypeError('%r object is not iterable' % self.__class__.__name__)
 * 
 *     def __getitem__(self, key):             # <<<<<<<<<<<<<<
 *         """
 *         use ``[]`` indexing notation as a short form for expression repetition:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_95__getitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_94__getitem__, "ParserElement.__getitem__(self, key)\n\n        use ``[]`` indexing notation as a short form for expression repetition:\n         - ``expr[n]`` is equivalent to ``expr*n``\n         - ``expr[m, n]`` is equivalent to ``expr*(m, n)``\n         - ``expr[n, ...]`` or ``expr[n,]`` is equivalent\n              to ``expr*n + ZeroOrMore(expr)``\n              (read as \"at least n instances of ``expr``\")\n         - ``expr[..., n]`` is equivalent to ``expr*(0, n)``\n              (read as \"0 to n instances of ``expr``\")\n         - ``expr[...]`` and ``expr[0, ...]`` are equivalent to ``ZeroOrMore(expr)``\n         - ``expr[1, ...]`` is equivalent to ``OneOrMore(expr)``\n         ``None`` may be used in place of ``...``.\n\n        Note that ``expr[..., n]`` and ``expr[m, n]``do not raise an exception\n        if more than ``n`` ``expr``s exist in the input stream.  If this behavior is\n        desired, then write ``expr[..., n] + ~expr``.\n       ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_95__getitem__ = {"__getitem__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_95__getitem__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_94__getitem__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_95__getitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2951, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2951, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, 1); __PYX_ERR(0, 2951, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__getitem__") < 0)) __PYX_ERR(0, 2951, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2951, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_94__getitem__(__pyx_self, __pyx_v_self, __pyx_v_key);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_94__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);
  __Pyx_INCREF(__pyx_v_key);

  /* "cPyparsing.pyx":2971
 * 
 *         # convert single arg keys to tuples
 *         try:             # <<<<<<<<<<<<<<
 *             if isinstance(key, str):
 *                 key = (key,)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":2972
 *         # convert single arg keys to tuples
 *         try:
 *             if isinstance(key, str):             # <<<<<<<<<<<<<<
 *                 key = (key,)
 *             iter(key)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2972, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyObject_IsInstance(__pyx_v_key, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2972, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":2973
 *         try:
 *             if isinstance(key, str):
 *                 key = (key,)             # <<<<<<<<<<<<<<
 *             iter(key)
 *         except TypeError:
 */
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2973, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_v_key);
        __Pyx_GIVEREF(__pyx_v_key);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_key)) __PYX_ERR(0, 2973, __pyx_L3_error);
        __Pyx_DECREF_SET(__pyx_v_key, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":2972
 *         # convert single arg keys to tuples
 *         try:
 *             if isinstance(key, str):             # <<<<<<<<<<<<<<
 *                 key = (key,)
 *             iter(key)
 */
      }

      /* "cPyparsing.pyx":2974
 *             if isinstance(key, str):
 *                 key = (key,)
 *             iter(key)             # <<<<<<<<<<<<<<
 *         except TypeError:
 *             key = (key, key)
 */
      __pyx_t_4 = PyObject_GetIter(__pyx_v_key); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2974, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":2971
 * 
 *         # convert single arg keys to tuples
 *         try:             # <<<<<<<<<<<<<<
 *             if isinstance(key, str):
 *                 key = (key,)
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2975
 *                 key = (key,)
 *             iter(key)
 *         except TypeError:             # <<<<<<<<<<<<<<
 *             key = (key, key)
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 2975, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "cPyparsing.pyx":2976
 *             iter(key)
 *         except TypeError:
 *             key = (key, key)             # <<<<<<<<<<<<<<
 * 
 *         if len(key) > 2:
 */
      __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2976, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_v_key);
      __Pyx_GIVEREF(__pyx_v_key);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_key)) __PYX_ERR(0, 2976, __pyx_L5_except_error);
      __Pyx_INCREF(__pyx_v_key);
      __Pyx_GIVEREF(__pyx_v_key);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_key)) __PYX_ERR(0, 2976, __pyx_L5_except_error);
      __Pyx_DECREF_SET(__pyx_v_key, __pyx_t_9);
      __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":2971
 * 
 *         # convert single arg keys to tuples
 *         try:             # <<<<<<<<<<<<<<
 *             if isinstance(key, str):
 *                 key = (key,)
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "cPyparsing.pyx":2978
 *             key = (key, key)
 * 
 *         if len(key) > 2:             # <<<<<<<<<<<<<<
 *             warnings.warn("only 1 or 2 index arguments supported ({0}{1})".format(key[:5],
 *                                                                                 '... [{0}]'.format(len(key))
 */
  __pyx_t_10 = PyObject_Length(__pyx_v_key); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2978, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_10 > 2);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2979
 * 
 *         if len(key) > 2:
 *             warnings.warn("only 1 or 2 index arguments supported ({0}{1})".format(key[:5],             # <<<<<<<<<<<<<<
 *                                                                                 '... [{0}]'.format(len(key))
 *                                                                                 if len(key) > 5 else ''))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_warnings); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_warn); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_only_1_or_2_index_arguments_supp, __pyx_n_s_format); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11 = __Pyx_PyObject_GetSlice(__pyx_v_key, 0, 5, NULL, NULL, &__pyx_slice__64, 0, 1, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);

    /* "cPyparsing.pyx":2981
 *             warnings.warn("only 1 or 2 index arguments supported ({0}{1})".format(key[:5],
 *                                                                                 '... [{0}]'.format(len(key))
 *                                                                                 if len(key) > 5 else ''))             # <<<<<<<<<<<<<<
 * 
 *         # clip to 2 elements
 */
    __pyx_t_10 = PyObject_Length(__pyx_v_key); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2981, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_10 > 5);
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":2980
 *         if len(key) > 2:
 *             warnings.warn("only 1 or 2 index arguments supported ({0}{1})".format(key[:5],
 *                                                                                 '... [{0}]'.format(len(key))             # <<<<<<<<<<<<<<
 *                                                                                 if len(key) > 5 else ''))
 * 
 */
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_2, __pyx_n_s_format); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2980, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_10 = PyObject_Length(__pyx_v_key); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2980, __pyx_L1_error)
      __pyx_t_15 = PyInt_FromSsize_t(__pyx_t_10); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2980, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_16 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_16)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_t_15};
        __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2980, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __pyx_t_12 = __pyx_t_13;
      __pyx_t_13 = 0;
    } else {
      __Pyx_INCREF(__pyx_kp_u__10);
      __pyx_t_12 = __pyx_kp_u__10;
    }
    __pyx_t_13 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_t_11, __pyx_t_12};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_9 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_7};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2978
 *             key = (key, key)
 * 
 *         if len(key) > 2:             # <<<<<<<<<<<<<<
 *             warnings.warn("only 1 or 2 index arguments supported ({0}{1})".format(key[:5],
 *                                                                                 '... [{0}]'.format(len(key))
 */
  }

  /* "cPyparsing.pyx":2984
 * 
 *         # clip to 2 elements
 *         ret = self * tuple(key[:2])             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
  __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_v_key, 0, 2, NULL, NULL, &__pyx_slice__37, 0, 1, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_Multiply(__pyx_v_self, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_ret = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2985
 *         # clip to 2 elements
 *         ret = self * tuple(key[:2])
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, name=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2951
 *         raise TypeError('%r object is not iterable' % self.__class__.__name__)
 * 
 *     def __getitem__(self, key):             # <<<<<<<<<<<<<<
 *         """
 *         use ``[]`` indexing notation as a short form for expression repetition:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2987
 *         return ret
 * 
 *     def __call__(self, name=None):             # <<<<<<<<<<<<<<
 *         """
 *         Shortcut for :class:`setResultsName`, with ``listAllMatches=False``.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_97__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_96__call__, "ParserElement.__call__(self, name=None)\n\n        Shortcut for :class:`setResultsName`, with ``listAllMatches=False``.\n\n        If ``name`` is given with a trailing ``'*'`` character, then ``listAllMatches`` will be\n        passed as ``True``.\n\n        If ``name` is omitted, same as calling :class:`copy`.\n\n        Example::\n\n            # these are equivalent\n            userdata = Word(alphas).setResultsName(\"name\") + Word(nums + \"-\").setResultsName(\"socsecno\")\n            userdata = Word(alphas)(\"name\") + Word(nums + \"-\")(\"socsecno\")\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_97__call__ = {"__call__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_97__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_96__call__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_97__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2987, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2987, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__call__") < 0)) __PYX_ERR(0, 2987, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 2987, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_96__call__(__pyx_self, __pyx_v_self, __pyx_v_name);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_96__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 1);

  /* "cPyparsing.pyx":3002
 *             userdata = Word(alphas)("name") + Word(nums + "-")("socsecno")
 *         """
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             return self._setResultsName(name)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_name != Py_None);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3003
 *         """
 *         if name is not None:
 *             return self._setResultsName(name)             # <<<<<<<<<<<<<<
 *         else:
 *             return self.copy()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_name};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3003, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3002
 *             userdata = Word(alphas)("name") + Word(nums + "-")("socsecno")
 *         """
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             return self._setResultsName(name)
 *         else:
 */
  }

  /* "cPyparsing.pyx":3005
 *             return self._setResultsName(name)
 *         else:
 *             return self.copy()             # <<<<<<<<<<<<<<
 * 
 *     def suppress(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3005, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2987
 *         return ret
 * 
 *     def __call__(self, name=None):             # <<<<<<<<<<<<<<
 *         """
 *         Shortcut for :class:`setResultsName`, with ``listAllMatches=False``.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3007
 *             return self.copy()
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         """
 *         Suppresses the output of this :class:`ParserElement`; useful to keep punctuation from
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_99suppress(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_98suppress, "ParserElement.suppress(self)\n\n        Suppresses the output of this :class:`ParserElement`; useful to keep punctuation from\n        cluttering up returned output.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_99suppress = {"suppress", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_99suppress, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_98suppress};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_99suppress(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("suppress (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3007, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "suppress") < 0)) __PYX_ERR(0, 3007, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("suppress", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3007, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.suppress", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_98suppress(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_98suppress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("suppress", 1);

  /* "cPyparsing.pyx":3012
 *         cluttering up returned output.
 *         """
 *         return Suppress(self)             # <<<<<<<<<<<<<<
 * 
 *     def leaveWhitespace(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3007
 *             return self.copy()
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         """
 *         Suppresses the output of this :class:`ParserElement`; useful to keep punctuation from
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.suppress", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3014
 *         return Suppress(self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """
 *         Disables the skipping of whitespace before matching the characters in the
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_101leaveWhitespace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_100leaveWhitespace, "ParserElement.leaveWhitespace(self)\n\n        Disables the skipping of whitespace before matching the characters in the\n        :class:`ParserElement`'s defined pattern.  This is normally only used internally by\n        the pyparsing module, but may be needed in some whitespace-sensitive grammars.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_101leaveWhitespace = {"leaveWhitespace", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_101leaveWhitespace, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_100leaveWhitespace};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_101leaveWhitespace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3014, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "leaveWhitespace") < 0)) __PYX_ERR(0, 3014, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("leaveWhitespace", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3014, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_100leaveWhitespace(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_100leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("leaveWhitespace", 1);

  /* "cPyparsing.pyx":3020
 *         the pyparsing module, but may be needed in some whitespace-sensitive grammars.
 *         """
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 3020, __pyx_L1_error)

  /* "cPyparsing.pyx":3021
 *         """
 *         self.skipWhitespace = False
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setWhitespaceChars(self, chars):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3014
 *         return Suppress(self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """
 *         Disables the skipping of whitespace before matching the characters in the
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3023
 *         return self
 * 
 *     def setWhitespaceChars(self, chars):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides the default whitespace chars
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_103setWhitespaceChars(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_102setWhitespaceChars, "ParserElement.setWhitespaceChars(self, chars)\n\n        Overrides the default whitespace chars\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_103setWhitespaceChars = {"setWhitespaceChars", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_103setWhitespaceChars, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_102setWhitespaceChars};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_103setWhitespaceChars(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_chars = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setWhitespaceChars (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_chars,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3023, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chars)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3023, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("setWhitespaceChars", 1, 2, 2, 1); __PYX_ERR(0, 3023, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setWhitespaceChars") < 0)) __PYX_ERR(0, 3023, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_chars = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setWhitespaceChars", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3023, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.setWhitespaceChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_102setWhitespaceChars(__pyx_self, __pyx_v_self, __pyx_v_chars);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_102setWhitespaceChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_chars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setWhitespaceChars", 1);

  /* "cPyparsing.pyx":3027
 *         Overrides the default whitespace chars
 *         """
 *         self.skipWhitespace = True             # <<<<<<<<<<<<<<
 *         self.whiteChars = chars
 *         self.copyDefaultWhiteChars = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_True) < 0) __PYX_ERR(0, 3027, __pyx_L1_error)

  /* "cPyparsing.pyx":3028
 *         """
 *         self.skipWhitespace = True
 *         self.whiteChars = chars             # <<<<<<<<<<<<<<
 *         self.copyDefaultWhiteChars = False
 *         return self
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_whiteChars, __pyx_v_chars) < 0) __PYX_ERR(0, 3028, __pyx_L1_error)

  /* "cPyparsing.pyx":3029
 *         self.skipWhitespace = True
 *         self.whiteChars = chars
 *         self.copyDefaultWhiteChars = False             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_copyDefaultWhiteChars, Py_False) < 0) __PYX_ERR(0, 3029, __pyx_L1_error)

  /* "cPyparsing.pyx":3030
 *         self.whiteChars = chars
 *         self.copyDefaultWhiteChars = False
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def parseWithTabs(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3023
 *         return self
 * 
 *     def setWhitespaceChars(self, chars):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides the default whitespace chars
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setWhitespaceChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3032
 *         return self
 * 
 *     def parseWithTabs(self):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides default behavior to expand ``<TAB>``s to spaces before parsing the input string.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_105parseWithTabs(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_104parseWithTabs, "ParserElement.parseWithTabs(self)\n\n        Overrides default behavior to expand ``<TAB>``s to spaces before parsing the input string.\n        Must be called before ``parseString`` when the input grammar contains elements that\n        match ``<TAB>`` characters.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_105parseWithTabs = {"parseWithTabs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_105parseWithTabs, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_104parseWithTabs};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_105parseWithTabs(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseWithTabs (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3032, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseWithTabs") < 0)) __PYX_ERR(0, 3032, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseWithTabs", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3032, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseWithTabs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_104parseWithTabs(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_104parseWithTabs(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseWithTabs", 1);

  /* "cPyparsing.pyx":3038
 *         match ``<TAB>`` characters.
 *         """
 *         self.keepTabs = True             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_keepTabs, Py_True) < 0) __PYX_ERR(0, 3038, __pyx_L1_error)

  /* "cPyparsing.pyx":3039
 *         """
 *         self.keepTabs = True
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def ignore(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3032
 *         return self
 * 
 *     def parseWithTabs(self):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides default behavior to expand ``<TAB>``s to spaces before parsing the input string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseWithTabs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3041
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Define expression to be ignored (e.g., comments) while doing pattern
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_107ignore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_106ignore, "ParserElement.ignore(self, other)\n\n        Define expression to be ignored (e.g., comments) while doing pattern\n        matching; may be called repeatedly, to define multiple comment or other\n        ignorable patterns.\n\n        Example::\n\n            patt = OneOrMore(Word(alphas))\n            patt.parseString('ablaj /* comment */ lskjd') # -> ['ablaj']\n\n            patt.ignore(cStyleComment)\n            patt.parseString('ablaj /* comment */ lskjd') # -> ['ablaj', 'lskjd']\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_107ignore = {"ignore", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_107ignore, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_106ignore};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_107ignore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ignore (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3041, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3041, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, 1); __PYX_ERR(0, 3041, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "ignore") < 0)) __PYX_ERR(0, 3041, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3041, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_106ignore(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_106ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ignore", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":3055
 *             patt.parseString('ablaj /[inserted by cython to avoid comment start]* comment *[inserted by cython to avoid comment closer]/ lskjd') # -> ['ablaj', 'lskjd']
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = Suppress(other)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3055, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3056
 *         """
 *         if isinstance(other, basestring):
 *             other = Suppress(other)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(other, Suppress):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3056, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3055
 *             patt.parseString('ablaj /[inserted by cython to avoid comment start]* comment *[inserted by cython to avoid comment closer]/ lskjd') # -> ['ablaj', 'lskjd']
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = Suppress(other)
 * 
 */
  }

  /* "cPyparsing.pyx":3058
 *             other = Suppress(other)
 * 
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 self.ignoreExprs.append(other)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3058, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3059
 * 
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 self.ignoreExprs.append(other)
 *         else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_other, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3060
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 *                 self.ignoreExprs.append(other)             # <<<<<<<<<<<<<<
 *         else:
 *             self.ignoreExprs.append(Suppress(other.copy()))
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3060, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_v_other); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3060, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3059
 * 
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 self.ignoreExprs.append(other)
 *         else:
 */
    }

    /* "cPyparsing.pyx":3058
 *             other = Suppress(other)
 * 
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 self.ignoreExprs.append(other)
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":3062
 *                 self.ignoreExprs.append(other)
 *         else:
 *             self.ignoreExprs.append(Suppress(other.copy()))             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_copy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_t_8 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_3); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3062, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":3063
 *         else:
 *             self.ignoreExprs.append(Suppress(other.copy()))
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3041
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Define expression to be ignored (e.g., comments) while doing pattern
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParserElement.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3065
 *         return self
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_109setDebugActions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_108setDebugActions, "ParserElement.setDebugActions(self, startAction, successAction, exceptionAction)\n\n        Enable display of debugging messages while doing pattern matching.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_109setDebugActions = {"setDebugActions", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_109setDebugActions, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_108setDebugActions};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_109setDebugActions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_startAction = 0;
  PyObject *__pyx_v_successAction = 0;
  PyObject *__pyx_v_exceptionAction = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setDebugActions (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_startAction,&__pyx_n_s_successAction,&__pyx_n_s_exceptionAction,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3065, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_startAction)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3065, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("setDebugActions", 1, 4, 4, 1); __PYX_ERR(0, 3065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_successAction)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3065, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("setDebugActions", 1, 4, 4, 2); __PYX_ERR(0, 3065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exceptionAction)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3065, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("setDebugActions", 1, 4, 4, 3); __PYX_ERR(0, 3065, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setDebugActions") < 0)) __PYX_ERR(0, 3065, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_startAction = values[1];
    __pyx_v_successAction = values[2];
    __pyx_v_exceptionAction = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setDebugActions", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 3065, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDebugActions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_108setDebugActions(__pyx_self, __pyx_v_self, __pyx_v_startAction, __pyx_v_successAction, __pyx_v_exceptionAction);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_108setDebugActions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_startAction, PyObject *__pyx_v_successAction, PyObject *__pyx_v_exceptionAction) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setDebugActions", 1);

  /* "cPyparsing.pyx":3069
 *         Enable display of debugging messages while doing pattern matching.
 *         """
 *         self.debugActions = (startAction or _defaultStartDebugAction,             # <<<<<<<<<<<<<<
 *                              successAction or _defaultSuccessDebugAction,
 *                              exceptionAction or _defaultExceptionDebugAction)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_startAction); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3069, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v_startAction);
    __pyx_t_1 = __pyx_v_startAction;
    goto __pyx_L3_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_defaultStartDebugAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;

  /* "cPyparsing.pyx":3070
 *         """
 *         self.debugActions = (startAction or _defaultStartDebugAction,
 *                              successAction or _defaultSuccessDebugAction,             # <<<<<<<<<<<<<<
 *                              exceptionAction or _defaultExceptionDebugAction)
 *         self.debug = True
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_successAction); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3070, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v_successAction);
    __pyx_t_3 = __pyx_v_successAction;
    goto __pyx_L5_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_defaultSuccessDebugAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_L5_bool_binop_done:;

  /* "cPyparsing.pyx":3071
 *         self.debugActions = (startAction or _defaultStartDebugAction,
 *                              successAction or _defaultSuccessDebugAction,
 *                              exceptionAction or _defaultExceptionDebugAction)             # <<<<<<<<<<<<<<
 *         self.debug = True
 *         return self
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_exceptionAction); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3071, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v_exceptionAction);
    __pyx_t_4 = __pyx_v_exceptionAction;
    goto __pyx_L7_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_defaultExceptionDebugAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_4 = __pyx_t_5;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_L7_bool_binop_done:;

  /* "cPyparsing.pyx":3069
 *         Enable display of debugging messages while doing pattern matching.
 *         """
 *         self.debugActions = (startAction or _defaultStartDebugAction,             # <<<<<<<<<<<<<<
 *                              successAction or _defaultSuccessDebugAction,
 *                              exceptionAction or _defaultExceptionDebugAction)
 */
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 3069, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3)) __PYX_ERR(0, 3069, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(0, 3069, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debugActions, __pyx_t_5) < 0) __PYX_ERR(0, 3069, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":3072
 *                              successAction or _defaultSuccessDebugAction,
 *                              exceptionAction or _defaultExceptionDebugAction)
 *         self.debug = True             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debug, Py_True) < 0) __PYX_ERR(0, 3072, __pyx_L1_error)

  /* "cPyparsing.pyx":3073
 *                              exceptionAction or _defaultExceptionDebugAction)
 *         self.debug = True
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setDebug(self, flag=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3065
 *         return self
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDebugActions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3075
 *         return self
 * 
 *     def setDebug(self, flag=True):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_111setDebug(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_110setDebug, "ParserElement.setDebug(self, flag=True)\n\n        Enable display of debugging messages while doing pattern matching.\n        Set ``flag`` to True to enable, False to disable.\n\n        Example::\n\n            wd = Word(alphas).setName(\"alphaword\")\n            integer = Word(nums).setName(\"numword\")\n            term = wd | integer\n\n            # turn on debugging for wd\n            wd.setDebug()\n\n            OneOrMore(term).parseString(\"abc 123 xyz 890\")\n\n        prints::\n\n            Match alphaword at loc 0(1,1)\n            Matched alphaword -> ['abc']\n            Match alphaword at loc 3(1,4)\n            Exception raised:Expected alphaword (at char 4), (line:1, col:5)\n            Match alphaword at loc 7(1,8)\n            Matched alphaword -> ['xyz']\n            Match alphaword at loc 11(1,12)\n            Exception raised:Expected alphaword (at char 12), (line:1, col:13)\n            Match alphaword at loc 15(1,16)\n            Exception raised:Expected alphaword (at char 15), (line:1, col:16)\n\n        The output shown is that produced by the default debug actions - custom debug actions can be\n        specified using :class:`setDebugActions`. Prior to attempting\n        to match the ``wd`` expression, the debugging message ``\"Match <exprname> at loc <n>(<line>,<col>)\"``\n        is shown. Then if the parse succeeds, a ``\"Matched\"`` message is shown, or an ``\"Exception raised\"``\n        message is shown. Also note the use of :class:`setName` to assign a human-readable name to the expression,\n        which makes debugging and exception messages easier to understand - for instance, the default\n        name created for the :class:`Word` expression without calling ``setName`` is ``\"W:(ABCD...)\"``.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_111setDebug = {"setDebug", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_111setDebug, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_110setDebug};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_111setDebug(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_flag = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setDebug (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_flag,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3075, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_flag);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3075, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setDebug") < 0)) __PYX_ERR(0, 3075, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_flag = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setDebug", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 3075, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDebug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_110setDebug(__pyx_self, __pyx_v_self, __pyx_v_flag);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_110setDebug(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_flag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setDebug", 1);

  /* "cPyparsing.pyx":3112
 *         name created for the :class:`Word` expression without calling ``setName`` is ``"W:(ABCD...)"``.
 *         """
 *         if flag:             # <<<<<<<<<<<<<<
 *             self.setDebugActions(_defaultStartDebugAction, _defaultSuccessDebugAction, _defaultExceptionDebugAction)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_flag); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3112, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3113
 *         """
 *         if flag:
 *             self.setDebugActions(_defaultStartDebugAction, _defaultSuccessDebugAction, _defaultExceptionDebugAction)             # <<<<<<<<<<<<<<
 *         else:
 *             self.debug = False
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setDebugActions); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_defaultStartDebugAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_defaultSuccessDebugAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_defaultExceptionDebugAction); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_t_4, __pyx_t_5, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 3+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3112
 *         name created for the :class:`Word` expression without calling ``setName`` is ``"W:(ABCD...)"``.
 *         """
 *         if flag:             # <<<<<<<<<<<<<<
 *             self.setDebugActions(_defaultStartDebugAction, _defaultSuccessDebugAction, _defaultExceptionDebugAction)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":3115
 *             self.setDebugActions(_defaultStartDebugAction, _defaultSuccessDebugAction, _defaultExceptionDebugAction)
 *         else:
 *             self.debug = False             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debug, Py_False) < 0) __PYX_ERR(0, 3115, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":3116
 *         else:
 *             self.debug = False
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3075
 *         return self
 * 
 *     def setDebug(self, flag=True):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDebug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3118
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_113__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_112__str__, "ParserElement.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_113__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_113__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_112__str__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_113__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3118, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 3118, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3118, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_112__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_112__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":3119
 * 
 *     def __str__(self):
 *         return self.name             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3118
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3121
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_115__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_114__repr__, "ParserElement.__repr__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_115__repr__ = {"__repr__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_115__repr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_114__repr__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_115__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3121, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__repr__") < 0)) __PYX_ERR(0, 3121, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__repr__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3121, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_114__repr__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_114__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "cPyparsing.pyx":3122
 * 
 *     def __repr__(self):
 *         return _ustr(self)             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3121
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3124
 *         return _ustr(self)
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         self.streamlined = True
 *         self.strRepr = None
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_117streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_116streamline, "ParserElement.streamline(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_117streamline = {"streamline", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_117streamline, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_116streamline};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_117streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3124, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "streamline") < 0)) __PYX_ERR(0, 3124, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("streamline", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3124, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_116streamline(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_116streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("streamline", 1);

  /* "cPyparsing.pyx":3125
 * 
 *     def streamline(self):
 *         self.streamlined = True             # <<<<<<<<<<<<<<
 *         self.strRepr = None
 *         return self
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_streamlined, Py_True) < 0) __PYX_ERR(0, 3125, __pyx_L1_error)

  /* "cPyparsing.pyx":3126
 *     def streamline(self):
 *         self.streamlined = True
 *         self.strRepr = None             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 3126, __pyx_L1_error)

  /* "cPyparsing.pyx":3127
 *         self.streamlined = True
 *         self.strRepr = None
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3124
 *         return _ustr(self)
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         self.streamlined = True
 *         self.strRepr = None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3129
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_119checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_118checkRecursion, "ParserElement.checkRecursion(self, parseElementList)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_119checkRecursion = {"checkRecursion", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_119checkRecursion, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_118checkRecursion};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_119checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_parseElementList = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3129, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseElementList)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3129, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 3129, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 3129, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3129, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_118checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_118checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion", 1);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3132
 *         pass
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         """
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_121validate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_120validate, "ParserElement.validate(self, validateTrace=None)\n\n        Check defined expressions for valid structure, check for infinite recursive definitions.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_121validate = {"validate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_121validate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_120validate};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_121validate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_validateTrace = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_validateTrace,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3132, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_validateTrace);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3132, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "validate") < 0)) __PYX_ERR(0, 3132, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_validateTrace = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("validate", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 3132, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_120validate(__pyx_self, __pyx_v_self, __pyx_v_validateTrace);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_120validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_validateTrace) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("validate", 1);

  /* "cPyparsing.pyx":3136
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 *         """
 *         self.checkRecursion([])             # <<<<<<<<<<<<<<
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3132
 *         pass
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         """
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3138
 *         self.checkRecursion([])
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on the given file or filename.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_123parseFile(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_122parseFile, "ParserElement.parseFile(self, file_or_filename, parseAll=False)\n\n        Execute the parse expression on the given file or filename.\n        If a filename is specified (instead of a file object),\n        the entire file is opened, read, and closed before parsing.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_123parseFile = {"parseFile", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_123parseFile, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_122parseFile};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_123parseFile(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_file_or_filename = 0;
  PyObject *__pyx_v_parseAll = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseFile (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_file_or_filename,&__pyx_n_s_parseAll,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3138, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_file_or_filename)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3138, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseFile", 0, 2, 3, 1); __PYX_ERR(0, 3138, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseAll);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3138, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseFile") < 0)) __PYX_ERR(0, 3138, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_file_or_filename = values[1];
    __pyx_v_parseAll = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseFile", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 3138, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_122parseFile(__pyx_self, __pyx_v_self, __pyx_v_file_or_filename, __pyx_v_parseAll);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_122parseFile(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_file_or_filename, PyObject *__pyx_v_parseAll) {
  PyObject *__pyx_v_file_contents = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  char const *__pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseFile", 1);

  /* "cPyparsing.pyx":3144
 *         the entire file is opened, read, and closed before parsing.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":3145
 *         """
 *         try:
 *             file_contents = file_or_filename.read()             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             with open(file_or_filename, "r") as f:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_file_or_filename, __pyx_n_s_read); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3145, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_v_file_contents = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":3144
 *         the entire file is opened, read, and closed before parsing.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":3146
 *         try:
 *             file_contents = file_or_filename.read()
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 3146, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "cPyparsing.pyx":3147
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 *             with open(file_or_filename, "r") as f:             # <<<<<<<<<<<<<<
 *                 file_contents = f.read()
 *         try:
 */
      /*with:*/ {
        __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3147, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_file_or_filename);
        __Pyx_GIVEREF(__pyx_v_file_or_filename);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_file_or_filename)) __PYX_ERR(0, 3147, __pyx_L5_except_error);
        __Pyx_INCREF(__pyx_n_u_r);
        __Pyx_GIVEREF(__pyx_n_u_r);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_n_u_r)) __PYX_ERR(0, 3147, __pyx_L5_except_error);
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_open, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3147, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_10 = __Pyx_PyObject_LookupSpecial(__pyx_t_9, __pyx_n_s_exit); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3147, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = __Pyx_PyObject_LookupSpecial(__pyx_t_9, __pyx_n_s_enter); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3147, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_12, NULL};
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3147, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
        __pyx_t_11 = __pyx_t_8;
        __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        /*try:*/ {
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_15);
            /*try:*/ {
              __pyx_v_f = __pyx_t_11;
              __pyx_t_11 = 0;

              /* "cPyparsing.pyx":3148
 *         except AttributeError:
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()             # <<<<<<<<<<<<<<
 *         try:
 *             return self.parseString(file_contents, parseAll)
 */
              __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_n_s_read); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3148, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_9);
              __pyx_t_8 = NULL;
              __pyx_t_7 = 0;
              #if CYTHON_UNPACK_METHODS
              if (likely(PyMethod_Check(__pyx_t_9))) {
                __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
                if (likely(__pyx_t_8)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
                  __Pyx_INCREF(__pyx_t_8);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_9, function);
                  __pyx_t_7 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
                __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
                __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3148, __pyx_L17_error)
                __Pyx_GOTREF(__pyx_t_11);
                __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              }
              __Pyx_XDECREF_SET(__pyx_v_file_contents, __pyx_t_11);
              __pyx_t_11 = 0;

              /* "cPyparsing.pyx":3147
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 *             with open(file_or_filename, "r") as f:             # <<<<<<<<<<<<<<
 *                 file_contents = f.read()
 *         try:
 */
            }
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            goto __pyx_L24_try_end;
            __pyx_L17_error:;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            /*except:*/ {
              __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_9, &__pyx_t_8) < 0) __PYX_ERR(0, 3147, __pyx_L19_except_error)
              __Pyx_XGOTREF(__pyx_t_11);
              __Pyx_XGOTREF(__pyx_t_9);
              __Pyx_XGOTREF(__pyx_t_8);
              __pyx_t_12 = PyTuple_Pack(3, __pyx_t_11, __pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3147, __pyx_L19_except_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_12, NULL);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3147, __pyx_L19_except_error)
              __Pyx_GOTREF(__pyx_t_16);
              __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
              if (__pyx_t_17 < 0) __PYX_ERR(0, 3147, __pyx_L19_except_error)
              __pyx_t_18 = (!__pyx_t_17);
              if (unlikely(__pyx_t_18)) {
                __Pyx_GIVEREF(__pyx_t_11);
                __Pyx_GIVEREF(__pyx_t_9);
                __Pyx_XGIVEREF(__pyx_t_8);
                __Pyx_ErrRestoreWithState(__pyx_t_11, __pyx_t_9, __pyx_t_8);
                __pyx_t_11 = 0; __pyx_t_9 = 0; __pyx_t_8 = 0; 
                __PYX_ERR(0, 3147, __pyx_L19_except_error)
              }
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              goto __pyx_L18_exception_handled;
            }
            __pyx_L19_except_error:;
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
            goto __pyx_L5_except_error;
            __pyx_L18_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
            __pyx_L24_try_end:;
          }
        }
        /*finally:*/ {
          /*normal exit:*/{
            if (__pyx_t_10) {
              __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__46, NULL);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3147, __pyx_L5_except_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            }
            goto __pyx_L16;
          }
          __pyx_L16:;
        }
        goto __pyx_L28;
        __pyx_L11_error:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L5_except_error;
        __pyx_L28:;
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":3144
 *         the entire file is opened, read, and closed before parsing.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "cPyparsing.pyx":3149
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()
 *         try:             # <<<<<<<<<<<<<<
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "cPyparsing.pyx":3150
 *                 file_contents = f.read()
 *         try:
 *             return self.parseString(file_contents, parseAll)             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseString); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3150, __pyx_L29_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(!__pyx_v_file_contents)) { __Pyx_RaiseUnboundLocalError("file_contents"); __PYX_ERR(0, 3150, __pyx_L29_error) }
      __pyx_t_4 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_file_contents, __pyx_v_parseAll};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3150, __pyx_L29_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L33_try_return;

      /* "cPyparsing.pyx":3149
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()
 *         try:             # <<<<<<<<<<<<<<
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 */
    }
    __pyx_L29_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":3151
 *         try:
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3151, __pyx_L31_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_6, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_6, __pyx_t_5, __pyx_t_4);
    __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0;
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 3151, __pyx_L31_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_v_exc = __pyx_t_5;
      /*try:*/ {

        /* "cPyparsing.pyx":3152
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3152, __pyx_L40_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3152, __pyx_L40_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 3152, __pyx_L40_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(__pyx_t_18)) {

          /* "cPyparsing.pyx":3153
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_5, __pyx_t_6);
          __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; 
          __PYX_ERR(0, 3153, __pyx_L40_error)

          /* "cPyparsing.pyx":3152
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":3156
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
        /*else*/ {
          __pyx_t_9 = __Pyx_GetAttr3(__pyx_v_exc, __pyx_n_u_traceback, Py_None); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3156, __pyx_L40_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_18 = (__pyx_t_9 != Py_None);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (__pyx_t_18) {

            /* "cPyparsing.pyx":3157
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)             # <<<<<<<<<<<<<<
 *                 raise exc
 * 
 */
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_trim_traceback); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3157, __pyx_L40_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_traceback); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3157, __pyx_L40_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_12 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_12)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_11};
              __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3157, __pyx_L40_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_traceback, __pyx_t_9) < 0) __PYX_ERR(0, 3157, __pyx_L40_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

            /* "cPyparsing.pyx":3156
 *             else:
 *                 # catch and re-raise exception from here, clearing out pyparsing internal stack trace
 *                 if getattr(exc, '__traceback__', None) is not None:             # <<<<<<<<<<<<<<
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc
 */
          }

          /* "cPyparsing.pyx":3158
 *                 if getattr(exc, '__traceback__', None) is not None:
 *                     exc.__traceback__ = self._trim_traceback(exc.__traceback__)
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
 */
          __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 3158, __pyx_L40_error)
        }
      }

      /* "cPyparsing.pyx":3151
 *         try:
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        __pyx_L40_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_10 = 0; __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_16 = 0; __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_16, &__pyx_t_21);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_15, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_15, &__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_7 = __pyx_lineno; __pyx_t_19 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc); __pyx_v_exc = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_16, __pyx_t_21);
          }
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ErrRestore(__pyx_t_10, __pyx_t_15, __pyx_t_14);
          __pyx_t_10 = 0; __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_16 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_19; __pyx_filename = __pyx_t_20;
          goto __pyx_L31_except_error;
        }
      }
    }
    goto __pyx_L31_except_error;

    /* "cPyparsing.pyx":3149
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()
 *         try:             # <<<<<<<<<<<<<<
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 */
    __pyx_L31_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L33_try_return:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":3138
 *         self.checkRecursion([])
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on the given file or filename.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_file_contents);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3160
 *                 raise exc
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if self is other:
 *             return True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_125__eq__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_124__eq__, "ParserElement.__eq__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_125__eq__ = {"__eq__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_125__eq__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_124__eq__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_125__eq__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3160, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3160, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__eq__", 1, 2, 2, 1); __PYX_ERR(0, 3160, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__eq__") < 0)) __PYX_ERR(0, 3160, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__eq__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3160, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_124__eq__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_124__eq__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 1);

  /* "cPyparsing.pyx":3161
 * 
 *     def __eq__(self, other):
 *         if self is other:             # <<<<<<<<<<<<<<
 *             return True
 *         elif isinstance(other, basestring):
 */
  __pyx_t_1 = (__pyx_v_self == __pyx_v_other);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3162
 *     def __eq__(self, other):
 *         if self is other:
 *             return True             # <<<<<<<<<<<<<<
 *         elif isinstance(other, basestring):
 *             return self.matches(other)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3161
 * 
 *     def __eq__(self, other):
 *         if self is other:             # <<<<<<<<<<<<<<
 *             return True
 *         elif isinstance(other, basestring):
 */
  }

  /* "cPyparsing.pyx":3163
 *         if self is other:
 *             return True
 *         elif isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             return self.matches(other)
 *         elif isinstance(other, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_basestring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_other, __pyx_t_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 3163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3164
 *             return True
 *         elif isinstance(other, basestring):
 *             return self.matches(other)             # <<<<<<<<<<<<<<
 *         elif isinstance(other, ParserElement):
 *             return vars(self) == vars(other)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matches); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3163
 *         if self is other:
 *             return True
 *         elif isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             return self.matches(other)
 *         elif isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":3165
 *         elif isinstance(other, basestring):
 *             return self.matches(other)
 *         elif isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             return vars(self) == vars(other)
 *         return False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_other, __pyx_t_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 3165, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3166
 *             return self.matches(other)
 *         elif isinstance(other, ParserElement):
 *             return vars(self) == vars(other)             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_vars, __pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_vars, __pyx_v_other); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3166, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3165
 *         elif isinstance(other, basestring):
 *             return self.matches(other)
 *         elif isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             return vars(self) == vars(other)
 *         return False
 */
  }

  /* "cPyparsing.pyx":3167
 *         elif isinstance(other, ParserElement):
 *             return vars(self) == vars(other)
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     def __ne__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3160
 *                 raise exc
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if self is other:
 *             return True
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3169
 *         return False
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_127__ne__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_126__ne__, "ParserElement.__ne__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_127__ne__ = {"__ne__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_127__ne__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_126__ne__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_127__ne__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ne__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3169, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3169, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__ne__", 1, 2, 2, 1); __PYX_ERR(0, 3169, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__ne__") < 0)) __PYX_ERR(0, 3169, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ne__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3169, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__ne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_126__ne__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_126__ne__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ne__", 1);

  /* "cPyparsing.pyx":3170
 * 
 *     def __ne__(self, other):
 *         return not (self == other)             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self, __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3170, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3169
 *         return False
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__ne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3172
 *         return not (self == other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return id(self)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_129__hash__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_128__hash__, "ParserElement.__hash__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_129__hash__ = {"__hash__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_129__hash__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_128__hash__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_129__hash__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3172, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__hash__") < 0)) __PYX_ERR(0, 3172, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__hash__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3172, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_128__hash__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_128__hash__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 1);

  /* "cPyparsing.pyx":3173
 * 
 *     def __hash__(self):
 *         return id(self)             # <<<<<<<<<<<<<<
 * 
 *     def __req__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3172
 *         return not (self == other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return id(self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3175
 *         return id(self)
 * 
 *     def __req__(self, other):             # <<<<<<<<<<<<<<
 *         return self == other
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_131__req__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_130__req__, "ParserElement.__req__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_131__req__ = {"__req__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_131__req__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_130__req__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_131__req__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__req__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3175, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3175, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__req__", 1, 2, 2, 1); __PYX_ERR(0, 3175, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__req__") < 0)) __PYX_ERR(0, 3175, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__req__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3175, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__req__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_130__req__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_130__req__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__req__", 1);

  /* "cPyparsing.pyx":3176
 * 
 *     def __req__(self, other):
 *         return self == other             # <<<<<<<<<<<<<<
 * 
 *     def __rne__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self, __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3176, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3175
 *         return id(self)
 * 
 *     def __req__(self, other):             # <<<<<<<<<<<<<<
 *         return self == other
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__req__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3178
 *         return self == other
 * 
 *     def __rne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_133__rne__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_132__rne__, "ParserElement.__rne__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_133__rne__ = {"__rne__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_133__rne__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_132__rne__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_133__rne__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rne__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3178, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3178, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__rne__", 1, 2, 2, 1); __PYX_ERR(0, 3178, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__rne__") < 0)) __PYX_ERR(0, 3178, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rne__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3178, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_132__rne__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_132__rne__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rne__", 1);

  /* "cPyparsing.pyx":3179
 * 
 *     def __rne__(self, other):
 *         return not (self == other)             # <<<<<<<<<<<<<<
 * 
 *     def matches(self, testString, parseAll=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self, __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3179, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3178
 *         return self == other
 * 
 *     def __rne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3181
 *         return not (self == other)
 * 
 *     def matches(self, testString, parseAll=True):             # <<<<<<<<<<<<<<
 *         """
 *         Method for quick testing of a parser against a test string. Good for simple
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_135matches(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_134matches, "ParserElement.matches(self, testString, parseAll=True)\n\n        Method for quick testing of a parser against a test string. Good for simple\n        inline microtests of sub expressions while building up larger parser.\n\n        Parameters:\n         - testString - to test against this expression for a match\n         - parseAll - (default= ``True``) - flag to pass to :class:`parseString` when running tests\n\n        Example::\n\n            expr = Word(nums)\n            assert expr.matches(\"100\")\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_135matches = {"matches", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_135matches, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_134matches};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_135matches(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_testString = 0;
  PyObject *__pyx_v_parseAll = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matches (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_testString,&__pyx_n_s_parseAll,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3181, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_testString)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3181, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("matches", 0, 2, 3, 1); __PYX_ERR(0, 3181, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseAll);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3181, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "matches") < 0)) __PYX_ERR(0, 3181, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_testString = values[1];
    __pyx_v_parseAll = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("matches", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 3181, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.matches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_134matches(__pyx_self, __pyx_v_self, __pyx_v_testString, __pyx_v_parseAll);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_134matches(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_testString, PyObject *__pyx_v_parseAll) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matches", 1);

  /* "cPyparsing.pyx":3195
 *             assert expr.matches("100")
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":3196
 *         """
 *         try:
 *             self.parseString(_ustr(testString), parseAll=parseAll)             # <<<<<<<<<<<<<<
 *             return True
 *         except ParseBaseException:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseString); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3196, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ustr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3196, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_testString};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3196, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3196, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5)) __PYX_ERR(0, 3196, __pyx_L3_error);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3196, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_parseAll, __pyx_v_parseAll) < 0) __PYX_ERR(0, 3196, __pyx_L3_error)
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3196, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "cPyparsing.pyx":3197
 *         try:
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True             # <<<<<<<<<<<<<<
 *         except ParseBaseException:
 *             return False
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":3195
 *             assert expr.matches("100")
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":3198
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True
 *         except ParseBaseException:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_5, &__pyx_t_6);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3198, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_7, __pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_ErrRestore(__pyx_t_7, __pyx_t_5, __pyx_t_6);
    __pyx_t_7 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.matches", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 3198, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "cPyparsing.pyx":3199
 *             return True
 *         except ParseBaseException:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *     def runTests(self, tests, parseAll=True, comment='#',
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":3195
 *             assert expr.matches("100")
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":3181
 *         return not (self == other)
 * 
 *     def matches(self, testString, parseAll=True):             # <<<<<<<<<<<<<<
 *         """
 *         Method for quick testing of a parser against a test string. Good for simple
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.matches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3201
 *             return False
 * 
 *     def runTests(self, tests, parseAll=True, comment='#',             # <<<<<<<<<<<<<<
 *                  fullDump=True, printResults=True, failureTests=False, postParse=None,
 *                  file=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_137runTests(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_13ParserElement_136runTests, "ParserElement.runTests(self, tests, parseAll=True, comment=u'#', fullDump=True, printResults=True, failureTests=False, postParse=None, file=None)\n\n        Execute the parse expression on a series of test strings, showing each\n        test, the parsed results or where the parse failed. Quick and easy way to\n        run a parse expression against a list of sample strings.\n\n        Parameters:\n         - tests - a list of separate test strings, or a multiline string of test strings\n         - parseAll - (default= ``True``) - flag to pass to :class:`parseString` when running tests\n         - comment - (default= ``'#'``) - expression for indicating embedded comments in the test\n              string; pass None to disable comment filtering\n         - fullDump - (default= ``True``) - dump results as list followed by results names in nested outline;\n              if False, only dump nested list\n         - printResults - (default= ``True``) prints test output to stdout\n         - failureTests - (default= ``False``) indicates if these tests are expected to fail parsing\n         - postParse - (default= ``None``) optional callback for successful parse results; called as\n              `fn(test_string, parse_results)` and returns a string to be added to the test output\n         - file - (default=``None``) optional file-like object to which test output will be written;\n              if None, will default to ``sys.stdout``\n\n        Returns: a (success, results) tuple, where success indicates that all tests succeeded\n        (or failed if ``failureTests`` is True), and the results contain a list of lines of each\n        test's output\n\n        Example::\n\n            number_expr = pyparsing_common.number.copy()\n\n            result = number_expr.runTests('''\n                # unsigned integer\n                100\n                # negative integer\n                -100\n                # float with scientific notation\n                6.02e23\n             ""   # integer with scientific notation\n                1e-12\n                ''')\n            print(\"Success\" if result[0] else \"Failed!\")\n\n            result = number_expr.runTests('''\n                # stray character\n                100Z\n                # missing leading digit before '.'\n                -.100\n                # too many '.'\n                3.14.159\n                ''', failureTests=True)\n            print(\"Success\" if result[0] else \"Failed!\")\n\n        prints::\n\n            # unsigned integer\n            100\n            [100]\n\n            # negative integer\n            -100\n            [-100]\n\n            # float with scientific notation\n            6.02e23\n            [6.02e+23]\n\n            # integer with scientific notation\n            1e-12\n            [1e-12]\n\n            Success\n\n            # stray character\n            100Z\n               ^\n            FAIL: Expected end of text (at char 3), (line:1, col:4)\n\n            # missing leading digit before '.'\n            -.100\n            ^\n            FAIL: Expected {real number with scientific notation | real number | signed integer} (at char 0), (line:1, col:1)\n\n            # too many '.'\n            3.14.159\n                ^\n            FAIL: Expected end of text (at char 4), (line:1, col:5)\n\n            Success\n\n        Each test string must be on a single line. If you want to test a string that spans multiple\n        lines, create a test like this::\n\n            expr.runTest(r\"this is a test\\n of strings that spans \\n 3 lines\")\n\n        (Note that this is a raw string literal, you must include the leading 'r'.)\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_137runTests = {"runTests", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13ParserElement_137runTests, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_136runTests};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_137runTests(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_tests = 0;
  PyObject *__pyx_v_parseAll = 0;
  PyObject *__pyx_v_comment = 0;
  PyObject *__pyx_v_fullDump = 0;
  PyObject *__pyx_v_printResults = 0;
  PyObject *__pyx_v_failureTests = 0;
  PyObject *__pyx_v_postParse = 0;
  PyObject *__pyx_v_file = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("runTests (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_tests,&__pyx_n_s_parseAll,&__pyx_n_s_comment,&__pyx_n_s_fullDump,&__pyx_n_s_printResults,&__pyx_n_s_failureTests,&__pyx_n_s_postParse,&__pyx_n_s_file,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__65)));

    /* "cPyparsing.pyx":3202
 * 
 *     def runTests(self, tests, parseAll=True, comment='#',
 *                  fullDump=True, printResults=True, failureTests=False, postParse=None,             # <<<<<<<<<<<<<<
 *                  file=None):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[7] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "cPyparsing.pyx":3203
 *     def runTests(self, tests, parseAll=True, comment='#',
 *                  fullDump=True, printResults=True, failureTests=False, postParse=None,
 *                  file=None):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on a series of test strings, showing each
 */
    values[8] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tests)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("runTests", 0, 2, 9, 1); __PYX_ERR(0, 3201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseAll);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_comment);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fullDump);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_printResults);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_failureTests);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_postParse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_file);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "runTests") < 0)) __PYX_ERR(0, 3201, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_tests = values[1];
    __pyx_v_parseAll = values[2];
    __pyx_v_comment = values[3];
    __pyx_v_fullDump = values[4];
    __pyx_v_printResults = values[5];
    __pyx_v_failureTests = values[6];
    __pyx_v_postParse = values[7];
    __pyx_v_file = values[8];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("runTests", 0, 2, 9, __pyx_nargs); __PYX_ERR(0, 3201, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParserElement.runTests", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_136runTests(__pyx_self, __pyx_v_self, __pyx_v_tests, __pyx_v_parseAll, __pyx_v_comment, __pyx_v_fullDump, __pyx_v_printResults, __pyx_v_failureTests, __pyx_v_postParse, __pyx_v_file);

  /* "cPyparsing.pyx":3201
 *             return False
 * 
 *     def runTests(self, tests, parseAll=True, comment='#',             # <<<<<<<<<<<<<<
 *                  fullDump=True, printResults=True, failureTests=False, postParse=None,
 *                  file=None):
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_136runTests(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_tests, PyObject *__pyx_v_parseAll, PyObject *__pyx_v_comment, PyObject *__pyx_v_fullDump, PyObject *__pyx_v_printResults, PyObject *__pyx_v_failureTests, PyObject *__pyx_v_postParse, PyObject *__pyx_v_file) {
  PyObject *__pyx_v_print_ = NULL;
  PyObject *__pyx_v_allResults = NULL;
  PyObject *__pyx_v_comments = NULL;
  PyObject *__pyx_v_success = NULL;
  PyObject *__pyx_v_NL = NULL;
  PyObject *__pyx_v_BOM = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_pe = NULL;
  PyObject *__pyx_v_fatal = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_v_pp_value = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  int __pyx_t_23;
  char const *__pyx_t_24;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  char const *__pyx_t_31;
  char const *__pyx_t_32;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("runTests", 0);
  __Pyx_INCREF(__pyx_v_tests);
  __Pyx_INCREF(__pyx_v_comment);
  __Pyx_INCREF(__pyx_v_file);

  /* "cPyparsing.pyx":3297
 *         (Note that this is a raw string literal, you must include the leading 'r'.)
 *         """
 *         if isinstance(tests, basestring):             # <<<<<<<<<<<<<<
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_tests, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3297, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3298
 *         """
 *         if isinstance(tests, basestring):
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))             # <<<<<<<<<<<<<<
 *         if isinstance(comment, basestring):
 *             comment = Literal(comment)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_tests, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_splitlines); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 3298, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1)) __PYX_ERR(0, 3298, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_tests, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":3297
 *         (Note that this is a raw string literal, you must include the leading 'r'.)
 *         """
 *         if isinstance(tests, basestring):             # <<<<<<<<<<<<<<
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):
 */
  }

  /* "cPyparsing.pyx":3299
 *         if isinstance(tests, basestring):
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):             # <<<<<<<<<<<<<<
 *             comment = Literal(comment)
 *         if file is None:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_basestring); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_comment, __pyx_t_5); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3300
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):
 *             comment = Literal(comment)             # <<<<<<<<<<<<<<
 *         if file is None:
 *             file = sys.stdout
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Literal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_comment};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_comment, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":3299
 *         if isinstance(tests, basestring):
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):             # <<<<<<<<<<<<<<
 *             comment = Literal(comment)
 *         if file is None:
 */
  }

  /* "cPyparsing.pyx":3301
 *         if isinstance(comment, basestring):
 *             comment = Literal(comment)
 *         if file is None:             # <<<<<<<<<<<<<<
 *             file = sys.stdout
 *         print_ = file.write
 */
  __pyx_t_2 = (__pyx_v_file == Py_None);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3302
 *             comment = Literal(comment)
 *         if file is None:
 *             file = sys.stdout             # <<<<<<<<<<<<<<
 *         print_ = file.write
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_sys); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_stdout); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_file, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3301
 *         if isinstance(comment, basestring):
 *             comment = Literal(comment)
 *         if file is None:             # <<<<<<<<<<<<<<
 *             file = sys.stdout
 *         print_ = file.write
 */
  }

  /* "cPyparsing.pyx":3303
 *         if file is None:
 *             file = sys.stdout
 *         print_ = file.write             # <<<<<<<<<<<<<<
 * 
 *         allResults = []
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_file, __pyx_n_s_write); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_print_ = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3305
 *         print_ = file.write
 * 
 *         allResults = []             # <<<<<<<<<<<<<<
 *         comments = []
 *         success = True
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_allResults = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3306
 * 
 *         allResults = []
 *         comments = []             # <<<<<<<<<<<<<<
 *         success = True
 *         NL = Literal(r'\n').addParseAction(replaceWith('\n')).ignore(quotedString)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_comments = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3307
 *         allResults = []
 *         comments = []
 *         success = True             # <<<<<<<<<<<<<<
 *         NL = Literal(r'\n').addParseAction(replaceWith('\n')).ignore(quotedString)
 *         BOM = u'\ufeff'
 */
  __Pyx_INCREF(Py_True);
  __pyx_v_success = Py_True;

  /* "cPyparsing.pyx":3308
 *         comments = []
 *         success = True
 *         NL = Literal(r'\n').addParseAction(replaceWith('\n')).ignore(quotedString)             # <<<<<<<<<<<<<<
 *         BOM = u'\ufeff'
 *         for t in tests:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Literal); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_u_n_2};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_replaceWith); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_kp_u__19};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ignore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_quotedString); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_NL = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3309
 *         success = True
 *         NL = Literal(r'\n').addParseAction(replaceWith('\n')).ignore(quotedString)
 *         BOM = u'\ufeff'             # <<<<<<<<<<<<<<
 *         for t in tests:
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 */
  __Pyx_INCREF(__pyx_kp_u__66);
  __pyx_v_BOM = __pyx_kp_u__66;

  /* "cPyparsing.pyx":3310
 *         NL = Literal(r'\n').addParseAction(replaceWith('\n')).ignore(quotedString)
 *         BOM = u'\ufeff'
 *         for t in tests:             # <<<<<<<<<<<<<<
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 *                 comments.append(t)
 */
  if (likely(PyList_CheckExact(__pyx_v_tests)) || PyTuple_CheckExact(__pyx_v_tests)) {
    __pyx_t_1 = __pyx_v_tests; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_9 = 0;
    __pyx_t_10 = NULL;
  } else {
    __pyx_t_9 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_tests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3310, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_10)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3310, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 3310, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3310, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3310, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 3310, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3310, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_10(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3310, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3311
 *         BOM = u'\ufeff'
 *         for t in tests:
 *             if comment is not None and comment.matches(t, False) or comments and not t:             # <<<<<<<<<<<<<<
 *                 comments.append(t)
 *                 continue
 */
    __pyx_t_11 = (__pyx_v_comment != Py_None);
    if (!__pyx_t_11) {
      goto __pyx_L10_next_or;
    } else {
    }
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comment, __pyx_n_s_matches); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_t, Py_False};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3311, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_11) {
    } else {
      __pyx_t_2 = __pyx_t_11;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_L10_next_or:;
    __pyx_t_11 = (PyList_GET_SIZE(__pyx_v_comments) != 0);
    if (__pyx_t_11) {
    } else {
      __pyx_t_2 = __pyx_t_11;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3311, __pyx_L1_error)
    __pyx_t_12 = (!__pyx_t_11);
    __pyx_t_2 = __pyx_t_12;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3312
 *         for t in tests:
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 *                 comments.append(t)             # <<<<<<<<<<<<<<
 *                 continue
 *             if not t:
 */
      __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_comments, __pyx_v_t); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3312, __pyx_L1_error)

      /* "cPyparsing.pyx":3313
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 *                 comments.append(t)
 *                 continue             # <<<<<<<<<<<<<<
 *             if not t:
 *                 continue
 */
      goto __pyx_L6_continue;

      /* "cPyparsing.pyx":3311
 *         BOM = u'\ufeff'
 *         for t in tests:
 *             if comment is not None and comment.matches(t, False) or comments and not t:             # <<<<<<<<<<<<<<
 *                 comments.append(t)
 *                 continue
 */
    }

    /* "cPyparsing.pyx":3314
 *                 comments.append(t)
 *                 continue
 *             if not t:             # <<<<<<<<<<<<<<
 *                 continue
 *             out = ['\n' + '\n'.join(comments) if comments else '', t]
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3314, __pyx_L1_error)
    __pyx_t_12 = (!__pyx_t_2);
    if (__pyx_t_12) {

      /* "cPyparsing.pyx":3315
 *                 continue
 *             if not t:
 *                 continue             # <<<<<<<<<<<<<<
 *             out = ['\n' + '\n'.join(comments) if comments else '', t]
 *             comments = []
 */
      goto __pyx_L6_continue;

      /* "cPyparsing.pyx":3314
 *                 comments.append(t)
 *                 continue
 *             if not t:             # <<<<<<<<<<<<<<
 *                 continue
 *             out = ['\n' + '\n'.join(comments) if comments else '', t]
 */
    }

    /* "cPyparsing.pyx":3316
 *             if not t:
 *                 continue
 *             out = ['\n' + '\n'.join(comments) if comments else '', t]             # <<<<<<<<<<<<<<
 *             comments = []
 *             try:
 */
    __pyx_t_12 = (PyList_GET_SIZE(__pyx_v_comments) != 0);
    if (__pyx_t_12) {
      __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__19, __pyx_v_comments); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u__19, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_4 = __pyx_t_3;
      __pyx_t_3 = 0;
    } else {
      __Pyx_INCREF(__pyx_kp_u__10);
      __pyx_t_4 = __pyx_kp_u__10;
    }
    __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 3316, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_t);
    __Pyx_GIVEREF(__pyx_v_t);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_v_t)) __PYX_ERR(0, 3316, __pyx_L1_error);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3317
 *                 continue
 *             out = ['\n' + '\n'.join(comments) if comments else '', t]
 *             comments = []             # <<<<<<<<<<<<<<
 *             try:
 *                 # convert newline marks to actual newlines, and strip leading BOM if present
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_comments, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3318
 *             out = ['\n' + '\n'.join(comments) if comments else '', t]
 *             comments = []
 *             try:             # <<<<<<<<<<<<<<
 *                 # convert newline marks to actual newlines, and strip leading BOM if present
 *                 t = NL.transformString(t.lstrip(BOM))
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      /*try:*/ {

        /* "cPyparsing.pyx":3320
 *             try:
 *                 # convert newline marks to actual newlines, and strip leading BOM if present
 *                 t = NL.transformString(t.lstrip(BOM))             # <<<<<<<<<<<<<<
 *                 result = self.parseString(t, parseAll=parseAll)
 *             except ParseBaseException as pe:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_NL, __pyx_n_s_transformString); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3320, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3320, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_8 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_BOM};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3320, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3320, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __Pyx_DECREF_SET(__pyx_v_t, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "cPyparsing.pyx":3321
 *                 # convert newline marks to actual newlines, and strip leading BOM if present
 *                 t = NL.transformString(t.lstrip(BOM))
 *                 result = self.parseString(t, parseAll=parseAll)             # <<<<<<<<<<<<<<
 *             except ParseBaseException as pe:
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseString); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3321, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3321, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_v_t);
        __Pyx_GIVEREF(__pyx_v_t);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_t)) __PYX_ERR(0, 3321, __pyx_L14_error);
        __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3321, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_parseAll, __pyx_v_parseAll) < 0) __PYX_ERR(0, 3321, __pyx_L14_error)
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3321, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "cPyparsing.pyx":3318
 *             out = ['\n' + '\n'.join(comments) if comments else '', t]
 *             comments = []
 *             try:             # <<<<<<<<<<<<<<
 *                 # convert newline marks to actual newlines, and strip leading BOM if present
 *                 t = NL.transformString(t.lstrip(BOM))
 */
      }

      /* "cPyparsing.pyx":3337
 *                 result = exc
 *             else:
 *                 success = success and not failureTests             # <<<<<<<<<<<<<<
 *                 if postParse is not None:
 *                     try:
 */
      /*else:*/ {
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_success); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3337, __pyx_L16_except_error)
        if (__pyx_t_12) {
        } else {
          __Pyx_INCREF(__pyx_v_success);
          __pyx_t_6 = __pyx_v_success;
          goto __pyx_L22_bool_binop_done;
        }
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_failureTests); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3337, __pyx_L16_except_error)
        __pyx_t_2 = (!__pyx_t_12);
        __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3337, __pyx_L16_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __pyx_t_5;
        __pyx_t_5 = 0;
        __pyx_L22_bool_binop_done:;
        __Pyx_DECREF_SET(__pyx_v_success, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "cPyparsing.pyx":3338
 *             else:
 *                 success = success and not failureTests
 *                 if postParse is not None:             # <<<<<<<<<<<<<<
 *                     try:
 *                         pp_value = postParse(t, result)
 */
        __pyx_t_2 = (__pyx_v_postParse != Py_None);
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":3339
 *                 success = success and not failureTests
 *                 if postParse is not None:
 *                     try:             # <<<<<<<<<<<<<<
 *                         pp_value = postParse(t, result)
 *                         if pp_value is not None:
 */
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            /*try:*/ {

              /* "cPyparsing.pyx":3340
 *                 if postParse is not None:
 *                     try:
 *                         pp_value = postParse(t, result)             # <<<<<<<<<<<<<<
 *                         if pp_value is not None:
 *                             if isinstance(pp_value, ParseResults):
 */
              __Pyx_INCREF(__pyx_v_postParse);
              __pyx_t_5 = __pyx_v_postParse; __pyx_t_4 = NULL;
              __pyx_t_7 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_5))) {
                __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
                if (likely(__pyx_t_4)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                  __Pyx_INCREF(__pyx_t_4);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_5, function);
                  __pyx_t_7 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_t, __pyx_v_result};
                __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3340, __pyx_L25_error)
                __Pyx_GOTREF(__pyx_t_6);
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              }
              __Pyx_XDECREF_SET(__pyx_v_pp_value, __pyx_t_6);
              __pyx_t_6 = 0;

              /* "cPyparsing.pyx":3341
 *                     try:
 *                         pp_value = postParse(t, result)
 *                         if pp_value is not None:             # <<<<<<<<<<<<<<
 *                             if isinstance(pp_value, ParseResults):
 *                                 out.append(pp_value.dump())
 */
              __pyx_t_2 = (__pyx_v_pp_value != Py_None);
              if (__pyx_t_2) {

                /* "cPyparsing.pyx":3342
 *                         pp_value = postParse(t, result)
 *                         if pp_value is not None:
 *                             if isinstance(pp_value, ParseResults):             # <<<<<<<<<<<<<<
 *                                 out.append(pp_value.dump())
 *                             else:
 */
                __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3342, __pyx_L25_error)
                __Pyx_GOTREF(__pyx_t_6);
                __pyx_t_2 = PyObject_IsInstance(__pyx_v_pp_value, __pyx_t_6); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3342, __pyx_L25_error)
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                if (__pyx_t_2) {

                  /* "cPyparsing.pyx":3343
 *                         if pp_value is not None:
 *                             if isinstance(pp_value, ParseResults):
 *                                 out.append(pp_value.dump())             # <<<<<<<<<<<<<<
 *                             else:
 *                                 out.append(str(pp_value))
 */
                  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_pp_value, __pyx_n_s_dump); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3343, __pyx_L25_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __pyx_t_4 = NULL;
                  __pyx_t_7 = 0;
                  #if CYTHON_UNPACK_METHODS
                  if (likely(PyMethod_Check(__pyx_t_5))) {
                    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
                    if (likely(__pyx_t_4)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                      __Pyx_INCREF(__pyx_t_4);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_5, function);
                      __pyx_t_7 = 1;
                    }
                  }
                  #endif
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
                    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
                    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3343, __pyx_L25_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                  }
                  __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_6); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3343, __pyx_L25_error)
                  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                  /* "cPyparsing.pyx":3342
 *                         pp_value = postParse(t, result)
 *                         if pp_value is not None:
 *                             if isinstance(pp_value, ParseResults):             # <<<<<<<<<<<<<<
 *                                 out.append(pp_value.dump())
 *                             else:
 */
                  goto __pyx_L34;
                }

                /* "cPyparsing.pyx":3345
 *                                 out.append(pp_value.dump())
 *                             else:
 *                                 out.append(str(pp_value))             # <<<<<<<<<<<<<<
 *                         else:
 *                             out.append(result.dump())
 */
                /*else*/ {
                  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3345, __pyx_L25_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __pyx_t_4 = NULL;
                  __pyx_t_7 = 0;
                  #if CYTHON_UNPACK_METHODS
                  if (unlikely(PyMethod_Check(__pyx_t_5))) {
                    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
                    if (likely(__pyx_t_4)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                      __Pyx_INCREF(__pyx_t_4);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_5, function);
                      __pyx_t_7 = 1;
                    }
                  }
                  #endif
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_pp_value};
                    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
                    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3345, __pyx_L25_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                  }
                  __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_6); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3345, __pyx_L25_error)
                  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                }
                __pyx_L34:;

                /* "cPyparsing.pyx":3341
 *                     try:
 *                         pp_value = postParse(t, result)
 *                         if pp_value is not None:             # <<<<<<<<<<<<<<
 *                             if isinstance(pp_value, ParseResults):
 *                                 out.append(pp_value.dump())
 */
                goto __pyx_L33;
              }

              /* "cPyparsing.pyx":3347
 *                                 out.append(str(pp_value))
 *                         else:
 *                             out.append(result.dump())             # <<<<<<<<<<<<<<
 *                     except Exception as e:
 *                         out.append(result.dump(full=fullDump))
 */
              /*else*/ {
                __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_dump); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3347, __pyx_L25_error)
                __Pyx_GOTREF(__pyx_t_5);
                __pyx_t_4 = NULL;
                __pyx_t_7 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_5))) {
                  __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
                  if (likely(__pyx_t_4)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                    __Pyx_INCREF(__pyx_t_4);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_5, function);
                    __pyx_t_7 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
                  __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
                  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3347, __pyx_L25_error)
                  __Pyx_GOTREF(__pyx_t_6);
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                }
                __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_6); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3347, __pyx_L25_error)
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              }
              __pyx_L33:;

              /* "cPyparsing.pyx":3339
 *                 success = success and not failureTests
 *                 if postParse is not None:
 *                     try:             # <<<<<<<<<<<<<<
 *                         pp_value = postParse(t, result)
 *                         if pp_value is not None:
 */
            }
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            goto __pyx_L32_try_end;
            __pyx_L25_error:;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

            /* "cPyparsing.pyx":3348
 *                         else:
 *                             out.append(result.dump())
 *                     except Exception as e:             # <<<<<<<<<<<<<<
 *                         out.append(result.dump(full=fullDump))
 *                         out.append("{0} failed: {1}: {2}".format(postParse.__name__, type(e).__name__, e))
 */
            __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
            if (__pyx_t_7) {
              __Pyx_AddTraceback("cPyparsing.ParserElement.runTests", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 3348, __pyx_L27_except_error)
              __Pyx_XGOTREF(__pyx_t_6);
              __Pyx_XGOTREF(__pyx_t_5);
              __Pyx_XGOTREF(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_5);
              __pyx_v_e = __pyx_t_5;
              /*try:*/ {

                /* "cPyparsing.pyx":3349
 *                             out.append(result.dump())
 *                     except Exception as e:
 *                         out.append(result.dump(full=fullDump))             # <<<<<<<<<<<<<<
 *                         out.append("{0} failed: {1}: {2}".format(postParse.__name__, type(e).__name__, e))
 *                 else:
 */
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_dump); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3349, __pyx_L40_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3349, __pyx_L40_error)
                __Pyx_GOTREF(__pyx_t_8);
                if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_full, __pyx_v_fullDump) < 0) __PYX_ERR(0, 3349, __pyx_L40_error)
                __pyx_t_20 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_8); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3349, __pyx_L40_error)
                __Pyx_GOTREF(__pyx_t_20);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_20); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3349, __pyx_L40_error)
                __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;

                /* "cPyparsing.pyx":3350
 *                     except Exception as e:
 *                         out.append(result.dump(full=fullDump))
 *                         out.append("{0} failed: {1}: {2}".format(postParse.__name__, type(e).__name__, e))             # <<<<<<<<<<<<<<
 *                 else:
 *                     out.append(result.dump(full=fullDump))
 */
                __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_failed_1_2, __pyx_n_s_format); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3350, __pyx_L40_error)
                __Pyx_GOTREF(__pyx_t_8);
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_postParse, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3350, __pyx_L40_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_21 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_e)), __pyx_n_s_name); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 3350, __pyx_L40_error)
                __Pyx_GOTREF(__pyx_t_21);
                __pyx_t_22 = NULL;
                __pyx_t_7 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_8))) {
                  __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_8);
                  if (likely(__pyx_t_22)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                    __Pyx_INCREF(__pyx_t_22);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_8, function);
                    __pyx_t_7 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[4] = {__pyx_t_22, __pyx_t_3, __pyx_t_21, __pyx_v_e};
                  __pyx_t_20 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
                  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
                  if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3350, __pyx_L40_error)
                  __Pyx_GOTREF(__pyx_t_20);
                  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                }
                __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_20); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3350, __pyx_L40_error)
                __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
              }

              /* "cPyparsing.pyx":3348
 *                         else:
 *                             out.append(result.dump())
 *                     except Exception as e:             # <<<<<<<<<<<<<<
 *                         out.append(result.dump(full=fullDump))
 *                         out.append("{0} failed: {1}: {2}".format(postParse.__name__, type(e).__name__, e))
 */
              /*finally:*/ {
                /*normal exit:*/{
                  __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
                  goto __pyx_L41;
                }
                __pyx_L40_error:;
                /*exception exit:*/{
                  __Pyx_PyThreadState_declare
                  __Pyx_PyThreadState_assign
                  __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0;
                  __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
                  __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
                  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
                  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                  if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_28, &__pyx_t_29, &__pyx_t_30);
                  if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27) < 0)) __Pyx_ErrFetch(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27);
                  __Pyx_XGOTREF(__pyx_t_25);
                  __Pyx_XGOTREF(__pyx_t_26);
                  __Pyx_XGOTREF(__pyx_t_27);
                  __Pyx_XGOTREF(__pyx_t_28);
                  __Pyx_XGOTREF(__pyx_t_29);
                  __Pyx_XGOTREF(__pyx_t_30);
                  __pyx_t_7 = __pyx_lineno; __pyx_t_23 = __pyx_clineno; __pyx_t_24 = __pyx_filename;
                  {
                    __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
                  }
                  if (PY_MAJOR_VERSION >= 3) {
                    __Pyx_XGIVEREF(__pyx_t_28);
                    __Pyx_XGIVEREF(__pyx_t_29);
                    __Pyx_XGIVEREF(__pyx_t_30);
                    __Pyx_ExceptionReset(__pyx_t_28, __pyx_t_29, __pyx_t_30);
                  }
                  __Pyx_XGIVEREF(__pyx_t_25);
                  __Pyx_XGIVEREF(__pyx_t_26);
                  __Pyx_XGIVEREF(__pyx_t_27);
                  __Pyx_ErrRestore(__pyx_t_25, __pyx_t_26, __pyx_t_27);
                  __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0;
                  __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_23; __pyx_filename = __pyx_t_24;
                  goto __pyx_L27_except_error;
                }
                __pyx_L41:;
              }
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              goto __pyx_L26_exception_handled;
            }
            goto __pyx_L27_except_error;

            /* "cPyparsing.pyx":3339
 *                 success = success and not failureTests
 *                 if postParse is not None:
 *                     try:             # <<<<<<<<<<<<<<
 *                         pp_value = postParse(t, result)
 *                         if pp_value is not None:
 */
            __pyx_L27_except_error:;
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            goto __pyx_L16_except_error;
            __pyx_L26_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            __pyx_L32_try_end:;
          }

          /* "cPyparsing.pyx":3338
 *             else:
 *                 success = success and not failureTests
 *                 if postParse is not None:             # <<<<<<<<<<<<<<
 *                     try:
 *                         pp_value = postParse(t, result)
 */
          goto __pyx_L24;
        }

        /* "cPyparsing.pyx":3352
 *                         out.append("{0} failed: {1}: {2}".format(postParse.__name__, type(e).__name__, e))
 *                 else:
 *                     out.append(result.dump(full=fullDump))             # <<<<<<<<<<<<<<
 * 
 *             if printResults:
 */
        /*else*/ {
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_dump); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3352, __pyx_L16_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3352, __pyx_L16_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_full, __pyx_v_fullDump) < 0) __PYX_ERR(0, 3352, __pyx_L16_except_error)
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3352, __pyx_L16_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_6); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3352, __pyx_L16_except_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __pyx_L24:;
      }
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      goto __pyx_L21_try_end;
      __pyx_L14_error:;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":3322
 *                 t = NL.transformString(t.lstrip(BOM))
 *                 result = self.parseString(t, parseAll=parseAll)
 *             except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:
 */
      __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
      __Pyx_GetModuleGlobalName(__pyx_t_20, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3322, __pyx_L16_except_error)
      __Pyx_GOTREF(__pyx_t_20);
      __pyx_t_23 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_6, __pyx_t_20);
      __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_5, __pyx_t_4);
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0;
      if (__pyx_t_23) {
        __Pyx_AddTraceback("cPyparsing.ParserElement.runTests", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 3322, __pyx_L16_except_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_v_pe = __pyx_t_5;
        /*try:*/ {

          /* "cPyparsing.pyx":3323
 *                 result = self.parseString(t, parseAll=parseAll)
 *             except ParseBaseException as pe:
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""             # <<<<<<<<<<<<<<
 *                 if '\n' in t:
 *                     out.append(line(pe.loc, t))
 */
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseFatalException); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3323, __pyx_L51_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_2 = PyObject_IsInstance(__pyx_v_pe, __pyx_t_8); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 3323, __pyx_L51_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (__pyx_t_2) {
            __Pyx_INCREF(__pyx_kp_u_FATAL);
            __pyx_t_20 = __pyx_kp_u_FATAL;
          } else {
            __Pyx_INCREF(__pyx_kp_u__10);
            __pyx_t_20 = __pyx_kp_u__10;
          }
          __Pyx_XDECREF_SET(__pyx_v_fatal, ((PyObject*)__pyx_t_20));
          __pyx_t_20 = 0;

          /* "cPyparsing.pyx":3324
 *             except ParseBaseException as pe:
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:             # <<<<<<<<<<<<<<
 *                     out.append(line(pe.loc, t))
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)
 */
          __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__19, __pyx_v_t, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3324, __pyx_L51_error)
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":3325
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:
 *                     out.append(line(pe.loc, t))             # <<<<<<<<<<<<<<
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)
 *                 else:
 */
            __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_line); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3325, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_loc); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 3325, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_21);
            __pyx_t_3 = NULL;
            __pyx_t_23 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_3)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_3);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
                __pyx_t_23 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_21, __pyx_v_t};
              __pyx_t_20 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_23, 2+__pyx_t_23);
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
              if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3325, __pyx_L51_error)
              __Pyx_GOTREF(__pyx_t_20);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_20); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3325, __pyx_L51_error)
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;

            /* "cPyparsing.pyx":3326
 *                 if '\n' in t:
 *                     out.append(line(pe.loc, t))
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)             # <<<<<<<<<<<<<<
 *                 else:
 *                     out.append(' ' * pe.loc + '^' + fatal)
 */
            __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3326, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_loc); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 3326, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_21);
            __pyx_t_3 = NULL;
            __pyx_t_23 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_3)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_3);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
                __pyx_t_23 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_21, __pyx_v_t};
              __pyx_t_20 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_23, 2+__pyx_t_23);
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
              if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3326, __pyx_L51_error)
              __Pyx_GOTREF(__pyx_t_20);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_t_20, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3326, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            __pyx_t_20 = PyNumber_Multiply(__pyx_kp_u__16, __pyx_t_8); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3326, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __pyx_t_8 = PyNumber_Add(__pyx_t_20, __pyx_kp_u__17); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3326, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            __pyx_t_20 = PyNumber_Add(__pyx_t_8, __pyx_v_fatal); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3326, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_20); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3326, __pyx_L51_error)
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;

            /* "cPyparsing.pyx":3324
 *             except ParseBaseException as pe:
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:             # <<<<<<<<<<<<<<
 *                     out.append(line(pe.loc, t))
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)
 */
            goto __pyx_L53;
          }

          /* "cPyparsing.pyx":3328
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)
 *                 else:
 *                     out.append(' ' * pe.loc + '^' + fatal)             # <<<<<<<<<<<<<<
 *                 out.append("FAIL: " + str(pe))
 *                 success = success and failureTests
 */
          /*else*/ {
            __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_loc); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3328, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_20);
            __pyx_t_8 = PyNumber_Multiply(__pyx_kp_u__16, __pyx_t_20); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3328, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            __pyx_t_20 = PyNumber_Add(__pyx_t_8, __pyx_kp_u__17); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3328, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __pyx_t_8 = PyNumber_Add(__pyx_t_20, __pyx_v_fatal); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3328, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_8); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3328, __pyx_L51_error)
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_L53:;

          /* "cPyparsing.pyx":3329
 *                 else:
 *                     out.append(' ' * pe.loc + '^' + fatal)
 *                 out.append("FAIL: " + str(pe))             # <<<<<<<<<<<<<<
 *                 success = success and failureTests
 *                 result = pe
 */
          __Pyx_GetModuleGlobalName(__pyx_t_20, __pyx_n_s_str); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3329, __pyx_L51_error)
          __Pyx_GOTREF(__pyx_t_20);
          __pyx_t_21 = NULL;
          __pyx_t_23 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_20))) {
            __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_20);
            if (likely(__pyx_t_21)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
              __Pyx_INCREF(__pyx_t_21);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_20, function);
              __pyx_t_23 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_v_pe};
            __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_20, __pyx_callargs+1-__pyx_t_23, 1+__pyx_t_23);
            __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3329, __pyx_L51_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
          }
          __pyx_t_20 = PyNumber_Add(__pyx_kp_u_FAIL_2, __pyx_t_8); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3329, __pyx_L51_error)
          __Pyx_GOTREF(__pyx_t_20);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_20); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3329, __pyx_L51_error)
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;

          /* "cPyparsing.pyx":3330
 *                     out.append(' ' * pe.loc + '^' + fatal)
 *                 out.append("FAIL: " + str(pe))
 *                 success = success and failureTests             # <<<<<<<<<<<<<<
 *                 result = pe
 *             except Exception as exc:
 */
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_success); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3330, __pyx_L51_error)
          if (__pyx_t_2) {
          } else {
            __Pyx_INCREF(__pyx_v_success);
            __pyx_t_20 = __pyx_v_success;
            goto __pyx_L54_bool_binop_done;
          }
          __Pyx_INCREF(__pyx_v_failureTests);
          __pyx_t_20 = __pyx_v_failureTests;
          __pyx_L54_bool_binop_done:;
          __Pyx_DECREF_SET(__pyx_v_success, __pyx_t_20);
          __pyx_t_20 = 0;

          /* "cPyparsing.pyx":3331
 *                 out.append("FAIL: " + str(pe))
 *                 success = success and failureTests
 *                 result = pe             # <<<<<<<<<<<<<<
 *             except Exception as exc:
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 */
          __Pyx_INCREF(__pyx_v_pe);
          __Pyx_XDECREF_SET(__pyx_v_result, __pyx_v_pe);
        }

        /* "cPyparsing.pyx":3322
 *                 t = NL.transformString(t.lstrip(BOM))
 *                 result = self.parseString(t, parseAll=parseAll)
 *             except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_pe); __pyx_v_pe = 0;
            goto __pyx_L52;
          }
          __pyx_L51_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0; __pyx_t_28 = 0;
            __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
            __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
            __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_30, &__pyx_t_29, &__pyx_t_28);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_30);
            __Pyx_XGOTREF(__pyx_t_29);
            __Pyx_XGOTREF(__pyx_t_28);
            __pyx_t_23 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_31 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_pe); __pyx_v_pe = 0;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_30);
              __Pyx_XGIVEREF(__pyx_t_29);
              __Pyx_XGIVEREF(__pyx_t_28);
              __Pyx_ExceptionReset(__pyx_t_30, __pyx_t_29, __pyx_t_28);
            }
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_ErrRestore(__pyx_t_19, __pyx_t_18, __pyx_t_17);
            __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0; __pyx_t_28 = 0;
            __pyx_lineno = __pyx_t_23; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_31;
            goto __pyx_L16_except_error;
          }
          __pyx_L52:;
        }
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L15_exception_handled;
      }

      /* "cPyparsing.pyx":3332
 *                 success = success and failureTests
 *                 result = pe
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 *                 success = success and failureTests
 */
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_7) {
        __Pyx_AddTraceback("cPyparsing.ParserElement.runTests", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 3332, __pyx_L16_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_v_exc = __pyx_t_5;
        /*try:*/ {

          /* "cPyparsing.pyx":3333
 *                 result = pe
 *             except Exception as exc:
 *                 out.append("FAIL-EXCEPTION: " + str(exc))             # <<<<<<<<<<<<<<
 *                 success = success and failureTests
 *                 result = exc
 */
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3333, __pyx_L65_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_21 = NULL;
          __pyx_t_7 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_21)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_21);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_7 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_v_exc};
            __pyx_t_20 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
            __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
            if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 3333, __pyx_L65_error)
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_t_8 = PyNumber_Add(__pyx_kp_u_FAIL_EXCEPTION, __pyx_t_20); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3333, __pyx_L65_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
          __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_8); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3333, __pyx_L65_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "cPyparsing.pyx":3334
 *             except Exception as exc:
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 *                 success = success and failureTests             # <<<<<<<<<<<<<<
 *                 result = exc
 *             else:
 */
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_success); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3334, __pyx_L65_error)
          if (__pyx_t_2) {
          } else {
            __Pyx_INCREF(__pyx_v_success);
            __pyx_t_8 = __pyx_v_success;
            goto __pyx_L67_bool_binop_done;
          }
          __Pyx_INCREF(__pyx_v_failureTests);
          __pyx_t_8 = __pyx_v_failureTests;
          __pyx_L67_bool_binop_done:;
          __Pyx_DECREF_SET(__pyx_v_success, __pyx_t_8);
          __pyx_t_8 = 0;

          /* "cPyparsing.pyx":3335
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 *                 success = success and failureTests
 *                 result = exc             # <<<<<<<<<<<<<<
 *             else:
 *                 success = success and not failureTests
 */
          __Pyx_INCREF(__pyx_v_exc);
          __Pyx_XDECREF_SET(__pyx_v_result, __pyx_v_exc);
        }

        /* "cPyparsing.pyx":3332
 *                 success = success and failureTests
 *                 result = pe
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 *                 success = success and failureTests
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_exc); __pyx_v_exc = 0;
            goto __pyx_L66;
          }
          __pyx_L65_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
            __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
            __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
            __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_28, &__pyx_t_29, &__pyx_t_30) < 0)) __Pyx_ErrFetch(&__pyx_t_28, &__pyx_t_29, &__pyx_t_30);
            __Pyx_XGOTREF(__pyx_t_28);
            __Pyx_XGOTREF(__pyx_t_29);
            __Pyx_XGOTREF(__pyx_t_30);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __pyx_t_7 = __pyx_lineno; __pyx_t_23 = __pyx_clineno; __pyx_t_32 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc); __pyx_v_exc = 0;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            }
            __Pyx_XGIVEREF(__pyx_t_28);
            __Pyx_XGIVEREF(__pyx_t_29);
            __Pyx_XGIVEREF(__pyx_t_30);
            __Pyx_ErrRestore(__pyx_t_28, __pyx_t_29, __pyx_t_30);
            __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
            __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_23; __pyx_filename = __pyx_t_32;
            goto __pyx_L16_except_error;
          }
          __pyx_L66:;
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L15_exception_handled;
      }
      goto __pyx_L16_except_error;

      /* "cPyparsing.pyx":3318
 *             out = ['\n' + '\n'.join(comments) if comments else '', t]
 *             comments = []
 *             try:             # <<<<<<<<<<<<<<
 *                 # convert newline marks to actual newlines, and strip leading BOM if present
 *                 t = NL.transformString(t.lstrip(BOM))
 */
      __pyx_L16_except_error:;
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      goto __pyx_L1_error;
      __pyx_L15_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      __pyx_L21_try_end:;
    }

    /* "cPyparsing.pyx":3354
 *                     out.append(result.dump(full=fullDump))
 * 
 *             if printResults:             # <<<<<<<<<<<<<<
 *                 if fullDump:
 *                     out.append('')
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_printResults); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3354, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3355
 * 
 *             if printResults:
 *                 if fullDump:             # <<<<<<<<<<<<<<
 *                     out.append('')
 *                 print_('\n'.join(out))
 */
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_fullDump); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3355, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":3356
 *             if printResults:
 *                 if fullDump:
 *                     out.append('')             # <<<<<<<<<<<<<<
 *                 print_('\n'.join(out))
 * 
 */
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_out, __pyx_kp_u__10); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3356, __pyx_L1_error)

        /* "cPyparsing.pyx":3355
 * 
 *             if printResults:
 *                 if fullDump:             # <<<<<<<<<<<<<<
 *                     out.append('')
 *                 print_('\n'.join(out))
 */
      }

      /* "cPyparsing.pyx":3357
 *                 if fullDump:
 *                     out.append('')
 *                 print_('\n'.join(out))             # <<<<<<<<<<<<<<
 * 
 *             allResults.append((t, result))
 */
      __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__19, __pyx_v_out); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_print_);
      __pyx_t_6 = __pyx_v_print_; __pyx_t_8 = NULL;
      __pyx_t_23 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_23 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_23, 1+__pyx_t_23);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3357, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":3354
 *                     out.append(result.dump(full=fullDump))
 * 
 *             if printResults:             # <<<<<<<<<<<<<<
 *                 if fullDump:
 *                     out.append('')
 */
    }

    /* "cPyparsing.pyx":3359
 *                 print_('\n'.join(out))
 * 
 *             allResults.append((t, result))             # <<<<<<<<<<<<<<
 * 
 *         return success, allResults
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3359, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_t);
    __Pyx_GIVEREF(__pyx_v_t);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_t)) __PYX_ERR(0, 3359, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_result);
    __Pyx_GIVEREF(__pyx_v_result);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_result)) __PYX_ERR(0, 3359, __pyx_L1_error);
    __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_allResults, __pyx_t_4); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3359, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3310
 *         NL = Literal(r'\n').addParseAction(replaceWith('\n')).ignore(quotedString)
 *         BOM = u'\ufeff'
 *         for t in tests:             # <<<<<<<<<<<<<<
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 *                 comments.append(t)
 */
    __pyx_L6_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3361
 *             allResults.append((t, result))
 * 
 *         return success, allResults             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_success);
  __Pyx_GIVEREF(__pyx_v_success);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_success)) __PYX_ERR(0, 3361, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_allResults);
  __Pyx_GIVEREF(__pyx_v_allResults);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_allResults)) __PYX_ERR(0, 3361, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3201
 *             return False
 * 
 *     def runTests(self, tests, parseAll=True, comment='#',             # <<<<<<<<<<<<<<
 *                  fullDump=True, printResults=True, failureTests=False, postParse=None,
 *                  file=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_AddTraceback("cPyparsing.ParserElement.runTests", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_print_);
  __Pyx_XDECREF(__pyx_v_allResults);
  __Pyx_XDECREF(__pyx_v_comments);
  __Pyx_XDECREF(__pyx_v_success);
  __Pyx_XDECREF(__pyx_v_NL);
  __Pyx_XDECREF(__pyx_v_BOM);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_pe);
  __Pyx_XDECREF(__pyx_v_fatal);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_pp_value);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_tests);
  __Pyx_XDECREF(__pyx_v_comment);
  __Pyx_XDECREF(__pyx_v_file);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3367
 *     # internal placeholder class to hold a place were '...' is added to a parser element,
 *     # once another ParserElement is added, this placeholder will be replaced with a SkipTo
 *     def __init__(self, expr, must_skip=False):             # <<<<<<<<<<<<<<
 *         super(_PendingSkip, self).__init__()
 *         self.strRepr = str(expr + Empty()).replace('Empty', '...')
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12_PendingSkip___init__, "_PendingSkip.__init__(self, expr, must_skip=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_12_PendingSkip_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12_PendingSkip_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12_PendingSkip___init__};
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_must_skip = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_must_skip,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3367, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3367, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3367, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_must_skip);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3367, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3367, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_must_skip = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 3367, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12_PendingSkip___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_must_skip);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_must_skip) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3368
 *     # once another ParserElement is added, this placeholder will be replaced with a SkipTo
 *     def __init__(self, expr, must_skip=False):
 *         super(_PendingSkip, self).__init__()             # <<<<<<<<<<<<<<
 *         self.strRepr = str(expr + Empty()).replace('Empty', '...')
 *         self.name = self.strRepr
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PendingSkip); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3368, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3368, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3369
 *     def __init__(self, expr, must_skip=False):
 *         super(_PendingSkip, self).__init__()
 *         self.strRepr = str(expr + Empty()).replace('Empty', '...')             # <<<<<<<<<<<<<<
 *         self.name = self.strRepr
 *         self.anchor = expr
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Empty); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyNumber_Add(__pyx_v_expr, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__68, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_1) < 0) __PYX_ERR(0, 3369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3370
 *         super(_PendingSkip, self).__init__()
 *         self.strRepr = str(expr + Empty()).replace('Empty', '...')
 *         self.name = self.strRepr             # <<<<<<<<<<<<<<
 *         self.anchor = expr
 *         self.must_skip = must_skip
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_t_1) < 0) __PYX_ERR(0, 3370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3371
 *         self.strRepr = str(expr + Empty()).replace('Empty', '...')
 *         self.name = self.strRepr
 *         self.anchor = expr             # <<<<<<<<<<<<<<
 *         self.must_skip = must_skip
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_anchor, __pyx_v_expr) < 0) __PYX_ERR(0, 3371, __pyx_L1_error)

  /* "cPyparsing.pyx":3372
 *         self.name = self.strRepr
 *         self.anchor = expr
 *         self.must_skip = must_skip             # <<<<<<<<<<<<<<
 * 
 *     def __add__(self, other):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_must_skip, __pyx_v_must_skip) < 0) __PYX_ERR(0, 3372, __pyx_L1_error)

  /* "cPyparsing.pyx":3367
 *     # internal placeholder class to hold a place were '...' is added to a parser element,
 *     # once another ParserElement is added, this placeholder will be replaced with a SkipTo
 *     def __init__(self, expr, must_skip=False):             # <<<<<<<<<<<<<<
 *         super(_PendingSkip, self).__init__()
 *         self.strRepr = str(expr + Empty()).replace('Empty', '...')
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3374
 *         self.must_skip = must_skip
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_3__add__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12_PendingSkip_2__add__, "_PendingSkip.__add__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_12_PendingSkip_3__add__ = {"__add__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12_PendingSkip_3__add__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12_PendingSkip_2__add__};
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_3__add__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__add__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3374, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3374, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, 1); __PYX_ERR(0, 3374, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__add__") < 0)) __PYX_ERR(0, 3374, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3374, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12_PendingSkip_2__add__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3377
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 *             def must_skip(t):             # <<<<<<<<<<<<<<
 *                 if not t._skipped or t._skipped.asList() == ['']:
 *                     del t[0]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_7__add___1must_skip(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12_PendingSkip_7__add___1must_skip = {"must_skip", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12_PendingSkip_7__add___1must_skip, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_7__add___1must_skip(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("must_skip (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3377, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "must_skip") < 0)) __PYX_ERR(0, 3377, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("must_skip", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3377, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__add__.must_skip", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12_PendingSkip_7__add___must_skip(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_7__add___must_skip(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("must_skip", 1);

  /* "cPyparsing.pyx":3378
 *         if self.must_skip:
 *             def must_skip(t):
 *                 if not t._skipped or t._skipped.asList() == ['']:             # <<<<<<<<<<<<<<
 *                     del t[0]
 *                     t.pop("_skipped", None)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_skipped_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (!__pyx_t_3);
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_skipped_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_asList); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_kp_u__10);
  __Pyx_GIVEREF(__pyx_kp_u__10);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_kp_u__10)) __PYX_ERR(0, 3378, __pyx_L1_error);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3379
 *             def must_skip(t):
 *                 if not t._skipped or t._skipped.asList() == ['']:
 *                     del t[0]             # <<<<<<<<<<<<<<
 *                     t.pop("_skipped", None)
 *             def show_skip(t):
 */
    if (unlikely((__Pyx_DelItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1) < 0))) __PYX_ERR(0, 3379, __pyx_L1_error)

    /* "cPyparsing.pyx":3380
 *                 if not t._skipped or t._skipped.asList() == ['']:
 *                     del t[0]
 *                     t.pop("_skipped", None)             # <<<<<<<<<<<<<<
 *             def show_skip(t):
 *                 if t._skipped.asList()[-1:] == ['']:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pop); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__69, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":3378
 *         if self.must_skip:
 *             def must_skip(t):
 *                 if not t._skipped or t._skipped.asList() == ['']:             # <<<<<<<<<<<<<<
 *                     del t[0]
 *                     t.pop("_skipped", None)
 */
  }

  /* "cPyparsing.pyx":3377
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 *             def must_skip(t):             # <<<<<<<<<<<<<<
 *                 if not t._skipped or t._skipped.asList() == ['']:
 *                     del t[0]
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__add__.must_skip", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3381
 *                     del t[0]
 *                     t.pop("_skipped", None)
 *             def show_skip(t):             # <<<<<<<<<<<<<<
 *                 if t._skipped.asList()[-1:] == ['']:
 *                     skipped = t.pop('_skipped')
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_7__add___3show_skip(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12_PendingSkip_7__add___3show_skip = {"show_skip", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12_PendingSkip_7__add___3show_skip, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_7__add___3show_skip(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("show_skip (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3381, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "show_skip") < 0)) __PYX_ERR(0, 3381, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("show_skip", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3381, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__add__.show_skip", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12_PendingSkip_7__add___2show_skip(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_7__add___2show_skip(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *__pyx_outer_scope;
  CYTHON_UNUSED PyObject *__pyx_v_skipped = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("show_skip", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":3382
 *                     t.pop("_skipped", None)
 *             def show_skip(t):
 *                 if t._skipped.asList()[-1:] == ['']:             # <<<<<<<<<<<<<<
 *                     skipped = t.pop('_skipped')
 *                     t['_skipped'] = 'missing <' + repr(self.anchor) + '>'
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_skipped_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, -1L, 0, NULL, NULL, &__pyx_slice__70, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_kp_u__10);
  __Pyx_GIVEREF(__pyx_kp_u__10);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u__10)) __PYX_ERR(0, 3382, __pyx_L1_error);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_3, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3383
 *             def show_skip(t):
 *                 if t._skipped.asList()[-1:] == ['']:
 *                     skipped = t.pop('_skipped')             # <<<<<<<<<<<<<<
 *                     t['_skipped'] = 'missing <' + repr(self.anchor) + '>'
 *             return (self.anchor + skipper().addParseAction(must_skip)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_skipped_2};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_v_skipped = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3384
 *                 if t._skipped.asList()[-1:] == ['']:
 *                     skipped = t.pop('_skipped')
 *                     t['_skipped'] = 'missing <' + repr(self.anchor) + '>'             # <<<<<<<<<<<<<<
 *             return (self.anchor + skipper().addParseAction(must_skip)
 *                     | skipper().addParseAction(show_skip)) + other
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_repr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3384, __pyx_L1_error) }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_anchor); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3384, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = PyNumber_Add(__pyx_kp_u_missing, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__27); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyObject_SetItem(__pyx_v_t, __pyx_n_u_skipped_2, __pyx_t_2) < 0))) __PYX_ERR(0, 3384, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3382
 *                     t.pop("_skipped", None)
 *             def show_skip(t):
 *                 if t._skipped.asList()[-1:] == ['']:             # <<<<<<<<<<<<<<
 *                     skipped = t.pop('_skipped')
 *                     t['_skipped'] = 'missing <' + repr(self.anchor) + '>'
 */
  }

  /* "cPyparsing.pyx":3381
 *                     del t[0]
 *                     t.pop("_skipped", None)
 *             def show_skip(t):             # <<<<<<<<<<<<<<
 *                 if t._skipped.asList()[-1:] == ['']:
 *                     skipped = t.pop('_skipped')
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__add__.show_skip", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_skipped);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3374
 *         self.must_skip = must_skip
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 */

static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_2__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *__pyx_cur_scope;
  PyObject *__pyx_v_skipper = NULL;
  PyObject *__pyx_v_must_skip = 0;
  PyObject *__pyx_v_show_skip = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__add__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_23___add__(__pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3374, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3375
 * 
 *     def __add__(self, other):
 *         skipper = SkipTo(other).setName("...")("_skipped*")             # <<<<<<<<<<<<<<
 *         if self.must_skip:
 *             def must_skip(t):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_SkipTo); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_other};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u__67};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_skipped};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_skipper = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3376
 *     def __add__(self, other):
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:             # <<<<<<<<<<<<<<
 *             def must_skip(t):
 *                 if not t._skipped or t._skipped.asList() == ['']:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_must_skip); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3376, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":3377
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 *             def must_skip(t):             # <<<<<<<<<<<<<<
 *                 if not t._skipped or t._skipped.asList() == ['']:
 *                     del t[0]
 */
    __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12_PendingSkip_7__add___1must_skip, 0, __pyx_n_s_PendingSkip___add___locals_must, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__72)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_must_skip = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3381
 *                     del t[0]
 *                     t.pop("_skipped", None)
 *             def show_skip(t):             # <<<<<<<<<<<<<<
 *                 if t._skipped.asList()[-1:] == ['']:
 *                     skipped = t.pop('_skipped')
 */
    __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12_PendingSkip_7__add___3show_skip, 0, __pyx_n_s_PendingSkip___add___locals_show, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__74)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3381, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_show_skip = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3385
 *                     skipped = t.pop('_skipped')
 *                     t['_skipped'] = 'missing <' + repr(self.anchor) + '>'
 *             return (self.anchor + skipper().addParseAction(must_skip)             # <<<<<<<<<<<<<<
 *                     | skipper().addParseAction(show_skip)) + other
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_anchor); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_skipper);
    __pyx_t_3 = __pyx_v_skipper; __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_must_skip};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3386
 *                     t['_skipped'] = 'missing <' + repr(self.anchor) + '>'
 *             return (self.anchor + skipper().addParseAction(must_skip)
 *                     | skipper().addParseAction(show_skip)) + other             # <<<<<<<<<<<<<<
 * 
 *         return self.anchor + skipper + other
 */
    __Pyx_INCREF(__pyx_v_skipper);
    __pyx_t_4 = __pyx_v_skipper; __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_show_skip};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = PyNumber_Or(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_v_other); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3376
 *     def __add__(self, other):
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:             # <<<<<<<<<<<<<<
 *             def must_skip(t):
 *                 if not t._skipped or t._skipped.asList() == ['']:
 */
  }

  /* "cPyparsing.pyx":3388
 *                     | skipper().addParseAction(show_skip)) + other
 * 
 *         return self.anchor + skipper + other             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_anchor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_v_skipper); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_v_other); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3374
 *         self.must_skip = must_skip
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_skipper);
  __Pyx_XDECREF(__pyx_v_must_skip);
  __Pyx_XDECREF(__pyx_v_show_skip);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3390
 *         return self.anchor + skipper + other
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.strRepr
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_5__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12_PendingSkip_4__repr__, "_PendingSkip.__repr__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12_PendingSkip_5__repr__ = {"__repr__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12_PendingSkip_5__repr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12_PendingSkip_4__repr__};
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_5__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3390, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__repr__") < 0)) __PYX_ERR(0, 3390, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__repr__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3390, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12_PendingSkip_4__repr__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "cPyparsing.pyx":3391
 * 
 *     def __repr__(self):
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, *args):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3390
 *         return self.anchor + skipper + other
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.strRepr
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._PendingSkip.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3393
 *         return self.strRepr
 * 
 *     def parseImpl(self, *args):             # <<<<<<<<<<<<<<
 *         raise Exception("use of `...` expression without following SkipTo target expression")
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_7parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12_PendingSkip_6parseImpl, "_PendingSkip.parseImpl(self, *args)");
static PyMethodDef __pyx_mdef_10cPyparsing_12_PendingSkip_7parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12_PendingSkip_7parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12_PendingSkip_6parseImpl};
static PyObject *__pyx_pw_10cPyparsing_12_PendingSkip_7parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3393, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3393, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 3393, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("cPyparsing._PendingSkip.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12_PendingSkip_6parseImpl(__pyx_self, __pyx_v_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12_PendingSkip_6parseImpl(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":3394
 * 
 *     def parseImpl(self, *args):
 *         raise Exception("use of `...` expression without following SkipTo target expression")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__75, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 3394, __pyx_L1_error)

  /* "cPyparsing.pyx":3393
 *         return self.strRepr
 * 
 *     def parseImpl(self, *args):             # <<<<<<<<<<<<<<
 *         raise Exception("use of `...` expression without following SkipTo target expression")
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._PendingSkip.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3401
 *     matching patterns.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Token, self).__init__(savelist=False)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Token_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Token___init__, "Token.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_5Token_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Token_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Token___init__};
static PyObject *__pyx_pw_10cPyparsing_5Token_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3401, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3401, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3401, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Token.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Token___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Token___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3402
 *     """
 *     def __init__(self):
 *         super(Token, self).__init__(savelist=False)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Token); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 3402, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self)) __PYX_ERR(0, 3402, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_savelist, Py_False) < 0) __PYX_ERR(0, 3402, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3401
 *     matching patterns.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Token, self).__init__(savelist=False)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Token.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3408
 *     """An empty token, will always match.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Empty_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Empty___init__, "Empty.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_5Empty_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Empty_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Empty___init__};
static PyObject *__pyx_pw_10cPyparsing_5Empty_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3408, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3408, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3408, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Empty.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Empty___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Empty___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3409
 *     """
 *     def __init__(self):
 *         super(Empty, self).__init__()             # <<<<<<<<<<<<<<
 *         self.name = "Empty"
 *         self.mayReturnEmpty = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3409, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3409, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3410
 *     def __init__(self):
 *         super(Empty, self).__init__()
 *         self.name = "Empty"             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_n_u_Empty) < 0) __PYX_ERR(0, 3410, __pyx_L1_error)

  /* "cPyparsing.pyx":3411
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 3411, __pyx_L1_error)

  /* "cPyparsing.pyx":3412
 *         self.name = "Empty"
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 3412, __pyx_L1_error)

  /* "cPyparsing.pyx":3408
 *     """An empty token, will always match.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Empty.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3418
 *     """A token that will never match.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7NoMatch_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7NoMatch___init__, "NoMatch.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_7NoMatch_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7NoMatch_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7NoMatch___init__};
static PyObject *__pyx_pw_10cPyparsing_7NoMatch_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3418, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3418, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3418, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.NoMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7NoMatch___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7NoMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3419
 *     """
 *     def __init__(self):
 *         super(NoMatch, self).__init__()             # <<<<<<<<<<<<<<
 *         self.name = "NoMatch"
 *         self.mayReturnEmpty = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_NoMatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3419, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3419, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3420
 *     def __init__(self):
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_n_u_NoMatch) < 0) __PYX_ERR(0, 3420, __pyx_L1_error)

  /* "cPyparsing.pyx":3421
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.errmsg = "Unmatchable token"
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 3421, __pyx_L1_error)

  /* "cPyparsing.pyx":3422
 *         self.name = "NoMatch"
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.errmsg = "Unmatchable token"
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 3422, __pyx_L1_error)

  /* "cPyparsing.pyx":3423
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 *         self.errmsg = "Unmatchable token"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Unmatchable_token) < 0) __PYX_ERR(0, 3423, __pyx_L1_error)

  /* "cPyparsing.pyx":3418
 *     """A token that will never match.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.NoMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3425
 *         self.errmsg = "Unmatchable token"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7NoMatch_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7NoMatch_2parseImpl, "NoMatch.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_7NoMatch_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7NoMatch_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7NoMatch_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_7NoMatch_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3425, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3425, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3425, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3425, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3425, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3425, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3425, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 3425, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.NoMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7NoMatch_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7NoMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":3426
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 3426, __pyx_L1_error)

  /* "cPyparsing.pyx":3425
 *         self.errmsg = "Unmatchable token"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.NoMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3443
 *     use :class:`Keyword` or :class:`CaselessKeyword`.
 *     """
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(Literal, self).__init__()
 *         self.match = matchString
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Literal_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Literal___init__, "Literal.__init__(self, matchString)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Literal_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Literal_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Literal___init__};
static PyObject *__pyx_pw_10cPyparsing_7Literal_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_matchString = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_matchString,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3443, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_matchString)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3443, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 3443, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3443, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_matchString = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3443, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Literal.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Literal___init__(__pyx_self, __pyx_v_self, __pyx_v_matchString);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Literal___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3444
 *     """
 *     def __init__(self, matchString):
 *         super(Literal, self).__init__()             # <<<<<<<<<<<<<<
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3444, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3444, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3445
 *     def __init__(self, matchString):
 *         super(Literal, self).__init__()
 *         self.match = matchString             # <<<<<<<<<<<<<<
 *         self.matchLen = len(matchString)
 *         try:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_match, __pyx_v_matchString) < 0) __PYX_ERR(0, 3445, __pyx_L1_error)

  /* "cPyparsing.pyx":3446
 *         super(Literal, self).__init__()
 *         self.match = matchString
 *         self.matchLen = len(matchString)             # <<<<<<<<<<<<<<
 *         try:
 *             self.firstMatchChar = matchString[0]
 */
  __pyx_t_5 = PyObject_Length(__pyx_v_matchString); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3446, __pyx_L1_error)
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_matchLen, __pyx_t_1) < 0) __PYX_ERR(0, 3446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3447
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "cPyparsing.pyx":3448
 *         self.matchLen = len(matchString)
 *         try:
 *             self.firstMatchChar = matchString[0]             # <<<<<<<<<<<<<<
 *         except IndexError:
 *             warnings.warn("null string passed to Literal; use Empty() instead",
 */
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_matchString, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3448, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_firstMatchChar, __pyx_t_1) < 0) __PYX_ERR(0, 3448, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3447
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3449
 *         try:
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:             # <<<<<<<<<<<<<<
 *             warnings.warn("null string passed to Literal; use Empty() instead",
 *                             SyntaxWarning, stacklevel=2)
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
    if (__pyx_t_4) {
      __Pyx_AddTraceback("cPyparsing.Literal.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 3449, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_2);

      /* "cPyparsing.pyx":3450
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Literal; use Empty() instead",             # <<<<<<<<<<<<<<
 *                             SyntaxWarning, stacklevel=2)
 *             self.__class__ = Empty
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_warnings); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3450, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_warn); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3450, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "cPyparsing.pyx":3451
 *         except IndexError:
 *             warnings.warn("null string passed to Literal; use Empty() instead",
 *                             SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             self.__class__ = Empty
 *         self.name = '"%s"' % _ustr(self.match)
 */
      __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3451, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 3451, __pyx_L5_except_error)

      /* "cPyparsing.pyx":3450
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Literal; use Empty() instead",             # <<<<<<<<<<<<<<
 *                             SyntaxWarning, stacklevel=2)
 *             self.__class__ = Empty
 */
      __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__76, __pyx_t_9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3450, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "cPyparsing.pyx":3452
 *             warnings.warn("null string passed to Literal; use Empty() instead",
 *                             SyntaxWarning, stacklevel=2)
 *             self.__class__ = Empty             # <<<<<<<<<<<<<<
 *         self.name = '"%s"' % _ustr(self.match)
 *         self.errmsg = "Expected " + self.name
 */
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_Empty); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3452, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_class, __pyx_t_11) < 0) __PYX_ERR(0, 3452, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":3447
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    __pyx_L8_try_end:;
  }

  /* "cPyparsing.pyx":3453
 *                             SyntaxWarning, stacklevel=2)
 *             self.__class__ = Empty
 *         self.name = '"%s"' % _ustr(self.match)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_11 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_1};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_2, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_t_3) < 0) __PYX_ERR(0, 3453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3454
 *             self.__class__ = Empty
 *         self.name = '"%s"' % _ustr(self.match)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 3454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3455
 *         self.name = '"%s"' % _ustr(self.match)
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_False) < 0) __PYX_ERR(0, 3455, __pyx_L1_error)

  /* "cPyparsing.pyx":3456
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 * 
 *         # Performance tuning: modify __class__ to select
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 3456, __pyx_L1_error)

  /* "cPyparsing.pyx":3460
 *         # Performance tuning: modify __class__ to select
 *         # a parseImpl optimized for single-character check
 *         if self.matchLen == 1 and type(self) is Literal:             # <<<<<<<<<<<<<<
 *             self.__class__ = _SingleCharLiteral
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 3460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_13) {
  } else {
    __pyx_t_12 = __pyx_t_13;
    goto __pyx_L12_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = (((PyObject *)Py_TYPE(__pyx_v_self)) == __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_12 = __pyx_t_13;
  __pyx_L12_bool_binop_done:;
  if (__pyx_t_12) {

    /* "cPyparsing.pyx":3461
 *         # a parseImpl optimized for single-character check
 *         if self.matchLen == 1 and type(self) is Literal:
 *             self.__class__ = _SingleCharLiteral             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SingleCharLiteral); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_class, __pyx_t_2) < 0) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3460
 *         # Performance tuning: modify __class__ to select
 *         # a parseImpl optimized for single-character check
 *         if self.matchLen == 1 and type(self) is Literal:             # <<<<<<<<<<<<<<
 *             self.__class__ = _SingleCharLiteral
 * 
 */
  }

  /* "cPyparsing.pyx":3443
 *     use :class:`Keyword` or :class:`CaselessKeyword`.
 *     """
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(Literal, self).__init__()
 *         self.match = matchString
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.Literal.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3472
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] == self.firstMatchChar and instring.startswith(self.match, loc):
 *             return loc + self.matchLen, self.match
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Literal_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Literal_2parseImpl, "Literal.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Literal_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Literal_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Literal_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_7Literal_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3472, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3472, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3472, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3472, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3472, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3472, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3472, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 3472, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Literal.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Literal_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Literal_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":3473
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] == self.firstMatchChar and instring.startswith(self.match, loc):             # <<<<<<<<<<<<<<
 *             return loc + self.matchLen, self.match
 *         # [CPYPARSING] update furthest_loc
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_firstMatchChar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3473, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3473, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_instring, __pyx_n_s_startswith); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_2, __pyx_v_loc};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3473, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3474
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] == self.firstMatchChar and instring.startswith(self.match, loc):
 *             return loc + self.matchLen, self.match             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3474, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Add(__pyx_v_loc, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3474, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3474, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3474, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 3474, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(0, 3474, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3473
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] == self.firstMatchChar and instring.startswith(self.match, loc):             # <<<<<<<<<<<<<<
 *             return loc + self.matchLen, self.match
 *         # [CPYPARSING] update furthest_loc
 */
  }

  /* "cPyparsing.pyx":3476
 *             return loc + self.matchLen, self.match
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_incrementalEnabled); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3476, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3477
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyNumber_Add(__pyx_v_loc, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_instring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = PyObject_RichCompare(__pyx_t_2, __pyx_t_4, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3477, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3477, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_1) {
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = __pyx_t_2;
    } else {
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_3 = __pyx_t_4;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __pyx_t_3;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely((PyObject_SetItem(__pyx_t_4, __pyx_v_instring, __pyx_t_2) < 0))) __PYX_ERR(0, 3477, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3476
 *             return loc + self.matchLen, self.match
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  }

  /* "cPyparsing.pyx":3478
 *         if ParserElement._incrementalEnabled:
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * class _SingleCharLiteral(Literal):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(0, 3478, __pyx_L1_error)

  /* "cPyparsing.pyx":3472
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] == self.firstMatchChar and instring.startswith(self.match, loc):
 *             return loc + self.matchLen, self.match
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Literal.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3481
 * 
 * class _SingleCharLiteral(Literal):
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] == self.firstMatchChar:
 *             return loc + 1, self.match
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18_SingleCharLiteral_1parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18_SingleCharLiteral_parseImpl, "_SingleCharLiteral.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_18_SingleCharLiteral_1parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18_SingleCharLiteral_1parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18_SingleCharLiteral_parseImpl};
static PyObject *__pyx_pw_10cPyparsing_18_SingleCharLiteral_1parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3481, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3481, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3481, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3481, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3481, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3481, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3481, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 3481, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._SingleCharLiteral.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18_SingleCharLiteral_parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18_SingleCharLiteral_parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":3482
 * class _SingleCharLiteral(Literal):
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] == self.firstMatchChar:             # <<<<<<<<<<<<<<
 *             return loc + 1, self.match
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_firstMatchChar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3482, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3482, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":3483
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] == self.firstMatchChar:
 *             return loc + 1, self.match             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3)) __PYX_ERR(0, 3483, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2)) __PYX_ERR(0, 3483, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3482
 * class _SingleCharLiteral(Literal):
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] == self.firstMatchChar:             # <<<<<<<<<<<<<<
 *             return loc + 1, self.match
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  }

  /* "cPyparsing.pyx":3484
 *         if instring[loc] == self.firstMatchChar:
 *             return loc + 1, self.match
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * _L = Literal
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 3484, __pyx_L1_error)

  /* "cPyparsing.pyx":3481
 * 
 * class _SingleCharLiteral(Literal):
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] == self.firstMatchChar:
 *             return loc + 1, self.match
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing._SingleCharLiteral.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3516
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):             # <<<<<<<<<<<<<<
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Keyword_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Keyword___init__, "Keyword.__init__(self, matchString, identChars=None, caseless=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Keyword_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Keyword_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Keyword___init__};
static PyObject *__pyx_pw_10cPyparsing_7Keyword_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_matchString = 0;
  PyObject *__pyx_v_identChars = 0;
  PyObject *__pyx_v_caseless = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_matchString,&__pyx_n_s_identChars,&__pyx_n_s_caseless,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3516, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_matchString)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3516, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, 1); __PYX_ERR(0, 3516, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_identChars);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3516, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_caseless);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3516, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3516, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_matchString = values[1];
    __pyx_v_identChars = values[2];
    __pyx_v_caseless = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 3516, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Keyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Keyword___init__(__pyx_self, __pyx_v_self, __pyx_v_matchString, __pyx_v_identChars, __pyx_v_caseless);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Keyword___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString, PyObject *__pyx_v_identChars, PyObject *__pyx_v_caseless) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_identChars);

  /* "cPyparsing.pyx":3517
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):
 *         super(Keyword, self).__init__()             # <<<<<<<<<<<<<<
 *         if identChars is None:
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3517, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3517, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3518
 *     def __init__(self, matchString, identChars=None, caseless=False):
 *         super(Keyword, self).__init__()
 *         if identChars is None:             # <<<<<<<<<<<<<<
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         self.match = matchString
 */
  __pyx_t_5 = (__pyx_v_identChars == Py_None);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3519
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS             # <<<<<<<<<<<<<<
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_KEYWORD_CHARS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_identChars, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3518
 *     def __init__(self, matchString, identChars=None, caseless=False):
 *         super(Keyword, self).__init__()
 *         if identChars is None:             # <<<<<<<<<<<<<<
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         self.match = matchString
 */
  }

  /* "cPyparsing.pyx":3520
 *         if identChars is None:
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         self.match = matchString             # <<<<<<<<<<<<<<
 *         self.matchLen = len(matchString)
 *         try:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_match, __pyx_v_matchString) < 0) __PYX_ERR(0, 3520, __pyx_L1_error)

  /* "cPyparsing.pyx":3521
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         self.match = matchString
 *         self.matchLen = len(matchString)             # <<<<<<<<<<<<<<
 *         try:
 *             self.firstMatchChar = matchString[0]
 */
  __pyx_t_6 = PyObject_Length(__pyx_v_matchString); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3521, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_matchLen, __pyx_t_3) < 0) __PYX_ERR(0, 3521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3522
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "cPyparsing.pyx":3523
 *         self.matchLen = len(matchString)
 *         try:
 *             self.firstMatchChar = matchString[0]             # <<<<<<<<<<<<<<
 *         except IndexError:
 *             warnings.warn("null string passed to Keyword; use Empty() instead",
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_matchString, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3523, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_firstMatchChar, __pyx_t_3) < 0) __PYX_ERR(0, 3523, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":3522
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
    }
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3524
 *         try:
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:             # <<<<<<<<<<<<<<
 *             warnings.warn("null string passed to Keyword; use Empty() instead",
 *                           SyntaxWarning, stacklevel=2)
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
    if (__pyx_t_4) {
      __Pyx_AddTraceback("cPyparsing.Keyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 3524, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_2);

      /* "cPyparsing.pyx":3525
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Keyword; use Empty() instead",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *         self.name = '"%s"' % self.match
 */
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_warnings); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3525, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_warn); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3525, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "cPyparsing.pyx":3526
 *         except IndexError:
 *             warnings.warn("null string passed to Keyword; use Empty() instead",
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *         self.name = '"%s"' % self.match
 *         self.errmsg = "Expected " + self.name
 */
      __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3526, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 3526, __pyx_L6_except_error)

      /* "cPyparsing.pyx":3525
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Keyword; use Empty() instead",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *         self.name = '"%s"' % self.match
 */
      __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__77, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3525, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;

    /* "cPyparsing.pyx":3522
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    __pyx_L9_try_end:;
  }

  /* "cPyparsing.pyx":3527
 *             warnings.warn("null string passed to Keyword; use Empty() instead",
 *                           SyntaxWarning, stacklevel=2)
 *         self.name = '"%s"' % self.match             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_2, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_t_1) < 0) __PYX_ERR(0, 3527, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3528
 *                           SyntaxWarning, stacklevel=2)
 *         self.name = '"%s"' % self.match
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 3528, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3529
 *         self.name = '"%s"' % self.match
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.caseless = caseless
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_False) < 0) __PYX_ERR(0, 3529, __pyx_L1_error)

  /* "cPyparsing.pyx":3530
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.caseless = caseless
 *         if caseless:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 3530, __pyx_L1_error)

  /* "cPyparsing.pyx":3531
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False
 *         self.caseless = caseless             # <<<<<<<<<<<<<<
 *         if caseless:
 *             self.caselessmatch = matchString.upper()
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_caseless, __pyx_v_caseless) < 0) __PYX_ERR(0, 3531, __pyx_L1_error)

  /* "cPyparsing.pyx":3532
 *         self.mayIndexError = False
 *         self.caseless = caseless
 *         if caseless:             # <<<<<<<<<<<<<<
 *             self.caselessmatch = matchString.upper()
 *             identChars = identChars.upper()
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_caseless); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3532, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3533
 *         self.caseless = caseless
 *         if caseless:
 *             self.caselessmatch = matchString.upper()             # <<<<<<<<<<<<<<
 *             identChars = identChars.upper()
 *         self.identChars = set(identChars)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchString, __pyx_n_s_upper); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3533, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_caselessmatch, __pyx_t_2) < 0) __PYX_ERR(0, 3533, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3534
 *         if caseless:
 *             self.caselessmatch = matchString.upper()
 *             identChars = identChars.upper()             # <<<<<<<<<<<<<<
 *         self.identChars = set(identChars)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_identChars, __pyx_n_s_upper); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3534, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_identChars, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3532
 *         self.mayIndexError = False
 *         self.caseless = caseless
 *         if caseless:             # <<<<<<<<<<<<<<
 *             self.caselessmatch = matchString.upper()
 *             identChars = identChars.upper()
 */
  }

  /* "cPyparsing.pyx":3535
 *             self.caselessmatch = matchString.upper()
 *             identChars = identChars.upper()
 *         self.identChars = set(identChars)             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  __pyx_t_2 = PySet_New(__pyx_v_identChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_identChars, __pyx_t_2) < 0) __PYX_ERR(0, 3535, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3516
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):             # <<<<<<<<<<<<<<
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.Keyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_identChars);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3560
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Keyword_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Keyword_2parseImpl, "Keyword.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Keyword_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Keyword_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Keyword_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_7Keyword_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3560, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3560, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3560, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3560, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3560, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3560, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3560, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 3560, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Keyword.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Keyword_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Keyword_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":3561
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.caseless:             # <<<<<<<<<<<<<<
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)
 *                     and (loc >= len(instring) - self.matchLen
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_caseless); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3562
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)             # <<<<<<<<<<<<<<
 *                     and (loc >= len(instring) - self.matchLen
 *                          or instring[loc + self.matchLen].upper() not in self.identChars)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyNumber_Add(__pyx_v_loc, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_loc, &__pyx_t_4, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_caselessmatch); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_2 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }

    /* "cPyparsing.pyx":3563
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)
 *                     and (loc >= len(instring) - self.matchLen             # <<<<<<<<<<<<<<
 *                          or instring[loc + self.matchLen].upper() not in self.identChars)
 *                     and (loc == 0
 */
    __pyx_t_7 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3563, __pyx_L1_error)
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyNumber_Subtract(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_1, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3563, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3563, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_6) {
    } else {
      goto __pyx_L7_next_and;
    }

    /* "cPyparsing.pyx":3564
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)
 *                     and (loc >= len(instring) - self.matchLen
 *                          or instring[loc + self.matchLen].upper() not in self.identChars)             # <<<<<<<<<<<<<<
 *                     and (loc == 0
 *                          or instring[loc - 1].upper() not in self.identChars)):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyNumber_Add(__pyx_v_loc, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_identChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_4, __pyx_t_3, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_2 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_L7_next_and:;

    /* "cPyparsing.pyx":3565
 *                     and (loc >= len(instring) - self.matchLen
 *                          or instring[loc + self.matchLen].upper() not in self.identChars)
 *                     and (loc == 0             # <<<<<<<<<<<<<<
 *                          or instring[loc - 1].upper() not in self.identChars)):
 *                 return loc + self.matchLen, self.match
 */
    __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_loc, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3565, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_2 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }

    /* "cPyparsing.pyx":3566
 *                          or instring[loc + self.matchLen].upper() not in self.identChars)
 *                     and (loc == 0
 *                          or instring[loc - 1].upper() not in self.identChars)):             # <<<<<<<<<<<<<<
 *                 return loc + self.matchLen, self.match
 * 
 */
    __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_loc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3566, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_identChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_t_4, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __pyx_t_6;
    __pyx_L5_bool_binop_done:;

    /* "cPyparsing.pyx":3562
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)             # <<<<<<<<<<<<<<
 *                     and (loc >= len(instring) - self.matchLen
 *                          or instring[loc + self.matchLen].upper() not in self.identChars)
 */
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3567
 *                     and (loc == 0
 *                          or instring[loc - 1].upper() not in self.identChars)):
 *                 return loc + self.matchLen, self.match             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3567, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyNumber_Add(__pyx_v_loc, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3567, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3567, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3567, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_3);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3)) __PYX_ERR(0, 3567, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4)) __PYX_ERR(0, 3567, __pyx_L1_error);
      __pyx_t_3 = 0;
      __pyx_t_4 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":3562
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)             # <<<<<<<<<<<<<<
 *                     and (loc >= len(instring) - self.matchLen
 *                          or instring[loc + self.matchLen].upper() not in self.identChars)
 */
    }

    /* "cPyparsing.pyx":3561
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.caseless:             # <<<<<<<<<<<<<<
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)
 *                     and (loc >= len(instring) - self.matchLen
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":3570
 * 
 *         else:
 *             if instring[loc] == self.firstMatchChar:             # <<<<<<<<<<<<<<
 *                 if ((self.matchLen == 1 or instring.startswith(self.match, loc))
 *                         and (loc >= len(instring) - self.matchLen
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_firstMatchChar); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3570, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3570, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3571
 *         else:
 *             if instring[loc] == self.firstMatchChar:
 *                 if ((self.matchLen == 1 or instring.startswith(self.match, loc))             # <<<<<<<<<<<<<<
 *                         and (loc >= len(instring) - self.matchLen
 *                              or instring[loc + self.matchLen] not in self.identChars)
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3571, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!__pyx_t_6) {
      } else {
        goto __pyx_L13_next_and;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_instring, __pyx_n_s_startswith); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_t_1, __pyx_v_loc};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3571, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3571, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
      } else {
        __pyx_t_2 = __pyx_t_6;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_L13_next_and:;

      /* "cPyparsing.pyx":3572
 *             if instring[loc] == self.firstMatchChar:
 *                 if ((self.matchLen == 1 or instring.startswith(self.match, loc))
 *                         and (loc >= len(instring) - self.matchLen             # <<<<<<<<<<<<<<
 *                              or instring[loc + self.matchLen] not in self.identChars)
 *                         and (loc == 0 or instring[loc - 1] not in self.identChars)):
 */
      __pyx_t_7 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3572, __pyx_L1_error)
      __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = PyNumber_Subtract(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_1, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3572, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3572, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!__pyx_t_6) {
      } else {
        goto __pyx_L15_next_and;
      }

      /* "cPyparsing.pyx":3573
 *                 if ((self.matchLen == 1 or instring.startswith(self.match, loc))
 *                         and (loc >= len(instring) - self.matchLen
 *                              or instring[loc + self.matchLen] not in self.identChars)             # <<<<<<<<<<<<<<
 *                         and (loc == 0 or instring[loc - 1] not in self.identChars)):
 *                     return loc + self.matchLen, self.match
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3573, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = PyNumber_Add(__pyx_v_loc, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3573, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3573, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_identChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3573, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_4, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3573, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_6) {
      } else {
        __pyx_t_2 = __pyx_t_6;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_L15_next_and:;

      /* "cPyparsing.pyx":3574
 *                         and (loc >= len(instring) - self.matchLen
 *                              or instring[loc + self.matchLen] not in self.identChars)
 *                         and (loc == 0 or instring[loc - 1] not in self.identChars)):             # <<<<<<<<<<<<<<
 *                     return loc + self.matchLen, self.match
 * 
 */
      __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_loc, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3574, __pyx_L1_error)
      if (!__pyx_t_6) {
      } else {
        __pyx_t_2 = __pyx_t_6;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_PyInt_SubtractObjC(__pyx_v_loc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3574, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3574, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_identChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3574, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_4, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3574, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = __pyx_t_6;
      __pyx_L12_bool_binop_done:;

      /* "cPyparsing.pyx":3571
 *         else:
 *             if instring[loc] == self.firstMatchChar:
 *                 if ((self.matchLen == 1 or instring.startswith(self.match, loc))             # <<<<<<<<<<<<<<
 *                         and (loc >= len(instring) - self.matchLen
 *                              or instring[loc + self.matchLen] not in self.identChars)
 */
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":3575
 *                              or instring[loc + self.matchLen] not in self.identChars)
 *                         and (loc == 0 or instring[loc - 1] not in self.identChars)):
 *                     return loc + self.matchLen, self.match             # <<<<<<<<<<<<<<
 * 
 *         # [CPYPARSING] update furthest_loc
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3575, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = PyNumber_Add(__pyx_v_loc, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3575, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3575, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3575, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_4);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 3575, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(0, 3575, __pyx_L1_error);
        __pyx_t_4 = 0;
        __pyx_t_1 = 0;
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "cPyparsing.pyx":3571
 *         else:
 *             if instring[loc] == self.firstMatchChar:
 *                 if ((self.matchLen == 1 or instring.startswith(self.match, loc))             # <<<<<<<<<<<<<<
 *                         and (loc >= len(instring) - self.matchLen
 *                              or instring[loc + self.matchLen] not in self.identChars)
 */
      }

      /* "cPyparsing.pyx":3570
 * 
 *         else:
 *             if instring[loc] == self.firstMatchChar:             # <<<<<<<<<<<<<<
 *                 if ((self.matchLen == 1 or instring.startswith(self.match, loc))
 *                         and (loc >= len(instring) - self.matchLen
 */
    }
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":3578
 * 
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_incrementalEnabled); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3578, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3579
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyNumber_Add(__pyx_v_loc, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_instring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_3, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3579, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_2) {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __pyx_t_4;
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_instring, __pyx_t_3) < 0))) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3578
 * 
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  }

  /* "cPyparsing.pyx":3580
 *         if ParserElement._incrementalEnabled:
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_8, __pyx_v_instring, __pyx_v_loc, __pyx_t_4, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 3580, __pyx_L1_error)

  /* "cPyparsing.pyx":3560
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.Keyword.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3582
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Keyword_5copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Keyword_4copy, "Keyword.copy(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Keyword_5copy = {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Keyword_5copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Keyword_4copy};
static PyObject *__pyx_pw_10cPyparsing_7Keyword_5copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3582, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "copy") < 0)) __PYX_ERR(0, 3582, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("copy", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3582, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Keyword.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Keyword_4copy(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Keyword_4copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_c = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 1);

  /* "cPyparsing.pyx":3583
 * 
 *     def copy(self):
 *         c = super(Keyword, self).copy()             # <<<<<<<<<<<<<<
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         return c
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3583, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3583, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_c = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3584
 *     def copy(self):
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS             # <<<<<<<<<<<<<<
 *         return c
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_KEYWORD_CHARS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_c, __pyx_n_s_identChars, __pyx_t_3) < 0) __PYX_ERR(0, 3584, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3585
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         return c             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_c);
  __pyx_r = __pyx_v_c;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3582
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Keyword.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3587
 *         return c
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultKeywordChars(chars):
 *         """Overrides the default Keyword chars
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Keyword_7setDefaultKeywordChars(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Keyword_6setDefaultKeywordChars, "Keyword.setDefaultKeywordChars(chars)\nOverrides the default Keyword chars\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_7Keyword_7setDefaultKeywordChars = {"setDefaultKeywordChars", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Keyword_7setDefaultKeywordChars, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Keyword_6setDefaultKeywordChars};
static PyObject *__pyx_pw_10cPyparsing_7Keyword_7setDefaultKeywordChars(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_chars = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setDefaultKeywordChars (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_chars,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chars)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3587, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setDefaultKeywordChars") < 0)) __PYX_ERR(0, 3587, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_chars = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setDefaultKeywordChars", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3587, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Keyword.setDefaultKeywordChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Keyword_6setDefaultKeywordChars(__pyx_self, __pyx_v_chars);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Keyword_6setDefaultKeywordChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setDefaultKeywordChars", 1);

  /* "cPyparsing.pyx":3591
 *         """Overrides the default Keyword chars
 *         """
 *         Keyword.DEFAULT_KEYWORD_CHARS = chars             # <<<<<<<<<<<<<<
 * 
 * class CaselessLiteral(Literal):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_KEYWORD_CHARS, __pyx_v_chars) < 0) __PYX_ERR(0, 3591, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3587
 *         return c
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultKeywordChars(chars):
 *         """Overrides the default Keyword chars
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.Keyword.setDefaultKeywordChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3604
 *     (Contrast with example for :class:`CaselessKeyword`.)
 *     """
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15CaselessLiteral_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15CaselessLiteral___init__, "CaselessLiteral.__init__(self, matchString)");
static PyMethodDef __pyx_mdef_10cPyparsing_15CaselessLiteral_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15CaselessLiteral_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15CaselessLiteral___init__};
static PyObject *__pyx_pw_10cPyparsing_15CaselessLiteral_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_matchString = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_matchString,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_matchString)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 3604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_matchString = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.CaselessLiteral.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15CaselessLiteral___init__(__pyx_self, __pyx_v_self, __pyx_v_matchString);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15CaselessLiteral___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3605
 *     """
 *     def __init__(self, matchString):
 *         super(CaselessLiteral, self).__init__(matchString.upper())             # <<<<<<<<<<<<<<
 *         # Preserve the defining literal.
 *         self.returnString = matchString
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CaselessLiteral); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3605, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3605, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchString, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3607
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 *         self.returnString = matchString             # <<<<<<<<<<<<<<
 *         self.name = "'%s'" % self.returnString
 *         self.errmsg = "Expected " + self.name
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_returnString, __pyx_v_matchString) < 0) __PYX_ERR(0, 3607, __pyx_L1_error)

  /* "cPyparsing.pyx":3608
 *         # Preserve the defining literal.
 *         self.returnString = matchString
 *         self.name = "'%s'" % self.returnString             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_returnString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_3, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_t_3) < 0) __PYX_ERR(0, 3608, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3609
 *         self.returnString = matchString
 *         self.name = "'%s'" % self.returnString
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_1) < 0) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3604
 *     (Contrast with example for :class:`CaselessKeyword`.)
 *     """
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.CaselessLiteral.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3620
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15CaselessLiteral_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15CaselessLiteral_2parseImpl, "CaselessLiteral.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_15CaselessLiteral_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15CaselessLiteral_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15CaselessLiteral_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_15CaselessLiteral_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3620, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3620, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3620, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3620, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3620, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3620, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3620, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 3620, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.CaselessLiteral.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15CaselessLiteral_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15CaselessLiteral_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":3621
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc:loc + self.matchLen].upper() == self.match:             # <<<<<<<<<<<<<<
 *             return loc + self.matchLen, self.returnString
 *         # [CPYPARSING] update furthest_loc
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_v_loc, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_loc, &__pyx_t_3, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3622
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Add(__pyx_v_loc, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_returnString); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3)) __PYX_ERR(0, 3622, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2)) __PYX_ERR(0, 3622, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3621
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc:loc + self.matchLen].upper() == self.match:             # <<<<<<<<<<<<<<
 *             return loc + self.matchLen, self.returnString
 *         # [CPYPARSING] update furthest_loc
 */
  }

  /* "cPyparsing.pyx":3624
 *             return loc + self.matchLen, self.returnString
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_incrementalEnabled); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3624, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3625
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyNumber_Add(__pyx_v_loc, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_instring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_5) {
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1;
    } else {
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = __pyx_t_2;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __pyx_t_3;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_furthest_locs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_v_instring, __pyx_t_1) < 0))) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3624
 *             return loc + self.matchLen, self.returnString
 *         # [CPYPARSING] update furthest_loc
 *         if ParserElement._incrementalEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  }

  /* "cPyparsing.pyx":3626
 *         if ParserElement._incrementalEnabled:
 *             ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * class CaselessKeyword(Keyword):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 3626, __pyx_L1_error)

  /* "cPyparsing.pyx":3620
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.CaselessLiteral.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3638
 *     (Contrast with example for :class:`CaselessLiteral`.)
 *     """
 *     def __init__(self, matchString, identChars=None):             # <<<<<<<<<<<<<<
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15CaselessKeyword_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15CaselessKeyword___init__, "CaselessKeyword.__init__(self, matchString, identChars=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_15CaselessKeyword_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15CaselessKeyword_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15CaselessKeyword___init__};
static PyObject *__pyx_pw_10cPyparsing_15CaselessKeyword_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_matchString = 0;
  PyObject *__pyx_v_identChars = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_matchString,&__pyx_n_s_identChars,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3638, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_matchString)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3638, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3638, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_identChars);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3638, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3638, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_matchString = values[1];
    __pyx_v_identChars = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 3638, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.CaselessKeyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15CaselessKeyword___init__(__pyx_self, __pyx_v_self, __pyx_v_matchString, __pyx_v_identChars);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15CaselessKeyword___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString, PyObject *__pyx_v_identChars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3639
 *     """
 *     def __init__(self, matchString, identChars=None):
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)             # <<<<<<<<<<<<<<
 * 
 * class CloseMatch(Token):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CaselessKeyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 3639, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self)) __PYX_ERR(0, 3639, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_matchString);
  __Pyx_GIVEREF(__pyx_v_matchString);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_matchString)) __PYX_ERR(0, 3639, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_identChars);
  __Pyx_GIVEREF(__pyx_v_identChars);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_identChars)) __PYX_ERR(0, 3639, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_caseless, Py_True) < 0) __PYX_ERR(0, 3639, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":3638
 *     (Contrast with example for :class:`CaselessLiteral`.)
 *     """
 *     def __init__(self, matchString, identChars=None):             # <<<<<<<<<<<<<<
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.CaselessKeyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3674
 *         patt.parseString("ATCAXCGAAXGGA") # -> (['ATCAXCGAAXGGA'], {'mismatches': [[4, 9]], 'original': ['ATCATCGAATGGA']})
 *     """
 *     def __init__(self, match_string, maxMismatches=1):             # <<<<<<<<<<<<<<
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CloseMatch_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10CloseMatch___init__, "CloseMatch.__init__(self, match_string, maxMismatches=1)");
static PyMethodDef __pyx_mdef_10cPyparsing_10CloseMatch_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10CloseMatch_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10CloseMatch___init__};
static PyObject *__pyx_pw_10cPyparsing_10CloseMatch_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_match_string = 0;
  PyObject *__pyx_v_maxMismatches = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_match_string,&__pyx_n_s_maxMismatches,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_1)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3674, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_match_string)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3674, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3674, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_maxMismatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3674, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3674, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_match_string = values[1];
    __pyx_v_maxMismatches = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 3674, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.CloseMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10CloseMatch___init__(__pyx_self, __pyx_v_self, __pyx_v_match_string, __pyx_v_maxMismatches);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CloseMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_match_string, PyObject *__pyx_v_maxMismatches) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3675
 *     """
 *     def __init__(self, match_string, maxMismatches=1):
 *         super(CloseMatch, self).__init__()             # <<<<<<<<<<<<<<
 *         self.name = match_string
 *         self.match_string = match_string
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CloseMatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3675, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3675, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3675, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3676
 *     def __init__(self, match_string, maxMismatches=1):
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string             # <<<<<<<<<<<<<<
 *         self.match_string = match_string
 *         self.maxMismatches = maxMismatches
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_v_match_string) < 0) __PYX_ERR(0, 3676, __pyx_L1_error)

  /* "cPyparsing.pyx":3677
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 *         self.match_string = match_string             # <<<<<<<<<<<<<<
 *         self.maxMismatches = maxMismatches
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_match_string, __pyx_v_match_string) < 0) __PYX_ERR(0, 3677, __pyx_L1_error)

  /* "cPyparsing.pyx":3678
 *         self.name = match_string
 *         self.match_string = match_string
 *         self.maxMismatches = maxMismatches             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)
 *         self.mayIndexError = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxMismatches, __pyx_v_maxMismatches) < 0) __PYX_ERR(0, 3678, __pyx_L1_error)

  /* "cPyparsing.pyx":3679
 *         self.match_string = match_string
 *         self.maxMismatches = maxMismatches
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = False
 */
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = 0;
  __pyx_t_6 = 127;
  __Pyx_INCREF(__pyx_kp_u_Expected);
  __pyx_t_5 += 9;
  __Pyx_GIVEREF(__pyx_kp_u_Expected);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_Expected);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match_string); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_3), __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_kp_u_with_up_to);
  __pyx_t_5 += 13;
  __Pyx_GIVEREF(__pyx_kp_u_with_up_to);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_with_up_to);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxMismatches); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_IntOrLong(__pyx_t_2), __pyx_n_u_d); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u_mismatches);
  __pyx_t_5 += 12;
  __Pyx_GIVEREF(__pyx_kp_u_mismatches);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u_mismatches);
  __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 3679, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3680
 *         self.maxMismatches = maxMismatches
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 3680, __pyx_L1_error)

  /* "cPyparsing.pyx":3681
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = False             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_False) < 0) __PYX_ERR(0, 3681, __pyx_L1_error)

  /* "cPyparsing.pyx":3674
 *         patt.parseString("ATCAXCGAAXGGA") # -> (['ATCAXCGAAXGGA'], {'mismatches': [[4, 9]], 'original': ['ATCATCGAATGGA']})
 *     """
 *     def __init__(self, match_string, maxMismatches=1):             # <<<<<<<<<<<<<<
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.CloseMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3683
 *         self.mayReturnEmpty = False
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         start = loc
 *         instrlen = len(instring)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CloseMatch_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10CloseMatch_2parseImpl, "CloseMatch.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_10CloseMatch_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10CloseMatch_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10CloseMatch_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_10CloseMatch_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3683, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3683, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3683, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3683, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3683, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3683, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3683, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 3683, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.CloseMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10CloseMatch_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CloseMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_start = NULL;
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_v_maxloc = NULL;
  PyObject *__pyx_v_match_string = NULL;
  PyObject *__pyx_v_match_stringloc = NULL;
  PyObject *__pyx_v_mismatches = NULL;
  PyObject *__pyx_v_maxMismatches = NULL;
  PyObject *__pyx_v_s_m = NULL;
  PyObject *__pyx_v_src = NULL;
  PyObject *__pyx_v_mat = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":3684
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         start = loc             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         maxloc = start + len(self.match_string)
 */
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_v_start = __pyx_v_loc;

  /* "cPyparsing.pyx":3685
 *     def parseImpl(self, instring, loc, doActions=True):
 *         start = loc
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         maxloc = start + len(self.match_string)
 * 
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3685, __pyx_L1_error)
  __pyx_v_instrlen = __pyx_t_1;

  /* "cPyparsing.pyx":3686
 *         start = loc
 *         instrlen = len(instring)
 *         maxloc = start + len(self.match_string)             # <<<<<<<<<<<<<<
 * 
 *         if maxloc <= instrlen:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match_string); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_v_start, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_maxloc = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3688
 *         maxloc = start + len(self.match_string)
 * 
 *         if maxloc <= instrlen:             # <<<<<<<<<<<<<<
 *             match_string = self.match_string
 *             match_stringloc = 0
 */
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_instrlen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_maxloc, __pyx_t_3, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":3689
 * 
 *         if maxloc <= instrlen:
 *             match_string = self.match_string             # <<<<<<<<<<<<<<
 *             match_stringloc = 0
 *             mismatches = []
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match_string); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3689, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_match_string = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3690
 *         if maxloc <= instrlen:
 *             match_string = self.match_string
 *             match_stringloc = 0             # <<<<<<<<<<<<<<
 *             mismatches = []
 *             maxMismatches = self.maxMismatches
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_v_match_stringloc = __pyx_int_0;

    /* "cPyparsing.pyx":3691
 *             match_string = self.match_string
 *             match_stringloc = 0
 *             mismatches = []             # <<<<<<<<<<<<<<
 *             maxMismatches = self.maxMismatches
 * 
 */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3691, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_mismatches = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3692
 *             match_stringloc = 0
 *             mismatches = []
 *             maxMismatches = self.maxMismatches             # <<<<<<<<<<<<<<
 * 
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], match_string)):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxMismatches); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_maxMismatches = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3694
 *             maxMismatches = self.maxMismatches
 * 
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], match_string)):             # <<<<<<<<<<<<<<
 *                 src, mat = s_m
 *                 if src != mat:
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_t_2 = __pyx_int_0;
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_loc, &__pyx_v_maxloc, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3694, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3694, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 3694, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_match_string);
    __Pyx_GIVEREF(__pyx_v_match_string);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_match_string)) __PYX_ERR(0, 3694, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3694, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_5 = __pyx_t_3; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_1 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_1 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3694, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3694, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3694, __pyx_L1_error)
            #endif
            if (__pyx_t_1 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_1); __Pyx_INCREF(__pyx_t_3); __pyx_t_1++; if (unlikely((0 < 0))) __PYX_ERR(0, 3694, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3694, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3694, __pyx_L1_error)
            #endif
            if (__pyx_t_1 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_1); __Pyx_INCREF(__pyx_t_3); __pyx_t_1++; if (unlikely((0 < 0))) __PYX_ERR(0, 3694, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3694, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_6(__pyx_t_5);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3694, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_s_m, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_match_stringloc, __pyx_t_2);
      __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3694, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":3695
 * 
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], match_string)):
 *                 src, mat = s_m             # <<<<<<<<<<<<<<
 *                 if src != mat:
 *                     mismatches.append(match_stringloc)
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_s_m))) || (PyList_CheckExact(__pyx_v_s_m))) {
        PyObject* sequence = __pyx_v_s_m;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 3695, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        #else
        __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3695, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3695, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_v_s_m); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3695, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
        index = 0; __pyx_t_3 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_3)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) __PYX_ERR(0, 3695, __pyx_L1_error)
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_unpacking_done;
        __pyx_L6_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 3695, __pyx_L1_error)
        __pyx_L7_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_src, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_v_mat, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "cPyparsing.pyx":3696
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], match_string)):
 *                 src, mat = s_m
 *                 if src != mat:             # <<<<<<<<<<<<<<
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:
 */
      __pyx_t_7 = PyObject_RichCompare(__pyx_v_src, __pyx_v_mat, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3696, __pyx_L1_error)
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3696, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_4) {

        /* "cPyparsing.pyx":3697
 *                 src, mat = s_m
 *                 if src != mat:
 *                     mismatches.append(match_stringloc)             # <<<<<<<<<<<<<<
 *                     if len(mismatches) > maxMismatches:
 *                         break
 */
        __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_mismatches, __pyx_v_match_stringloc); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 3697, __pyx_L1_error)

        /* "cPyparsing.pyx":3698
 *                 if src != mat:
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:             # <<<<<<<<<<<<<<
 *                         break
 *             else:
 */
        __pyx_t_11 = __Pyx_PyList_GET_SIZE(__pyx_v_mismatches); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3698, __pyx_L1_error)
        __pyx_t_7 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3698, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_3 = PyObject_RichCompare(__pyx_t_7, __pyx_v_maxMismatches, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3698, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3698, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_4) {

          /* "cPyparsing.pyx":3699
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:
 *                         break             # <<<<<<<<<<<<<<
 *             else:
 *                 loc = match_stringloc + 1
 */
          goto __pyx_L5_break;

          /* "cPyparsing.pyx":3698
 *                 if src != mat:
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:             # <<<<<<<<<<<<<<
 *                         break
 *             else:
 */
        }

        /* "cPyparsing.pyx":3696
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], match_string)):
 *                 src, mat = s_m
 *                 if src != mat:             # <<<<<<<<<<<<<<
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:
 */
      }

      /* "cPyparsing.pyx":3694
 *             maxMismatches = self.maxMismatches
 * 
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], match_string)):             # <<<<<<<<<<<<<<
 *                 src, mat = s_m
 *                 if src != mat:
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L10_for_else;
    __pyx_L5_break:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L11_for_end;
    /*else*/ {
      __pyx_L10_for_else:;

      /* "cPyparsing.pyx":3701
 *                         break
 *             else:
 *                 loc = match_stringloc + 1             # <<<<<<<<<<<<<<
 *                 results = ParseResults([instring[start:loc]])
 *                 results['original'] = match_string
 */
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_match_stringloc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":3702
 *             else:
 *                 loc = match_stringloc + 1
 *                 results = ParseResults([instring[start:loc]])             # <<<<<<<<<<<<<<
 *                 results['original'] = match_string
 *                 results['mismatches'] = mismatches
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3702, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_start, &__pyx_v_loc, NULL, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3702, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3702, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_7);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_t_7)) __PYX_ERR(0, 3702, __pyx_L1_error);
      __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      __pyx_t_12 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_12 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_8};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3702, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_v_results = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":3703
 *                 loc = match_stringloc + 1
 *                 results = ParseResults([instring[start:loc]])
 *                 results['original'] = match_string             # <<<<<<<<<<<<<<
 *                 results['mismatches'] = mismatches
 *                 return loc, results
 */
      if (unlikely((PyObject_SetItem(__pyx_v_results, __pyx_n_u_original, __pyx_v_match_string) < 0))) __PYX_ERR(0, 3703, __pyx_L1_error)

      /* "cPyparsing.pyx":3704
 *                 results = ParseResults([instring[start:loc]])
 *                 results['original'] = match_string
 *                 results['mismatches'] = mismatches             # <<<<<<<<<<<<<<
 *                 return loc, results
 * 
 */
      if (unlikely((PyObject_SetItem(__pyx_v_results, __pyx_n_u_mismatches_2, __pyx_v_mismatches) < 0))) __PYX_ERR(0, 3704, __pyx_L1_error)

      /* "cPyparsing.pyx":3705
 *                 results['original'] = match_string
 *                 results['mismatches'] = mismatches
 *                 return loc, results             # <<<<<<<<<<<<<<
 * 
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3705, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_loc);
      __Pyx_GIVEREF(__pyx_v_loc);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_loc)) __PYX_ERR(0, 3705, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_results);
      __Pyx_GIVEREF(__pyx_v_results);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_results)) __PYX_ERR(0, 3705, __pyx_L1_error);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;
    }
    __pyx_L11_for_end:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3688
 *         maxloc = start + len(self.match_string)
 * 
 *         if maxloc <= instrlen:             # <<<<<<<<<<<<<<
 *             match_string = self.match_string
 *             match_stringloc = 0
 */
  }

  /* "cPyparsing.pyx":3707
 *                 return loc, results
 * 
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = NULL;
  __pyx_t_12 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_12 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_8, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_12, 4+__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3707, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(0, 3707, __pyx_L1_error)

  /* "cPyparsing.pyx":3683
 *         self.mayReturnEmpty = False
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         start = loc
 *         instrlen = len(instring)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.CloseMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_maxloc);
  __Pyx_XDECREF(__pyx_v_match_string);
  __Pyx_XDECREF(__pyx_v_match_stringloc);
  __Pyx_XDECREF(__pyx_v_mismatches);
  __Pyx_XDECREF(__pyx_v_maxMismatches);
  __Pyx_XDECREF(__pyx_v_s_m);
  __Pyx_XDECREF(__pyx_v_src);
  __Pyx_XDECREF(__pyx_v_mat);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3763
 *         csv_value = Word(printables, excludeChars=",")
 *     """
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Word_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Word___init__, "Word.__init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Word_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Word_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Word___init__};
static PyObject *__pyx_pw_10cPyparsing_4Word_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_initChars = 0;
  PyObject *__pyx_v_bodyChars = 0;
  PyObject *__pyx_v_min = 0;
  PyObject *__pyx_v_max = 0;
  PyObject *__pyx_v_exact = 0;
  PyObject *__pyx_v_asKeyword = 0;
  PyObject *__pyx_v_excludeChars = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[8] = {0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_initChars,&__pyx_n_s_bodyChars,&__pyx_n_s_min,&__pyx_n_s_max,&__pyx_n_s_exact,&__pyx_n_s_asKeyword,&__pyx_n_s_excludeChars,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_1)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[7] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3763, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_initChars)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3763, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, 1); __PYX_ERR(0, 3763, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_bodyChars);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3763, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_min);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3763, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_max);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3763, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exact);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3763, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_asKeyword);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3763, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_excludeChars);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3763, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3763, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_initChars = values[1];
    __pyx_v_bodyChars = values[2];
    __pyx_v_min = values[3];
    __pyx_v_max = values[4];
    __pyx_v_exact = values[5];
    __pyx_v_asKeyword = values[6];
    __pyx_v_excludeChars = values[7];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, __pyx_nargs); __PYX_ERR(0, 3763, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Word.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Word___init__(__pyx_self, __pyx_v_self, __pyx_v_initChars, __pyx_v_bodyChars, __pyx_v_min, __pyx_v_max, __pyx_v_exact, __pyx_v_asKeyword, __pyx_v_excludeChars);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Word_8__init___2generator16(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3767
 *         if excludeChars:
 *             excludeChars = set(excludeChars)
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 */

static PyObject *__pyx_pf_10cPyparsing_4Word_8__init___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_25_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3767, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Word_8__init___2generator16, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Word___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3767, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Word.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Word_8__init___2generator16(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3767, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 3767, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3767, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3767, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 3767, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3767, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3767, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 3767, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3767, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3767, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_excludeChars)) { __Pyx_RaiseClosureNameError("excludeChars"); __PYX_ERR(0, 3767, __pyx_L1_error) }
    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_c, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_excludeChars, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3767, __pyx_L1_error)
    if (__pyx_t_5) {
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_c))) __PYX_ERR(0, 3767, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Word_8__init___5generator17(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3769
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 */

static PyObject *__pyx_pf_10cPyparsing_4Word_8__init___3genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_26_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3769, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Word_8__init___5generator17, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Word___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3769, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Word.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Word_8__init___5generator17(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3769, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 3769, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3769, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3769, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3769, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 3769, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3769, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3769, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 3769, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3769, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3769, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_excludeChars)) { __Pyx_RaiseClosureNameError("excludeChars"); __PYX_ERR(0, 3769, __pyx_L1_error) }
    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_c, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_excludeChars, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3769, __pyx_L1_error)
    if (__pyx_t_5) {
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_c))) __PYX_ERR(0, 3769, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3763
 *         csv_value = Word(printables, excludeChars=",")
 *     """
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */

static PyObject *__pyx_pf_10cPyparsing_4Word___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_initChars, PyObject *__pyx_v_bodyChars, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact, PyObject *__pyx_v_asKeyword, PyObject *__pyx_v_excludeChars) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *__pyx_cur_scope;
  PyObject *__pyx_gb_10cPyparsing_4Word_8__init___2generator16 = 0;
  PyObject *__pyx_gb_10cPyparsing_4Word_8__init___5generator17 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  Py_UCS4 __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_24___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3763, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_excludeChars = __pyx_v_excludeChars;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_excludeChars);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_excludeChars);
  __Pyx_INCREF(__pyx_v_initChars);
  __Pyx_INCREF(__pyx_v_bodyChars);

  /* "cPyparsing.pyx":3764
 *     """
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):
 *         super(Word, self).__init__()             # <<<<<<<<<<<<<<
 *         if excludeChars:
 *             excludeChars = set(excludeChars)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Word); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3764, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3764, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3765
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):
 *         super(Word, self).__init__()
 *         if excludeChars:             # <<<<<<<<<<<<<<
 *             excludeChars = set(excludeChars)
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_excludeChars); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3765, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3766
 *         super(Word, self).__init__()
 *         if excludeChars:
 *             excludeChars = set(excludeChars)             # <<<<<<<<<<<<<<
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:
 */
    __pyx_t_1 = PySet_New(__pyx_cur_scope->__pyx_v_excludeChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_excludeChars);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_excludeChars, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3767
 *         if excludeChars:
 *             excludeChars = set(excludeChars)
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_4Word_8__init___genexpr(((PyObject*)__pyx_cur_scope), __pyx_v_initChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_initChars, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3768
 *             excludeChars = set(excludeChars)
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:             # <<<<<<<<<<<<<<
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 *         self.initCharsOrig = initChars
 */
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_bodyChars); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3768, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":3769
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 */
      __pyx_t_1 = __pyx_pf_10cPyparsing_4Word_8__init___3genexpr(((PyObject*)__pyx_cur_scope), __pyx_v_bodyChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_bodyChars, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3768
 *             excludeChars = set(excludeChars)
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:             # <<<<<<<<<<<<<<
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 *         self.initCharsOrig = initChars
 */
    }

    /* "cPyparsing.pyx":3765
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):
 *         super(Word, self).__init__()
 *         if excludeChars:             # <<<<<<<<<<<<<<
 *             excludeChars = set(excludeChars)
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 */
  }

  /* "cPyparsing.pyx":3770
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 *         self.initCharsOrig = initChars             # <<<<<<<<<<<<<<
 *         self.initChars = set(initChars)
 *         if bodyChars:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig, __pyx_v_initChars) < 0) __PYX_ERR(0, 3770, __pyx_L1_error)

  /* "cPyparsing.pyx":3771
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)             # <<<<<<<<<<<<<<
 *         if bodyChars:
 *             self.bodyCharsOrig = bodyChars
 */
  __pyx_t_1 = PySet_New(__pyx_v_initChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_initChars, __pyx_t_1) < 0) __PYX_ERR(0, 3771, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3772
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 *         if bodyChars:             # <<<<<<<<<<<<<<
 *             self.bodyCharsOrig = bodyChars
 *             self.bodyChars = set(bodyChars)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_bodyChars); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3772, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3773
 *         self.initChars = set(initChars)
 *         if bodyChars:
 *             self.bodyCharsOrig = bodyChars             # <<<<<<<<<<<<<<
 *             self.bodyChars = set(bodyChars)
 *         else:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig, __pyx_v_bodyChars) < 0) __PYX_ERR(0, 3773, __pyx_L1_error)

    /* "cPyparsing.pyx":3774
 *         if bodyChars:
 *             self.bodyCharsOrig = bodyChars
 *             self.bodyChars = set(bodyChars)             # <<<<<<<<<<<<<<
 *         else:
 *             self.bodyCharsOrig = initChars
 */
    __pyx_t_1 = PySet_New(__pyx_v_bodyChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3774, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_bodyChars, __pyx_t_1) < 0) __PYX_ERR(0, 3774, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3772
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 *         if bodyChars:             # <<<<<<<<<<<<<<
 *             self.bodyCharsOrig = bodyChars
 *             self.bodyChars = set(bodyChars)
 */
    goto __pyx_L5;
  }

  /* "cPyparsing.pyx":3776
 *             self.bodyChars = set(bodyChars)
 *         else:
 *             self.bodyCharsOrig = initChars             # <<<<<<<<<<<<<<
 *             self.bodyChars = set(initChars)
 * 
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig, __pyx_v_initChars) < 0) __PYX_ERR(0, 3776, __pyx_L1_error)

    /* "cPyparsing.pyx":3777
 *         else:
 *             self.bodyCharsOrig = initChars
 *             self.bodyChars = set(initChars)             # <<<<<<<<<<<<<<
 * 
 *         self.maxSpecified = max > 0
 */
    __pyx_t_1 = PySet_New(__pyx_v_initChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_bodyChars, __pyx_t_1) < 0) __PYX_ERR(0, 3777, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L5:;

  /* "cPyparsing.pyx":3779
 *             self.bodyChars = set(initChars)
 * 
 *         self.maxSpecified = max > 0             # <<<<<<<<<<<<<<
 * 
 *         if min < 1:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_max, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3779, __pyx_L1_error)
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxSpecified, __pyx_t_1) < 0) __PYX_ERR(0, 3779, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3781
 *         self.maxSpecified = max > 0
 * 
 *         if min < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")
 * 
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_min, __pyx_int_1, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3781, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3781, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_5)) {

    /* "cPyparsing.pyx":3782
 * 
 *         if min < 1:
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")             # <<<<<<<<<<<<<<
 * 
 *         self.minLen = min
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__78, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 3782, __pyx_L1_error)

    /* "cPyparsing.pyx":3781
 *         self.maxSpecified = max > 0
 * 
 *         if min < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")
 * 
 */
  }

  /* "cPyparsing.pyx":3784
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")
 * 
 *         self.minLen = min             # <<<<<<<<<<<<<<
 * 
 *         if max > 0:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_minLen, __pyx_v_min) < 0) __PYX_ERR(0, 3784, __pyx_L1_error)

  /* "cPyparsing.pyx":3786
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_max, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3786, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3786, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3787
 * 
 *         if max > 0:
 *             self.maxLen = max             # <<<<<<<<<<<<<<
 *         else:
 *             self.maxLen = _MAX_INT
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_max) < 0) __PYX_ERR(0, 3787, __pyx_L1_error)

    /* "cPyparsing.pyx":3786
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
    goto __pyx_L7;
  }

  /* "cPyparsing.pyx":3789
 *             self.maxLen = max
 *         else:
 *             self.maxLen = _MAX_INT             # <<<<<<<<<<<<<<
 * 
 *         if exact > 0:
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_t_1) < 0) __PYX_ERR(0, 3789, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L7:;

  /* "cPyparsing.pyx":3791
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_exact, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3791, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3791, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3792
 * 
 *         if exact > 0:
 *             self.maxLen = exact             # <<<<<<<<<<<<<<
 *             self.minLen = exact
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_exact) < 0) __PYX_ERR(0, 3792, __pyx_L1_error)

    /* "cPyparsing.pyx":3793
 *         if exact > 0:
 *             self.maxLen = exact
 *             self.minLen = exact             # <<<<<<<<<<<<<<
 * 
 *         self.name = _ustr(self)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_minLen, __pyx_v_exact) < 0) __PYX_ERR(0, 3793, __pyx_L1_error)

    /* "cPyparsing.pyx":3791
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  }

  /* "cPyparsing.pyx":3795
 *             self.minLen = exact
 * 
 *         self.name = _ustr(self)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_t_1) < 0) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3796
 * 
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.asKeyword = asKeyword
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 3796, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3797
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.asKeyword = asKeyword
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 3797, __pyx_L1_error)

  /* "cPyparsing.pyx":3798
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 *         self.asKeyword = asKeyword             # <<<<<<<<<<<<<<
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_asKeyword, __pyx_v_asKeyword) < 0) __PYX_ERR(0, 3798, __pyx_L1_error)

  /* "cPyparsing.pyx":3800
 *         self.asKeyword = asKeyword
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):             # <<<<<<<<<<<<<<
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__16, __pyx_t_2, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_min, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3800, __pyx_L1_error)
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_max, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3800, __pyx_L1_error)
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_exact, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3800, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_6;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3801
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):
 *             if self.bodyCharsOrig == self.initCharsOrig:             # <<<<<<<<<<<<<<
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3801, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3801, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":3802
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)             # <<<<<<<<<<<<<<
 *             elif len(self.initCharsOrig) == 1:
 *                 self.reString = "%s[%s]*" % (re.escape(self.initCharsOrig),
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3802, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_4, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_1) < 0) __PYX_ERR(0, 3802, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3801
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):
 *             if self.bodyCharsOrig == self.initCharsOrig:             # <<<<<<<<<<<<<<
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:
 */
      goto __pyx_L14;
    }

    /* "cPyparsing.pyx":3803
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:             # <<<<<<<<<<<<<<
 *                 self.reString = "%s[%s]*" % (re.escape(self.initCharsOrig),
 *                                              _escapeRegexRangeChars(self.bodyCharsOrig),)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3803, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__pyx_t_8 == 1);
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":3804
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:
 *                 self.reString = "%s[%s]*" % (re.escape(self.initCharsOrig),             # <<<<<<<<<<<<<<
 *                                              _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             else:
 */
      __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = 0;
      __pyx_t_9 = 127;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_escape); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_10 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_2};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3804, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_3), __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_9) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_9;
      __pyx_t_8 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_INCREF(__pyx_kp_u__2);
      __pyx_t_8 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__2);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__2);

      /* "cPyparsing.pyx":3805
 *             elif len(self.initCharsOrig) == 1:
 *                 self.reString = "%s[%s]*" % (re.escape(self.initCharsOrig),
 *                                              _escapeRegexRangeChars(self.bodyCharsOrig),)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.reString = "[%s][%s]*" % (_escapeRegexRangeChars(self.initCharsOrig),
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3805, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3805, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_10 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_2};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3805, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_7), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3805, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_9 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_9) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_9;
      __pyx_t_8 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_INCREF(__pyx_kp_u__79);
      __pyx_t_8 += 2;
      __Pyx_GIVEREF(__pyx_kp_u__79);
      PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u__79);

      /* "cPyparsing.pyx":3804
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:
 *                 self.reString = "%s[%s]*" % (re.escape(self.initCharsOrig),             # <<<<<<<<<<<<<<
 *                                              _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             else:
 */
      __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 4, __pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_3) < 0) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":3803
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:             # <<<<<<<<<<<<<<
 *                 self.reString = "%s[%s]*" % (re.escape(self.initCharsOrig),
 *                                              _escapeRegexRangeChars(self.bodyCharsOrig),)
 */
      goto __pyx_L14;
    }

    /* "cPyparsing.pyx":3807
 *                                              _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             else:
 *                 self.reString = "[%s][%s]*" % (_escapeRegexRangeChars(self.initCharsOrig),             # <<<<<<<<<<<<<<
 *                                                _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:
 */
    /*else*/ {
      __pyx_t_3 = PyTuple_New(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3807, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = 0;
      __pyx_t_9 = 127;
      __Pyx_INCREF(__pyx_kp_u__2);
      __pyx_t_8 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__2);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u__2);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3807, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3807, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_10 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_2};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_1), __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3807, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_9 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_9) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_9;
      __pyx_t_8 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_INCREF(__pyx_kp_u__80);
      __pyx_t_8 += 2;
      __Pyx_GIVEREF(__pyx_kp_u__80);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u__80);

      /* "cPyparsing.pyx":3808
 *             else:
 *                 self.reString = "[%s][%s]*" % (_escapeRegexRangeChars(self.initCharsOrig),
 *                                                _escapeRegexRangeChars(self.bodyCharsOrig),)             # <<<<<<<<<<<<<<
 *             if self.asKeyword:
 *                 self.reString = r"\b" + self.reString + r"\b"
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3808, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3808, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_10 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_2};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_7), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3808, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_9 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_9) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_9;
      __pyx_t_8 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_1);
      __pyx_t_1 = 0;
      __Pyx_INCREF(__pyx_kp_u__79);
      __pyx_t_8 += 2;
      __Pyx_GIVEREF(__pyx_kp_u__79);
      PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_kp_u__79);

      /* "cPyparsing.pyx":3807
 *                                              _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             else:
 *                 self.reString = "[%s][%s]*" % (_escapeRegexRangeChars(self.initCharsOrig),             # <<<<<<<<<<<<<<
 *                                                _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:
 */
      __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_3, 5, __pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3807, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_1) < 0) __PYX_ERR(0, 3807, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L14:;

    /* "cPyparsing.pyx":3809
 *                 self.reString = "[%s][%s]*" % (_escapeRegexRangeChars(self.initCharsOrig),
 *                                                _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:             # <<<<<<<<<<<<<<
 *                 self.reString = r"\b" + self.reString + r"\b"
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_asKeyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3809, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3809, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":3810
 *                                                _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:
 *                 self.reString = r"\b" + self.reString + r"\b"             # <<<<<<<<<<<<<<
 * 
 *             try:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_reString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyNumber_Add(__pyx_kp_u_b, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_kp_u_b); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_1) < 0) __PYX_ERR(0, 3810, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3809
 *                 self.reString = "[%s][%s]*" % (_escapeRegexRangeChars(self.initCharsOrig),
 *                                                _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:             # <<<<<<<<<<<<<<
 *                 self.reString = r"\b" + self.reString + r"\b"
 * 
 */
    }

    /* "cPyparsing.pyx":3812
 *                 self.reString = r"\b" + self.reString + r"\b"
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.reString)
 *             except Exception:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      /*try:*/ {

        /* "cPyparsing.pyx":3813
 * 
 *             try:
 *                 self.re = re.compile(self.reString)             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 self.re = None
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3813, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_compile); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3813, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_reString); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3813, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3813, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, __pyx_t_1) < 0) __PYX_ERR(0, 3813, __pyx_L16_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":3812
 *                 self.reString = r"\b" + self.reString + r"\b"
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.reString)
 *             except Exception:
 */
      }

      /* "cPyparsing.pyx":3817
 *                 self.re = None
 *             else:
 *                 self.re_match = self.re.match             # <<<<<<<<<<<<<<
 *                 self.__class__ = _WordRegex
 * 
 */
      /*else:*/ {
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3817, __pyx_L18_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_match); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3817, __pyx_L18_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re_match, __pyx_t_7) < 0) __PYX_ERR(0, 3817, __pyx_L18_except_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "cPyparsing.pyx":3818
 *             else:
 *                 self.re_match = self.re.match
 *                 self.__class__ = _WordRegex             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_WordRegex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3818, __pyx_L18_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_class, __pyx_t_7) < 0) __PYX_ERR(0, 3818, __pyx_L18_except_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L21_try_end;
      __pyx_L16_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "cPyparsing.pyx":3814
 *             try:
 *                 self.re = re.compile(self.reString)
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 self.re = None
 *             else:
 */
      __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_4) {
        __Pyx_AddTraceback("cPyparsing.Word.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_1, &__pyx_t_3) < 0) __PYX_ERR(0, 3814, __pyx_L18_except_error)
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_3);

        /* "cPyparsing.pyx":3815
 *                 self.re = re.compile(self.reString)
 *             except Exception:
 *                 self.re = None             # <<<<<<<<<<<<<<
 *             else:
 *                 self.re_match = self.re.match
 */
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, Py_None) < 0) __PYX_ERR(0, 3815, __pyx_L18_except_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L17_exception_handled;
      }
      goto __pyx_L18_except_error;

      /* "cPyparsing.pyx":3812
 *                 self.reString = r"\b" + self.reString + r"\b"
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.reString)
 *             except Exception:
 */
      __pyx_L18_except_error:;
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L1_error;
      __pyx_L17_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __pyx_L21_try_end:;
    }

    /* "cPyparsing.pyx":3800
 *         self.asKeyword = asKeyword
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):             # <<<<<<<<<<<<<<
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 */
  }

  /* "cPyparsing.pyx":3763
 *         csv_value = Word(printables, excludeChars=",")
 *     """
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.Word.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_4Word_8__init___2generator16);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_4Word_8__init___5generator17);
  __Pyx_XDECREF(__pyx_v_initChars);
  __Pyx_XDECREF(__pyx_v_bodyChars);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3849
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] not in self.initChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Word_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Word_2parseImpl, "Word.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Word_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Word_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Word_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_4Word_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3849, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3849, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3849, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3849, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3849, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3849, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3849, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 3849, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Word.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Word_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Word_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_start = NULL;
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_v_bodychars = NULL;
  PyObject *__pyx_v_maxloc = NULL;
  int __pyx_v_throwException;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":3850
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] not in self.initChars:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_2, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3850, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_3)) {

    /* "cPyparsing.pyx":3851
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] not in self.initChars:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         start = loc
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3851, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3851, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc, __pyx_t_4, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3851, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 3851, __pyx_L1_error)

    /* "cPyparsing.pyx":3850
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] not in self.initChars:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":3853
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         start = loc             # <<<<<<<<<<<<<<
 *         loc += 1
 *         instrlen = len(instring)
 */
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_v_start = __pyx_v_loc;

  /* "cPyparsing.pyx":3854
 * 
 *         start = loc
 *         loc += 1             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         bodychars = self.bodyChars
 */
  __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3855
 *         start = loc
 *         loc += 1
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         bodychars = self.bodyChars
 *         maxloc = start + self.maxLen
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3855, __pyx_L1_error)
  __pyx_v_instrlen = __pyx_t_7;

  /* "cPyparsing.pyx":3856
 *         loc += 1
 *         instrlen = len(instring)
 *         bodychars = self.bodyChars             # <<<<<<<<<<<<<<
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, instrlen)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_bodychars = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3857
 *         instrlen = len(instring)
 *         bodychars = self.bodyChars
 *         maxloc = start + self.maxLen             # <<<<<<<<<<<<<<
 *         maxloc = min(maxloc, instrlen)
 *         while loc < maxloc and instring[loc] in bodychars:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Add(__pyx_v_start, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_maxloc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3858
 *         bodychars = self.bodyChars
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, instrlen)             # <<<<<<<<<<<<<<
 *         while loc < maxloc and instring[loc] in bodychars:
 *             loc += 1
 */
  __pyx_t_7 = __pyx_v_instrlen;
  __Pyx_INCREF(__pyx_v_maxloc);
  __pyx_t_1 = __pyx_v_maxloc;
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_4, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_3) {
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
    __pyx_t_5 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = __pyx_t_1;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_maxloc, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3859
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, instrlen)
 *         while loc < maxloc and instring[loc] in bodychars:             # <<<<<<<<<<<<<<
 *             loc += 1
 * 
 */
  while (1) {
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_loc, __pyx_v_maxloc, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3859, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3859, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_8) {
    } else {
      __pyx_t_3 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_v_bodychars, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3859, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __pyx_t_8;
    __pyx_L6_bool_binop_done:;
    if (!__pyx_t_3) break;

    /* "cPyparsing.pyx":3860
 *         maxloc = min(maxloc, instrlen)
 *         while loc < maxloc and instring[loc] in bodychars:
 *             loc += 1             # <<<<<<<<<<<<<<
 * 
 *         throwException = False
 */
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3860, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
    __pyx_t_1 = 0;
  }

  /* "cPyparsing.pyx":3862
 *             loc += 1
 * 
 *         throwException = False             # <<<<<<<<<<<<<<
 *         if loc - start < self.minLen:
 *             throwException = True
 */
  __pyx_v_throwException = 0;

  /* "cPyparsing.pyx":3863
 * 
 *         throwException = False
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             throwException = True
 *         elif self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 */
  __pyx_t_1 = PyNumber_Subtract(__pyx_v_loc, __pyx_v_start); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_minLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3864
 *         throwException = False
 *         if loc - start < self.minLen:
 *             throwException = True             # <<<<<<<<<<<<<<
 *         elif self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 *             throwException = True
 */
    __pyx_v_throwException = 1;

    /* "cPyparsing.pyx":3863
 * 
 *         throwException = False
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             throwException = True
 *         elif self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 */
    goto __pyx_L8;
  }

  /* "cPyparsing.pyx":3865
 *         if loc - start < self.minLen:
 *             throwException = True
 *         elif self.maxSpecified and loc < instrlen and instring[loc] in bodychars:             # <<<<<<<<<<<<<<
 *             throwException = True
 *         elif self.asKeyword:
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxSpecified); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_3 = __pyx_t_8;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_instrlen); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_5, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_3 = __pyx_t_8;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_v_bodychars, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __pyx_t_8;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3866
 *             throwException = True
 *         elif self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 *             throwException = True             # <<<<<<<<<<<<<<
 *         elif self.asKeyword:
 *             if (start > 0 and instring[start - 1] in bodychars
 */
    __pyx_v_throwException = 1;

    /* "cPyparsing.pyx":3865
 *         if loc - start < self.minLen:
 *             throwException = True
 *         elif self.maxSpecified and loc < instrlen and instring[loc] in bodychars:             # <<<<<<<<<<<<<<
 *             throwException = True
 *         elif self.asKeyword:
 */
    goto __pyx_L8;
  }

  /* "cPyparsing.pyx":3867
 *         elif self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 *             throwException = True
 *         elif self.asKeyword:             # <<<<<<<<<<<<<<
 *             if (start > 0 and instring[start - 1] in bodychars
 *                     or loc < instrlen and instring[loc] in bodychars):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_asKeyword); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3867, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3868
 *             throwException = True
 *         elif self.asKeyword:
 *             if (start > 0 and instring[start - 1] in bodychars             # <<<<<<<<<<<<<<
 *                     or loc < instrlen and instring[loc] in bodychars):
 *                 throwException = True
 */
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_start, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3868, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3868, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!__pyx_t_8) {
      goto __pyx_L14_next_or;
    } else {
    }
    __pyx_t_2 = __Pyx_PyInt_SubtractObjC(__pyx_v_start, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3868, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3868, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_5, __pyx_v_bodychars, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3868, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!__pyx_t_8) {
    } else {
      __pyx_t_3 = __pyx_t_8;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_L14_next_or:;

    /* "cPyparsing.pyx":3869
 *         elif self.asKeyword:
 *             if (start > 0 and instring[start - 1] in bodychars
 *                     or loc < instrlen and instring[loc] in bodychars):             # <<<<<<<<<<<<<<
 *                 throwException = True
 * 
 */
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_instrlen); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_5, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3869, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3869, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_8) {
    } else {
      __pyx_t_3 = __pyx_t_8;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_v_bodychars, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3869, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __pyx_t_8;
    __pyx_L13_bool_binop_done:;

    /* "cPyparsing.pyx":3868
 *             throwException = True
 *         elif self.asKeyword:
 *             if (start > 0 and instring[start - 1] in bodychars             # <<<<<<<<<<<<<<
 *                     or loc < instrlen and instring[loc] in bodychars):
 *                 throwException = True
 */
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":3870
 *             if (start > 0 and instring[start - 1] in bodychars
 *                     or loc < instrlen and instring[loc] in bodychars):
 *                 throwException = True             # <<<<<<<<<<<<<<
 * 
 *         if throwException:
 */
      __pyx_v_throwException = 1;

      /* "cPyparsing.pyx":3868
 *             throwException = True
 *         elif self.asKeyword:
 *             if (start > 0 and instring[start - 1] in bodychars             # <<<<<<<<<<<<<<
 *                     or loc < instrlen and instring[loc] in bodychars):
 *                 throwException = True
 */
    }

    /* "cPyparsing.pyx":3867
 *         elif self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 *             throwException = True
 *         elif self.asKeyword:             # <<<<<<<<<<<<<<
 *             if (start > 0 and instring[start - 1] in bodychars
 *                     or loc < instrlen and instring[loc] in bodychars):
 */
  }
  __pyx_L8:;

  /* "cPyparsing.pyx":3872
 *                 throwException = True
 * 
 *         if throwException:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  if (unlikely(__pyx_v_throwException)) {

    /* "cPyparsing.pyx":3873
 * 
 *         if throwException:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         return loc, instring[start:loc]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_instring, __pyx_v_loc, __pyx_t_1, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3873, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 3873, __pyx_L1_error)

    /* "cPyparsing.pyx":3872
 *                 throwException = True
 * 
 *         if throwException:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":3875
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         return loc, instring[start:loc]             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_start, &__pyx_v_loc, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_loc)) __PYX_ERR(0, 3875, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(0, 3875, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3849
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] not in self.initChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.Word.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_bodychars);
  __Pyx_XDECREF(__pyx_v_maxloc);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3877
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Word_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Word_4__str__, "Word.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Word_5__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Word_5__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Word_4__str__};
static PyObject *__pyx_pw_10cPyparsing_4Word_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3877, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 3877, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3877, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Word.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Word_4__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3885
 *         if self.strRepr is None:
 * 
 *             def charsAsStr(s):             # <<<<<<<<<<<<<<
 *                 if len(s) > 4:
 *                     return s[:4] + "..."
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Word_7__str___1charsAsStr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Word_7__str___1charsAsStr = {"charsAsStr", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Word_7__str___1charsAsStr, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_4Word_7__str___1charsAsStr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("charsAsStr (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3885, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "charsAsStr") < 0)) __PYX_ERR(0, 3885, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_s = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("charsAsStr", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3885, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Word.__str__.charsAsStr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(__pyx_self, __pyx_v_s);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("charsAsStr", 1);

  /* "cPyparsing.pyx":3886
 * 
 *             def charsAsStr(s):
 *                 if len(s) > 4:             # <<<<<<<<<<<<<<
 *                     return s[:4] + "..."
 *                 else:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_s); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3886, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 > 4);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3887
 *             def charsAsStr(s):
 *                 if len(s) > 4:
 *                     return s[:4] + "..."             # <<<<<<<<<<<<<<
 *                 else:
 *                     return s
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_s, 0, 4, NULL, NULL, &__pyx_slice__81, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__67); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3886
 * 
 *             def charsAsStr(s):
 *                 if len(s) > 4:             # <<<<<<<<<<<<<<
 *                     return s[:4] + "..."
 *                 else:
 */
  }

  /* "cPyparsing.pyx":3889
 *                     return s[:4] + "..."
 *                 else:
 *                     return s             # <<<<<<<<<<<<<<
 * 
 *             if self.initCharsOrig != self.bodyCharsOrig:
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_s);
    __pyx_r = __pyx_v_s;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":3885
 *         if self.strRepr is None:
 * 
 *             def charsAsStr(s):             # <<<<<<<<<<<<<<
 *                 if len(s) > 4:
 *                     return s[:4] + "..."
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Word.__str__.charsAsStr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3877
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */

static PyObject *__pyx_pf_10cPyparsing_4Word_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_charsAsStr = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_UCS4 __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":3878
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Word, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":3879
 *     def __str__(self):
 *         try:
 *             return super(Word, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Word); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3879, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3879, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5)) __PYX_ERR(0, 3879, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 3879, __pyx_L3_error);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3879, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3879, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3879, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":3878
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Word, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":3880
 *         try:
 *             return super(Word, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":3878
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Word, self).__str__()
 *         except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":3883
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 * 
 *             def charsAsStr(s):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":3885
 *         if self.strRepr is None:
 * 
 *             def charsAsStr(s):             # <<<<<<<<<<<<<<
 *                 if len(s) > 4:
 *                     return s[:4] + "..."
 */
    __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Word_7__str___1charsAsStr, 0, __pyx_n_s_Word___str___locals_charsAsStr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__83)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_charsAsStr = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3891
 *                     return s
 * 
 *             if self.initCharsOrig != self.bodyCharsOrig:             # <<<<<<<<<<<<<<
 *                 self.strRepr = "W:(%s, %s)" % (charsAsStr(self.initCharsOrig), charsAsStr(self.bodyCharsOrig))
 *             else:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_4, __pyx_t_6, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3891, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3891, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":3892
 * 
 *             if self.initCharsOrig != self.bodyCharsOrig:
 *                 self.strRepr = "W:(%s, %s)" % (charsAsStr(self.initCharsOrig), charsAsStr(self.bodyCharsOrig))             # <<<<<<<<<<<<<<
 *             else:
 *                 self.strRepr = "W:(%s)" % charsAsStr(self.initCharsOrig)
 */
      __pyx_t_5 = PyTuple_New(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = 0;
      __pyx_t_10 = 127;
      __Pyx_INCREF(__pyx_kp_u_W);
      __pyx_t_9 += 3;
      __Pyx_GIVEREF(__pyx_kp_u_W);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_W);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = __pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(__pyx_v_charsAsStr, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_10;
      __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u__3);
      __pyx_t_9 += 2;
      __Pyx_GIVEREF(__pyx_kp_u__3);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u__3);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = __pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(__pyx_v_charsAsStr, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_10;
      __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u__13);
      __pyx_t_9 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__13);
      PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_kp_u__13);
      __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, __pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_6) < 0) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":3891
 *                     return s
 * 
 *             if self.initCharsOrig != self.bodyCharsOrig:             # <<<<<<<<<<<<<<
 *                 self.strRepr = "W:(%s, %s)" % (charsAsStr(self.initCharsOrig), charsAsStr(self.bodyCharsOrig))
 *             else:
 */
      goto __pyx_L10;
    }

    /* "cPyparsing.pyx":3894
 *                 self.strRepr = "W:(%s, %s)" % (charsAsStr(self.initCharsOrig), charsAsStr(self.bodyCharsOrig))
 *             else:
 *                 self.strRepr = "W:(%s)" % charsAsStr(self.initCharsOrig)             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    /*else*/ {
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(__pyx_v_charsAsStr, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_W_s, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_6) < 0) __PYX_ERR(0, 3894, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L10:;

    /* "cPyparsing.pyx":3883
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 * 
 *             def charsAsStr(s):
 */
  }

  /* "cPyparsing.pyx":3896
 *                 self.strRepr = "W:(%s)" % charsAsStr(self.initCharsOrig)
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * class _WordRegex(Word):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3877
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Word.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_charsAsStr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3912
 *     #     self._update_furthest_loc_for_regex(instring, loc)
 *     #     return loc, result.group()
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_WordRegex_1parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_WordRegex_parseImpl, "_WordRegex.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_WordRegex_1parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_WordRegex_1parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_WordRegex_parseImpl};
static PyObject *__pyx_pw_10cPyparsing_10_WordRegex_1parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3912, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3912, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3912, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3912, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3912, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3912, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3912, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 3912, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._WordRegex.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_WordRegex_parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_WordRegex_parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":3913
 *     #     return loc, result.group()
 *     def parseImpl(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)             # <<<<<<<<<<<<<<
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3914
 *     def parseImpl(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3914, __pyx_L1_error)
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "cPyparsing.pyx":3916
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3916, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3917
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc)
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         loc = result.end()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3917, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 3917, __pyx_L1_error)

    /* "cPyparsing.pyx":3914
 *     def parseImpl(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc)
 */
  }

  /* "cPyparsing.pyx":3919
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         loc = result.end()             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_end); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3921
 *         loc = result.end()
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc)             # <<<<<<<<<<<<<<
 *         return loc, result.group()
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3921, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3922
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc)
 *         return loc, result.group()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_group); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_loc)) __PYX_ERR(0, 3922, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1)) __PYX_ERR(0, 3922, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3912
 *     #     self._update_furthest_loc_for_regex(instring, loc)
 *     #     return loc, result.group()
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing._WordRegex.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3930
 *     characters.
 *     """
 *     def __init__(self, charset, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Char, self).__init__(charset, exact=1, asKeyword=asKeyword, excludeChars=excludeChars)
 *         self.reString = "[%s]" % _escapeRegexRangeChars(''.join(self.initChars))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Char_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Char___init__, "Char.__init__(self, charset, asKeyword=False, excludeChars=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Char_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Char_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Char___init__};
static PyObject *__pyx_pw_10cPyparsing_4Char_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_charset = 0;
  PyObject *__pyx_v_asKeyword = 0;
  PyObject *__pyx_v_excludeChars = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_charset,&__pyx_n_s_asKeyword,&__pyx_n_s_excludeChars,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3930, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_charset)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3930, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, 1); __PYX_ERR(0, 3930, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_asKeyword);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3930, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_excludeChars);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3930, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3930, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_charset = values[1];
    __pyx_v_asKeyword = values[2];
    __pyx_v_excludeChars = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 3930, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Char.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Char___init__(__pyx_self, __pyx_v_self, __pyx_v_charset, __pyx_v_asKeyword, __pyx_v_excludeChars);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Char___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_charset, PyObject *__pyx_v_asKeyword, PyObject *__pyx_v_excludeChars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3931
 *     """
 *     def __init__(self, charset, asKeyword=False, excludeChars=None):
 *         super(Char, self).__init__(charset, exact=1, asKeyword=asKeyword, excludeChars=excludeChars)             # <<<<<<<<<<<<<<
 *         self.reString = "[%s]" % _escapeRegexRangeChars(''.join(self.initChars))
 *         if asKeyword:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Char); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 3931, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self)) __PYX_ERR(0, 3931, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_charset);
  __Pyx_GIVEREF(__pyx_v_charset);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_charset)) __PYX_ERR(0, 3931, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_exact, __pyx_int_1) < 0) __PYX_ERR(0, 3931, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_asKeyword, __pyx_v_asKeyword) < 0) __PYX_ERR(0, 3931, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_excludeChars, __pyx_v_excludeChars) < 0) __PYX_ERR(0, 3931, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":3932
 *     def __init__(self, charset, asKeyword=False, excludeChars=None):
 *         super(Char, self).__init__(charset, exact=1, asKeyword=asKeyword, excludeChars=excludeChars)
 *         self.reString = "[%s]" % _escapeRegexRangeChars(''.join(self.initChars))             # <<<<<<<<<<<<<<
 *         if asKeyword:
 *             self.reString = r"\b%s\b" % self.reString
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_3) < 0) __PYX_ERR(0, 3932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3933
 *         super(Char, self).__init__(charset, exact=1, asKeyword=asKeyword, excludeChars=excludeChars)
 *         self.reString = "[%s]" % _escapeRegexRangeChars(''.join(self.initChars))
 *         if asKeyword:             # <<<<<<<<<<<<<<
 *             self.reString = r"\b%s\b" % self.reString
 *         self.re = re.compile(self.reString)
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_asKeyword); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3933, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3934
 *         self.reString = "[%s]" % _escapeRegexRangeChars(''.join(self.initChars))
 *         if asKeyword:
 *             self.reString = r"\b%s\b" % self.reString             # <<<<<<<<<<<<<<
 *         self.re = re.compile(self.reString)
 *         self.re_match = self.re.match
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_reString); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_b_s_b, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_4) < 0) __PYX_ERR(0, 3934, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3933
 *         super(Char, self).__init__(charset, exact=1, asKeyword=asKeyword, excludeChars=excludeChars)
 *         self.reString = "[%s]" % _escapeRegexRangeChars(''.join(self.initChars))
 *         if asKeyword:             # <<<<<<<<<<<<<<
 *             self.reString = r"\b%s\b" % self.reString
 *         self.re = re.compile(self.reString)
 */
  }

  /* "cPyparsing.pyx":3935
 *         if asKeyword:
 *             self.reString = r"\b%s\b" % self.reString
 *         self.re = re.compile(self.reString)             # <<<<<<<<<<<<<<
 *         self.re_match = self.re.match
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_compile); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_reString); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_3};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, __pyx_t_4) < 0) __PYX_ERR(0, 3935, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":3936
 *             self.reString = r"\b%s\b" % self.reString
 *         self.re = re.compile(self.reString)
 *         self.re_match = self.re.match             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re_match, __pyx_t_2) < 0) __PYX_ERR(0, 3936, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3930
 *     characters.
 *     """
 *     def __init__(self, charset, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Char, self).__init__(charset, exact=1, asKeyword=asKeyword, excludeChars=excludeChars)
 *         self.reString = "[%s]" % _escapeRegexRangeChars(''.join(self.initChars))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Char.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3963
 * 
 *     """
 *     def __init__(self, pattern, flags=0, asGroupList=False, asMatch=False):             # <<<<<<<<<<<<<<
 *         """The parameters ``pattern`` and ``flags`` are passed
 *         to the ``re.compile()`` function as-is. See the Python
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Regex___init__, "Regex.__init__(self, pattern, flags=0, asGroupList=False, asMatch=False)\nThe parameters ``pattern`` and ``flags`` are passed\n        to the ``re.compile()`` function as-is. See the Python\n        `re module <https://docs.python.org/3/library/re.html>`_ module for an\n        explanation of the acceptable patterns and flags.\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Regex_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Regex___init__};
static PyObject *__pyx_pw_10cPyparsing_5Regex_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_pattern = 0;
  PyObject *__pyx_v_flags = 0;
  PyObject *__pyx_v_asGroupList = 0;
  PyObject *__pyx_v_asMatch = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_pattern,&__pyx_n_s_flags,&__pyx_n_s_asGroupList,&__pyx_n_s_asMatch,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3963, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pattern)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3963, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, 1); __PYX_ERR(0, 3963, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_flags);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3963, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_asGroupList);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3963, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_asMatch);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3963, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3963, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_pattern = values[1];
    __pyx_v_flags = values[2];
    __pyx_v_asGroupList = values[3];
    __pyx_v_asMatch = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, __pyx_nargs); __PYX_ERR(0, 3963, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Regex.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex___init__(__pyx_self, __pyx_v_self, __pyx_v_pattern, __pyx_v_flags, __pyx_v_asGroupList, __pyx_v_asMatch);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_pattern, PyObject *__pyx_v_flags, PyObject *__pyx_v_asGroupList, PyObject *__pyx_v_asMatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":3969
 *         explanation of the acceptable patterns and flags.
 *         """
 *         super(Regex, self).__init__()             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(pattern, basestring):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3969, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 3969, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3971
 *         super(Regex, self).__init__()
 * 
 *         if isinstance(pattern, basestring):             # <<<<<<<<<<<<<<
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_pattern, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 3971, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3972
 * 
 *         if isinstance(pattern, basestring):
 *             if not pattern:             # <<<<<<<<<<<<<<
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 *                               SyntaxWarning, stacklevel=2)
 */
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_pattern); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3972, __pyx_L1_error)
    __pyx_t_6 = (!__pyx_t_5);
    if (__pyx_t_6) {

      /* "cPyparsing.pyx":3973
 *         if isinstance(pattern, basestring):
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",             # <<<<<<<<<<<<<<
 *                               SyntaxWarning, stacklevel=2)
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3973, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3973, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3974
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 *                               SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 * 
 *             self.pattern = pattern
 */
      __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3974, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 3974, __pyx_L1_error)

      /* "cPyparsing.pyx":3973
 *         if isinstance(pattern, basestring):
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",             # <<<<<<<<<<<<<<
 *                               SyntaxWarning, stacklevel=2)
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__84, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3973, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":3972
 * 
 *         if isinstance(pattern, basestring):
 *             if not pattern:             # <<<<<<<<<<<<<<
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 *                               SyntaxWarning, stacklevel=2)
 */
    }

    /* "cPyparsing.pyx":3976
 *                               SyntaxWarning, stacklevel=2)
 * 
 *             self.pattern = pattern             # <<<<<<<<<<<<<<
 *             self.flags = flags
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pattern, __pyx_v_pattern) < 0) __PYX_ERR(0, 3976, __pyx_L1_error)

    /* "cPyparsing.pyx":3977
 * 
 *             self.pattern = pattern
 *             self.flags = flags             # <<<<<<<<<<<<<<
 * 
 *             try:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_flags, __pyx_v_flags) < 0) __PYX_ERR(0, 3977, __pyx_L1_error)

    /* "cPyparsing.pyx":3979
 *             self.flags = flags
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "cPyparsing.pyx":3980
 * 
 *             try:
 *                 self.re = re.compile(self.pattern, self.flags)             # <<<<<<<<<<<<<<
 *                 self.reString = self.pattern
 *             except sre_constants.error:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3980, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_compile); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3980, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3980, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3980, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_1, __pyx_t_10};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3980, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, __pyx_t_2) < 0) __PYX_ERR(0, 3980, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":3981
 *             try:
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern             # <<<<<<<<<<<<<<
 *             except sre_constants.error:
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3981, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_2) < 0) __PYX_ERR(0, 3981, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":3979
 *             self.flags = flags
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern
 */
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L10_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":3982
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern
 *             except sre_constants.error:             # <<<<<<<<<<<<<<
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,
 *                               SyntaxWarning, stacklevel=2)
 */
      __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_3, &__pyx_t_10);
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sre_constants); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3982, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_error); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3982, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_4 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_11);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_ErrRestore(__pyx_t_2, __pyx_t_3, __pyx_t_10);
      __pyx_t_2 = 0; __pyx_t_3 = 0; __pyx_t_10 = 0;
      if (__pyx_t_4) {
        __Pyx_AddTraceback("cPyparsing.Regex.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_10, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 3982, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_2);

        /* "cPyparsing.pyx":3983
 *                 self.reString = self.pattern
 *             except sre_constants.error:
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,             # <<<<<<<<<<<<<<
 *                               SyntaxWarning, stacklevel=2)
 *                 raise
 */
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_warnings); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3983, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_warn); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3983, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_invalid_pattern_s_passed_to_Rege, __pyx_v_pattern); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3983, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_11);

        /* "cPyparsing.pyx":3984
 *             except sre_constants.error:
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,
 *                               SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
        __pyx_t_12 = PyTuple_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3983, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_11);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11)) __PYX_ERR(0, 3983, __pyx_L7_except_error);
        __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
        __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 3983, __pyx_L7_except_error);
        __pyx_t_11 = 0;
        __pyx_t_11 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3984, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 3984, __pyx_L7_except_error)

        /* "cPyparsing.pyx":3983
 *                 self.reString = self.pattern
 *             except sre_constants.error:
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,             # <<<<<<<<<<<<<<
 *                               SyntaxWarning, stacklevel=2)
 *                 raise
 */
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_12, __pyx_t_11); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3983, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "cPyparsing.pyx":3985
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,
 *                               SyntaxWarning, stacklevel=2)
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *         elif hasattr(pattern, 'pattern') and hasattr(pattern, 'match'):
 */
        __Pyx_GIVEREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_2);
        __Pyx_ErrRestoreWithState(__pyx_t_10, __pyx_t_3, __pyx_t_2);
        __pyx_t_10 = 0; __pyx_t_3 = 0; __pyx_t_2 = 0; 
        __PYX_ERR(0, 3985, __pyx_L7_except_error)
      }
      goto __pyx_L7_except_error;

      /* "cPyparsing.pyx":3979
 *             self.flags = flags
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern
 */
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L10_try_end:;
    }

    /* "cPyparsing.pyx":3971
 *         super(Regex, self).__init__()
 * 
 *         if isinstance(pattern, basestring):             # <<<<<<<<<<<<<<
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":3987
 *                 raise
 * 
 *         elif hasattr(pattern, 'pattern') and hasattr(pattern, 'match'):             # <<<<<<<<<<<<<<
 *             self.re = pattern
 *             self.pattern = self.reString = pattern.pattern
 */
  __pyx_t_5 = __Pyx_HasAttr(__pyx_v_pattern, __pyx_n_u_pattern); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 3987, __pyx_L1_error)
  if (__pyx_t_5) {
  } else {
    __pyx_t_6 = __pyx_t_5;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(__pyx_v_pattern, __pyx_n_u_match); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 3987, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_5;
  __pyx_L13_bool_binop_done:;
  if (likely(__pyx_t_6)) {

    /* "cPyparsing.pyx":3988
 * 
 *         elif hasattr(pattern, 'pattern') and hasattr(pattern, 'match'):
 *             self.re = pattern             # <<<<<<<<<<<<<<
 *             self.pattern = self.reString = pattern.pattern
 *             self.flags = flags
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, __pyx_v_pattern) < 0) __PYX_ERR(0, 3988, __pyx_L1_error)

    /* "cPyparsing.pyx":3989
 *         elif hasattr(pattern, 'pattern') and hasattr(pattern, 'match'):
 *             self.re = pattern
 *             self.pattern = self.reString = pattern.pattern             # <<<<<<<<<<<<<<
 *             self.flags = flags
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_pattern, __pyx_n_s_pattern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pattern, __pyx_t_2) < 0) __PYX_ERR(0, 3989, __pyx_L1_error)
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_2) < 0) __PYX_ERR(0, 3989, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3990
 *             self.re = pattern
 *             self.pattern = self.reString = pattern.pattern
 *             self.flags = flags             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_flags, __pyx_v_flags) < 0) __PYX_ERR(0, 3990, __pyx_L1_error)

    /* "cPyparsing.pyx":3987
 *                 raise
 * 
 *         elif hasattr(pattern, 'pattern') and hasattr(pattern, 'match'):             # <<<<<<<<<<<<<<
 *             self.re = pattern
 *             self.pattern = self.reString = pattern.pattern
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":3993
 * 
 *         else:
 *             raise TypeError("Regex may only be constructed with a string or a compiled RE object")             # <<<<<<<<<<<<<<
 * 
 *         self.re_match = self.re.match
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__85, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 3993, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":3995
 *             raise TypeError("Regex may only be constructed with a string or a compiled RE object")
 * 
 *         self.re_match = self.re.match             # <<<<<<<<<<<<<<
 * 
 *         self.name = _ustr(self)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re_match, __pyx_t_3) < 0) __PYX_ERR(0, 3995, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3997
 *         self.re_match = self.re.match
 * 
 *         self.name = _ustr(self)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_t_3) < 0) __PYX_ERR(0, 3997, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3998
 * 
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = self.re_match("") is not None
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3999
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = self.re_match("") is not None
 *         self.asGroupList = asGroupList
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 3999, __pyx_L1_error)

  /* "cPyparsing.pyx":4000
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = self.re_match("") is not None             # <<<<<<<<<<<<<<
 *         self.asGroupList = asGroupList
 *         self.asMatch = asMatch
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_kp_u__10};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4000, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_6 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_2) < 0) __PYX_ERR(0, 4000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4001
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = self.re_match("") is not None
 *         self.asGroupList = asGroupList             # <<<<<<<<<<<<<<
 *         self.asMatch = asMatch
 *         if self.asGroupList:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_asGroupList, __pyx_v_asGroupList) < 0) __PYX_ERR(0, 4001, __pyx_L1_error)

  /* "cPyparsing.pyx":4002
 *         self.mayReturnEmpty = self.re_match("") is not None
 *         self.asGroupList = asGroupList
 *         self.asMatch = asMatch             # <<<<<<<<<<<<<<
 *         if self.asGroupList:
 *             self.parseImpl = self.parseImplAsGroupList
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_asMatch, __pyx_v_asMatch) < 0) __PYX_ERR(0, 4002, __pyx_L1_error)

  /* "cPyparsing.pyx":4003
 *         self.asGroupList = asGroupList
 *         self.asMatch = asMatch
 *         if self.asGroupList:             # <<<<<<<<<<<<<<
 *             self.parseImpl = self.parseImplAsGroupList
 *         if self.asMatch:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_asGroupList); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4003, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4004
 *         self.asMatch = asMatch
 *         if self.asGroupList:
 *             self.parseImpl = self.parseImplAsGroupList             # <<<<<<<<<<<<<<
 *         if self.asMatch:
 *             self.parseImpl = self.parseImplAsMatch
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImplAsGroupList); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 4004, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4003
 *         self.asGroupList = asGroupList
 *         self.asMatch = asMatch
 *         if self.asGroupList:             # <<<<<<<<<<<<<<
 *             self.parseImpl = self.parseImplAsGroupList
 *         if self.asMatch:
 */
  }

  /* "cPyparsing.pyx":4005
 *         if self.asGroupList:
 *             self.parseImpl = self.parseImplAsGroupList
 *         if self.asMatch:             # <<<<<<<<<<<<<<
 *             self.parseImpl = self.parseImplAsMatch
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_asMatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4005, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4006
 *             self.parseImpl = self.parseImplAsGroupList
 *         if self.asMatch:
 *             self.parseImpl = self.parseImplAsMatch             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImplAsMatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 4006, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4005
 *         if self.asGroupList:
 *             self.parseImpl = self.parseImplAsGroupList
 *         if self.asMatch:             # <<<<<<<<<<<<<<
 *             self.parseImpl = self.parseImplAsMatch
 * 
 */
  }

  /* "cPyparsing.pyx":3963
 * 
 *     """
 *     def __init__(self, pattern, flags=0, asGroupList=False, asMatch=False):             # <<<<<<<<<<<<<<
 *         """The parameters ``pattern`` and ``flags`` are passed
 *         to the ``re.compile()`` function as-is. See the Python
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.Regex.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4026
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Regex_2parseImpl, "Regex.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Regex_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Regex_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_5Regex_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4026, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4026, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4026, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4026, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4026, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4026, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4026, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4026, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Regex.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_d = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":4027
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)             # <<<<<<<<<<<<<<
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4028
 *     def parseImpl(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4028, __pyx_L1_error)
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "cPyparsing.pyx":4030
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4030, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4030, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4030, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4031
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         loc = result.end()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4031, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 4031, __pyx_L1_error)

    /* "cPyparsing.pyx":4028
 *     def parseImpl(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  }

  /* "cPyparsing.pyx":4033
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         loc = result.end()             # <<<<<<<<<<<<<<
 *         ret = ParseResults(result.group())
 *         d = result.groupdict()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_end); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4034
 * 
 *         loc = result.end()
 *         ret = ParseResults(result.group())             # <<<<<<<<<<<<<<
 *         d = result.groupdict()
 *         if d:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4035
 *         loc = result.end()
 *         ret = ParseResults(result.group())
 *         d = result.groupdict()             # <<<<<<<<<<<<<<
 *         if d:
 *             for k, v in d.items():
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_groupdict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4035, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_d = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4036
 *         ret = ParseResults(result.group())
 *         d = result.groupdict()
 *         if d:             # <<<<<<<<<<<<<<
 *             for k, v in d.items():
 *                 ret[k] = v
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_d); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4036, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4037
 *         d = result.groupdict()
 *         if d:
 *             for k, v in d.items():             # <<<<<<<<<<<<<<
 *                 ret[k] = v
 *         # [CPYPARSING] update furthest_loc
 */
    __pyx_t_9 = 0;
    if (unlikely(__pyx_v_d == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
      __PYX_ERR(0, 4037, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_dict_iterator(__pyx_v_d, 0, __pyx_n_s_items, (&__pyx_t_10), (&__pyx_t_4)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4037, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
    while (1) {
      __pyx_t_11 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_10, &__pyx_t_9, &__pyx_t_2, &__pyx_t_3, NULL, __pyx_t_4);
      if (unlikely(__pyx_t_11 == 0)) break;
      if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 4037, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":4038
 *         if d:
 *             for k, v in d.items():
 *                 ret[k] = v             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
      if (unlikely((PyObject_SetItem(__pyx_v_ret, __pyx_v_k, __pyx_v_v) < 0))) __PYX_ERR(0, 4038, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4036
 *         ret = ParseResults(result.group())
 *         d = result.groupdict()
 *         if d:             # <<<<<<<<<<<<<<
 *             for k, v in d.items():
 *                 ret[k] = v
 */
  }

  /* "cPyparsing.pyx":4040
 *                 ret[k] = v
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)             # <<<<<<<<<<<<<<
 *         return loc, ret
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4041
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *         return loc, ret             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_loc)) __PYX_ERR(0, 4041, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_ret)) __PYX_ERR(0, 4041, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4026
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.Regex.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4057
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImplAsGroupList(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_5parseImplAsGroupList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Regex_4parseImplAsGroupList, "Regex.parseImplAsGroupList(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_5parseImplAsGroupList = {"parseImplAsGroupList", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Regex_5parseImplAsGroupList, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Regex_4parseImplAsGroupList};
static PyObject *__pyx_pw_10cPyparsing_5Regex_5parseImplAsGroupList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImplAsGroupList (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4057, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4057, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImplAsGroupList", 0, 3, 4, 1); __PYX_ERR(0, 4057, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4057, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImplAsGroupList", 0, 3, 4, 2); __PYX_ERR(0, 4057, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4057, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImplAsGroupList") < 0)) __PYX_ERR(0, 4057, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImplAsGroupList", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4057, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Regex.parseImplAsGroupList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex_4parseImplAsGroupList(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex_4parseImplAsGroupList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImplAsGroupList", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":4058
 *     #     return loc, ret
 *     def parseImplAsGroupList(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)             # <<<<<<<<<<<<<<
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4059
 *     def parseImplAsGroupList(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4059, __pyx_L1_error)
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "cPyparsing.pyx":4061
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4061, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4061, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4061, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4062
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         loc = result.end()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 4062, __pyx_L1_error)

    /* "cPyparsing.pyx":4059
 *     def parseImplAsGroupList(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  }

  /* "cPyparsing.pyx":4064
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         loc = result.end()             # <<<<<<<<<<<<<<
 *         ret = result.groups()
 *         # [CPYPARSING] update furthest_loc
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_end); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4064, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4065
 * 
 *         loc = result.end()
 *         ret = result.groups()             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_groups); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4067
 *         ret = result.groups()
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)             # <<<<<<<<<<<<<<
 *         return loc, ret
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4067, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4068
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *         return loc, ret             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_loc)) __PYX_ERR(0, 4068, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_ret)) __PYX_ERR(0, 4068, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4057
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImplAsGroupList(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.Regex.parseImplAsGroupList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4084
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImplAsMatch(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_7parseImplAsMatch(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Regex_6parseImplAsMatch, "Regex.parseImplAsMatch(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_7parseImplAsMatch = {"parseImplAsMatch", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Regex_7parseImplAsMatch, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Regex_6parseImplAsMatch};
static PyObject *__pyx_pw_10cPyparsing_5Regex_7parseImplAsMatch(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImplAsMatch (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4084, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4084, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImplAsMatch", 0, 3, 4, 1); __PYX_ERR(0, 4084, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4084, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImplAsMatch", 0, 3, 4, 2); __PYX_ERR(0, 4084, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4084, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImplAsMatch") < 0)) __PYX_ERR(0, 4084, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImplAsMatch", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4084, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Regex.parseImplAsMatch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex_6parseImplAsMatch(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex_6parseImplAsMatch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImplAsMatch", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":4085
 *     #     return loc, ret
 *     def parseImplAsMatch(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)             # <<<<<<<<<<<<<<
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4085, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4086
 *     def parseImplAsMatch(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4086, __pyx_L1_error)
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "cPyparsing.pyx":4088
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4088, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4089
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         loc = result.end()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4089, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 4089, __pyx_L1_error)

    /* "cPyparsing.pyx":4086
 *     def parseImplAsMatch(self, instring, loc, doActions=True):
 *         result = self.re_match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  }

  /* "cPyparsing.pyx":4091
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         loc = result.end()             # <<<<<<<<<<<<<<
 *         ret = result
 *         # [CPYPARSING] update furthest_loc
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_end); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4092
 * 
 *         loc = result.end()
 *         ret = result             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  __Pyx_INCREF(__pyx_v_result);
  __pyx_v_ret = __pyx_v_result;

  /* "cPyparsing.pyx":4094
 *         ret = result
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)             # <<<<<<<<<<<<<<
 *         return loc, ret
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4095
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *         return loc, ret             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_loc)) __PYX_ERR(0, 4095, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_ret)) __PYX_ERR(0, 4095, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4084
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImplAsMatch(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.Regex.parseImplAsMatch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4097
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Regex, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_9__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Regex_8__str__, "Regex.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_9__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Regex_9__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Regex_8__str__};
static PyObject *__pyx_pw_10cPyparsing_5Regex_9__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4097, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 4097, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4097, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Regex.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex_8__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex_8__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":4098
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Regex, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":4099
 *     def __str__(self):
 *         try:
 *             return super(Regex, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Regex); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4099, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4099, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5)) __PYX_ERR(0, 4099, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 4099, __pyx_L3_error);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4099, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4099, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4099, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":4098
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Regex, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4100
 *         try:
 *             return super(Regex, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":4098
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Regex, self).__str__()
 *         except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":4103
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "Re:(%s)" % repr(self.pattern)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":4104
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "Re:(%s)" % repr(self.pattern)             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_repr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_5};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4104, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Re_s, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_6) < 0) __PYX_ERR(0, 4104, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4103
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "Re:(%s)" % repr(self.pattern)
 * 
 */
  }

  /* "cPyparsing.pyx":4106
 *             self.strRepr = "Re:(%s)" % repr(self.pattern)
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def sub(self, repl):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4097
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Regex, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.Regex.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4108
 *         return self.strRepr
 * 
 *     def sub(self, repl):             # <<<<<<<<<<<<<<
 *         r"""
 *         Return Regex with an attached parse action to transform the parsed
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_11sub(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Regex_10sub, "Regex.sub(self, repl)\n\n        Return Regex with an attached parse action to transform the parsed\n        result as if called using `re.sub(expr, repl, string) <https://docs.python.org/3/library/re.html#re.sub>`_.\n\n        Example::\n\n            make_html = Regex(r\"(\\w+):(.*?):\").sub(r\"<\\1>\\2</\\1>\")\n            print(make_html.transformString(\"h1:main title:\"))\n            # prints \"<h1>main title</h1>\"\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_11sub = {"sub", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Regex_11sub, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Regex_10sub};
static PyObject *__pyx_pw_10cPyparsing_5Regex_11sub(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_repl = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sub (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_repl,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4108, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_repl)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4108, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("sub", 1, 2, 2, 1); __PYX_ERR(0, 4108, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sub") < 0)) __PYX_ERR(0, 4108, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_repl = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sub", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4108, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Regex.sub", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex_10sub(__pyx_self, __pyx_v_self, __pyx_v_repl);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4130
 * 
 *         if self.asMatch:
 *             def pa(tokens):             # <<<<<<<<<<<<<<
 *                 return tokens[0].expand(repl)
 *         else:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_3sub_1pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_3sub_1pa = {"pa", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Regex_3sub_1pa, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5Regex_3sub_1pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_tokens = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pa (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tokens,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tokens)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4130, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pa") < 0)) __PYX_ERR(0, 4130, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_tokens = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pa", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4130, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Regex.sub.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex_3sub_pa(__pyx_self, __pyx_v_tokens);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex_3sub_pa(PyObject *__pyx_self, PyObject *__pyx_v_tokens) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pa", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":4131
 *         if self.asMatch:
 *             def pa(tokens):
 *                 return tokens[0].expand(repl)             # <<<<<<<<<<<<<<
 *         else:
 *             def pa(tokens):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_expand); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_v_repl)) { __Pyx_RaiseClosureNameError("repl"); __PYX_ERR(0, 4131, __pyx_L1_error) }
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_cur_scope->__pyx_v_repl};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4130
 * 
 *         if self.asMatch:
 *             def pa(tokens):             # <<<<<<<<<<<<<<
 *                 return tokens[0].expand(repl)
 *         else:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Regex.sub.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4133
 *                 return tokens[0].expand(repl)
 *         else:
 *             def pa(tokens):             # <<<<<<<<<<<<<<
 *                 return self.re.sub(repl, tokens[0])
 *         return self.addParseAction(pa)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_3sub_3pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_3sub_3pa = {"pa", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Regex_3sub_3pa, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5Regex_3sub_3pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_tokens = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pa (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tokens,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tokens)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4133, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pa") < 0)) __PYX_ERR(0, 4133, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_tokens = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pa", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4133, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Regex.sub.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex_3sub_2pa(__pyx_self, __pyx_v_tokens);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex_3sub_2pa(PyObject *__pyx_self, PyObject *__pyx_v_tokens) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pa", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":4134
 *         else:
 *             def pa(tokens):
 *                 return self.re.sub(repl, tokens[0])             # <<<<<<<<<<<<<<
 *         return self.addParseAction(pa)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4134, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_sub); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_v_repl)) { __Pyx_RaiseClosureNameError("repl"); __PYX_ERR(0, 4134, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_cur_scope->__pyx_v_repl, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4133
 *                 return tokens[0].expand(repl)
 *         else:
 *             def pa(tokens):             # <<<<<<<<<<<<<<
 *                 return self.re.sub(repl, tokens[0])
 *         return self.addParseAction(pa)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Regex.sub.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4108
 *         return self.strRepr
 * 
 *     def sub(self, repl):             # <<<<<<<<<<<<<<
 *         r"""
 *         Return Regex with an attached parse action to transform the parsed
 */

static PyObject *__pyx_pf_10cPyparsing_5Regex_10sub(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_repl) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *__pyx_cur_scope;
  PyObject *__pyx_v_pa = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sub", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_27_sub(__pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4108, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_repl = __pyx_v_repl;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_repl);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_repl);

  /* "cPyparsing.pyx":4119
 *             # prints "<h1>main title</h1>"
 *         """
 *         if self.asGroupList:             # <<<<<<<<<<<<<<
 *             warnings.warn("cannot use sub() with Regex(asGroupList=True)",
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_asGroupList); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4119, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_2)) {

    /* "cPyparsing.pyx":4120
 *         """
 *         if self.asGroupList:
 *             warnings.warn("cannot use sub() with Regex(asGroupList=True)",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4121
 *         if self.asGroupList:
 *             warnings.warn("cannot use sub() with Regex(asGroupList=True)",
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             raise SyntaxError()
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 4121, __pyx_L1_error)

    /* "cPyparsing.pyx":4120
 *         """
 *         if self.asGroupList:
 *             warnings.warn("cannot use sub() with Regex(asGroupList=True)",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__86, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4122
 *             warnings.warn("cannot use sub() with Regex(asGroupList=True)",
 *                           SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()             # <<<<<<<<<<<<<<
 * 
 *         if self.asMatch and callable(repl):
 */
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_builtin_SyntaxError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 4122, __pyx_L1_error)

    /* "cPyparsing.pyx":4119
 *             # prints "<h1>main title</h1>"
 *         """
 *         if self.asGroupList:             # <<<<<<<<<<<<<<
 *             warnings.warn("cannot use sub() with Regex(asGroupList=True)",
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":4124
 *             raise SyntaxError()
 * 
 *         if self.asMatch and callable(repl):             # <<<<<<<<<<<<<<
 *             warnings.warn("cannot use sub() with a callable with Regex(asMatch=True)",
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_asMatch); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_repl;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyCallable_Check(__pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 4124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __pyx_t_5;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "cPyparsing.pyx":4125
 * 
 *         if self.asMatch and callable(repl):
 *             warnings.warn("cannot use sub() with a callable with Regex(asMatch=True)",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_warnings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_warn); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4126
 *         if self.asMatch and callable(repl):
 *             warnings.warn("cannot use sub() with a callable with Regex(asMatch=True)",
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             raise SyntaxError()
 * 
 */
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 4126, __pyx_L1_error)

    /* "cPyparsing.pyx":4125
 * 
 *         if self.asMatch and callable(repl):
 *             warnings.warn("cannot use sub() with a callable with Regex(asMatch=True)",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__87, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4127
 *             warnings.warn("cannot use sub() with a callable with Regex(asMatch=True)",
 *                           SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()             # <<<<<<<<<<<<<<
 * 
 *         if self.asMatch:
 */
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_builtin_SyntaxError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 4127, __pyx_L1_error)

    /* "cPyparsing.pyx":4124
 *             raise SyntaxError()
 * 
 *         if self.asMatch and callable(repl):             # <<<<<<<<<<<<<<
 *             warnings.warn("cannot use sub() with a callable with Regex(asMatch=True)",
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":4129
 *             raise SyntaxError()
 * 
 *         if self.asMatch:             # <<<<<<<<<<<<<<
 *             def pa(tokens):
 *                 return tokens[0].expand(repl)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_asMatch); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4130
 * 
 *         if self.asMatch:
 *             def pa(tokens):             # <<<<<<<<<<<<<<
 *                 return tokens[0].expand(repl)
 *         else:
 */
    __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Regex_3sub_1pa, 0, __pyx_n_s_Regex_sub_locals_pa, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__89)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_pa = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4129
 *             raise SyntaxError()
 * 
 *         if self.asMatch:             # <<<<<<<<<<<<<<
 *             def pa(tokens):
 *                 return tokens[0].expand(repl)
 */
    goto __pyx_L7;
  }

  /* "cPyparsing.pyx":4133
 *                 return tokens[0].expand(repl)
 *         else:
 *             def pa(tokens):             # <<<<<<<<<<<<<<
 *                 return self.re.sub(repl, tokens[0])
 *         return self.addParseAction(pa)
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Regex_3sub_3pa, 0, __pyx_n_s_Regex_sub_locals_pa, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__90)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_pa = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L7:;

  /* "cPyparsing.pyx":4135
 *             def pa(tokens):
 *                 return self.re.sub(repl, tokens[0])
 *         return self.addParseAction(pa)             # <<<<<<<<<<<<<<
 * 
 * class QuotedString(Token):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_pa};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4108
 *         return self.strRepr
 * 
 *     def sub(self, repl):             # <<<<<<<<<<<<<<
 *         r"""
 *         Return Regex with an attached parse action to transform the parsed
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Regex.sub", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pa);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4176
 *         [['This is the quote with "embedded" quotes']]
 *     """
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False,             # <<<<<<<<<<<<<<
 *                  unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):
 *         super(QuotedString, self).__init__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12QuotedString___init__, "QuotedString.__init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_12QuotedString_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12QuotedString_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12QuotedString___init__};
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_quoteChar = 0;
  PyObject *__pyx_v_escChar = 0;
  PyObject *__pyx_v_escQuote = 0;
  PyObject *__pyx_v_multiline = 0;
  PyObject *__pyx_v_unquoteResults = 0;
  PyObject *__pyx_v_endQuoteChar = 0;
  PyObject *__pyx_v_convertWhitespaceEscapes = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[8] = {0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_quoteChar,&__pyx_n_s_escChar,&__pyx_n_s_escQuote,&__pyx_n_s_multiline,&__pyx_n_s_unquoteResults,&__pyx_n_s_endQuoteChar,&__pyx_n_s_convertWhitespaceEscapes,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));

    /* "cPyparsing.pyx":4177
 *     """
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False,
 *                  unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):             # <<<<<<<<<<<<<<
 *         super(QuotedString, self).__init__()
 * 
 */
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[7] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4176, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_quoteChar)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4176, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, 1); __PYX_ERR(0, 4176, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_escChar);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4176, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_escQuote);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4176, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_multiline);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4176, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_unquoteResults);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4176, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_endQuoteChar);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4176, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_convertWhitespaceEscapes);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4176, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4176, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_quoteChar = values[1];
    __pyx_v_escChar = values[2];
    __pyx_v_escQuote = values[3];
    __pyx_v_multiline = values[4];
    __pyx_v_unquoteResults = values[5];
    __pyx_v_endQuoteChar = values[6];
    __pyx_v_convertWhitespaceEscapes = values[7];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, __pyx_nargs); __PYX_ERR(0, 4176, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.QuotedString.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12QuotedString___init__(__pyx_self, __pyx_v_self, __pyx_v_quoteChar, __pyx_v_escChar, __pyx_v_escQuote, __pyx_v_multiline, __pyx_v_unquoteResults, __pyx_v_endQuoteChar, __pyx_v_convertWhitespaceEscapes);

  /* "cPyparsing.pyx":4176
 *         [['This is the quote with "embedded" quotes']]
 *     """
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False,             # <<<<<<<<<<<<<<
 *                  unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):
 *         super(QuotedString, self).__init__()
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12QuotedString_8__init___2generator18(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4216
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')
 */

static PyObject *__pyx_pf_10cPyparsing_12QuotedString_8__init___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_29_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4216, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12QuotedString_8__init___2generator18, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_QuotedString___init___locals_gen, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.QuotedString.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12QuotedString_8__init___2generator18(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4216, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 4216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);

  /* "cPyparsing.pyx":4218
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')             # <<<<<<<<<<<<<<
 * 
 *         if escQuote:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 4218, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4218, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4218, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4218, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4218, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4218, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4218, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4218, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4218, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_i);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_i, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4216
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')
 */
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    __pyx_t_6 = 127;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_escape); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4216, __pyx_L1_error) }
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = __Pyx_PyObject_GetSlice(__pyx_t_8, 0, 0, NULL, &__pyx_cur_scope->__pyx_v_i, NULL, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    __pyx_t_11 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_11 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_10};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_7), __pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) : __pyx_t_6;
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_9);
    __pyx_t_9 = 0;
    __Pyx_INCREF(__pyx_kp_u__91);
    __pyx_t_5 += 2;
    __Pyx_GIVEREF(__pyx_kp_u__91);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_kp_u__91);

    /* "cPyparsing.pyx":4217
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))             # <<<<<<<<<<<<<<
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4217, __pyx_L1_error) }
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_10, __pyx_cur_scope->__pyx_v_i); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = NULL;
    __pyx_t_11 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_11 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_8};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_9), __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_6;
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_kp_u__4);
    __pyx_t_5 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__4);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_kp_u__4);

    /* "cPyparsing.pyx":4216
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')
 */
    __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_7))) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":4218
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')             # <<<<<<<<<<<<<<
 * 
 *         if escQuote:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":4216
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4176
 *         [['This is the quote with "embedded" quotes']]
 *     """
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False,             # <<<<<<<<<<<<<<
 *                  unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):
 *         super(QuotedString, self).__init__()
 */

static PyObject *__pyx_pf_10cPyparsing_12QuotedString___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_quoteChar, PyObject *__pyx_v_escChar, PyObject *__pyx_v_escQuote, PyObject *__pyx_v_multiline, PyObject *__pyx_v_unquoteResults, PyObject *__pyx_v_endQuoteChar, PyObject *__pyx_v_convertWhitespaceEscapes) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *__pyx_cur_scope;
  PyObject *__pyx_gb_10cPyparsing_12QuotedString_8__init___2generator18 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_UCS4 __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_28___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4176, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_v_quoteChar);
  __Pyx_INCREF(__pyx_v_endQuoteChar);

  /* "cPyparsing.pyx":4178
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False,
 *                  unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):
 *         super(QuotedString, self).__init__()             # <<<<<<<<<<<<<<
 * 
 *         # remove white space from quote chars - wont work anyway
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_QuotedString); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4178, __pyx_L1_error);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_self)) __PYX_ERR(0, 4178, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4181
 * 
 *         # remove white space from quote chars - wont work anyway
 *         quoteChar = quoteChar.strip()             # <<<<<<<<<<<<<<
 *         if not quoteChar:
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_quoteChar, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_quoteChar, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4182
 *         # remove white space from quote chars - wont work anyway
 *         quoteChar = quoteChar.strip()
 *         if not quoteChar:             # <<<<<<<<<<<<<<
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_quoteChar); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4182, __pyx_L1_error)
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "cPyparsing.pyx":4183
 *         quoteChar = quoteChar.strip()
 *         if not quoteChar:
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             raise SyntaxError()
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 4183, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__92, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4184
 *         if not quoteChar:
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()             # <<<<<<<<<<<<<<
 * 
 *         if endQuoteChar is None:
 */
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_builtin_SyntaxError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4184, __pyx_L1_error)

    /* "cPyparsing.pyx":4182
 *         # remove white space from quote chars - wont work anyway
 *         quoteChar = quoteChar.strip()
 *         if not quoteChar:             # <<<<<<<<<<<<<<
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
  }

  /* "cPyparsing.pyx":4186
 *             raise SyntaxError()
 * 
 *         if endQuoteChar is None:             # <<<<<<<<<<<<<<
 *             endQuoteChar = quoteChar
 *         else:
 */
  __pyx_t_6 = (__pyx_v_endQuoteChar == Py_None);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4187
 * 
 *         if endQuoteChar is None:
 *             endQuoteChar = quoteChar             # <<<<<<<<<<<<<<
 *         else:
 *             endQuoteChar = endQuoteChar.strip()
 */
    __Pyx_INCREF(__pyx_v_quoteChar);
    __Pyx_DECREF_SET(__pyx_v_endQuoteChar, __pyx_v_quoteChar);

    /* "cPyparsing.pyx":4186
 *             raise SyntaxError()
 * 
 *         if endQuoteChar is None:             # <<<<<<<<<<<<<<
 *             endQuoteChar = quoteChar
 *         else:
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":4189
 *             endQuoteChar = quoteChar
 *         else:
 *             endQuoteChar = endQuoteChar.strip()             # <<<<<<<<<<<<<<
 *             if not endQuoteChar:
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_endQuoteChar, __pyx_n_s_strip); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4189, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_endQuoteChar, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4190
 *         else:
 *             endQuoteChar = endQuoteChar.strip()
 *             if not endQuoteChar:             # <<<<<<<<<<<<<<
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *                 raise SyntaxError()
 */
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_endQuoteChar); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4190, __pyx_L1_error)
    __pyx_t_5 = (!__pyx_t_6);
    if (unlikely(__pyx_t_5)) {

      /* "cPyparsing.pyx":4191
 *             endQuoteChar = endQuoteChar.strip()
 *             if not endQuoteChar:
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *                 raise SyntaxError()
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warn); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 4191, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__93, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":4192
 *             if not endQuoteChar:
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *                 raise SyntaxError()             # <<<<<<<<<<<<<<
 * 
 *         self.quoteChar = quoteChar
 */
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_builtin_SyntaxError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4192, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4192, __pyx_L1_error)

      /* "cPyparsing.pyx":4190
 *         else:
 *             endQuoteChar = endQuoteChar.strip()
 *             if not endQuoteChar:             # <<<<<<<<<<<<<<
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *                 raise SyntaxError()
 */
    }
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":4194
 *                 raise SyntaxError()
 * 
 *         self.quoteChar = quoteChar             # <<<<<<<<<<<<<<
 *         self.quoteCharLen = len(quoteChar)
 *         self.firstQuoteChar = quoteChar[0]
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_quoteChar, __pyx_v_quoteChar) < 0) __PYX_ERR(0, 4194, __pyx_L1_error)

  /* "cPyparsing.pyx":4195
 * 
 *         self.quoteChar = quoteChar
 *         self.quoteCharLen = len(quoteChar)             # <<<<<<<<<<<<<<
 *         self.firstQuoteChar = quoteChar[0]
 *         self.endQuoteChar = endQuoteChar
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_quoteChar); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4195, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_quoteCharLen, __pyx_t_3) < 0) __PYX_ERR(0, 4195, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4196
 *         self.quoteChar = quoteChar
 *         self.quoteCharLen = len(quoteChar)
 *         self.firstQuoteChar = quoteChar[0]             # <<<<<<<<<<<<<<
 *         self.endQuoteChar = endQuoteChar
 *         self.endQuoteCharLen = len(endQuoteChar)
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_quoteChar, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_firstQuoteChar, __pyx_t_3) < 0) __PYX_ERR(0, 4196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4197
 *         self.quoteCharLen = len(quoteChar)
 *         self.firstQuoteChar = quoteChar[0]
 *         self.endQuoteChar = endQuoteChar             # <<<<<<<<<<<<<<
 *         self.endQuoteCharLen = len(endQuoteChar)
 *         self.escChar = escChar
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar, __pyx_v_endQuoteChar) < 0) __PYX_ERR(0, 4197, __pyx_L1_error)

  /* "cPyparsing.pyx":4198
 *         self.firstQuoteChar = quoteChar[0]
 *         self.endQuoteChar = endQuoteChar
 *         self.endQuoteCharLen = len(endQuoteChar)             # <<<<<<<<<<<<<<
 *         self.escChar = escChar
 *         self.escQuote = escQuote
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_endQuoteChar); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4198, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteCharLen, __pyx_t_3) < 0) __PYX_ERR(0, 4198, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4199
 *         self.endQuoteChar = endQuoteChar
 *         self.endQuoteCharLen = len(endQuoteChar)
 *         self.escChar = escChar             # <<<<<<<<<<<<<<
 *         self.escQuote = escQuote
 *         self.unquoteResults = unquoteResults
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_escChar, __pyx_v_escChar) < 0) __PYX_ERR(0, 4199, __pyx_L1_error)

  /* "cPyparsing.pyx":4200
 *         self.endQuoteCharLen = len(endQuoteChar)
 *         self.escChar = escChar
 *         self.escQuote = escQuote             # <<<<<<<<<<<<<<
 *         self.unquoteResults = unquoteResults
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_escQuote, __pyx_v_escQuote) < 0) __PYX_ERR(0, 4200, __pyx_L1_error)

  /* "cPyparsing.pyx":4201
 *         self.escChar = escChar
 *         self.escQuote = escQuote
 *         self.unquoteResults = unquoteResults             # <<<<<<<<<<<<<<
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_unquoteResults, __pyx_v_unquoteResults) < 0) __PYX_ERR(0, 4201, __pyx_L1_error)

  /* "cPyparsing.pyx":4202
 *         self.escQuote = escQuote
 *         self.unquoteResults = unquoteResults
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes             # <<<<<<<<<<<<<<
 * 
 *         if multiline:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_convertWhitespaceEscapes, __pyx_v_convertWhitespaceEscapes) < 0) __PYX_ERR(0, 4202, __pyx_L1_error)

  /* "cPyparsing.pyx":4204
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes
 * 
 *         if multiline:             # <<<<<<<<<<<<<<
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % (re.escape(self.quoteChar),
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_multiline); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4204, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4205
 * 
 *         if multiline:
 *             self.flags = re.MULTILINE | re.DOTALL             # <<<<<<<<<<<<<<
 *             self.pattern = r'%s(?:[^%s%s]' % (re.escape(self.quoteChar),
 *                                               _escapeRegexRangeChars(self.endQuoteChar[0]),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MULTILINE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DOTALL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Or(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_flags, __pyx_t_3) < 0) __PYX_ERR(0, 4205, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4206
 *         if multiline:
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % (re.escape(self.quoteChar),             # <<<<<<<<<<<<<<
 *                                               _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                                               (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 */
    __pyx_t_3 = PyTuple_New(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = 0;
    __pyx_t_8 = 127;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_escape); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_quoteChar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_1), __pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9);
    __pyx_t_9 = 0;
    __Pyx_INCREF(__pyx_kp_u__94);
    __pyx_t_7 += 5;
    __Pyx_GIVEREF(__pyx_kp_u__94);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_kp_u__94);

    /* "cPyparsing.pyx":4207
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % (re.escape(self.quoteChar),
 *                                               _escapeRegexRangeChars(self.endQuoteChar[0]),             # <<<<<<<<<<<<<<
 *                                               (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_10};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_9), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4208
 *             self.pattern = r'%s(?:[^%s%s]' % (re.escape(self.quoteChar),
 *                                               _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                                               (escChar is not None and _escapeRegexRangeChars(escChar) or ''))             # <<<<<<<<<<<<<<
 *         else:
 *             self.flags = 0
 */
    __pyx_t_5 = (__pyx_v_escChar != Py_None);
    if (!__pyx_t_5) {
      goto __pyx_L8_next_or;
    } else {
    }
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_escChar};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4208, __pyx_L1_error)
    if (!__pyx_t_5) {
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_9);
      __pyx_t_1 = __pyx_t_9;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_L8_next_or:;
    __Pyx_INCREF(__pyx_kp_u__10);
    __pyx_t_1 = __pyx_kp_u__10;
    __pyx_L7_bool_binop_done:;
    __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_1), __pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_9);
    __pyx_t_9 = 0;
    __Pyx_INCREF(__pyx_kp_u__4);
    __pyx_t_7 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__4);
    PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_kp_u__4);

    /* "cPyparsing.pyx":4206
 *         if multiline:
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % (re.escape(self.quoteChar),             # <<<<<<<<<<<<<<
 *                                               _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                                               (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 */
    __pyx_t_9 = __Pyx_PyUnicode_Join(__pyx_t_3, 5, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_9) < 0) __PYX_ERR(0, 4206, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":4204
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes
 * 
 *         if multiline:             # <<<<<<<<<<<<<<
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % (re.escape(self.quoteChar),
 */
    goto __pyx_L6;
  }

  /* "cPyparsing.pyx":4210
 *                                               (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         else:
 *             self.flags = 0             # <<<<<<<<<<<<<<
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % (re.escape(self.quoteChar),
 *                                                   _escapeRegexRangeChars(self.endQuoteChar[0]),
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_flags, __pyx_int_0) < 0) __PYX_ERR(0, 4210, __pyx_L1_error)

    /* "cPyparsing.pyx":4211
 *         else:
 *             self.flags = 0
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % (re.escape(self.quoteChar),             # <<<<<<<<<<<<<<
 *                                                   _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                                                   (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 */
    __pyx_t_9 = PyTuple_New(6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = 0;
    __pyx_t_8 = 127;
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_escape); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_quoteChar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __pyx_t_10 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_3), __pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_10);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_10);
    __pyx_t_10 = 0;
    __Pyx_INCREF(__pyx_kp_u__94);
    __pyx_t_7 += 5;
    __Pyx_GIVEREF(__pyx_kp_u__94);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_kp_u__94);

    /* "cPyparsing.pyx":4212
 *             self.flags = 0
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % (re.escape(self.quoteChar),
 *                                                   _escapeRegexRangeChars(self.endQuoteChar[0]),             # <<<<<<<<<<<<<<
 *                                                   (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_2};
      __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_10), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_n_r);
    __pyx_t_7 += 4;
    __Pyx_GIVEREF(__pyx_kp_u_n_r);
    PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_kp_u_n_r);

    /* "cPyparsing.pyx":4213
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % (re.escape(self.quoteChar),
 *                                                   _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                                                   (escChar is not None and _escapeRegexRangeChars(escChar) or ''))             # <<<<<<<<<<<<<<
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 */
    __pyx_t_5 = (__pyx_v_escChar != Py_None);
    if (!__pyx_t_5) {
      goto __pyx_L11_next_or;
    } else {
    }
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_escChar};
      __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4213, __pyx_L1_error)
    if (!__pyx_t_5) {
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_3 = __pyx_t_10;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_L11_next_or:;
    __Pyx_INCREF(__pyx_kp_u__10);
    __pyx_t_3 = __pyx_kp_u__10;
    __pyx_L10_bool_binop_done:;
    __pyx_t_10 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_3), __pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_10);
    PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_10);
    __pyx_t_10 = 0;
    __Pyx_INCREF(__pyx_kp_u__4);
    __pyx_t_7 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__4);
    PyTuple_SET_ITEM(__pyx_t_9, 5, __pyx_kp_u__4);

    /* "cPyparsing.pyx":4211
 *         else:
 *             self.flags = 0
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % (re.escape(self.quoteChar),             # <<<<<<<<<<<<<<
 *                                                   _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                                                   (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 */
    __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 6, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_10) < 0) __PYX_ERR(0, 4211, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  __pyx_L6:;

  /* "cPyparsing.pyx":4214
 *                                                   _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                                                   (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:             # <<<<<<<<<<<<<<
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 */
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_7 = PyObject_Length(__pyx_t_10); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_5 = (__pyx_t_7 > 1);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4215
 *                                                   (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (             # <<<<<<<<<<<<<<
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 */
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);

    /* "cPyparsing.pyx":4218
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')             # <<<<<<<<<<<<<<
 * 
 *         if escQuote:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_range); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_11 = __Pyx_sub_const_Py_ssize_t_checking_overflow(__pyx_t_7, 1, &__pyx_t_4);
    if (unlikely(__pyx_t_4)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 4218, __pyx_L1_error)
    }
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_t_2, __pyx_int_0, __pyx_int_neg_1};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }

    /* "cPyparsing.pyx":4216
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')
 */
    __pyx_t_3 = __pyx_pf_10cPyparsing_12QuotedString_8__init___genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__96, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_kp_u__95, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4218
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')             # <<<<<<<<<<<<<<
 * 
 *         if escQuote:
 */
    __pyx_t_3 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_9, __pyx_kp_u__13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":4215
 *                                                   (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (             # <<<<<<<<<<<<<<
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 */
    __pyx_t_9 = PyNumber_InPlaceAdd(__pyx_t_10, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_9) < 0) __PYX_ERR(0, 4215, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":4214
 *                                                   _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                                                   (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:             # <<<<<<<<<<<<<<
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 */
  }

  /* "cPyparsing.pyx":4220
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')
 * 
 *         if escQuote:             # <<<<<<<<<<<<<<
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_escQuote); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4220, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4221
 * 
 *         if escQuote:
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))             # <<<<<<<<<<<<<<
 *         if escChar:
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 */
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_re); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_escape); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_escQuote};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4221, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_6, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_3) < 0) __PYX_ERR(0, 4221, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4220
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')')
 * 
 *         if escQuote:             # <<<<<<<<<<<<<<
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:
 */
  }

  /* "cPyparsing.pyx":4222
 *         if escQuote:
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:             # <<<<<<<<<<<<<<
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_escChar); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4222, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4223
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))             # <<<<<<<<<<<<<<
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_escape); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_escChar};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __pyx_t_10 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_7, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_t_3, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_2) < 0) __PYX_ERR(0, 4223, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4224
 *         if escChar:
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"             # <<<<<<<<<<<<<<
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_re); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_escape); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_escChar); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_9 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_10};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__97); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_escCharReplacePattern, __pyx_t_3) < 0) __PYX_ERR(0, 4224, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4222
 *         if escQuote:
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:             # <<<<<<<<<<<<<<
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"
 */
  }

  /* "cPyparsing.pyx":4225
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_re); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_escape); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_10};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_8, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_2) < 0) __PYX_ERR(0, 4225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4227
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
    __Pyx_XGOTREF(__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_13);
    __Pyx_XGOTREF(__pyx_t_14);
    /*try:*/ {

      /* "cPyparsing.pyx":4228
 * 
 *         try:
 *             self.re = re.compile(self.pattern, self.flags)             # <<<<<<<<<<<<<<
 *             self.reString = self.pattern
 *             self.re_match = self.re.match
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4228, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_compile); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4228, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4228, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4228, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_1 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_t_9, __pyx_t_10};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4228, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_re, __pyx_t_2) < 0) __PYX_ERR(0, 4228, __pyx_L16_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":4229
 *         try:
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern             # <<<<<<<<<<<<<<
 *             self.re_match = self.re.match
 *         except sre_constants.error:
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4229, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_reString, __pyx_t_2) < 0) __PYX_ERR(0, 4229, __pyx_L16_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":4230
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern
 *             self.re_match = self.re.match             # <<<<<<<<<<<<<<
 *         except sre_constants.error:
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4230, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4230, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_re_match, __pyx_t_3) < 0) __PYX_ERR(0, 4230, __pyx_L16_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":4227
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern
 */
    }
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    goto __pyx_L21_try_end;
    __pyx_L16_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":4231
 *             self.reString = self.pattern
 *             self.re_match = self.re.match
 *         except sre_constants.error:             # <<<<<<<<<<<<<<
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,
 *                           SyntaxWarning, stacklevel=2)
 */
    __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_2, &__pyx_t_10);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_sre_constants); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4231, __pyx_L18_except_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_error); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4231, __pyx_L18_except_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_4 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_3, __pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_ErrRestore(__pyx_t_3, __pyx_t_2, __pyx_t_10);
    __pyx_t_3 = 0; __pyx_t_2 = 0; __pyx_t_10 = 0;
    if (__pyx_t_4) {
      __Pyx_AddTraceback("cPyparsing.QuotedString.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_10, &__pyx_t_2, &__pyx_t_3) < 0) __PYX_ERR(0, 4231, __pyx_L18_except_error)
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);

      /* "cPyparsing.pyx":4232
 *             self.re_match = self.re.match
 *         except sre_constants.error:
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4232, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4232, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4232, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_15 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_invalid_pattern_s_passed_to_Rege, __pyx_t_1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4232, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":4233
 *         except sre_constants.error:
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4232, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_15);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_15)) __PYX_ERR(0, 4232, __pyx_L18_except_error);
      __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
      __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_builtin_SyntaxWarning)) __PYX_ERR(0, 4232, __pyx_L18_except_error);
      __pyx_t_15 = 0;
      __pyx_t_15 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4233, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_15);
      if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 4233, __pyx_L18_except_error)

      /* "cPyparsing.pyx":4232
 *             self.re_match = self.re.match
 *         except sre_constants.error:
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise
 */
      __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_1, __pyx_t_15); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4232, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

      /* "cPyparsing.pyx":4234
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,
 *                           SyntaxWarning, stacklevel=2)
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         self.name = _ustr(self)
 */
      __Pyx_GIVEREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ErrRestoreWithState(__pyx_t_10, __pyx_t_2, __pyx_t_3);
      __pyx_t_10 = 0; __pyx_t_2 = 0; __pyx_t_3 = 0; 
      __PYX_ERR(0, 4234, __pyx_L18_except_error)
    }
    goto __pyx_L18_except_error;

    /* "cPyparsing.pyx":4227
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern
 */
    __pyx_L18_except_error:;
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_XGIVEREF(__pyx_t_14);
    __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
    goto __pyx_L1_error;
    __pyx_L21_try_end:;
  }

  /* "cPyparsing.pyx":4236
 *             raise
 * 
 *         self.name = _ustr(self)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_cur_scope->__pyx_v_self};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name_2, __pyx_t_3) < 0) __PYX_ERR(0, 4236, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4237
 * 
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = True
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 4237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4238
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 4238, __pyx_L1_error)

  /* "cPyparsing.pyx":4239
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 4239, __pyx_L1_error)

  /* "cPyparsing.pyx":4176
 *         [['This is the quote with "embedded" quotes']]
 *     """
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False,             # <<<<<<<<<<<<<<
 *                  unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):
 *         super(QuotedString, self).__init__()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("cPyparsing.QuotedString.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_12QuotedString_8__init___2generator18);
  __Pyx_XDECREF(__pyx_v_quoteChar);
  __Pyx_XDECREF(__pyx_v_endQuoteChar);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4281
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = instring[loc] == self.firstQuoteChar and self.re_match(instring, loc) or None
 *         if not result:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12QuotedString_2parseImpl, "QuotedString.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_12QuotedString_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12QuotedString_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12QuotedString_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4281, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4281, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4281, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4281, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4281, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4281, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4281, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4281, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.QuotedString.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12QuotedString_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12QuotedString_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_ws_map = NULL;
  PyObject *__pyx_v_wslit = NULL;
  PyObject *__pyx_v_wschar = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":4282
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):
 *         result = instring[loc] == self.firstQuoteChar and self.re_match(instring, loc) or None             # <<<<<<<<<<<<<<
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_firstQuoteChar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!__pyx_t_5) {
    goto __pyx_L4_next_or;
  } else {
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_instring, __pyx_v_loc};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4282, __pyx_L1_error)
  if (!__pyx_t_5) {
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_L4_next_or:;
  __Pyx_INCREF(Py_None);
  __pyx_t_1 = Py_None;
  __pyx_L3_bool_binop_done:;
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4283
 *     def parseImpl(self, instring, loc, doActions=True):
 *         result = instring[loc] == self.firstQuoteChar and self.re_match(instring, loc) or None
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4283, __pyx_L1_error)
  __pyx_t_7 = (!__pyx_t_5);
  if (unlikely(__pyx_t_7)) {

    /* "cPyparsing.pyx":4285
 *         if not result:
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_instring, __pyx_v_loc, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4285, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4286
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         loc = result.end()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_2, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4286, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 4286, __pyx_L1_error)

    /* "cPyparsing.pyx":4283
 *     def parseImpl(self, instring, loc, doActions=True):
 *         result = instring[loc] == self.firstQuoteChar and self.re_match(instring, loc) or None
 *         if not result:             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] update furthest_loc
 *             self._update_furthest_loc_for_regex(instring, loc, self.flags)
 */
  }

  /* "cPyparsing.pyx":4288
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         loc = result.end()             # <<<<<<<<<<<<<<
 *         ret = result.group()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_end); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4289
 * 
 *         loc = result.end()
 *         ret = result.group()             # <<<<<<<<<<<<<<
 * 
 *         if self.unquoteResults:
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_group); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4291
 *         ret = result.group()
 * 
 *         if self.unquoteResults:             # <<<<<<<<<<<<<<
 * 
 *             # strip off quotes
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_unquoteResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":4294
 * 
 *             # strip off quotes
 *             ret = ret[self.quoteCharLen: -self.endQuoteCharLen]             # <<<<<<<<<<<<<<
 * 
 *             if isinstance(ret, basestring):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_quoteCharLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_endQuoteCharLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Negative(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_ret, 0, 0, &__pyx_t_1, &__pyx_t_3, NULL, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4296
 *             ret = ret[self.quoteCharLen: -self.endQuoteCharLen]
 * 
 *             if isinstance(ret, basestring):             # <<<<<<<<<<<<<<
 *                 # replace escaped whitespace
 *                 if '\\' in ret and self.convertWhitespaceEscapes:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_basestring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4296, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyObject_IsInstance(__pyx_v_ret, __pyx_t_4); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 4296, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":4298
 *             if isinstance(ret, basestring):
 *                 # replace escaped whitespace
 *                 if '\\' in ret and self.convertWhitespaceEscapes:             # <<<<<<<<<<<<<<
 *                     ws_map = {
 *                         r'\t': '\t',
 */
      __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__12, __pyx_v_ret, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4298, __pyx_L1_error)
      if (__pyx_t_5) {
      } else {
        __pyx_t_7 = __pyx_t_5;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_convertWhitespaceEscapes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4298, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_7 = __pyx_t_5;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_7) {

        /* "cPyparsing.pyx":4300
 *                 if '\\' in ret and self.convertWhitespaceEscapes:
 *                     ws_map = {
 *                         r'\t': '\t',             # <<<<<<<<<<<<<<
 *                         r'\n': '\n',
 *                         r'\f': '\f',
 */
        __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (PyDict_SetItem(__pyx_t_4, __pyx_kp_u_t_2, __pyx_kp_u__98) < 0) __PYX_ERR(0, 4300, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_4, __pyx_kp_u_n_2, __pyx_kp_u__19) < 0) __PYX_ERR(0, 4300, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_4, __pyx_kp_u_f, __pyx_kp_u__99) < 0) __PYX_ERR(0, 4300, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_4, __pyx_kp_u_r_2, __pyx_kp_u__100) < 0) __PYX_ERR(0, 4300, __pyx_L1_error)
        __pyx_v_ws_map = ((PyObject*)__pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":4305
 *                         r'\r': '\r',
 *                     }
 *                     for wslit, wschar in ws_map.items():             # <<<<<<<<<<<<<<
 *                         ret = ret.replace(wslit, wschar)
 * 
 */
        __pyx_t_8 = 0;
        __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_ws_map, 1, __pyx_n_s_items, (&__pyx_t_9), (&__pyx_t_6)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4305, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4);
        __pyx_t_4 = __pyx_t_3;
        __pyx_t_3 = 0;
        while (1) {
          __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_4, __pyx_t_9, &__pyx_t_8, &__pyx_t_3, &__pyx_t_1, NULL, __pyx_t_6);
          if (unlikely(__pyx_t_10 == 0)) break;
          if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 4305, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_wslit, __pyx_t_3);
          __pyx_t_3 = 0;
          __Pyx_XDECREF_SET(__pyx_v_wschar, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":4306
 *                     }
 *                     for wslit, wschar in ws_map.items():
 *                         ret = ret.replace(wslit, wschar)             # <<<<<<<<<<<<<<
 * 
 *                 # replace escaped characters
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ret, __pyx_n_s_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4306, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_wslit, __pyx_v_wschar};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4306, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_1);
          __pyx_t_1 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "cPyparsing.pyx":4298
 *             if isinstance(ret, basestring):
 *                 # replace escaped whitespace
 *                 if '\\' in ret and self.convertWhitespaceEscapes:             # <<<<<<<<<<<<<<
 *                     ws_map = {
 *                         r'\t': '\t',
 */
      }

      /* "cPyparsing.pyx":4309
 * 
 *                 # replace escaped characters
 *                 if self.escChar:             # <<<<<<<<<<<<<<
 *                     ret = re.sub(self.escCharReplacePattern, r"\g<1>", ret)
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_escChar); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4309, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_7) {

        /* "cPyparsing.pyx":4310
 *                 # replace escaped characters
 *                 if self.escChar:
 *                     ret = re.sub(self.escCharReplacePattern, r"\g<1>", ret)             # <<<<<<<<<<<<<<
 * 
 *                 # replace escaped quotes
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4310, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_sub); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4310, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_escCharReplacePattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4310, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_t_1, __pyx_kp_u_g_1, __pyx_v_ret};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4310, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":4309
 * 
 *                 # replace escaped characters
 *                 if self.escChar:             # <<<<<<<<<<<<<<
 *                     ret = re.sub(self.escCharReplacePattern, r"\g<1>", ret)
 * 
 */
      }

      /* "cPyparsing.pyx":4313
 * 
 *                 # replace escaped quotes
 *                 if self.escQuote:             # <<<<<<<<<<<<<<
 *                     ret = ret.replace(self.escQuote, self.endQuoteChar)
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_escQuote); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4313, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_7) {

        /* "cPyparsing.pyx":4314
 *                 # replace escaped quotes
 *                 if self.escQuote:
 *                     ret = ret.replace(self.escQuote, self.endQuoteChar)             # <<<<<<<<<<<<<<
 * 
 *         # [CPYPARSING] update furthest_loc
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ret, __pyx_n_s_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4314, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_escQuote); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4314, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4314, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_11 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_1, __pyx_t_2};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4314, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":4313
 * 
 *                 # replace escaped quotes
 *                 if self.escQuote:             # <<<<<<<<<<<<<<
 *                     ret = ret.replace(self.escQuote, self.endQuoteChar)
 * 
 */
      }

      /* "cPyparsing.pyx":4296
 *             ret = ret[self.quoteCharLen: -self.endQuoteCharLen]
 * 
 *             if isinstance(ret, basestring):             # <<<<<<<<<<<<<<
 *                 # replace escaped whitespace
 *                 if '\\' in ret and self.convertWhitespaceEscapes:
 */
    }

    /* "cPyparsing.pyx":4291
 *         ret = result.group()
 * 
 *         if self.unquoteResults:             # <<<<<<<<<<<<<<
 * 
 *             # strip off quotes
 */
  }

  /* "cPyparsing.pyx":4317
 * 
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)             # <<<<<<<<<<<<<<
 *         return loc, ret
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_update_furthest_loc_for_regex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4318
 *         # [CPYPARSING] update furthest_loc
 *         self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *         return loc, ret             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_loc)) __PYX_ERR(0, 4318, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_ret)) __PYX_ERR(0, 4318, __pyx_L1_error);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4281
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = instring[loc] == self.firstQuoteChar and self.re_match(instring, loc) or None
 *         if not result:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.QuotedString.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_ws_map);
  __Pyx_XDECREF(__pyx_v_wslit);
  __Pyx_XDECREF(__pyx_v_wschar);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4320
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(QuotedString, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_12QuotedString_4__str__, "QuotedString.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_12QuotedString_5__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12QuotedString_5__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_12QuotedString_4__str__};
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4320, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 4320, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4320, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.QuotedString.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12QuotedString_4__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12QuotedString_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_UCS4 __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":4321
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(QuotedString, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":4322
 *     def __str__(self):
 *         try:
 *             return super(QuotedString, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_QuotedString); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4322, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4322, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5)) __PYX_ERR(0, 4322, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 4322, __pyx_L3_error);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4322, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4322, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4322, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":4321
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(QuotedString, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4323
 *         try:
 *             return super(QuotedString, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":4321
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(QuotedString, self).__str__()
 *         except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":4326
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "quoted string, starting with %s ending with %s" % (self.quoteChar, self.endQuoteChar)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":4327
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "quoted string, starting with %s ending with %s" % (self.quoteChar, self.endQuoteChar)             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = 0;
    __pyx_t_10 = 127;
    __Pyx_INCREF(__pyx_kp_u_quoted_string_starting_with);
    __pyx_t_9 += 29;
    __Pyx_GIVEREF(__pyx_kp_u_quoted_string_starting_with);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u_quoted_string_starting_with);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_quoteChar); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_6), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_10;
    __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_kp_u_ending_with);
    __pyx_t_9 += 13;
    __Pyx_GIVEREF(__pyx_kp_u_ending_with);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_kp_u_ending_with);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_10;
    __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_6) < 0) __PYX_ERR(0, 4327, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4326
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "quoted string, starting with %s ending with %s" % (self.quoteChar, self.endQuoteChar)
 * 
 */
  }

  /* "cPyparsing.pyx":4329
 *             self.strRepr = "quoted string, starting with %s ending with %s" % (self.quoteChar, self.endQuoteChar)
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4320
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(QuotedString, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.QuotedString.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4352
 *         ['dkls', 'lsdkjf', 's12 34', '@!#', '213']
 *     """
 *     def __init__(self, notChars, min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10CharsNotIn___init__, "CharsNotIn.__init__(self, notChars, min=1, max=0, exact=0)");
static PyMethodDef __pyx_mdef_10cPyparsing_10CharsNotIn_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10CharsNotIn_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10CharsNotIn___init__};
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_notChars = 0;
  PyObject *__pyx_v_min = 0;
  PyObject *__pyx_v_max = 0;
  PyObject *__pyx_v_exact = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_notChars,&__pyx_n_s_min,&__pyx_n_s_max,&__pyx_n_s_exact,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_1)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4352, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_notChars)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4352, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, 1); __PYX_ERR(0, 4352, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_min);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4352, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_max);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4352, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exact);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4352, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4352, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_notChars = values[1];
    __pyx_v_min = values[2];
    __pyx_v_max = values[3];
    __pyx_v_exact = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, __pyx_nargs); __PYX_ERR(0, 4352, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10CharsNotIn___init__(__pyx_self, __pyx_v_self, __pyx_v_notChars, __pyx_v_min, __pyx_v_max, __pyx_v_exact);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_notChars, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4353
 *     """
 *     def __init__(self, notChars, min=1, max=0, exact=0):
 *         super(CharsNotIn, self).__init__()             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.notChars = notChars
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4353, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4353, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4353, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4354
 *     def __init__(self, notChars, min=1, max=0, exact=0):
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         self.notChars = notChars
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 4354, __pyx_L1_error)

  /* "cPyparsing.pyx":4355
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 *         self.notChars = notChars             # <<<<<<<<<<<<<<
 * 
 *         if min < 1:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_notChars, __pyx_v_notChars) < 0) __PYX_ERR(0, 4355, __pyx_L1_error)

  /* "cPyparsing.pyx":4357
 *         self.notChars = notChars
 * 
 *         if min < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot specify a minimum length < 1; use "
 *                              "Optional(CharsNotIn()) if zero-length char group is permitted")
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_min, __pyx_int_1, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4357, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_5)) {

    /* "cPyparsing.pyx":4358
 * 
 *         if min < 1:
 *             raise ValueError("cannot specify a minimum length < 1; use "             # <<<<<<<<<<<<<<
 *                              "Optional(CharsNotIn()) if zero-length char group is permitted")
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__101, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 4358, __pyx_L1_error)

    /* "cPyparsing.pyx":4357
 *         self.notChars = notChars
 * 
 *         if min < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot specify a minimum length < 1; use "
 *                              "Optional(CharsNotIn()) if zero-length char group is permitted")
 */
  }

  /* "cPyparsing.pyx":4361
 *                              "Optional(CharsNotIn()) if zero-length char group is permitted")
 * 
 *         self.minLen = min             # <<<<<<<<<<<<<<
 * 
 *         if max > 0:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_minLen, __pyx_v_min) < 0) __PYX_ERR(0, 4361, __pyx_L1_error)

  /* "cPyparsing.pyx":4363
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_max, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4363, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4364
 * 
 *         if max > 0:
 *             self.maxLen = max             # <<<<<<<<<<<<<<
 *         else:
 *             self.maxLen = _MAX_INT
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_max) < 0) __PYX_ERR(0, 4364, __pyx_L1_error)

    /* "cPyparsing.pyx":4363
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":4366
 *             self.maxLen = max
 *         else:
 *             self.maxLen = _MAX_INT             # <<<<<<<<<<<<<<
 * 
 *         if exact > 0:
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4366, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_t_1) < 0) __PYX_ERR(0, 4366, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":4368
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_exact, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4368, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4369
 * 
 *         if exact > 0:
 *             self.maxLen = exact             # <<<<<<<<<<<<<<
 *             self.minLen = exact
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_exact) < 0) __PYX_ERR(0, 4369, __pyx_L1_error)

    /* "cPyparsing.pyx":4370
 *         if exact > 0:
 *             self.maxLen = exact
 *             self.minLen = exact             # <<<<<<<<<<<<<<
 * 
 *         self.name = _ustr(self)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_minLen, __pyx_v_exact) < 0) __PYX_ERR(0, 4370, __pyx_L1_error)

    /* "cPyparsing.pyx":4368
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  }

  /* "cPyparsing.pyx":4372
 *             self.minLen = exact
 * 
 *         self.name = _ustr(self)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = (self.minLen == 0)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4372, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_t_1) < 0) __PYX_ERR(0, 4372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4373
 * 
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = (self.minLen == 0)
 *         self.mayIndexError = False
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 4373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4374
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = (self.minLen == 0)             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_minLen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_t_3, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 4374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4375
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = (self.minLen == 0)
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 4375, __pyx_L1_error)

  /* "cPyparsing.pyx":4352
 *         ['dkls', 'lsdkjf', 's12 34', '@!#', '213']
 *     """
 *     def __init__(self, notChars, min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4394
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10CharsNotIn_2parseImpl, "CharsNotIn.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_10CharsNotIn_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10CharsNotIn_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10CharsNotIn_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4394, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4394, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4394, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4394, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4394, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4394, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4394, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4394, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10CharsNotIn_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_notchars = NULL;
  PyObject *__pyx_v_maxlen = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":4395
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] in self.notChars:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_2, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_3)) {

    /* "cPyparsing.pyx":4396
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         start = loc
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc, __pyx_t_4, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4396, __pyx_L1_error)

    /* "cPyparsing.pyx":4395
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] in self.notChars:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":4398
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         start = loc             # <<<<<<<<<<<<<<
 *         loc += 1
 *         notchars = self.notChars
 */
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_v_start = __pyx_v_loc;

  /* "cPyparsing.pyx":4399
 * 
 *         start = loc
 *         loc += 1             # <<<<<<<<<<<<<<
 *         notchars = self.notChars
 *         maxlen = min(start + self.maxLen, len(instring))
 */
  __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4400
 *         start = loc
 *         loc += 1
 *         notchars = self.notChars             # <<<<<<<<<<<<<<
 *         maxlen = min(start + self.maxLen, len(instring))
 *         while loc < maxlen and instring[loc] not in notchars:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_notchars = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4401
 *         loc += 1
 *         notchars = self.notChars
 *         maxlen = min(start + self.maxLen, len(instring))             # <<<<<<<<<<<<<<
 *         while loc < maxlen and instring[loc] not in notchars:
 *             loc += 1
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4401, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Add(__pyx_v_start, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_4, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_3) {
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
    __pyx_t_5 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = __pyx_t_1;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_maxlen = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4402
 *         notchars = self.notChars
 *         maxlen = min(start + self.maxLen, len(instring))
 *         while loc < maxlen and instring[loc] not in notchars:             # <<<<<<<<<<<<<<
 *             loc += 1
 * 
 */
  while (1) {
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_loc, __pyx_v_maxlen, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4402, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4402, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_8) {
    } else {
      __pyx_t_3 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_v_notchars, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4402, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __pyx_t_8;
    __pyx_L6_bool_binop_done:;
    if (!__pyx_t_3) break;

    /* "cPyparsing.pyx":4403
 *         maxlen = min(start + self.maxLen, len(instring))
 *         while loc < maxlen and instring[loc] not in notchars:
 *             loc += 1             # <<<<<<<<<<<<<<
 * 
 *         if loc - start < self.minLen:
 */
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
    __pyx_t_1 = 0;
  }

  /* "cPyparsing.pyx":4405
 *             loc += 1
 * 
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_1 = PyNumber_Subtract(__pyx_v_loc, __pyx_v_start); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_minLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(__pyx_t_3)) {

    /* "cPyparsing.pyx":4406
 * 
 *         if loc - start < self.minLen:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         return loc, instring[start:loc]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_instring, __pyx_v_loc, __pyx_t_1, __pyx_v_self};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4406, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 4406, __pyx_L1_error)

    /* "cPyparsing.pyx":4405
 *             loc += 1
 * 
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":4408
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         return loc, instring[start:loc]             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_start, &__pyx_v_loc, NULL, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_loc)) __PYX_ERR(0, 4408, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5)) __PYX_ERR(0, 4408, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4394
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_notchars);
  __Pyx_XDECREF(__pyx_v_maxlen);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4410
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(CharsNotIn, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10CharsNotIn_4__str__, "CharsNotIn.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10CharsNotIn_5__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10CharsNotIn_5__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10CharsNotIn_4__str__};
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4410, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 4410, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4410, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10CharsNotIn_4__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":4411
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(CharsNotIn, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":4412
 *     def __str__(self):
 *         try:
 *             return super(CharsNotIn, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4412, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4412, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5)) __PYX_ERR(0, 4412, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 4412, __pyx_L3_error);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4412, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4412, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4412, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":4411
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(CharsNotIn, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4413
 *         try:
 *             return super(CharsNotIn, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":4411
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(CharsNotIn, self).__str__()
 *         except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":4416
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             if len(self.notChars) > 4:
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":4417
 * 
 *         if self.strRepr is None:
 *             if len(self.notChars) > 4:             # <<<<<<<<<<<<<<
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 *             else:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4417, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = (__pyx_t_9 > 4);
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":4418
 *         if self.strRepr is None:
 *             if len(self.notChars) > 4:
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]             # <<<<<<<<<<<<<<
 *             else:
 *                 self.strRepr = "!W:(%s)" % self.notChars
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 4, NULL, NULL, &__pyx_slice__81, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_W_s_2, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_4) < 0) __PYX_ERR(0, 4418, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":4417
 * 
 *         if self.strRepr is None:
 *             if len(self.notChars) > 4:             # <<<<<<<<<<<<<<
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 *             else:
 */
      goto __pyx_L10;
    }

    /* "cPyparsing.pyx":4420
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 *             else:
 *                 self.strRepr = "!W:(%s)" % self.notChars             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4420, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_W_s_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4420, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_6) < 0) __PYX_ERR(0, 4420, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L10:;

    /* "cPyparsing.pyx":4416
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             if len(self.notChars) > 4:
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 */
  }

  /* "cPyparsing.pyx":4422
 *                 self.strRepr = "!W:(%s)" % self.notChars
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * class White(Token):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4410
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(CharsNotIn, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4458
 *         u'\u3000': '<IDEOGRAPHIC_SPACE>',
 *         }
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5White_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5White___init__, "White.__init__(self, ws=u' \\t\\r\\n', min=1, max=0, exact=0)");
static PyMethodDef __pyx_mdef_10cPyparsing_5White_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5White_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5White___init__};
static PyObject *__pyx_pw_10cPyparsing_5White_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_ws = 0;
  PyObject *__pyx_v_min = 0;
  PyObject *__pyx_v_max = 0;
  PyObject *__pyx_v_exact = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_ws,&__pyx_n_s_min,&__pyx_n_s_max,&__pyx_n_s_exact,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__102)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_1)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4458, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ws);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4458, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_min);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4458, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_max);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4458, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exact);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4458, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4458, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_ws = values[1];
    __pyx_v_min = values[2];
    __pyx_v_max = values[3];
    __pyx_v_exact = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 5, __pyx_nargs); __PYX_ERR(0, 4458, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.White.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5White___init__(__pyx_self, __pyx_v_self, __pyx_v_ws, __pyx_v_min, __pyx_v_max, __pyx_v_exact);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5White_8__init___2generator19(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4461
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))             # <<<<<<<<<<<<<<
 *         # ~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 */

static PyObject *__pyx_pf_10cPyparsing_5White_8__init___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_31_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4461, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5White_8__init___2generator19, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_White___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4461, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.White.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5White_8__init___2generator19(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4461, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 4461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 4461, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4461, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4461, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4461, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4461, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4461, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4461, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4461, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_matchWhite); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_c, __pyx_t_4, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4461, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_c))) __PYX_ERR(0, 4461, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5White_8__init___5generator20(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4463
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 *         # ~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Expected " + self.name
 */

static PyObject *__pyx_pf_10cPyparsing_5White_8__init___3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_32_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4463, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5White_8__init___5generator20, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_White___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4463, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.White.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5White_8__init___5generator20(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4463, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 4463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 4463, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4463, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4463, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4463, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4463, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4463, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4463, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4463, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4463, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_White); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_whiteStrs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_cur_scope->__pyx_v_c); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 4463, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4458
 *         u'\u3000': '<IDEOGRAPHIC_SPACE>',
 *         }
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */

static PyObject *__pyx_pf_10cPyparsing_5White___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ws, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *__pyx_cur_scope;
  PyObject *__pyx_gb_10cPyparsing_5White_8__init___2generator19 = 0;
  PyObject *__pyx_gb_10cPyparsing_5White_8__init___5generator20 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_30___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4458, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":4459
 *         }
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):
 *         super(White, self).__init__()             # <<<<<<<<<<<<<<
 *         self.matchWhite = ws
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_White); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4459, __pyx_L1_error);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_self)) __PYX_ERR(0, 4459, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4459, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4460
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):
 *         super(White, self).__init__()
 *         self.matchWhite = ws             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 *         # ~ self.leaveWhitespace()
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_matchWhite, __pyx_v_ws) < 0) __PYX_ERR(0, 4460, __pyx_L1_error)

  /* "cPyparsing.pyx":4461
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))             # <<<<<<<<<<<<<<
 *         # ~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __pyx_pf_10cPyparsing_5White_8__init___genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4463
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 *         # ~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Expected " + self.name
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_matchWhite); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_pf_10cPyparsing_5White_8__init___3genexpr(NULL, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name_2, __pyx_t_3) < 0) __PYX_ERR(0, 4463, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4464
 *         # ~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 4464, __pyx_L1_error)

  /* "cPyparsing.pyx":4465
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 * 
 *         self.minLen = min
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_1) < 0) __PYX_ERR(0, 4465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4467
 *         self.errmsg = "Expected " + self.name
 * 
 *         self.minLen = min             # <<<<<<<<<<<<<<
 * 
 *         if max > 0:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_minLen, __pyx_v_min) < 0) __PYX_ERR(0, 4467, __pyx_L1_error)

  /* "cPyparsing.pyx":4469
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_max, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4469, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4469, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4470
 * 
 *         if max > 0:
 *             self.maxLen = max             # <<<<<<<<<<<<<<
 *         else:
 *             self.maxLen = _MAX_INT
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_max) < 0) __PYX_ERR(0, 4470, __pyx_L1_error)

    /* "cPyparsing.pyx":4469
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4472
 *             self.maxLen = max
 *         else:
 *             self.maxLen = _MAX_INT             # <<<<<<<<<<<<<<
 * 
 *         if exact > 0:
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_maxLen, __pyx_t_1) < 0) __PYX_ERR(0, 4472, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4474
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_exact, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4474, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4475
 * 
 *         if exact > 0:
 *             self.maxLen = exact             # <<<<<<<<<<<<<<
 *             self.minLen = exact
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_exact) < 0) __PYX_ERR(0, 4475, __pyx_L1_error)

    /* "cPyparsing.pyx":4476
 *         if exact > 0:
 *             self.maxLen = exact
 *             self.minLen = exact             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_minLen, __pyx_v_exact) < 0) __PYX_ERR(0, 4476, __pyx_L1_error)

    /* "cPyparsing.pyx":4474
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  }

  /* "cPyparsing.pyx":4458
 *         u'\u3000': '<IDEOGRAPHIC_SPACE>',
 *         }
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.White.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_5White_8__init___2generator19);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_5White_8__init___5generator20);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4494
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] not in self.matchWhite:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5White_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5White_2parseImpl, "White.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_5White_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5White_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5White_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_5White_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4494, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4494, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4494, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4494, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4494, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4494, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4494, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4494, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.White.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5White_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5White_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_maxloc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":4495
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] not in self.matchWhite:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         start = loc
 */
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchWhite); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_2, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4495, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_3)) {

    /* "cPyparsing.pyx":4496
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] not in self.matchWhite:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         start = loc
 *         loc += 1
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc, __pyx_t_4, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4496, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4496, __pyx_L1_error)

    /* "cPyparsing.pyx":4495
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] not in self.matchWhite:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         start = loc
 */
  }

  /* "cPyparsing.pyx":4497
 *         if instring[loc] not in self.matchWhite:
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         start = loc             # <<<<<<<<<<<<<<
 *         loc += 1
 *         maxloc = start + self.maxLen
 */
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_v_start = __pyx_v_loc;

  /* "cPyparsing.pyx":4498
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         start = loc
 *         loc += 1             # <<<<<<<<<<<<<<
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, len(instring))
 */
  __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4499
 *         start = loc
 *         loc += 1
 *         maxloc = start + self.maxLen             # <<<<<<<<<<<<<<
 *         maxloc = min(maxloc, len(instring))
 *         while loc < maxloc and instring[loc] in self.matchWhite:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Add(__pyx_v_start, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_maxloc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4500
 *         loc += 1
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, len(instring))             # <<<<<<<<<<<<<<
 *         while loc < maxloc and instring[loc] in self.matchWhite:
 *             loc += 1
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4500, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_maxloc);
  __pyx_t_1 = __pyx_v_maxloc;
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_4, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4500, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4500, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_3) {
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
    __pyx_t_5 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = __pyx_t_1;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_maxloc, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4501
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, len(instring))
 *         while loc < maxloc and instring[loc] in self.matchWhite:             # <<<<<<<<<<<<<<
 *             loc += 1
 * 
 */
  while (1) {
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_loc, __pyx_v_maxloc, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4501, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4501, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_8) {
    } else {
      __pyx_t_3 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchWhite); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_2, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4501, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __pyx_t_8;
    __pyx_L6_bool_binop_done:;
    if (!__pyx_t_3) break;

    /* "cPyparsing.pyx":4502
 *         maxloc = min(maxloc, len(instring))
 *         while loc < maxloc and instring[loc] in self.matchWhite:
 *             loc += 1             # <<<<<<<<<<<<<<
 * 
 *         if loc - start < self.minLen:
 */
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_2);
    __pyx_t_2 = 0;
  }

  /* "cPyparsing.pyx":4504
 *             loc += 1
 * 
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_2 = PyNumber_Subtract(__pyx_v_loc, __pyx_v_start); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_minLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4504, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4504, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(__pyx_t_3)) {

    /* "cPyparsing.pyx":4505
 * 
 *         if loc - start < self.minLen:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         return loc, instring[start:loc]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_instring, __pyx_v_loc, __pyx_t_2, __pyx_v_self};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4505, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 4505, __pyx_L1_error)

    /* "cPyparsing.pyx":4504
 *             loc += 1
 * 
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":4507
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         return loc, instring[start:loc]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_start, &__pyx_v_loc, NULL, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_loc)) __PYX_ERR(0, 4507, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5)) __PYX_ERR(0, 4507, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4494
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] not in self.matchWhite:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.White.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_maxloc);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4511
 * 
 * class _PositionToken(Token):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14_PositionToken_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_14_PositionToken___init__, "_PositionToken.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_14_PositionToken_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_14_PositionToken_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_14_PositionToken___init__};
static PyObject *__pyx_pw_10cPyparsing_14_PositionToken_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4511, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4511, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4511, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._PositionToken.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14_PositionToken___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14_PositionToken___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4512
 * class _PositionToken(Token):
 *     def __init__(self):
 *         super(_PositionToken, self).__init__()             # <<<<<<<<<<<<<<
 *         self.name = self.__class__.__name__
 *         self.mayReturnEmpty = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PositionToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4512, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4512, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4513
 *     def __init__(self):
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_t_3) < 0) __PYX_ERR(0, 4513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4514
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 4514, __pyx_L1_error)

  /* "cPyparsing.pyx":4515
 *         self.name = self.__class__.__name__
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 * 
 * class GoToColumn(_PositionToken):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 4515, __pyx_L1_error)

  /* "cPyparsing.pyx":4511
 * 
 * class _PositionToken(Token):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._PositionToken.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4521
 *     tabular report scraping.
 *     """
 *     def __init__(self, colno):             # <<<<<<<<<<<<<<
 *         super(GoToColumn, self).__init__()
 *         self.col = colno
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10GoToColumn___init__, "GoToColumn.__init__(self, colno)");
static PyMethodDef __pyx_mdef_10cPyparsing_10GoToColumn_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10GoToColumn_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10GoToColumn___init__};
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_colno = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_colno,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4521, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_colno)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4521, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 4521, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4521, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_colno = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4521, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.GoToColumn.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10GoToColumn___init__(__pyx_self, __pyx_v_self, __pyx_v_colno);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10GoToColumn___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_colno) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4522
 *     """
 *     def __init__(self, colno):
 *         super(GoToColumn, self).__init__()             # <<<<<<<<<<<<<<
 *         self.col = colno
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_GoToColumn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4522, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4522, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4523
 *     def __init__(self, colno):
 *         super(GoToColumn, self).__init__()
 *         self.col = colno             # <<<<<<<<<<<<<<
 * 
 *     def preParse(self, instring, loc):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_col, __pyx_v_colno) < 0) __PYX_ERR(0, 4523, __pyx_L1_error)

  /* "cPyparsing.pyx":4521
 *     tabular report scraping.
 *     """
 *     def __init__(self, colno):             # <<<<<<<<<<<<<<
 *         super(GoToColumn, self).__init__()
 *         self.col = colno
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.GoToColumn.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4525
 *         self.col = colno
 * 
 *     def preParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_3preParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10GoToColumn_2preParse, "GoToColumn.preParse(self, instring, loc)");
static PyMethodDef __pyx_mdef_10cPyparsing_10GoToColumn_3preParse = {"preParse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10GoToColumn_3preParse, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10GoToColumn_2preParse};
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_3preParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("preParse (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4525, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4525, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, 1); __PYX_ERR(0, 4525, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4525, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, 2); __PYX_ERR(0, 4525, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "preParse") < 0)) __PYX_ERR(0, 4525, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4525, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.GoToColumn.preParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10GoToColumn_2preParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10GoToColumn_2preParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc) {
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("preParse", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":4526
 * 
 *     def preParse(self, instring, loc):
 *         if col(loc, instring) != self.col:             # <<<<<<<<<<<<<<
 *             instrlen = len(instring)
 *             if self.ignoreExprs:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_loc, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4526, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4526, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4526, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4527
 *     def preParse(self, instring, loc):
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)             # <<<<<<<<<<<<<<
 *             if self.ignoreExprs:
 *                 loc = self._skipIgnorables(instring, loc)
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4527, __pyx_L1_error)
    __pyx_v_instrlen = __pyx_t_6;

    /* "cPyparsing.pyx":4528
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 *             if self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 loc = self._skipIgnorables(instring, loc)
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4528, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4528, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":4529
 *             instrlen = len(instring)
 *             if self.ignoreExprs:
 *                 loc = self._skipIgnorables(instring, loc)             # <<<<<<<<<<<<<<
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 *                 loc += 1
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_skipIgnorables); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4529, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":4528
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 *             if self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 loc = self._skipIgnorables(instring, loc)
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 */
    }

    /* "cPyparsing.pyx":4530
 *             if self.ignoreExprs:
 *                 loc = self._skipIgnorables(instring, loc)
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:             # <<<<<<<<<<<<<<
 *                 loc += 1
 *         return loc
 */
    while (1) {
      __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_instrlen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_3, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_7) {
      } else {
        __pyx_t_5 = __pyx_t_7;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_isspace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4530, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_7) {
      } else {
        __pyx_t_5 = __pyx_t_7;
        goto __pyx_L7_bool_binop_done;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_col); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_loc, __pyx_v_instring};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4530, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_col); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4530, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5 = __pyx_t_7;
      __pyx_L7_bool_binop_done:;
      if (!__pyx_t_5) break;

      /* "cPyparsing.pyx":4531
 *                 loc = self._skipIgnorables(instring, loc)
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 *                 loc += 1             # <<<<<<<<<<<<<<
 *         return loc
 * 
 */
      __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4531, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_3);
      __pyx_t_3 = 0;
    }

    /* "cPyparsing.pyx":4526
 * 
 *     def preParse(self, instring, loc):
 *         if col(loc, instring) != self.col:             # <<<<<<<<<<<<<<
 *             instrlen = len(instring)
 *             if self.ignoreExprs:
 */
  }

  /* "cPyparsing.pyx":4532
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 *                 loc += 1
 *         return loc             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_r = __pyx_v_loc;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4525
 *         self.col = colno
 * 
 *     def preParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.GoToColumn.preParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4534
 *         return loc
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10GoToColumn_4parseImpl, "GoToColumn.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_10GoToColumn_5parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10GoToColumn_5parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10GoToColumn_4parseImpl};
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4534, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4534, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4534, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4534, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4534, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4534, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4534, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4534, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.GoToColumn.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10GoToColumn_4parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10GoToColumn_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_thiscol = NULL;
  PyObject *__pyx_v_newloc = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":4535
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         thiscol = col(loc, instring)             # <<<<<<<<<<<<<<
 *         if thiscol > self.col:
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_loc, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_thiscol = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4536
 *     def parseImpl(self, instring, loc, doActions=True):
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 *         newloc = loc + self.col - thiscol
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_col); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_thiscol, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_5)) {

    /* "cPyparsing.pyx":4537
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 *             raise ParseException(instring, loc, "Text not in expected column", self)             # <<<<<<<<<<<<<<
 *         newloc = loc + self.col - thiscol
 *         ret = instring[loc: newloc]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc, __pyx_kp_u_Text_not_in_expected_column, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4537, __pyx_L1_error)

    /* "cPyparsing.pyx":4536
 *     def parseImpl(self, instring, loc, doActions=True):
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 *         newloc = loc + self.col - thiscol
 */
  }

  /* "cPyparsing.pyx":4538
 *         if thiscol > self.col:
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 *         newloc = loc + self.col - thiscol             # <<<<<<<<<<<<<<
 *         ret = instring[loc: newloc]
 *         return newloc, ret
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Add(__pyx_v_loc, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_t_1, __pyx_v_thiscol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_newloc = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4539
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 *         newloc = loc + self.col - thiscol
 *         ret = instring[loc: newloc]             # <<<<<<<<<<<<<<
 *         return newloc, ret
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_loc, &__pyx_v_newloc, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_ret = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4540
 *         newloc = loc + self.col - thiscol
 *         ret = instring[loc: newloc]
 *         return newloc, ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_newloc);
  __Pyx_GIVEREF(__pyx_v_newloc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_newloc)) __PYX_ERR(0, 4540, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_ret)) __PYX_ERR(0, 4540, __pyx_L1_error);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4534
 *         return loc
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.GoToColumn.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_thiscol);
  __Pyx_XDECREF(__pyx_v_newloc);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4565
 * 
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9LineStart_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_9LineStart___init__, "LineStart.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_9LineStart_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9LineStart_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_9LineStart___init__};
static PyObject *__pyx_pw_10cPyparsing_9LineStart_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4565, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4565, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4565, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.LineStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9LineStart___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9LineStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4566
 *     """
 *     def __init__(self):
 *         super(LineStart, self).__init__()             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected start of line"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_LineStart); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4566, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4566, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4567
 *     def __init__(self):
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Expected_start_of_line) < 0) __PYX_ERR(0, 4567, __pyx_L1_error)

  /* "cPyparsing.pyx":4565
 * 
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.LineStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4569
 *         self.errmsg = "Expected start of line"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) == 1:
 *             return loc, []
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9LineStart_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_9LineStart_2parseImpl, "LineStart.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_9LineStart_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9LineStart_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_9LineStart_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_9LineStart_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4569, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4569, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4569, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4569, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4569, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4569, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4569, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4569, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.LineStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9LineStart_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9LineStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":4570
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if col(loc, instring) == 1:             # <<<<<<<<<<<<<<
 *             return loc, []
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_loc, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4571
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if col(loc, instring) == 1:
 *             return loc, []             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_loc);
    __Pyx_GIVEREF(__pyx_v_loc);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_loc)) __PYX_ERR(0, 4571, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1)) __PYX_ERR(0, 4571, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4570
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if col(loc, instring) == 1:             # <<<<<<<<<<<<<<
 *             return loc, []
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  }

  /* "cPyparsing.pyx":4572
 *         if col(loc, instring) == 1:
 *             return loc, []
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * class LineEnd(_PositionToken):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(0, 4572, __pyx_L1_error)

  /* "cPyparsing.pyx":4569
 *         self.errmsg = "Expected start of line"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) == 1:
 *             return loc, []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.LineStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4578
 *     parse string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7LineEnd_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7LineEnd___init__, "LineEnd.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_7LineEnd_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7LineEnd_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7LineEnd___init__};
static PyObject *__pyx_pw_10cPyparsing_7LineEnd_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4578, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4578, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4578, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.LineEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7LineEnd___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7LineEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4579
 *     """
 *     def __init__(self):
 *         super(LineEnd, self).__init__()             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 *         self.errmsg = "Expected end of line"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_LineEnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4579, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4579, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4580
 *     def __init__(self):
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected end of line"
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_replace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__103, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4581
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 *         self.errmsg = "Expected end of line"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Expected_end_of_line) < 0) __PYX_ERR(0, 4581, __pyx_L1_error)

  /* "cPyparsing.pyx":4578
 *     parse string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.LineEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4583
 *         self.errmsg = "Expected end of line"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7LineEnd_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7LineEnd_2parseImpl, "LineEnd.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_7LineEnd_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7LineEnd_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7LineEnd_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_7LineEnd_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4583, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4583, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4583, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4583, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4583, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4583, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4583, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4583, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.LineEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7LineEnd_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7LineEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":4584
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc < len(instring):             # <<<<<<<<<<<<<<
 *             if instring[loc] == "\n":
 *                 return loc + 1, "\n"
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4584, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4584, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4584, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":4585
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc < len(instring):
 *             if instring[loc] == "\n":             # <<<<<<<<<<<<<<
 *                 return loc + 1, "\n"
 *             else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u__19, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4585, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (likely(__pyx_t_4)) {

      /* "cPyparsing.pyx":4586
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 *                 return loc + 1, "\n"             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_3);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 4586, __pyx_L1_error);
      __Pyx_INCREF(__pyx_kp_u__19);
      __Pyx_GIVEREF(__pyx_kp_u__19);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_kp_u__19)) __PYX_ERR(0, 4586, __pyx_L1_error);
      __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":4585
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc < len(instring):
 *             if instring[loc] == "\n":             # <<<<<<<<<<<<<<
 *                 return loc + 1, "\n"
 *             else:
 */
    }

    /* "cPyparsing.pyx":4588
 *                 return loc + 1, "\n"
 *             else:
 *                 raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         elif loc == len(instring):
 *             return loc + 1, []
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4588, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4588, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_5, __pyx_v_self};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4588, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 4588, __pyx_L1_error)
    }

    /* "cPyparsing.pyx":4584
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc < len(instring):             # <<<<<<<<<<<<<<
 *             if instring[loc] == "\n":
 *                 return loc + 1, "\n"
 */
  }

  /* "cPyparsing.pyx":4589
 *             else:
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):             # <<<<<<<<<<<<<<
 *             return loc + 1, []
 *         else:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4589, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4589, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4589, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(__pyx_t_4)) {

    /* "cPyparsing.pyx":4590
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):
 *             return loc + 1, []             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 4590, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(0, 4590, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4589
 *             else:
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):             # <<<<<<<<<<<<<<
 *             return loc + 1, []
 *         else:
 */
  }

  /* "cPyparsing.pyx":4592
 *             return loc + 1, []
 *         else:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * class StringStart(_PositionToken):
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_3, __pyx_v_self};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 4592, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":4583
 *         self.errmsg = "Expected end of line"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.LineEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4598
 *     string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11StringStart_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_11StringStart___init__, "StringStart.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_11StringStart_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11StringStart_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_11StringStart___init__};
static PyObject *__pyx_pw_10cPyparsing_11StringStart_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4598, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4598, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4598, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.StringStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11StringStart___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11StringStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4599
 *     """
 *     def __init__(self):
 *         super(StringStart, self).__init__()             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected start of text"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_StringStart); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4599, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4599, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4600
 *     def __init__(self):
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Expected_start_of_text) < 0) __PYX_ERR(0, 4600, __pyx_L1_error)

  /* "cPyparsing.pyx":4598
 *     string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.StringStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4610
 *     #             return ParseException(instring, loc, self.errmsg, self)
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11StringStart_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_11StringStart_2parseImpl, "StringStart.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_11StringStart_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11StringStart_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_11StringStart_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_11StringStart_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4610, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4610, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4610, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4610, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4610, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4610, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4610, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4610, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.StringStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11StringStart_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11StringStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":4611
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc != 0:             # <<<<<<<<<<<<<<
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_loc, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4611, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4613
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4613, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_instring, __pyx_int_0};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4613, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_2, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4613, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4613, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__pyx_t_1)) {

      /* "cPyparsing.pyx":4614
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):
 *                 raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4614, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4614, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_4, __pyx_v_self};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4614, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4614, __pyx_L1_error)

      /* "cPyparsing.pyx":4613
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
    }

    /* "cPyparsing.pyx":4611
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc != 0:             # <<<<<<<<<<<<<<
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):
 */
  }

  /* "cPyparsing.pyx":4615
 *             if loc != self.preParse(instring, 0):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 * class StringEnd(_PositionToken):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_loc)) __PYX_ERR(0, 4615, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3)) __PYX_ERR(0, 4615, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4610
 *     #             return ParseException(instring, loc, self.errmsg, self)
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.StringStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4620
 *     """Matches if current position is at the end of the parse string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9StringEnd_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_9StringEnd___init__, "StringEnd.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_9StringEnd_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9StringEnd_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_9StringEnd___init__};
static PyObject *__pyx_pw_10cPyparsing_9StringEnd_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4620, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4620, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4620, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.StringEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9StringEnd___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9StringEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4621
 *     """
 *     def __init__(self):
 *         super(StringEnd, self).__init__()             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected end of text"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_StringEnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4621, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4621, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4622
 *     def __init__(self):
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Expected_end_of_text) < 0) __PYX_ERR(0, 4622, __pyx_L1_error)

  /* "cPyparsing.pyx":4620
 *     """Matches if current position is at the end of the parse string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.StringEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4635
 *     #     else:
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9StringEnd_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_9StringEnd_2parseImpl, "StringEnd.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_9StringEnd_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9StringEnd_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_9StringEnd_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_9StringEnd_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4635, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4635, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4635, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4635, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4635, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4635, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4635, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4635, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.StringEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9StringEnd_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9StringEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":4636
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc < len(instring):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4636, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4636, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4636, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(__pyx_t_4)) {

    /* "cPyparsing.pyx":4637
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         elif loc == len(instring):
 *             return loc + 1, []
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_5, __pyx_v_self};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4637, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 4637, __pyx_L1_error)

    /* "cPyparsing.pyx":4636
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc < len(instring):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):
 */
  }

  /* "cPyparsing.pyx":4638
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):             # <<<<<<<<<<<<<<
 *             return loc + 1, []
 *         elif loc > len(instring):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4638, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":4639
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):
 *             return loc + 1, []             # <<<<<<<<<<<<<<
 *         elif loc > len(instring):
 *             return loc, []
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_loc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4639, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3)) __PYX_ERR(0, 4639, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4638
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):             # <<<<<<<<<<<<<<
 *             return loc + 1, []
 *         elif loc > len(instring):
 */
  }

  /* "cPyparsing.pyx":4640
 *         elif loc == len(instring):
 *             return loc + 1, []
 *         elif loc > len(instring):             # <<<<<<<<<<<<<<
 *             return loc, []
 *         else:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4640, __pyx_L1_error)
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_5, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(__pyx_t_4)) {

    /* "cPyparsing.pyx":4641
 *             return loc + 1, []
 *         elif loc > len(instring):
 *             return loc, []             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_loc);
    __Pyx_GIVEREF(__pyx_v_loc);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_loc)) __PYX_ERR(0, 4641, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3)) __PYX_ERR(0, 4641, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4640
 *         elif loc == len(instring):
 *             return loc + 1, []
 *         elif loc > len(instring):             # <<<<<<<<<<<<<<
 *             return loc, []
 *         else:
 */
  }

  /* "cPyparsing.pyx":4643
 *             return loc, []
 *         else:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * class WordStart(_PositionToken):
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_2, __pyx_v_self};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4643, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 4643, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":4635
 *     #     else:
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.StringEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4654
 *     a line.
 *     """
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 */

static PyObject *__pyx_pf_10cPyparsing_99__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_wordChars);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_wordChars);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_wordChars)) __PYX_ERR(0, 4654, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 4654, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 4654, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9WordStart_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_9WordStart___init__, "WordStart.__init__(self, wordChars=printables)");
static PyMethodDef __pyx_mdef_10cPyparsing_9WordStart_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9WordStart_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_9WordStart___init__};
static PyObject *__pyx_pw_10cPyparsing_9WordStart_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_wordChars = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_wordChars,0};
    __pyx_defaults5 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self);
    values[1] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_wordChars);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4654, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_wordChars);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4654, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4654, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_wordChars = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 4654, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.WordStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9WordStart___init__(__pyx_self, __pyx_v_self, __pyx_v_wordChars);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9WordStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_wordChars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4655
 *     """
 *     def __init__(self, wordChars=printables):
 *         super(WordStart, self).__init__()             # <<<<<<<<<<<<<<
 *         self.wordChars = set(wordChars)
 *         self.errmsg = "Not at the start of a word"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_WordStart); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4655, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4655, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4656
 *     def __init__(self, wordChars=printables):
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Not at the start of a word"
 * 
 */
  __pyx_t_1 = PySet_New(__pyx_v_wordChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_wordChars, __pyx_t_1) < 0) __PYX_ERR(0, 4656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4657
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 *         self.errmsg = "Not at the start of a word"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Not_at_the_start_of_a_word) < 0) __PYX_ERR(0, 4657, __pyx_L1_error)

  /* "cPyparsing.pyx":4654
 *     a line.
 *     """
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.WordStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4659
 *         self.errmsg = "Not at the start of a word"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9WordStart_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_9WordStart_2parseImpl, "WordStart.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_9WordStart_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9WordStart_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_9WordStart_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_9WordStart_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4659, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4659, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4659, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4659, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4659, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4659, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4659, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4659, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.WordStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9WordStart_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9WordStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":4660
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc != 0:             # <<<<<<<<<<<<<<
 *             if (instring[loc - 1] in self.wordChars
 *                     or instring[loc] not in self.wordChars):
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_loc, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4660, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4661
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars             # <<<<<<<<<<<<<<
 *                     or instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    __pyx_t_2 = __Pyx_PyInt_SubtractObjC(__pyx_v_loc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_t_2, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4661, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!__pyx_t_4) {
    } else {
      __pyx_t_1 = __pyx_t_4;
      goto __pyx_L5_bool_binop_done;
    }

    /* "cPyparsing.pyx":4662
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars
 *                     or instring[loc] not in self.wordChars):             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_t_3, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4662, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_4;
    __pyx_L5_bool_binop_done:;

    /* "cPyparsing.pyx":4661
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars             # <<<<<<<<<<<<<<
 *                     or instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    if (unlikely(__pyx_t_1)) {

      /* "cPyparsing.pyx":4663
 *             if (instring[loc - 1] in self.wordChars
 *                     or instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4663, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4663, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_5, __pyx_v_self};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4663, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 4663, __pyx_L1_error)

      /* "cPyparsing.pyx":4661
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars             # <<<<<<<<<<<<<<
 *                     or instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    }

    /* "cPyparsing.pyx":4660
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if loc != 0:             # <<<<<<<<<<<<<<
 *             if (instring[loc - 1] in self.wordChars
 *                     or instring[loc] not in self.wordChars):
 */
  }

  /* "cPyparsing.pyx":4664
 *                     or instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 * class WordEnd(_PositionToken):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_loc)) __PYX_ERR(0, 4664, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3)) __PYX_ERR(0, 4664, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4659
 *         self.errmsg = "Not at the start of a word"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.WordStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4674
 *     of a line.
 *     """
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 */

static PyObject *__pyx_pf_10cPyparsing_101__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_wordChars);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_wordChars);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_wordChars)) __PYX_ERR(0, 4674, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 4674, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 4674, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7WordEnd_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7WordEnd___init__, "WordEnd.__init__(self, wordChars=printables)");
static PyMethodDef __pyx_mdef_10cPyparsing_7WordEnd_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7WordEnd_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7WordEnd___init__};
static PyObject *__pyx_pw_10cPyparsing_7WordEnd_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_wordChars = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_wordChars,0};
    __pyx_defaults6 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self);
    values[1] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_wordChars);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4674, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_wordChars);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4674, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4674, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_wordChars = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 4674, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.WordEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7WordEnd___init__(__pyx_self, __pyx_v_self, __pyx_v_wordChars);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7WordEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_wordChars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4675
 *     """
 *     def __init__(self, wordChars=printables):
 *         super(WordEnd, self).__init__()             # <<<<<<<<<<<<<<
 *         self.wordChars = set(wordChars)
 *         self.skipWhitespace = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_WordEnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4675, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4675, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4675, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4676
 *     def __init__(self, wordChars=printables):
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.errmsg = "Not at the end of a word"
 */
  __pyx_t_1 = PySet_New(__pyx_v_wordChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_wordChars, __pyx_t_1) < 0) __PYX_ERR(0, 4676, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4677
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         self.errmsg = "Not at the end of a word"
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 4677, __pyx_L1_error)

  /* "cPyparsing.pyx":4678
 *         self.wordChars = set(wordChars)
 *         self.skipWhitespace = False
 *         self.errmsg = "Not at the end of a word"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Not_at_the_end_of_a_word) < 0) __PYX_ERR(0, 4678, __pyx_L1_error)

  /* "cPyparsing.pyx":4674
 *     of a line.
 *     """
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.WordEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4680
 *         self.errmsg = "Not at the end of a word"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7WordEnd_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7WordEnd_2parseImpl, "WordEnd.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_7WordEnd_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7WordEnd_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7WordEnd_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_7WordEnd_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4680, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4680, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4680, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4680, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4680, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4680, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4680, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4680, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.WordEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7WordEnd_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7WordEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":4681
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4681, __pyx_L1_error)
  __pyx_v_instrlen = __pyx_t_1;

  /* "cPyparsing.pyx":4682
 *     def parseImpl(self, instring, loc, doActions=True):
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:             # <<<<<<<<<<<<<<
 *             if (instring[loc] in self.wordChars or
 *                     instring[loc - 1] not in self.wordChars):
 */
  __pyx_t_3 = (__pyx_v_instrlen > 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_instrlen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4682, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4682, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4683
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or             # <<<<<<<<<<<<<<
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_5, __pyx_t_4, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4683, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L7_bool_binop_done;
    }

    /* "cPyparsing.pyx":4684
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or
 *                     instring[loc - 1] not in self.wordChars):             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
    __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_loc, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_instring, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_5, __pyx_t_4, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4684, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L7_bool_binop_done:;

    /* "cPyparsing.pyx":4683
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or             # <<<<<<<<<<<<<<
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    if (unlikely(__pyx_t_2)) {

      /* "cPyparsing.pyx":4685
 *             if (instring[loc] in self.wordChars or
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4685, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4685, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_instring, __pyx_v_loc, __pyx_t_6, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 4+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4685, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 4685, __pyx_L1_error)

      /* "cPyparsing.pyx":4683
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or             # <<<<<<<<<<<<<<
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    }

    /* "cPyparsing.pyx":4682
 *     def parseImpl(self, instring, loc, doActions=True):
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:             # <<<<<<<<<<<<<<
 *             if (instring[loc] in self.wordChars or
 *                     instring[loc - 1] not in self.wordChars):
 */
  }

  /* "cPyparsing.pyx":4686
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_loc)) __PYX_ERR(0, 4686, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4)) __PYX_ERR(0, 4686, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4680
 *         self.errmsg = "Not at the end of a word"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.WordEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4693
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15ParseExpression___init__, "ParseExpression.__init__(self, exprs, savelist=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15ParseExpression___init__};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4693, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exprs)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4693, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 4693, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_savelist);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4693, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4693, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4693, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_15ParseExpression_8__init___2generator21(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4705
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 *             if any(isinstance(expr, basestring) for expr in exprs):             # <<<<<<<<<<<<<<
 *                 # [CPYPARSING] use map not iterator
 *                 exprs = map(lambda e: self._literalStringClass(e) if isinstance(e, basestring) else e, exprs)
 */

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_34_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4705, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_15ParseExpression_8__init___2generator21, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseExpression___init___locals, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4705, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_15ParseExpression_8__init___2generator21(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4705, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 4705, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4705, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4705, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4705, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4705, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4705, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4705, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4705, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4705, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_expr);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_expr, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_basestring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_expr, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 4705, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4707
 *             if any(isinstance(expr, basestring) for expr in exprs):
 *                 # [CPYPARSING] use map not iterator
 *                 exprs = map(lambda e: self._literalStringClass(e) if isinstance(e, basestring) else e, exprs)             # <<<<<<<<<<<<<<
 *             self.exprs = list(exprs)
 *         else:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_8__init___3lambda22(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_8__init___3lambda22 = {"lambda22", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_8__init___3lambda22, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_8__init___3lambda22(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_e = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda22 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_e,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_e)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4707, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda22") < 0)) __PYX_ERR(0, 4707, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_e = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda22", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4707, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__.lambda22", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda22(__pyx_self, __pyx_v_e);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda22(PyObject *__pyx_self, PyObject *__pyx_v_e) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda22", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_basestring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_e, __pyx_t_2); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 4707, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4707, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_e};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4707, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __Pyx_INCREF(__pyx_v_e);
    __pyx_t_1 = __pyx_v_e;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__.lambda22", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4693
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *__pyx_cur_scope;
  PyObject *__pyx_gb_10cPyparsing_15ParseExpression_8__init___2generator21 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_33___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4693, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_v_exprs);

  /* "cPyparsing.pyx":4694
 *     """
 *     def __init__(self, exprs, savelist=False):
 *         super(ParseExpression, self).__init__(savelist)             # <<<<<<<<<<<<<<
 *         if isinstance(exprs, _generatorType):
 *             exprs = list(exprs)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4694, __pyx_L1_error);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_self)) __PYX_ERR(0, 4694, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4694, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4695
 *     def __init__(self, exprs, savelist=False):
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):             # <<<<<<<<<<<<<<
 *             exprs = list(exprs)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_generatorType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_exprs, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 4695, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4696
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 *             exprs = list(exprs)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(exprs, basestring):
 */
    __pyx_t_1 = PySequence_List(__pyx_v_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_exprs, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4695
 *     def __init__(self, exprs, savelist=False):
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):             # <<<<<<<<<<<<<<
 *             exprs = list(exprs)
 * 
 */
  }

  /* "cPyparsing.pyx":4698
 *             exprs = list(exprs)
 * 
 *         if isinstance(exprs, basestring):             # <<<<<<<<<<<<<<
 *             self.exprs = [self._literalStringClass(exprs)]
 *         elif isinstance(exprs, ParserElement):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_exprs, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 4698, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4699
 * 
 *         if isinstance(exprs, basestring):
 *             self.exprs = [self._literalStringClass(exprs)]             # <<<<<<<<<<<<<<
 *         elif isinstance(exprs, ParserElement):
 *             self.exprs = [exprs]
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_exprs};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4699, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 4699, __pyx_L1_error);
    __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs, __pyx_t_3) < 0) __PYX_ERR(0, 4699, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4698
 *             exprs = list(exprs)
 * 
 *         if isinstance(exprs, basestring):             # <<<<<<<<<<<<<<
 *             self.exprs = [self._literalStringClass(exprs)]
 *         elif isinstance(exprs, ParserElement):
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":4700
 *         if isinstance(exprs, basestring):
 *             self.exprs = [self._literalStringClass(exprs)]
 *         elif isinstance(exprs, ParserElement):             # <<<<<<<<<<<<<<
 *             self.exprs = [exprs]
 *         elif isinstance(exprs, Iterable):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_exprs, __pyx_t_3); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 4700, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4701
 *             self.exprs = [self._literalStringClass(exprs)]
 *         elif isinstance(exprs, ParserElement):
 *             self.exprs = [exprs]             # <<<<<<<<<<<<<<
 *         elif isinstance(exprs, Iterable):
 *             exprs = list(exprs)
 */
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_exprs);
    __Pyx_GIVEREF(__pyx_v_exprs);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_exprs)) __PYX_ERR(0, 4701, __pyx_L1_error);
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs, __pyx_t_3) < 0) __PYX_ERR(0, 4701, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4700
 *         if isinstance(exprs, basestring):
 *             self.exprs = [self._literalStringClass(exprs)]
 *         elif isinstance(exprs, ParserElement):             # <<<<<<<<<<<<<<
 *             self.exprs = [exprs]
 *         elif isinstance(exprs, Iterable):
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":4702
 *         elif isinstance(exprs, ParserElement):
 *             self.exprs = [exprs]
 *         elif isinstance(exprs, Iterable):             # <<<<<<<<<<<<<<
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Iterable); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_exprs, __pyx_t_3); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 4702, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4703
 *             self.exprs = [exprs]
 *         elif isinstance(exprs, Iterable):
 *             exprs = list(exprs)             # <<<<<<<<<<<<<<
 *             # if sequence of strings provided, wrap with Literal
 *             if any(isinstance(expr, basestring) for expr in exprs):
 */
    __pyx_t_3 = PySequence_List(__pyx_v_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_exprs, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4705
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 *             if any(isinstance(expr, basestring) for expr in exprs):             # <<<<<<<<<<<<<<
 *                 # [CPYPARSING] use map not iterator
 *                 exprs = map(lambda e: self._literalStringClass(e) if isinstance(e, basestring) else e, exprs)
 */
    __pyx_t_3 = __pyx_pf_10cPyparsing_15ParseExpression_8__init___genexpr(NULL, __pyx_v_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4705, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":4707
 *             if any(isinstance(expr, basestring) for expr in exprs):
 *                 # [CPYPARSING] use map not iterator
 *                 exprs = map(lambda e: self._literalStringClass(e) if isinstance(e, basestring) else e, exprs)             # <<<<<<<<<<<<<<
 *             self.exprs = list(exprs)
 *         else:
 */
      __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_8__init___3lambda22, 0, __pyx_n_s_ParseExpression___init___locals_2, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4707, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4707, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 4707, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_exprs);
      __Pyx_GIVEREF(__pyx_v_exprs);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_exprs)) __PYX_ERR(0, 4707, __pyx_L1_error);
      __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4707, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_exprs, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":4705
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 *             if any(isinstance(expr, basestring) for expr in exprs):             # <<<<<<<<<<<<<<
 *                 # [CPYPARSING] use map not iterator
 *                 exprs = map(lambda e: self._literalStringClass(e) if isinstance(e, basestring) else e, exprs)
 */
    }

    /* "cPyparsing.pyx":4708
 *                 # [CPYPARSING] use map not iterator
 *                 exprs = map(lambda e: self._literalStringClass(e) if isinstance(e, basestring) else e, exprs)
 *             self.exprs = list(exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             try:
 */
    __pyx_t_1 = PySequence_List(__pyx_v_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4708, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs, __pyx_t_1) < 0) __PYX_ERR(0, 4708, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4702
 *         elif isinstance(exprs, ParserElement):
 *             self.exprs = [exprs]
 *         elif isinstance(exprs, Iterable):             # <<<<<<<<<<<<<<
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":4710
 *             self.exprs = list(exprs)
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.exprs = list(exprs)
 *             except TypeError:
 */
  /*else*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "cPyparsing.pyx":4711
 *         else:
 *             try:
 *                 self.exprs = list(exprs)             # <<<<<<<<<<<<<<
 *             except TypeError:
 *                 self.exprs = [exprs]
 */
        __pyx_t_1 = PySequence_List(__pyx_v_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4711, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs, __pyx_t_1) < 0) __PYX_ERR(0, 4711, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":4710
 *             self.exprs = list(exprs)
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.exprs = list(exprs)
 *             except TypeError:
 */
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L11_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":4712
 *             try:
 *                 self.exprs = list(exprs)
 *             except TypeError:             # <<<<<<<<<<<<<<
 *                 self.exprs = [exprs]
 *         self.callPreparse = False
 */
      __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
      if (__pyx_t_4) {
        __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 4712, __pyx_L8_except_error)
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_2);

        /* "cPyparsing.pyx":4713
 *                 self.exprs = list(exprs)
 *             except TypeError:
 *                 self.exprs = [exprs]             # <<<<<<<<<<<<<<
 *         self.callPreparse = False
 * 
 */
        __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4713, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_v_exprs);
        __Pyx_GIVEREF(__pyx_v_exprs);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_v_exprs)) __PYX_ERR(0, 4713, __pyx_L8_except_error);
        if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs, __pyx_t_9) < 0) __PYX_ERR(0, 4713, __pyx_L8_except_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L7_exception_handled;
      }
      goto __pyx_L8_except_error;

      /* "cPyparsing.pyx":4710
 *             self.exprs = list(exprs)
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.exprs = list(exprs)
 *             except TypeError:
 */
      __pyx_L8_except_error:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L1_error;
      __pyx_L7_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_L11_try_end:;
    }
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":4714
 *             except TypeError:
 *                 self.exprs = [exprs]
 *         self.callPreparse = False             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] fix append
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_callPreparse, Py_False) < 0) __PYX_ERR(0, 4714, __pyx_L1_error)

  /* "cPyparsing.pyx":4693
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_15ParseExpression_8__init___2generator21);
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4717
 * 
 *     # [CPYPARSING] fix append
 *     def append(self, other):             # <<<<<<<<<<<<<<
 *         if (self.parseAction
 *                 or self.resultsName is not None
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_3append(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15ParseExpression_2append, "ParseExpression.append(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_3append = {"append", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_3append, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15ParseExpression_2append};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_3append(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("append (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4717, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4717, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("append", 1, 2, 2, 1); __PYX_ERR(0, 4717, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "append") < 0)) __PYX_ERR(0, 4717, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("append", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4717, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_2append(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_2append(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "cPyparsing.pyx":4718
 *     # [CPYPARSING] fix append
 *     def append(self, other):
 *         if (self.parseAction             # <<<<<<<<<<<<<<
 *                 or self.resultsName is not None
 *                 or self.debug):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4718, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }

  /* "cPyparsing.pyx":4719
 *     def append(self, other):
 *         if (self.parseAction
 *                 or self.resultsName is not None             # <<<<<<<<<<<<<<
 *                 or self.debug):
 *             return self.__class__([self, other])
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }

  /* "cPyparsing.pyx":4720
 *         if (self.parseAction
 *                 or self.resultsName is not None
 *                 or self.debug):             # <<<<<<<<<<<<<<
 *             return self.__class__([self, other])
 *         elif (other.__class__ == self.__class__
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debug); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4720, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;

  /* "cPyparsing.pyx":4718
 *     # [CPYPARSING] fix append
 *     def append(self, other):
 *         if (self.parseAction             # <<<<<<<<<<<<<<
 *                 or self.resultsName is not None
 *                 or self.debug):
 */
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4721
 *                 or self.resultsName is not None
 *                 or self.debug):
 *             return self.__class__([self, other])             # <<<<<<<<<<<<<<
 *         elif (other.__class__ == self.__class__
 *                 and not other.parseAction
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_self)) __PYX_ERR(0, 4721, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_other);
    __Pyx_GIVEREF(__pyx_v_other);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_other)) __PYX_ERR(0, 4721, __pyx_L1_error);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4721, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4718
 *     # [CPYPARSING] fix append
 *     def append(self, other):
 *         if (self.parseAction             # <<<<<<<<<<<<<<
 *                 or self.resultsName is not None
 *                 or self.debug):
 */
  }

  /* "cPyparsing.pyx":4722
 *                 or self.debug):
 *             return self.__class__([self, other])
 *         elif (other.__class__ == self.__class__             # <<<<<<<<<<<<<<
 *                 and not other.parseAction
 *                 and other.resultsName is None
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L7_bool_binop_done;
  }

  /* "cPyparsing.pyx":4723
 *             return self.__class__([self, other])
 *         elif (other.__class__ == self.__class__
 *                 and not other.parseAction             # <<<<<<<<<<<<<<
 *                 and other.resultsName is None
 *                 and not other.debug):
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4723, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = (!__pyx_t_3);
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L7_bool_binop_done;
  }

  /* "cPyparsing.pyx":4724
 *         elif (other.__class__ == self.__class__
 *                 and not other.parseAction
 *                 and other.resultsName is None             # <<<<<<<<<<<<<<
 *                 and not other.debug):
 *             self.exprs += other.exprs
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = (__pyx_t_5 == Py_None);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L7_bool_binop_done;
  }

  /* "cPyparsing.pyx":4725
 *                 and not other.parseAction
 *                 and other.resultsName is None
 *                 and not other.debug):             # <<<<<<<<<<<<<<
 *             self.exprs += other.exprs
 *             self.strRepr = None
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_debug); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = (!__pyx_t_8);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L7_bool_binop_done:;

  /* "cPyparsing.pyx":4722
 *                 or self.debug):
 *             return self.__class__([self, other])
 *         elif (other.__class__ == self.__class__             # <<<<<<<<<<<<<<
 *                 and not other.parseAction
 *                 and other.resultsName is None
 */
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4726
 *                 and other.resultsName is None
 *                 and not other.debug):
 *             self.exprs += other.exprs             # <<<<<<<<<<<<<<
 *             self.strRepr = None
 *             self.saveAsList |= other.saveAsList
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_2) < 0) __PYX_ERR(0, 4726, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4727
 *                 and not other.debug):
 *             self.exprs += other.exprs
 *             self.strRepr = None             # <<<<<<<<<<<<<<
 *             self.saveAsList |= other.saveAsList
 *             if isinstance(self, And):
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 4727, __pyx_L1_error)

    /* "cPyparsing.pyx":4728
 *             self.exprs += other.exprs
 *             self.strRepr = None
 *             self.saveAsList |= other.saveAsList             # <<<<<<<<<<<<<<
 *             if isinstance(self, And):
 *                 self.mayReturnEmpty &= other.mayReturnEmpty
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4728, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4728, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyNumber_InPlaceOr(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4728, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_5) < 0) __PYX_ERR(0, 4728, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4729
 *             self.strRepr = None
 *             self.saveAsList |= other.saveAsList
 *             if isinstance(self, And):             # <<<<<<<<<<<<<<
 *                 self.mayReturnEmpty &= other.mayReturnEmpty
 *             else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_And); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyObject_IsInstance(__pyx_v_self, __pyx_t_5); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 4729, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":4730
 *             self.saveAsList |= other.saveAsList
 *             if isinstance(self, And):
 *                 self.mayReturnEmpty &= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *             else:
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4730, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4730, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyNumber_InPlaceAnd(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4730, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_2) < 0) __PYX_ERR(0, 4730, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":4729
 *             self.strRepr = None
 *             self.saveAsList |= other.saveAsList
 *             if isinstance(self, And):             # <<<<<<<<<<<<<<
 *                 self.mayReturnEmpty &= other.mayReturnEmpty
 *             else:
 */
      goto __pyx_L11;
    }

    /* "cPyparsing.pyx":4732
 *                 self.mayReturnEmpty &= other.mayReturnEmpty
 *             else:
 *                 self.mayReturnEmpty |= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *             self.mayIndexError |= other.mayIndexError
 *         else:
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyNumber_InPlaceOr(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_5) < 0) __PYX_ERR(0, 4732, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_L11:;

    /* "cPyparsing.pyx":4733
 *             else:
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 *             self.mayIndexError |= other.mayIndexError             # <<<<<<<<<<<<<<
 *         else:
 *             self.exprs.append(other)
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyNumber_InPlaceOr(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_2) < 0) __PYX_ERR(0, 4733, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4722
 *                 or self.debug):
 *             return self.__class__([self, other])
 *         elif (other.__class__ == self.__class__             # <<<<<<<<<<<<<<
 *                 and not other.parseAction
 *                 and other.resultsName is None
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4735
 *             self.mayIndexError |= other.mayIndexError
 *         else:
 *             self.exprs.append(other)             # <<<<<<<<<<<<<<
 *             self.strRepr = None
 *             if isinstance(self, And):
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_v_other); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 4735, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4736
 *         else:
 *             self.exprs.append(other)
 *             self.strRepr = None             # <<<<<<<<<<<<<<
 *             if isinstance(self, And):
 *                 self.mayReturnEmpty &= other.mayReturnEmpty
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 4736, __pyx_L1_error)

    /* "cPyparsing.pyx":4737
 *             self.exprs.append(other)
 *             self.strRepr = None
 *             if isinstance(self, And):             # <<<<<<<<<<<<<<
 *                 self.mayReturnEmpty &= other.mayReturnEmpty
 *             else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_And); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4737, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyObject_IsInstance(__pyx_v_self, __pyx_t_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 4737, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":4738
 *             self.strRepr = None
 *             if isinstance(self, And):
 *                 self.mayReturnEmpty &= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *             else:
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyNumber_InPlaceAnd(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_5) < 0) __PYX_ERR(0, 4738, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":4737
 *             self.exprs.append(other)
 *             self.strRepr = None
 *             if isinstance(self, And):             # <<<<<<<<<<<<<<
 *                 self.mayReturnEmpty &= other.mayReturnEmpty
 *             else:
 */
      goto __pyx_L12;
    }

    /* "cPyparsing.pyx":4740
 *                 self.mayReturnEmpty &= other.mayReturnEmpty
 *             else:
 *                 self.mayReturnEmpty |= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *             self.mayIndexError |= other.mayIndexError
 *             self.saveAsList |= other.saveAsList
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4740, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4740, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyNumber_InPlaceOr(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4740, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_2) < 0) __PYX_ERR(0, 4740, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L12:;

    /* "cPyparsing.pyx":4741
 *             else:
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 *             self.mayIndexError |= other.mayIndexError             # <<<<<<<<<<<<<<
 *             self.saveAsList |= other.saveAsList
 *         return self
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyNumber_InPlaceOr(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_5) < 0) __PYX_ERR(0, 4741, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4742
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 *             self.mayIndexError |= other.mayIndexError
 *             self.saveAsList |= other.saveAsList             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyNumber_InPlaceOr(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_2) < 0) __PYX_ERR(0, 4742, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4743
 *             self.mayIndexError |= other.mayIndexError
 *             self.saveAsList |= other.saveAsList
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def leaveWhitespace(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4717
 * 
 *     # [CPYPARSING] fix append
 *     def append(self, other):             # <<<<<<<<<<<<<<
 *         if (self.parseAction
 *                 or self.resultsName is not None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4745
 *         return self
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """Extends ``leaveWhitespace`` defined in base class, and also invokes ``leaveWhitespace`` on
 *            all contained expressions."""
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_5leaveWhitespace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15ParseExpression_4leaveWhitespace, "ParseExpression.leaveWhitespace(self)\nExtends ``leaveWhitespace`` defined in base class, and also invokes ``leaveWhitespace`` on\n           all contained expressions.");
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_5leaveWhitespace = {"leaveWhitespace", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_5leaveWhitespace, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15ParseExpression_4leaveWhitespace};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_5leaveWhitespace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4745, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "leaveWhitespace") < 0)) __PYX_ERR(0, 4745, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("leaveWhitespace", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4745, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_4leaveWhitespace(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_4leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_9genexpr26__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("leaveWhitespace", 1);

  /* "cPyparsing.pyx":4748
 *         """Extends ``leaveWhitespace`` defined in base class, and also invokes ``leaveWhitespace`` on
 *            all contained expressions."""
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         self.exprs = [e.copy() for e in self.exprs]
 *         for e in self.exprs:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 4748, __pyx_L1_error)

  /* "cPyparsing.pyx":4749
 *            all contained expressions."""
 *         self.skipWhitespace = False
 *         self.exprs = [e.copy() for e in self.exprs]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.leaveWhitespace()
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4749, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4749, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4749, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4749, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4749, __pyx_L5_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 4749, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4749, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4749, __pyx_L5_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 4749, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4749, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 4749, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr26__pyx_v_e, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr26__pyx_v_e, __pyx_n_s_copy); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4749, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4749, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 4749, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_9genexpr26__pyx_v_e); __pyx_9genexpr26__pyx_v_e = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_9genexpr26__pyx_v_e); __pyx_9genexpr26__pyx_v_e = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_1) < 0) __PYX_ERR(0, 4749, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4750
 *         self.skipWhitespace = False
 *         self.exprs = [e.copy() for e in self.exprs]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.leaveWhitespace()
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4750, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4750, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 4750, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4750, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4750, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 4750, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4750, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4750, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4751
 *         self.exprs = [e.copy() for e in self.exprs]
 *         for e in self.exprs:
 *             e.leaveWhitespace()             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4750
 *         self.skipWhitespace = False
 *         self.exprs = [e.copy() for e in self.exprs]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.leaveWhitespace()
 *         return self
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4752
 *         for e in self.exprs:
 *             e.leaveWhitespace()
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def ignore(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4745
 *         return self
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """Extends ``leaveWhitespace`` defined in base class, and also invokes ``leaveWhitespace`` on
 *            all contained expressions."""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_9genexpr26__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4754
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_7ignore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15ParseExpression_6ignore, "ParseExpression.ignore(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_7ignore = {"ignore", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_7ignore, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15ParseExpression_6ignore};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_7ignore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ignore (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4754, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4754, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, 1); __PYX_ERR(0, 4754, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "ignore") < 0)) __PYX_ERR(0, 4754, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4754, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_6ignore(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_6ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ignore", 1);

  /* "cPyparsing.pyx":4755
 * 
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4755, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4756
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_other, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4756, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":4757
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)             # <<<<<<<<<<<<<<
 *                 for e in self.exprs:
 *                     e.ignore(self.ignoreExprs[-1])
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(0, 4757, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self)) __PYX_ERR(0, 4757, __pyx_L1_error);
      __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ignore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4757, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":4758
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:             # <<<<<<<<<<<<<<
 *                     e.ignore(self.ignoreExprs[-1])
 *         else:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4758, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4);
        __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4758, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4758, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4758, __pyx_L1_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 4758, __pyx_L1_error)
            #else
            __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4758, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4758, __pyx_L1_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 4758, __pyx_L1_error)
            #else
            __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4758, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_7(__pyx_t_4);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 4758, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":4759
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:
 *                     e.ignore(self.ignoreExprs[-1])             # <<<<<<<<<<<<<<
 *         else:
 *             super(ParseExpression, self).ignore(other)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_ignore); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4759, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4759, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_GetItemInt(__pyx_t_8, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4759, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_9};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4759, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":4758
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:             # <<<<<<<<<<<<<<
 *                     e.ignore(self.ignoreExprs[-1])
 *         else:
 */
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":4756
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:
 */
    }

    /* "cPyparsing.pyx":4755
 * 
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4761
 *                     e.ignore(self.ignoreExprs[-1])
 *         else:
 *             super(ParseExpression, self).ignore(other)             # <<<<<<<<<<<<<<
 *             for e in self.exprs:
 *                 e.ignore(self.ignoreExprs[-1])
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 4761, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4761, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ignore); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_other};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4761, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4762
 *         else:
 *             super(ParseExpression, self).ignore(other)
 *             for e in self.exprs:             # <<<<<<<<<<<<<<
 *                 e.ignore(self.ignoreExprs[-1])
 *         return self
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4762, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
      __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4762, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4762, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 4762, __pyx_L1_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4762, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4762, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 4762, __pyx_L1_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4762, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_7(__pyx_t_3);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 4762, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":4763
 *             super(ParseExpression, self).ignore(other)
 *             for e in self.exprs:
 *                 e.ignore(self.ignoreExprs[-1])             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_ignore); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_9, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4763, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":4762
 *         else:
 *             super(ParseExpression, self).ignore(other)
 *             for e in self.exprs:             # <<<<<<<<<<<<<<
 *                 e.ignore(self.ignoreExprs[-1])
 *         return self
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4764
 *             for e in self.exprs:
 *                 e.ignore(self.ignoreExprs[-1])
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4754
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4766
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseExpression, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_9__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15ParseExpression_8__str__, "ParseExpression.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_9__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_9__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15ParseExpression_8__str__};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_9__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4766, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 4766, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4766, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_8__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_8__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_UCS4 __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":4767
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseExpression, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":4768
 *     def __str__(self):
 *         try:
 *             return super(ParseExpression, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4768, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4768, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5)) __PYX_ERR(0, 4768, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 4768, __pyx_L3_error);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4768, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4768, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4768, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":4767
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseExpression, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4769
 *         try:
 *             return super(ParseExpression, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":4767
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseExpression, self).__str__()
 *         except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":4772
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.exprs))
 *         return self.strRepr
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":4773
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.exprs))             # <<<<<<<<<<<<<<
 *         return self.strRepr
 * 
 */
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = 0;
    __pyx_t_10 = 127;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_10;
    __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u__104);
    __pyx_t_9 += 2;
    __Pyx_GIVEREF(__pyx_kp_u__104);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_kp_u__104);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_11};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4773, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_6), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_10;
    __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_kp_u__13);
    __pyx_t_9 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__13);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_kp_u__13);
    __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_5) < 0) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4772
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.exprs))
 *         return self.strRepr
 */
  }

  /* "cPyparsing.pyx":4774
 *         if self.strRepr is None:
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.exprs))
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4766
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseExpression, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4776
 *         return self.strRepr
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).streamline()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_11streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15ParseExpression_10streamline, "ParseExpression.streamline(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_11streamline = {"streamline", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_11streamline, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15ParseExpression_10streamline};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_11streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4776, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "streamline") < 0)) __PYX_ERR(0, 4776, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("streamline", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4776, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_10streamline(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_10streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_other = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("streamline", 1);

  /* "cPyparsing.pyx":4777
 * 
 *     def streamline(self):
 *         super(ParseExpression, self).streamline()             # <<<<<<<<<<<<<<
 * 
 *         for e in self.exprs:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4777, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4777, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4779
 *         super(ParseExpression, self).streamline()
 * 
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4779, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4779, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4779, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4779, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4779, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4779, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4779, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_6(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4779, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4780
 * 
 *         for e in self.exprs:
 *             e.streamline()             # <<<<<<<<<<<<<<
 * 
 *         # collapse nested And's of the form And(And(And(a, b), c), d) to And(a, b, c, d)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_streamline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4780, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4779
 *         super(ParseExpression, self).streamline()
 * 
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4785
 *         # but only if there are no parse actions or resultsNames on the nested And's
 *         # (likewise for Or's and MatchFirst's)
 *         if len(self.exprs) == 2:             # <<<<<<<<<<<<<<
 *             other = self.exprs[0]
 *             # [CPYPARSING] enforce __class__ equality
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4785, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_8 = (__pyx_t_5 == 2);
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":4786
 *         # (likewise for Or's and MatchFirst's)
 *         if len(self.exprs) == 2:
 *             other = self.exprs[0]             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4786, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4786, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_other = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4788
 *             other = self.exprs[0]
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__             # <<<<<<<<<<<<<<
 *                     and not other.parseAction
 *                     and other.resultsName is None
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4788, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 4788, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_9) {
    } else {
      __pyx_t_8 = __pyx_t_9;
      goto __pyx_L8_bool_binop_done;
    }

    /* "cPyparsing.pyx":4789
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__
 *                     and not other.parseAction             # <<<<<<<<<<<<<<
 *                     and other.resultsName is None
 *                     and not other.debug):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 4789, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_10 = (!__pyx_t_9);
    if (__pyx_t_10) {
    } else {
      __pyx_t_8 = __pyx_t_10;
      goto __pyx_L8_bool_binop_done;
    }

    /* "cPyparsing.pyx":4790
 *             if (other.__class__ == self.__class__
 *                     and not other.parseAction
 *                     and other.resultsName is None             # <<<<<<<<<<<<<<
 *                     and not other.debug):
 *                 # [CPYPARSING] don't copy exprs
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = (__pyx_t_2 == Py_None);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_10) {
    } else {
      __pyx_t_8 = __pyx_t_10;
      goto __pyx_L8_bool_binop_done;
    }

    /* "cPyparsing.pyx":4791
 *                     and not other.parseAction
 *                     and other.resultsName is None
 *                     and not other.debug):             # <<<<<<<<<<<<<<
 *                 # [CPYPARSING] don't copy exprs
 *                 self.exprs = other.exprs + [self.exprs[1]]
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_debug); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4791, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 4791, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_9 = (!__pyx_t_10);
    __pyx_t_8 = __pyx_t_9;
    __pyx_L8_bool_binop_done:;

    /* "cPyparsing.pyx":4788
 *             other = self.exprs[0]
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__             # <<<<<<<<<<<<<<
 *                     and not other.parseAction
 *                     and other.resultsName is None
 */
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":4793
 *                     and not other.debug):
 *                 # [CPYPARSING] don't copy exprs
 *                 self.exprs = other.exprs + [self.exprs[1]]             # <<<<<<<<<<<<<<
 *                 self.strRepr = None
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 4793, __pyx_L1_error);
      __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_1) < 0) __PYX_ERR(0, 4793, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":4794
 *                 # [CPYPARSING] don't copy exprs
 *                 self.exprs = other.exprs + [self.exprs[1]]
 *                 self.strRepr = None             # <<<<<<<<<<<<<<
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 *                 self.saveAsList |= other.saveAsList
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 4794, __pyx_L1_error)

      /* "cPyparsing.pyx":4796
 *                 self.strRepr = None
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 *                 self.saveAsList |= other.saveAsList             # <<<<<<<<<<<<<<
 *                 if isinstance(self, And):
 *                     self.mayReturnEmpty &= other.mayReturnEmpty
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyNumber_InPlaceOr(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_2) < 0) __PYX_ERR(0, 4796, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":4797
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 *                 self.saveAsList |= other.saveAsList
 *                 if isinstance(self, And):             # <<<<<<<<<<<<<<
 *                     self.mayReturnEmpty &= other.mayReturnEmpty
 *                 else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_And); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = PyObject_IsInstance(__pyx_v_self, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_8) {

        /* "cPyparsing.pyx":4798
 *                 self.saveAsList |= other.saveAsList
 *                 if isinstance(self, And):
 *                     self.mayReturnEmpty &= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *                 else:
 *                     self.mayReturnEmpty |= other.mayReturnEmpty
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = PyNumber_InPlaceAnd(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 4798, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":4797
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 *                 self.saveAsList |= other.saveAsList
 *                 if isinstance(self, And):             # <<<<<<<<<<<<<<
 *                     self.mayReturnEmpty &= other.mayReturnEmpty
 *                 else:
 */
        goto __pyx_L12;
      }

      /* "cPyparsing.pyx":4800
 *                     self.mayReturnEmpty &= other.mayReturnEmpty
 *                 else:
 *                     self.mayReturnEmpty |= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *                 self.mayIndexError |= other.mayIndexError
 * 
 */
      /*else*/ {
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4800, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4800, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = PyNumber_InPlaceOr(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4800, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_2) < 0) __PYX_ERR(0, 4800, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_L12:;

      /* "cPyparsing.pyx":4801
 *                 else:
 *                     self.mayReturnEmpty |= other.mayReturnEmpty
 *                 self.mayIndexError |= other.mayIndexError             # <<<<<<<<<<<<<<
 * 
 *             other = self.exprs[-1]
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4801, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4801, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = PyNumber_InPlaceOr(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4801, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_1) < 0) __PYX_ERR(0, 4801, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":4788
 *             other = self.exprs[0]
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__             # <<<<<<<<<<<<<<
 *                     and not other.parseAction
 *                     and other.resultsName is None
 */
    }

    /* "cPyparsing.pyx":4803
 *                 self.mayIndexError |= other.mayIndexError
 * 
 *             other = self.exprs[-1]             # <<<<<<<<<<<<<<
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4805
 *             other = self.exprs[-1]
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__             # <<<<<<<<<<<<<<
 *                     and not other.parseAction
 *                     and other.resultsName is None
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4805, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4805, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_3, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4805, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 4805, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_9) {
    } else {
      __pyx_t_8 = __pyx_t_9;
      goto __pyx_L14_bool_binop_done;
    }

    /* "cPyparsing.pyx":4806
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__
 *                     and not other.parseAction             # <<<<<<<<<<<<<<
 *                     and other.resultsName is None
 *                     and not other.debug):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 4806, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_10 = (!__pyx_t_9);
    if (__pyx_t_10) {
    } else {
      __pyx_t_8 = __pyx_t_10;
      goto __pyx_L14_bool_binop_done;
    }

    /* "cPyparsing.pyx":4807
 *             if (other.__class__ == self.__class__
 *                     and not other.parseAction
 *                     and other.resultsName is None             # <<<<<<<<<<<<<<
 *                     and not other.debug):
 *                 # [CPYPARSING] don't copy exprs
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4807, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = (__pyx_t_2 == Py_None);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_10) {
    } else {
      __pyx_t_8 = __pyx_t_10;
      goto __pyx_L14_bool_binop_done;
    }

    /* "cPyparsing.pyx":4808
 *                     and not other.parseAction
 *                     and other.resultsName is None
 *                     and not other.debug):             # <<<<<<<<<<<<<<
 *                 # [CPYPARSING] don't copy exprs
 *                 self.exprs = self.exprs[:-1] + other.exprs
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_debug); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4808, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 4808, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_9 = (!__pyx_t_10);
    __pyx_t_8 = __pyx_t_9;
    __pyx_L14_bool_binop_done:;

    /* "cPyparsing.pyx":4805
 *             other = self.exprs[-1]
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__             # <<<<<<<<<<<<<<
 *                     and not other.parseAction
 *                     and other.resultsName is None
 */
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":4810
 *                     and not other.debug):
 *                 # [CPYPARSING] don't copy exprs
 *                 self.exprs = self.exprs[:-1] + other.exprs             # <<<<<<<<<<<<<<
 *                 self.strRepr = None
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, -1L, NULL, NULL, &__pyx_slice__47, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_3) < 0) __PYX_ERR(0, 4810, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":4811
 *                 # [CPYPARSING] don't copy exprs
 *                 self.exprs = self.exprs[:-1] + other.exprs
 *                 self.strRepr = None             # <<<<<<<<<<<<<<
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 *                 self.saveAsList |= other.saveAsList
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 4811, __pyx_L1_error)

      /* "cPyparsing.pyx":4813
 *                 self.strRepr = None
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 *                 self.saveAsList |= other.saveAsList             # <<<<<<<<<<<<<<
 *                 if isinstance(self, And):
 *                     self.mayReturnEmpty &= other.mayReturnEmpty
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = PyNumber_InPlaceOr(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_1) < 0) __PYX_ERR(0, 4813, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":4814
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 *                 self.saveAsList |= other.saveAsList
 *                 if isinstance(self, And):             # <<<<<<<<<<<<<<
 *                     self.mayReturnEmpty &= other.mayReturnEmpty
 *                 else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_And); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4814, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyObject_IsInstance(__pyx_v_self, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 4814, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_8) {

        /* "cPyparsing.pyx":4815
 *                 self.saveAsList |= other.saveAsList
 *                 if isinstance(self, And):
 *                     self.mayReturnEmpty &= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *                 else:
 *                     self.mayReturnEmpty |= other.mayReturnEmpty
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4815, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4815, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = PyNumber_InPlaceAnd(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4815, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_3) < 0) __PYX_ERR(0, 4815, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "cPyparsing.pyx":4814
 *                 # [CPYPARSING] fix saveAsList, mayReturnEmpty
 *                 self.saveAsList |= other.saveAsList
 *                 if isinstance(self, And):             # <<<<<<<<<<<<<<
 *                     self.mayReturnEmpty &= other.mayReturnEmpty
 *                 else:
 */
        goto __pyx_L18;
      }

      /* "cPyparsing.pyx":4817
 *                     self.mayReturnEmpty &= other.mayReturnEmpty
 *                 else:
 *                     self.mayReturnEmpty |= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *                 self.mayIndexError |= other.mayIndexError
 * 
 */
      /*else*/ {
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = PyNumber_InPlaceOr(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 4817, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_L18:;

      /* "cPyparsing.pyx":4818
 *                 else:
 *                     self.mayReturnEmpty |= other.mayReturnEmpty
 *                 self.mayIndexError |= other.mayIndexError             # <<<<<<<<<<<<<<
 * 
 *         self.errmsg = "Expected " + _ustr(self)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyNumber_InPlaceOr(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_3) < 0) __PYX_ERR(0, 4818, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":4805
 *             other = self.exprs[-1]
 *             # [CPYPARSING] enforce __class__ equality
 *             if (other.__class__ == self.__class__             # <<<<<<<<<<<<<<
 *                     and not other.parseAction
 *                     and other.resultsName is None
 */
    }

    /* "cPyparsing.pyx":4785
 *         # but only if there are no parse actions or resultsNames on the nested And's
 *         # (likewise for Or's and MatchFirst's)
 *         if len(self.exprs) == 2:             # <<<<<<<<<<<<<<
 *             other = self.exprs[0]
 *             # [CPYPARSING] enforce __class__ equality
 */
  }

  /* "cPyparsing.pyx":4820
 *                 self.mayIndexError |= other.mayIndexError
 * 
 *         self.errmsg = "Expected " + _ustr(self)             # <<<<<<<<<<<<<<
 * 
 *         return self
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 4820, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4822
 *         self.errmsg = "Expected " + _ustr(self)
 * 
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def validate(self, validateTrace=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4776
 *         return self.strRepr
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).streamline()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4824
 *         return self
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         tmp = (validateTrace if validateTrace is not None else [])[:] + [self]
 *         for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_13validate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15ParseExpression_12validate, "ParseExpression.validate(self, validateTrace=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_13validate = {"validate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_13validate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15ParseExpression_12validate};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_13validate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_validateTrace = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_validateTrace,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4824, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_validateTrace);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4824, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "validate") < 0)) __PYX_ERR(0, 4824, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_validateTrace = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("validate", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 4824, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_12validate(__pyx_self, __pyx_v_self, __pyx_v_validateTrace);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_12validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace) {
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("validate", 1);

  /* "cPyparsing.pyx":4825
 * 
 *     def validate(self, validateTrace=None):
 *         tmp = (validateTrace if validateTrace is not None else [])[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.validate(tmp)
 */
  __pyx_t_2 = (__pyx_v_validateTrace != Py_None);
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_v_validateTrace);
    __pyx_t_1 = __pyx_v_validateTrace;
  } else {
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_self)) __PYX_ERR(0, 4825, __pyx_L1_error);
  __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_tmp = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4826
 *     def validate(self, validateTrace=None):
 *         tmp = (validateTrace if validateTrace is not None else [])[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.validate(tmp)
 *         self.checkRecursion([])
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4826, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4826, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4826, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4826, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4826, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4826, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4827
 *         tmp = (validateTrace if validateTrace is not None else [])[:] + [self]
 *         for e in self.exprs:
 *             e.validate(tmp)             # <<<<<<<<<<<<<<
 *         self.checkRecursion([])
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_validate); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_tmp};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4827, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4826
 *     def validate(self, validateTrace=None):
 *         tmp = (validateTrace if validateTrace is not None else [])[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.validate(tmp)
 *         self.checkRecursion([])
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4828
 *         for e in self.exprs:
 *             e.validate(tmp)
 *         self.checkRecursion([])             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4824
 *         return self
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         tmp = (validateTrace if validateTrace is not None else [])[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4830
 *         self.checkRecursion([])
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_15copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15ParseExpression_14copy, "ParseExpression.copy(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_15copy = {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_15copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15ParseExpression_14copy};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_15copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4830, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "copy") < 0)) __PYX_ERR(0, 4830, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("copy", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4830, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_14copy(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_14copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_9genexpr27__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 1);

  /* "cPyparsing.pyx":4831
 * 
 *     def copy(self):
 *         ret = super(ParseExpression, self).copy()             # <<<<<<<<<<<<<<
 *         ret.exprs = [e.copy() for e in self.exprs]
 *         return ret
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 4831, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 4831, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4831, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4832
 *     def copy(self):
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4832, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4832, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4832, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4832, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4832, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4832, __pyx_L5_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4832, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4832, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4832, __pyx_L5_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4832, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_6(__pyx_t_2);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 4832, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr27__pyx_v_e, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr27__pyx_v_e, __pyx_n_s_copy); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4832, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4832, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 4832, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_9genexpr27__pyx_v_e); __pyx_9genexpr27__pyx_v_e = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_9genexpr27__pyx_v_e); __pyx_9genexpr27__pyx_v_e = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ret, __pyx_n_s_exprs, __pyx_t_1) < 0) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4833
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4830
 *         self.checkRecursion([])
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_9genexpr27__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4835
 *         return ret
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_17_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_15ParseExpression_16_setResultsName, "ParseExpression._setResultsName(self, name, listAllMatches=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_17_setResultsName = {"_setResultsName", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15ParseExpression_17_setResultsName, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_15ParseExpression_16_setResultsName};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_17_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_listAllMatches = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_setResultsName (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,&__pyx_n_s_listAllMatches,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4835, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4835, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, 1); __PYX_ERR(0, 4835, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listAllMatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4835, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_setResultsName") < 0)) __PYX_ERR(0, 4835, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_listAllMatches = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4835, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseExpression._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_16_setResultsName(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_listAllMatches);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_16_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_setResultsName", 1);

  /* "cPyparsing.pyx":4836
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:             # <<<<<<<<<<<<<<
 *             for e in self.exprs:
 *                 if isinstance(e, ParserElement) and e.resultsName:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn_ungrouped_named_tokens_in_c); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4837
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in self.exprs:             # <<<<<<<<<<<<<<
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4837, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4837, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4837, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 4837, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4837, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4837, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 4837, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4837, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_5(__pyx_t_1);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 4837, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":4838
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in self.exprs:
 *                 if isinstance(e, ParserElement) and e.resultsName:             # <<<<<<<<<<<<<<
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4838, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = PyObject_IsInstance(__pyx_v_e, __pyx_t_2); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 4838, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_6) {
      } else {
        __pyx_t_3 = __pyx_t_6;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4838, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4838, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_3 = __pyx_t_6;
      __pyx_L7_bool_binop_done:;
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":4839
 *             for e in self.exprs:
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 *                                                                                        name,
 */
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4839, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warn); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4839, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":4840
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",             # <<<<<<<<<<<<<<
 *                                                                                        name,
 *                                                                                        type(self).__name__,
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_setting_results_name_1_r_on_2, __pyx_n_s_format); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4840, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);

        /* "cPyparsing.pyx":4842
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 *                                                                                        name,
 *                                                                                        type(self).__name__,             # <<<<<<<<<<<<<<
 *                                                                                        e.resultsName),
 *                                   stacklevel=3)
 */
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_self)), __pyx_n_s_name); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4842, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);

        /* "cPyparsing.pyx":4843
 *                                                                                        name,
 *                                                                                        type(self).__name__,
 *                                                                                        e.resultsName),             # <<<<<<<<<<<<<<
 *                                   stacklevel=3)
 * 
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4843, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = NULL;
        __pyx_t_12 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_12 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_11, __pyx_n_u_warn_ungrouped_named_tokens_in_c, __pyx_v_name, __pyx_t_9, __pyx_t_10};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_12, 4+__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4840, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }

        /* "cPyparsing.pyx":4839
 *             for e in self.exprs:
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 *                                                                                        name,
 */
        __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4839, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_2);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2)) __PYX_ERR(0, 4839, __pyx_L1_error);
        __pyx_t_2 = 0;

        /* "cPyparsing.pyx":4844
 *                                                                                        type(self).__name__,
 *                                                                                        e.resultsName),
 *                                   stacklevel=3)             # <<<<<<<<<<<<<<
 * 
 *         return super(ParseExpression, self)._setResultsName(name, listAllMatches)
 */
        __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4844, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stacklevel, __pyx_int_3) < 0) __PYX_ERR(0, 4844, __pyx_L1_error)

        /* "cPyparsing.pyx":4839
 *             for e in self.exprs:
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 *                                                                                        name,
 */
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4839, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "cPyparsing.pyx":4838
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in self.exprs:
 *                 if isinstance(e, ParserElement) and e.resultsName:             # <<<<<<<<<<<<<<
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 */
      }

      /* "cPyparsing.pyx":4837
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in self.exprs:             # <<<<<<<<<<<<<<
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4836
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:             # <<<<<<<<<<<<<<
 *             for e in self.exprs:
 *                 if isinstance(e, ParserElement) and e.resultsName:
 */
  }

  /* "cPyparsing.pyx":4846
 *                                   stacklevel=3)
 * 
 *         return super(ParseExpression, self)._setResultsName(name, listAllMatches)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_10)) __PYX_ERR(0, 4846, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self)) __PYX_ERR(0, 4846, __pyx_L1_error);
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  __pyx_t_12 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_12 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_v_name, __pyx_v_listAllMatches};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 2+__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4846, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4835
 *         return ret
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in self.exprs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.ParseExpression._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4868
 * 
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_ErrorStop_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_ErrorStop___init__, "_ErrorStop.__init__(self, *args, **kwargs)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_ErrorStop_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_ErrorStop_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_ErrorStop___init__};
static PyObject *__pyx_pw_10cPyparsing_10_ErrorStop_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4868, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, used_pos_args, "__init__") < 0)) __PYX_ERR(0, 4868, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 4868, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing._ErrorStop.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_ErrorStop___init__(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_ErrorStop___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":4869
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)             # <<<<<<<<<<<<<<
 *             self.name = '-'
 *             self.leaveWhitespace()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_And); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ErrorStop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(0, 4869, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self)) __PYX_ERR(0, 4869, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_v_args, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4870
 *         def __init__(self, *args, **kwargs):
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'             # <<<<<<<<<<<<<<
 *             self.leaveWhitespace()
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name_2, __pyx_kp_u__105) < 0) __PYX_ERR(0, 4870, __pyx_L1_error)

  /* "cPyparsing.pyx":4871
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 *             self.leaveWhitespace()             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, exprs, savelist=True):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4868
 * 
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._ErrorStop.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4873
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         exprs = list(exprs)
 *         if exprs and Ellipsis in exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_3And___init__, "And.__init__(self, exprs, savelist=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_3And_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_3And_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_3And___init__};
static PyObject *__pyx_pw_10cPyparsing_3And_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4873, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exprs)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4873, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 4873, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_savelist);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4873, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 4873, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4873, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.And.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_3And_8__init___2generator22(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4888
 *             exprs[:] = tmp
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 */

static PyObject *__pyx_pf_10cPyparsing_3And_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_35_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4888, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_3And_8__init___2generator22, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_And___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4888, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.And.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_3And_8__init___2generator22(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4888, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 4888, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4888, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4888, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4888, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4888, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4888, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4888, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4888, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4888, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4888, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = (!__pyx_t_5);
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4873
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         exprs = list(exprs)
 *         if exprs and Ellipsis in exprs:
 */

static PyObject *__pyx_pf_10cPyparsing_3And___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_skipto_arg = NULL;
  PyObject *__pyx_gb_10cPyparsing_3And_8__init___2generator22 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_exprs);

  /* "cPyparsing.pyx":4874
 * 
 *     def __init__(self, exprs, savelist=True):
 *         exprs = list(exprs)             # <<<<<<<<<<<<<<
 *         if exprs and Ellipsis in exprs:
 *             tmp = []
 */
  __pyx_t_1 = PySequence_List(__pyx_v_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_exprs, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4875
 *     def __init__(self, exprs, savelist=True):
 *         exprs = list(exprs)
 *         if exprs and Ellipsis in exprs:             # <<<<<<<<<<<<<<
 *             tmp = []
 *             for i, expr in enumerate(exprs):
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_exprs); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4875, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_builtin_Ellipsis, __pyx_v_exprs, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4875, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4876
 *         exprs = list(exprs)
 *         if exprs and Ellipsis in exprs:
 *             tmp = []             # <<<<<<<<<<<<<<
 *             for i, expr in enumerate(exprs):
 *                 if expr is Ellipsis:
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4876, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_tmp = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4877
 *         if exprs and Ellipsis in exprs:
 *             tmp = []
 *             for i, expr in enumerate(exprs):             # <<<<<<<<<<<<<<
 *                 if expr is Ellipsis:
 *                     if i < len(exprs) - 1:
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_t_1 = __pyx_int_0;
    if (likely(PyList_CheckExact(__pyx_v_exprs)) || PyTuple_CheckExact(__pyx_v_exprs)) {
      __pyx_t_4 = __pyx_v_exprs; __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4877, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4877, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_7 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4877, __pyx_L1_error)
          #else
          __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4877, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4877, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4877, __pyx_L1_error)
          #else
          __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4877, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
        }
      } else {
        __pyx_t_7 = __pyx_t_6(__pyx_t_4);
        if (unlikely(!__pyx_t_7)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 4877, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_XDECREF_SET(__pyx_v_expr, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
      __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1);
      __pyx_t_1 = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "cPyparsing.pyx":4878
 *             tmp = []
 *             for i, expr in enumerate(exprs):
 *                 if expr is Ellipsis:             # <<<<<<<<<<<<<<
 *                     if i < len(exprs) - 1:
 *                         skipto_arg = (Empty() + exprs[i + 1]).exprs[-1]
 */
      __pyx_t_2 = (__pyx_v_expr == __pyx_builtin_Ellipsis);
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":4879
 *             for i, expr in enumerate(exprs):
 *                 if expr is Ellipsis:
 *                     if i < len(exprs) - 1:             # <<<<<<<<<<<<<<
 *                         skipto_arg = (Empty() + exprs[i + 1]).exprs[-1]
 *                         tmp.append(SkipTo(skipto_arg)("_skipped*"))
 */
        __pyx_t_8 = 0;
        __pyx_t_9 = PyObject_Length(__pyx_v_exprs); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4879, __pyx_L1_error)
        __pyx_t_10 = __Pyx_sub_const_Py_ssize_t_checking_overflow(__pyx_t_9, 1, &__pyx_t_8);
        if (unlikely(__pyx_t_8)) {
          PyErr_SetString(PyExc_OverflowError, "value too large");
          __PYX_ERR(0, 4879, __pyx_L1_error)
        }
        __pyx_t_7 = PyInt_FromSsize_t(__pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4879, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_11 = PyObject_RichCompare(__pyx_v_i, __pyx_t_7, Py_LT); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4879, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4879, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (likely(__pyx_t_2)) {

          /* "cPyparsing.pyx":4880
 *                 if expr is Ellipsis:
 *                     if i < len(exprs) - 1:
 *                         skipto_arg = (Empty() + exprs[i + 1]).exprs[-1]             # <<<<<<<<<<<<<<
 *                         tmp.append(SkipTo(skipto_arg)("_skipped*"))
 *                     else:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_Empty); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_12 = NULL;
          __pyx_t_8 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_8 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, NULL};
            __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4880, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_12 = __Pyx_PyObject_GetItem(__pyx_v_exprs, __pyx_t_7); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4880, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = PyNumber_Add(__pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_exprs); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4880, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_12, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF_SET(__pyx_v_skipto_arg, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "cPyparsing.pyx":4881
 *                     if i < len(exprs) - 1:
 *                         skipto_arg = (Empty() + exprs[i + 1]).exprs[-1]
 *                         tmp.append(SkipTo(skipto_arg)("_skipped*"))             # <<<<<<<<<<<<<<
 *                     else:
 *                         raise Exception("cannot construct And with sequence ending in ...")
 */
          __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_SkipTo); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4881, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_13 = NULL;
          __pyx_t_8 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_11))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_11);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_11, function);
              __pyx_t_8 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_skipto_arg};
            __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4881, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          }
          __pyx_t_11 = NULL;
          __pyx_t_8 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
              __pyx_t_8 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_kp_u_skipped};
            __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4881, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          }
          __pyx_t_14 = __Pyx_PyList_Append(__pyx_v_tmp, __pyx_t_7); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 4881, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "cPyparsing.pyx":4879
 *             for i, expr in enumerate(exprs):
 *                 if expr is Ellipsis:
 *                     if i < len(exprs) - 1:             # <<<<<<<<<<<<<<
 *                         skipto_arg = (Empty() + exprs[i + 1]).exprs[-1]
 *                         tmp.append(SkipTo(skipto_arg)("_skipped*"))
 */
          goto __pyx_L9;
        }

        /* "cPyparsing.pyx":4883
 *                         tmp.append(SkipTo(skipto_arg)("_skipped*"))
 *                     else:
 *                         raise Exception("cannot construct And with sequence ending in ...")             # <<<<<<<<<<<<<<
 *                 else:
 *                     tmp.append(expr)
 */
        /*else*/ {
          __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__106, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4883, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_Raise(__pyx_t_7, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __PYX_ERR(0, 4883, __pyx_L1_error)
        }
        __pyx_L9:;

        /* "cPyparsing.pyx":4878
 *             tmp = []
 *             for i, expr in enumerate(exprs):
 *                 if expr is Ellipsis:             # <<<<<<<<<<<<<<
 *                     if i < len(exprs) - 1:
 *                         skipto_arg = (Empty() + exprs[i + 1]).exprs[-1]
 */
        goto __pyx_L8;
      }

      /* "cPyparsing.pyx":4885
 *                         raise Exception("cannot construct And with sequence ending in ...")
 *                 else:
 *                     tmp.append(expr)             # <<<<<<<<<<<<<<
 *             exprs[:] = tmp
 *         super(And, self).__init__(exprs, savelist)
 */
      /*else*/ {
        __pyx_t_14 = __Pyx_PyList_Append(__pyx_v_tmp, __pyx_v_expr); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 4885, __pyx_L1_error)
      }
      __pyx_L8:;

      /* "cPyparsing.pyx":4877
 *         if exprs and Ellipsis in exprs:
 *             tmp = []
 *             for i, expr in enumerate(exprs):             # <<<<<<<<<<<<<<
 *                 if expr is Ellipsis:
 *                     if i < len(exprs) - 1:
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4886
 *                 else:
 *                     tmp.append(expr)
 *             exprs[:] = tmp             # <<<<<<<<<<<<<<
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
    if (__Pyx_PyObject_SetSlice(__pyx_v_exprs, __pyx_v_tmp, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1) < 0) __PYX_ERR(0, 4886, __pyx_L1_error)

    /* "cPyparsing.pyx":4875
 *     def __init__(self, exprs, savelist=True):
 *         exprs = list(exprs)
 *         if exprs and Ellipsis in exprs:             # <<<<<<<<<<<<<<
 *             tmp = []
 *             for i, expr in enumerate(exprs):
 */
  }

  /* "cPyparsing.pyx":4887
 *                     tmp.append(expr)
 *             exprs[:] = tmp
 *         super(And, self).__init__(exprs, savelist)             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_And); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4)) __PYX_ERR(0, 4887, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_self)) __PYX_ERR(0, 4887, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_init); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4888
 *             exprs[:] = tmp
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __pyx_pf_10cPyparsing_3And_8__init___genexpr(NULL, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 4888, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4889
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 *         self.callPreparse = True
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_12 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4890
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace             # <<<<<<<<<<<<<<
 *         self.callPreparse = True
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_skipWhitespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, __pyx_t_1) < 0) __PYX_ERR(0, 4890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4891
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 *         self.callPreparse = True             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse, Py_True) < 0) __PYX_ERR(0, 4891, __pyx_L1_error)

  /* "cPyparsing.pyx":4873
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         exprs = list(exprs)
 *         if exprs and Ellipsis in exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.And.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_skipto_arg);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_3And_8__init___2generator22);
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4893
 *         self.callPreparse = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_3streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_3And_2streamline, "And.streamline(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_3And_3streamline = {"streamline", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_3And_3streamline, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_3And_2streamline};
static PyObject *__pyx_pw_10cPyparsing_3And_3streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4893, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "streamline") < 0)) __PYX_ERR(0, 4893, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("streamline", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4893, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.And.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And_2streamline(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_3And_10streamline_2generator23(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4896
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)             # <<<<<<<<<<<<<<
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):
 */

static PyObject *__pyx_pf_10cPyparsing_3And_10streamline_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_36_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4896, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_3And_10streamline_2generator23, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_And_streamline_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.And.streamline.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_3And_10streamline_2generator23(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4896, __pyx_L1_error)

  /* "cPyparsing.pyx":4897
 *         if self.exprs:
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)
 *                    for e in self.exprs[:-1]):             # <<<<<<<<<<<<<<
 *                 for i, e in enumerate(self.exprs[:-1]):
 *                     if e is None:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 4897, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4897, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4897, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4897, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4897, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4897, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4897, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4897, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4897, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4896
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)             # <<<<<<<<<<<<<<
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_4, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_PendingSkip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyObject_IsInstance(__pyx_t_7, __pyx_t_4); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __pyx_t_6;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }

    /* "cPyparsing.pyx":4897
 *         if self.exprs:
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)
 *                    for e in self.exprs[:-1]):             # <<<<<<<<<<<<<<
 *                 for i, e in enumerate(self.exprs[:-1]):
 *                     if e is None:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {

    /* "cPyparsing.pyx":4896
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)             # <<<<<<<<<<<<<<
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_3And_10streamline_5generator24(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4908
 * 
 *         super(And, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_3And_10streamline_3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_37_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4908, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_3And_10streamline_5generator24, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_And_streamline_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4908, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.And.streamline.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_3And_10streamline_5generator24(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4908, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 4908, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4908, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4908, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4908, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4908, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4908, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4908, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4908, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4908, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4908, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = (!__pyx_t_5);
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4893
 *         self.callPreparse = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 */

static PyObject *__pyx_pf_10cPyparsing_3And_2streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_gb_10cPyparsing_3And_10streamline_2generator23 = 0;
  PyObject *__pyx_9genexpr30__pyx_v_e = NULL;
  PyObject *__pyx_gb_10cPyparsing_3And_10streamline_5generator24 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("streamline", 1);

  /* "cPyparsing.pyx":4895
 *     def streamline(self):
 *         # collapse any _PendingSkip's
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)
 *                    for e in self.exprs[:-1]):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4895, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4897
 *         if self.exprs:
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)
 *                    for e in self.exprs[:-1]):             # <<<<<<<<<<<<<<
 *                 for i, e in enumerate(self.exprs[:-1]):
 *                     if e is None:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, -1L, NULL, NULL, &__pyx_slice__47, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4896
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)             # <<<<<<<<<<<<<<
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_3And_10streamline_genexpr(NULL, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4896, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":4898
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):             # <<<<<<<<<<<<<<
 *                     if e is None:
 *                         continue
 */
      __Pyx_INCREF(__pyx_int_0);
      __pyx_t_3 = __pyx_int_0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4898, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, -1L, NULL, NULL, &__pyx_slice__47, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4898, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4898, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4898, __pyx_L1_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4898, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4898, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4898, __pyx_L1_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4898, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4898, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_6(__pyx_t_1);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 4898, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_4);
        __pyx_t_4 = 0;
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
        __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3);
        __pyx_t_3 = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":4899
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):
 *                     if e is None:             # <<<<<<<<<<<<<<
 *                         continue
 *                     if (isinstance(e, ParseExpression)
 */
        __pyx_t_2 = (__pyx_v_e == Py_None);
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":4900
 *                 for i, e in enumerate(self.exprs[:-1]):
 *                     if e is None:
 *                         continue             # <<<<<<<<<<<<<<
 *                     if (isinstance(e, ParseExpression)
 *                             and e.exprs and isinstance(e.exprs[-1], _PendingSkip)):
 */
          goto __pyx_L5_continue;

          /* "cPyparsing.pyx":4899
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):
 *                     if e is None:             # <<<<<<<<<<<<<<
 *                         continue
 *                     if (isinstance(e, ParseExpression)
 */
        }

        /* "cPyparsing.pyx":4901
 *                     if e is None:
 *                         continue
 *                     if (isinstance(e, ParseExpression)             # <<<<<<<<<<<<<<
 *                             and e.exprs and isinstance(e.exprs[-1], _PendingSkip)):
 *                         e.exprs[-1] = e.exprs[-1] + self.exprs[i + 1]
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = PyObject_IsInstance(__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 4901, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_7) {
        } else {
          __pyx_t_2 = __pyx_t_7;
          goto __pyx_L9_bool_binop_done;
        }

        /* "cPyparsing.pyx":4902
 *                         continue
 *                     if (isinstance(e, ParseExpression)
 *                             and e.exprs and isinstance(e.exprs[-1], _PendingSkip)):             # <<<<<<<<<<<<<<
 *                         e.exprs[-1] = e.exprs[-1] + self.exprs[i + 1]
 *                         self.exprs[i + 1] = None
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4902, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4902, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_7) {
        } else {
          __pyx_t_2 = __pyx_t_7;
          goto __pyx_L9_bool_binop_done;
        }
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4902, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_4, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4902, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_PendingSkip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4902, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = PyObject_IsInstance(__pyx_t_8, __pyx_t_4); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 4902, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __pyx_t_7;
        __pyx_L9_bool_binop_done:;

        /* "cPyparsing.pyx":4901
 *                     if e is None:
 *                         continue
 *                     if (isinstance(e, ParseExpression)             # <<<<<<<<<<<<<<
 *                             and e.exprs and isinstance(e.exprs[-1], _PendingSkip)):
 *                         e.exprs[-1] = e.exprs[-1] + self.exprs[i + 1]
 */
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":4903
 *                     if (isinstance(e, ParseExpression)
 *                             and e.exprs and isinstance(e.exprs[-1], _PendingSkip)):
 *                         e.exprs[-1] = e.exprs[-1] + self.exprs[i + 1]             # <<<<<<<<<<<<<<
 *                         self.exprs[i + 1] = None
 *                 self.exprs = [e for e in self.exprs if e is not None]
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4903, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_4, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4903, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4903, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_9 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4903, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4903, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = PyNumber_Add(__pyx_t_8, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4903, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_exprs); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4903, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (unlikely((__Pyx_SetItemInt(__pyx_t_10, -1L, __pyx_t_9, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0))) __PYX_ERR(0, 4903, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":4904
 *                             and e.exprs and isinstance(e.exprs[-1], _PendingSkip)):
 *                         e.exprs[-1] = e.exprs[-1] + self.exprs[i + 1]
 *                         self.exprs[i + 1] = None             # <<<<<<<<<<<<<<
 *                 self.exprs = [e for e in self.exprs if e is not None]
 * 
 */
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4904, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4904, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (unlikely((PyObject_SetItem(__pyx_t_9, __pyx_t_10, Py_None) < 0))) __PYX_ERR(0, 4904, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "cPyparsing.pyx":4901
 *                     if e is None:
 *                         continue
 *                     if (isinstance(e, ParseExpression)             # <<<<<<<<<<<<<<
 *                             and e.exprs and isinstance(e.exprs[-1], _PendingSkip)):
 *                         e.exprs[-1] = e.exprs[-1] + self.exprs[i + 1]
 */
        }

        /* "cPyparsing.pyx":4898
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):             # <<<<<<<<<<<<<<
 *                     if e is None:
 *                         continue
 */
        __pyx_L5_continue:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":4905
 *                         e.exprs[-1] = e.exprs[-1] + self.exprs[i + 1]
 *                         self.exprs[i + 1] = None
 *                 self.exprs = [e for e in self.exprs if e is not None]             # <<<<<<<<<<<<<<
 * 
 *         super(And, self).streamline()
 */
      { /* enter inner scope */
        __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4905, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4905, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
          __pyx_t_10 = __pyx_t_1; __Pyx_INCREF(__pyx_t_10);
          __pyx_t_5 = 0;
          __pyx_t_6 = NULL;
        } else {
          __pyx_t_5 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4905, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4905, __pyx_L15_error)
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        for (;;) {
          if (likely(!__pyx_t_6)) {
            if (likely(PyList_CheckExact(__pyx_t_10))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_10);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4905, __pyx_L15_error)
                #endif
                if (__pyx_t_5 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4905, __pyx_L15_error)
              #else
              __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_10, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4905, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_1);
              #endif
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_10);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4905, __pyx_L15_error)
                #endif
                if (__pyx_t_5 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 4905, __pyx_L15_error)
              #else
              __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_10, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4905, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_1);
              #endif
            }
          } else {
            __pyx_t_1 = __pyx_t_6(__pyx_t_10);
            if (unlikely(!__pyx_t_1)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 4905, __pyx_L15_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_XDECREF_SET(__pyx_9genexpr30__pyx_v_e, __pyx_t_1);
          __pyx_t_1 = 0;
          __pyx_t_2 = (__pyx_9genexpr30__pyx_v_e != Py_None);
          if (__pyx_t_2) {
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_9genexpr30__pyx_v_e))) __PYX_ERR(0, 4905, __pyx_L15_error)
          }
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_9genexpr30__pyx_v_e); __pyx_9genexpr30__pyx_v_e = 0;
        goto __pyx_L20_exit_scope;
        __pyx_L15_error:;
        __Pyx_XDECREF(__pyx_9genexpr30__pyx_v_e); __pyx_9genexpr30__pyx_v_e = 0;
        goto __pyx_L1_error;
        __pyx_L20_exit_scope:;
      } /* exit inner scope */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_3) < 0) __PYX_ERR(0, 4905, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":4896
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)             # <<<<<<<<<<<<<<
 *                    for e in self.exprs[:-1]):
 *                 for i, e in enumerate(self.exprs[:-1]):
 */
    }

    /* "cPyparsing.pyx":4895
 *     def streamline(self):
 *         # collapse any _PendingSkip's
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             if any(isinstance(e, ParseExpression) and e.exprs and isinstance(e.exprs[-1], _PendingSkip)
 *                    for e in self.exprs[:-1]):
 */
  }

  /* "cPyparsing.pyx":4907
 *                 self.exprs = [e for e in self.exprs if e is not None]
 * 
 *         super(And, self).streamline()             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         return self
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_And); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_10)) __PYX_ERR(0, 4907, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self)) __PYX_ERR(0, 4907, __pyx_L1_error);
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_1, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_streamline); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_11, 0+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4908
 * 
 *         super(And, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __pyx_pf_10cPyparsing_3And_10streamline_3genexpr(NULL, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_3) < 0) __PYX_ERR(0, 4908, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4909
 *         super(And, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4893
 *         self.callPreparse = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.And.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_3And_10streamline_2generator23);
  __Pyx_XDECREF(__pyx_9genexpr30__pyx_v_e);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_3And_10streamline_5generator24);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4944
 *     #             resultlist += exprtokens
 *     #     return loc, resultlist
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_3And_4parseImpl, "And.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_3And_5parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_3And_5parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_3And_4parseImpl};
static PyObject *__pyx_pw_10cPyparsing_3And_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4944, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4944, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4944, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4944, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4944, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4944, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4944, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4944, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And_4parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_3And_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_resultlist = NULL;
  int __pyx_v_errorStop;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_exprtokens = NULL;
  PyObject *__pyx_v_pe = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  Py_ssize_t __pyx_t_24;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  int __pyx_t_27;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":4947
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 *         loc, resultlist = self.exprs[0]._parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *         errorStop = False
 *         for e in self.exprs[1:]:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_parse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_v_instring);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_instring)) __PYX_ERR(0, 4947, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_loc)) __PYX_ERR(0, 4947, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_doActions);
  __Pyx_GIVEREF(__pyx_v_doActions);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_doActions)) __PYX_ERR(0, 4947, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 4947, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 4947, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(0, 4947, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 4947, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_resultlist = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4948
 *         # pre-parsed the string as part of our And pre-parsing
 *         loc, resultlist = self.exprs[0]._parse(instring, loc, doActions, callPreParse=False)
 *         errorStop = False             # <<<<<<<<<<<<<<
 *         for e in self.exprs[1:]:
 *             if isinstance(e, And._ErrorStop):
 */
  __pyx_v_errorStop = 0;

  /* "cPyparsing.pyx":4949
 *         loc, resultlist = self.exprs[0]._parse(instring, loc, doActions, callPreParse=False)
 *         errorStop = False
 *         for e in self.exprs[1:]:             # <<<<<<<<<<<<<<
 *             if isinstance(e, And._ErrorStop):
 *                 errorStop = True
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_4, 1, 0, NULL, NULL, &__pyx_slice_, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_4 = __pyx_t_2; __Pyx_INCREF(__pyx_t_4);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4949, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4949, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 4949, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4949, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4949, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 4949, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4949, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_7(__pyx_t_4);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4949, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4950
 *         errorStop = False
 *         for e in self.exprs[1:]:
 *             if isinstance(e, And._ErrorStop):             # <<<<<<<<<<<<<<
 *                 errorStop = True
 *                 continue
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_And); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ErrorStop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = PyObject_IsInstance(__pyx_v_e, __pyx_t_3); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 4950, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":4951
 *         for e in self.exprs[1:]:
 *             if isinstance(e, And._ErrorStop):
 *                 errorStop = True             # <<<<<<<<<<<<<<
 *                 continue
 *             if errorStop:
 */
      __pyx_v_errorStop = 1;

      /* "cPyparsing.pyx":4952
 *             if isinstance(e, And._ErrorStop):
 *                 errorStop = True
 *                 continue             # <<<<<<<<<<<<<<
 *             if errorStop:
 *                 try:
 */
      goto __pyx_L5_continue;

      /* "cPyparsing.pyx":4950
 *         errorStop = False
 *         for e in self.exprs[1:]:
 *             if isinstance(e, And._ErrorStop):             # <<<<<<<<<<<<<<
 *                 errorStop = True
 *                 continue
 */
    }

    /* "cPyparsing.pyx":4953
 *                 errorStop = True
 *                 continue
 *             if errorStop:             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 */
    if (__pyx_v_errorStop) {

      /* "cPyparsing.pyx":4954
 *                 continue
 *             if errorStop:
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        /*try:*/ {

          /* "cPyparsing.pyx":4955
 *             if errorStop:
 *                 try:
 *                     loc, exprtokens = e._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *                 except ParseSyntaxException:
 *                     raise
 */
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4955, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_1 = NULL;
          __pyx_t_12 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
              __pyx_t_12 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 3+__pyx_t_12);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4955, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
            PyObject* sequence = __pyx_t_3;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 4955, __pyx_L9_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_1);
            #else
            __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4955, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4955, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_13 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4955, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_13);
            index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_13); if (unlikely(!__pyx_t_2)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_2);
            index = 1; __pyx_t_1 = __pyx_t_5(__pyx_t_13); if (unlikely(!__pyx_t_1)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_1);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_13), 2) < 0) __PYX_ERR(0, 4955, __pyx_L9_error)
            __pyx_t_5 = NULL;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            goto __pyx_L18_unpacking_done;
            __pyx_L17_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_5 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 4955, __pyx_L9_error)
            __pyx_L18_unpacking_done:;
          }
          __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_2);
          __pyx_t_2 = 0;
          __Pyx_XDECREF_SET(__pyx_v_exprtokens, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":4954
 *                 continue
 *             if errorStop:
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:
 */
        }
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L16_try_end;
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "cPyparsing.pyx":4956
 *                 try:
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:             # <<<<<<<<<<<<<<
 *                     raise
 *                 except ParseBaseException as pe:
 */
        __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2);
        __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_ParseSyntaxException); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4956, __pyx_L11_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_12 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_3, __pyx_t_13);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_ErrRestore(__pyx_t_3, __pyx_t_1, __pyx_t_2);
        __pyx_t_3 = 0; __pyx_t_1 = 0; __pyx_t_2 = 0;
        if (__pyx_t_12) {
          __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_1, &__pyx_t_3) < 0) __PYX_ERR(0, 4956, __pyx_L11_except_error)
          __Pyx_XGOTREF(__pyx_t_2);
          __Pyx_XGOTREF(__pyx_t_1);
          __Pyx_XGOTREF(__pyx_t_3);

          /* "cPyparsing.pyx":4957
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:
 *                     raise             # <<<<<<<<<<<<<<
 *                 except ParseBaseException as pe:
 *                     pe.__traceback__ = None
 */
          __Pyx_GIVEREF(__pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_1);
          __Pyx_XGIVEREF(__pyx_t_3);
          __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_1, __pyx_t_3);
          __pyx_t_2 = 0; __pyx_t_1 = 0; __pyx_t_3 = 0; 
          __PYX_ERR(0, 4957, __pyx_L11_except_error)
        }

        /* "cPyparsing.pyx":4958
 *                 except ParseSyntaxException:
 *                     raise
 *                 except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                     pe.__traceback__ = None
 *                     raise ParseSyntaxException._from_exception(pe)
 */
        __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2);
        __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4958, __pyx_L11_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_12 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_3, __pyx_t_13);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_ErrRestore(__pyx_t_3, __pyx_t_1, __pyx_t_2);
        __pyx_t_3 = 0; __pyx_t_1 = 0; __pyx_t_2 = 0;
        if (__pyx_t_12) {
          __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_1, &__pyx_t_3) < 0) __PYX_ERR(0, 4958, __pyx_L11_except_error)
          __Pyx_XGOTREF(__pyx_t_2);
          __Pyx_XGOTREF(__pyx_t_1);
          __Pyx_XGOTREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_1);
          __pyx_v_pe = __pyx_t_1;
          /*try:*/ {

            /* "cPyparsing.pyx":4959
 *                     raise
 *                 except ParseBaseException as pe:
 *                     pe.__traceback__ = None             # <<<<<<<<<<<<<<
 *                     raise ParseSyntaxException._from_exception(pe)
 *                 except IndexError:
 */
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_pe, __pyx_n_s_traceback, Py_None) < 0) __PYX_ERR(0, 4959, __pyx_L26_error)

            /* "cPyparsing.pyx":4960
 *                 except ParseBaseException as pe:
 *                     pe.__traceback__ = None
 *                     raise ParseSyntaxException._from_exception(pe)             # <<<<<<<<<<<<<<
 *                 except IndexError:
 *                     raise ParseSyntaxException(instring, len(instring), self.errmsg, self)
 */
            __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_ParseSyntaxException); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4960, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_from_exception); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4960, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_15);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __pyx_t_14 = NULL;
            __pyx_t_12 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_15))) {
              __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
              if (likely(__pyx_t_14)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
                __Pyx_INCREF(__pyx_t_14);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_15, function);
                __pyx_t_12 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_14, __pyx_v_pe};
              __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_15, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4960, __pyx_L26_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            }
            __Pyx_Raise(__pyx_t_13, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __PYX_ERR(0, 4960, __pyx_L26_error)
          }

          /* "cPyparsing.pyx":4958
 *                 except ParseSyntaxException:
 *                     raise
 *                 except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                     pe.__traceback__ = None
 *                     raise ParseSyntaxException._from_exception(pe)
 */
          /*finally:*/ {
            __pyx_L26_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_23);
              __pyx_t_12 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_pe); __pyx_v_pe = 0;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_XGIVEREF(__pyx_t_22);
                __Pyx_XGIVEREF(__pyx_t_23);
                __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
              }
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
              __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
              __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
              goto __pyx_L11_except_error;
            }
          }
        }

        /* "cPyparsing.pyx":4961
 *                     pe.__traceback__ = None
 *                     raise ParseSyntaxException._from_exception(pe)
 *                 except IndexError:             # <<<<<<<<<<<<<<
 *                     raise ParseSyntaxException(instring, len(instring), self.errmsg, self)
 *             else:
 */
        __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
        if (__pyx_t_16) {
          __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 4961, __pyx_L11_except_error)
          __Pyx_XGOTREF(__pyx_t_3);
          __Pyx_XGOTREF(__pyx_t_1);
          __Pyx_XGOTREF(__pyx_t_2);

          /* "cPyparsing.pyx":4962
 *                     raise ParseSyntaxException._from_exception(pe)
 *                 except IndexError:
 *                     raise ParseSyntaxException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *             else:
 *                 loc, exprtokens = e._parse(instring, loc, doActions)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_ParseSyntaxException); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4962, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __pyx_t_24 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_24 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4962, __pyx_L11_except_error)
          __pyx_t_14 = PyInt_FromSsize_t(__pyx_t_24); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4962, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 4962, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_25);
          __pyx_t_26 = NULL;
          __pyx_t_16 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_15))) {
            __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_15);
            if (likely(__pyx_t_26)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
              __Pyx_INCREF(__pyx_t_26);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_15, function);
              __pyx_t_16 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_26, __pyx_v_instring, __pyx_t_14, __pyx_t_25, __pyx_v_self};
            __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_15, __pyx_callargs+1-__pyx_t_16, 4+__pyx_t_16);
            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4962, __pyx_L11_except_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          }
          __Pyx_Raise(__pyx_t_13, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __PYX_ERR(0, 4962, __pyx_L11_except_error)
        }
        goto __pyx_L11_except_error;

        /* "cPyparsing.pyx":4954
 *                 continue
 *             if errorStop:
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:
 */
        __pyx_L11_except_error:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        goto __pyx_L1_error;
        __pyx_L16_try_end:;
      }

      /* "cPyparsing.pyx":4953
 *                 errorStop = True
 *                 continue
 *             if errorStop:             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 */
      goto __pyx_L8;
    }

    /* "cPyparsing.pyx":4964
 *                     raise ParseSyntaxException(instring, len(instring), self.errmsg, self)
 *             else:
 *                 loc, exprtokens = e._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *             if exprtokens or exprtokens.haskeys():
 *                 resultlist += exprtokens
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4964, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = NULL;
      __pyx_t_16 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_16 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_16, 3+__pyx_t_16);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4964, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
        PyObject* sequence = __pyx_t_2;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 4964, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        #else
        __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4964, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4964, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_13 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4964, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_13);
        index = 0; __pyx_t_1 = __pyx_t_5(__pyx_t_13); if (unlikely(!__pyx_t_1)) goto __pyx_L34_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_13); if (unlikely(!__pyx_t_3)) goto __pyx_L34_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_13), 2) < 0) __PYX_ERR(0, 4964, __pyx_L1_error)
        __pyx_t_5 = NULL;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L35_unpacking_done;
        __pyx_L34_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_5 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 4964, __pyx_L1_error)
        __pyx_L35_unpacking_done:;
      }
      __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
      __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_exprtokens, __pyx_t_3);
      __pyx_t_3 = 0;
    }
    __pyx_L8:;

    /* "cPyparsing.pyx":4965
 *             else:
 *                 loc, exprtokens = e._parse(instring, loc, doActions)
 *             if exprtokens or exprtokens.haskeys():             # <<<<<<<<<<<<<<
 *                 resultlist += exprtokens
 *         return loc, resultlist
 */
    __pyx_t_27 = __Pyx_PyObject_IsTrue(__pyx_v_exprtokens); if (unlikely((__pyx_t_27 < 0))) __PYX_ERR(0, 4965, __pyx_L1_error)
    if (!__pyx_t_27) {
    } else {
      __pyx_t_8 = __pyx_t_27;
      goto __pyx_L37_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_exprtokens, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = NULL;
    __pyx_t_16 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_16 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_16, 0+__pyx_t_16);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4965, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_27 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_27 < 0))) __PYX_ERR(0, 4965, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = __pyx_t_27;
    __pyx_L37_bool_binop_done:;
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":4966
 *                 loc, exprtokens = e._parse(instring, loc, doActions)
 *             if exprtokens or exprtokens.haskeys():
 *                 resultlist += exprtokens             # <<<<<<<<<<<<<<
 *         return loc, resultlist
 * 
 */
      __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_resultlist, __pyx_v_exprtokens); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4966, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_resultlist, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":4965
 *             else:
 *                 loc, exprtokens = e._parse(instring, loc, doActions)
 *             if exprtokens or exprtokens.haskeys():             # <<<<<<<<<<<<<<
 *                 resultlist += exprtokens
 *         return loc, resultlist
 */
    }

    /* "cPyparsing.pyx":4949
 *         loc, resultlist = self.exprs[0]._parse(instring, loc, doActions, callPreParse=False)
 *         errorStop = False
 *         for e in self.exprs[1:]:             # <<<<<<<<<<<<<<
 *             if isinstance(e, And._ErrorStop):
 *                 errorStop = True
 */
    __pyx_L5_continue:;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4967
 *             if exprtokens or exprtokens.haskeys():
 *                 resultlist += exprtokens
 *         return loc, resultlist             # <<<<<<<<<<<<<<
 * 
 *     def __iadd__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_loc)) __PYX_ERR(0, 4967, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_resultlist);
  __Pyx_GIVEREF(__pyx_v_resultlist);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_resultlist)) __PYX_ERR(0, 4967, __pyx_L1_error);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4944
 *     #             resultlist += exprtokens
 *     #     return loc, resultlist
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_resultlist);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_exprtokens);
  __Pyx_XDECREF(__pyx_v_pe);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4969
 *         return loc, resultlist
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_7__iadd__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_3And_6__iadd__, "And.__iadd__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_3And_7__iadd__ = {"__iadd__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_3And_7__iadd__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_3And_6__iadd__};
static PyObject *__pyx_pw_10cPyparsing_3And_7__iadd__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iadd__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4969, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4969, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__iadd__", 1, 2, 2, 1); __PYX_ERR(0, 4969, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__iadd__") < 0)) __PYX_ERR(0, 4969, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__iadd__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4969, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.And.__iadd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And_6__iadd__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_3And_6__iadd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iadd__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":4970
 * 
 *     def __iadd__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         return self.append(other)  # And([self, other])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4970, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4971
 *     def __iadd__(self, other):
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         return self.append(other)  # And([self, other])
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4971, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4971, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4970
 * 
 *     def __iadd__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         return self.append(other)  # And([self, other])
 */
  }

  /* "cPyparsing.pyx":4972
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         return self.append(other)  # And([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_append); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4969
 *         return loc, resultlist
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.And.__iadd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4974
 *         return self.append(other)  # And([self, other])
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_9checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_3And_8checkRecursion, "And.checkRecursion(self, parseElementList)");
static PyMethodDef __pyx_mdef_10cPyparsing_3And_9checkRecursion = {"checkRecursion", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_3And_9checkRecursion, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_3And_8checkRecursion};
static PyObject *__pyx_pw_10cPyparsing_3And_9checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4974, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseElementList)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4974, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 4974, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 4974, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4974, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.And.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And_8checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_3And_8checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkRecursion", 1);

  /* "cPyparsing.pyx":4975
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self)) __PYX_ERR(0, 4975, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_subRecCheckList = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4976
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4976, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4976, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 4976, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4976, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4976, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 4976, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4976, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4976, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4977
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 *             if not e.mayReturnEmpty:
 *                 break
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4977, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4978
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4978, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = (!__pyx_t_8);
    if (__pyx_t_9) {

      /* "cPyparsing.pyx":4979
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
      goto __pyx_L4_break;

      /* "cPyparsing.pyx":4978
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    }

    /* "cPyparsing.pyx":4976
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L6_for_end;
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L6_for_end;
  __pyx_L6_for_end:;

  /* "cPyparsing.pyx":4974
 *         return self.append(other)  # And([self, other])
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.And.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4981
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_11__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_3And_10__str__, "And.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_3And_11__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_3And_11__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_3And_10__str__};
static PyObject *__pyx_pw_10cPyparsing_3And_11__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4981, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 4981, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4981, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.And.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And_10__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_3And_7__str___2generator25(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4986
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */

static PyObject *__pyx_pf_10cPyparsing_3And_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_38_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4986, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_3And_7__str___2generator25, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_And___str___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.And.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_3And_7__str___2generator25(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4986, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 4986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 4986, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4986, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4986, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4986, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4986, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4986, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 4986, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4986, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4986, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4986, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4981
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

static PyObject *__pyx_pf_10cPyparsing_3And_10__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_gb_10cPyparsing_3And_7__str___2generator25 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":4982
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_name_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 4982, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4983
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4983, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4982
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":4985
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4986
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_pf_10cPyparsing_3And_7__str___genexpr(NULL, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__16, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__107, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_2, __pyx_kp_u__108); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_3) < 0) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4985
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":4988
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4981
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.And.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_3And_7__str___2generator25);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5008
 *         [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_2Or___init__, "Or.__init__(self, exprs, savelist=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_2Or_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_2Or___init__};
static PyObject *__pyx_pw_10cPyparsing_2Or_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5008, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exprs)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5008, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 5008, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_savelist);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5008, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5008, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5008, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Or.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_2Or_8__init___2generator26(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5011
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_39_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5011, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_2Or_8__init___2generator26, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Or___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5011, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Or.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_2Or_8__init___2generator26(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5011, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5011, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5011, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5011, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5011, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5011, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5011, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5011, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5011, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5011, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5011, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5008
 *         [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

static PyObject *__pyx_pf_10cPyparsing_2Or___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  PyObject *__pyx_gb_10cPyparsing_2Or_8__init___2generator26 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":5009
 *     """
 *     def __init__(self, exprs, savelist=False):
 *         super(Or, self).__init__(exprs, savelist)             # <<<<<<<<<<<<<<
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Or); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5009, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5009, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5010
 *     def __init__(self, exprs, savelist=False):
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":5011
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __pyx_pf_10cPyparsing_2Or_8__init___genexpr(NULL, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 5011, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5010
 *     def __init__(self, exprs, savelist=False):
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5013
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 *             self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 5013, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":5008
 *         [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Or.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_2Or_8__init___2generator26);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5015
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_3streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_2Or_2streamline, "Or.streamline(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_3streamline = {"streamline", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_2Or_3streamline, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_2Or_2streamline};
static PyObject *__pyx_pw_10cPyparsing_2Or_3streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5015, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "streamline") < 0)) __PYX_ERR(0, 5015, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("streamline", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5015, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Or.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or_2streamline(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_2Or_10streamline_2generator27(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5018
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_10streamline_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_40_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5018, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_2Or_10streamline_2generator27, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Or_streamline_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5018, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Or.streamline.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_2Or_10streamline_2generator27(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5018, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5018, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5018, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5018, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5018, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5018, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5018, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5018, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5018, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5018, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5018, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5015
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_2streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_gb_10cPyparsing_2Or_10streamline_2generator27 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("streamline", 1);

  /* "cPyparsing.pyx":5016
 * 
 *     def streamline(self):
 *         super(Or, self).streamline()             # <<<<<<<<<<<<<<
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Or); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5016, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5016, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5017
 *     def streamline(self):
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:             # <<<<<<<<<<<<<<
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)
 *         return self
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_compat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_collect_all_And_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":5018
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_pf_10cPyparsing_2Or_10streamline_genexpr(NULL, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_3) < 0) __PYX_ERR(0, 5018, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5017
 *     def streamline(self):
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:             # <<<<<<<<<<<<<<
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)
 *         return self
 */
  }

  /* "cPyparsing.pyx":5019
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5015
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Or.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_2Or_10streamline_2generator27);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5021
 *         return self
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_2Or_4parseImpl, "Or.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_5parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_2Or_5parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_2Or_4parseImpl};
static PyObject *__pyx_pw_10cPyparsing_2Or_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5021, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5021, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 5021, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5021, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 5021, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5021, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5021, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 5021, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or_4parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_2Or_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_maxExcLoc = NULL;
  PyObject *__pyx_v_maxException = NULL;
  PyObject *__pyx_v_matches = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_loc2 = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_v_best_expr = NULL;
  PyObject *__pyx_v_longest = NULL;
  PyObject *__pyx_v_loc1 = NULL;
  PyObject *__pyx_v_expr1 = NULL;
  PyObject *__pyx_v_toks = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  Py_ssize_t __pyx_t_23;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  int __pyx_t_27;
  PyObject *(*__pyx_t_28)(PyObject *);
  char const *__pyx_t_29;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":5022
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         maxExcLoc = -1             # <<<<<<<<<<<<<<
 *         maxException = None
 *         matches = []
 */
  __Pyx_INCREF(__pyx_int_neg_1);
  __pyx_v_maxExcLoc = __pyx_int_neg_1;

  /* "cPyparsing.pyx":5023
 *     def parseImpl(self, instring, loc, doActions=True):
 *         maxExcLoc = -1
 *         maxException = None             # <<<<<<<<<<<<<<
 *         matches = []
 *         for e in self.exprs:
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_maxException = Py_None;

  /* "cPyparsing.pyx":5024
 *         maxExcLoc = -1
 *         maxException = None
 *         matches = []             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             try:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_matches = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5025
 *         maxException = None
 *         matches = []
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             try:
 *                 loc2 = e.tryParse(instring, loc)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5025, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5025, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5025, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 5025, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5025, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5025, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 5025, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5025, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5025, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5026
 *         matches = []
 *         for e in self.exprs:
 *             try:             # <<<<<<<<<<<<<<
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "cPyparsing.pyx":5027
 *         for e in self.exprs:
 *             try:
 *                 loc2 = e.tryParse(instring, loc)             # <<<<<<<<<<<<<<
 *             except ParseException as err:
 *                 err.__traceback__ = None
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5027, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_v_instring, __pyx_v_loc};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5027, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __Pyx_XDECREF_SET(__pyx_v_loc2, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":5026
 *         matches = []
 *         for e in self.exprs:
 *             try:             # <<<<<<<<<<<<<<
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:
 */
      }

      /* "cPyparsing.pyx":5039
 *             else:
 *                 # save match among all matches, to retry longest to shortest
 *                 matches.append((loc2, e))             # <<<<<<<<<<<<<<
 * 
 *         if matches:
 */
      /*else:*/ {
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5039, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_loc2);
        __Pyx_GIVEREF(__pyx_v_loc2);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_loc2)) __PYX_ERR(0, 5039, __pyx_L7_except_error);
        __Pyx_INCREF(__pyx_v_e);
        __Pyx_GIVEREF(__pyx_v_e);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_e)) __PYX_ERR(0, 5039, __pyx_L7_except_error);
        __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_matches, __pyx_t_1); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 5039, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "cPyparsing.pyx":5028
 *             try:
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:             # <<<<<<<<<<<<<<
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:
 */
      __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_8, &__pyx_t_9);
      __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5028, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_12);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_ErrRestore(__pyx_t_1, __pyx_t_8, __pyx_t_9);
      __pyx_t_1 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0;
      if (__pyx_t_10) {
        __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(0, 5028, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_v_err = __pyx_t_8;
        /*try:*/ {

          /* "cPyparsing.pyx":5029
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:
 *                 err.__traceback__ = None             # <<<<<<<<<<<<<<
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 */
          if (__Pyx_PyObject_SetAttrStr(__pyx_v_err, __pyx_n_s_traceback, Py_None) < 0) __PYX_ERR(0, 5029, __pyx_L18_error)

          /* "cPyparsing.pyx":5030
 *             except ParseException as err:
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = err
 *                     maxExcLoc = err.loc
 */
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5030, __pyx_L18_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = PyObject_RichCompare(__pyx_t_12, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5030, __pyx_L18_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 5030, __pyx_L18_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (__pyx_t_14) {

            /* "cPyparsing.pyx":5031
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:
 *                     maxException = err             # <<<<<<<<<<<<<<
 *                     maxExcLoc = err.loc
 *             except IndexError:
 */
            __Pyx_INCREF(__pyx_v_err);
            __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_v_err);

            /* "cPyparsing.pyx":5032
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 *                     maxExcLoc = err.loc             # <<<<<<<<<<<<<<
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:
 */
            __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5032, __pyx_L18_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_13);
            __pyx_t_13 = 0;

            /* "cPyparsing.pyx":5030
 *             except ParseException as err:
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = err
 *                     maxExcLoc = err.loc
 */
          }
        }

        /* "cPyparsing.pyx":5028
 *             try:
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:             # <<<<<<<<<<<<<<
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
            goto __pyx_L19;
          }
          __pyx_L18_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __pyx_t_10 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
            }
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
            goto __pyx_L7_except_error;
          }
          __pyx_L19:;
        }
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L6_exception_handled;
      }

      /* "cPyparsing.pyx":5033
 *                     maxException = err
 *                     maxExcLoc = err.loc
 *             except IndexError:             # <<<<<<<<<<<<<<
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 */
      __pyx_t_15 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
      if (__pyx_t_15) {
        __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 5033, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);

        /* "cPyparsing.pyx":5034
 *                     maxExcLoc = err.loc
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)
 */
        __pyx_t_23 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_23 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5034, __pyx_L7_except_error)
        __pyx_t_13 = PyInt_FromSsize_t(__pyx_t_23); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5034, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_12 = PyObject_RichCompare(__pyx_t_13, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5034, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 5034, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (__pyx_t_14) {

          /* "cPyparsing.pyx":5035
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)             # <<<<<<<<<<<<<<
 *                     maxExcLoc = len(instring)
 *             else:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5035, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_23 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_23 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5035, __pyx_L7_except_error)
          __pyx_t_24 = PyInt_FromSsize_t(__pyx_t_23); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 5035, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_24);
          __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 5035, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_25);
          __pyx_t_26 = NULL;
          __pyx_t_15 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_26)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_26);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
              __pyx_t_15 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_26, __pyx_v_instring, __pyx_t_24, __pyx_t_25, __pyx_v_self};
            __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_15, 4+__pyx_t_15);
            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5035, __pyx_L7_except_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "cPyparsing.pyx":5036
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)             # <<<<<<<<<<<<<<
 *             else:
 *                 # save match among all matches, to retry longest to shortest
 */
          __pyx_t_23 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_23 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5036, __pyx_L7_except_error)
          __pyx_t_12 = PyInt_FromSsize_t(__pyx_t_23); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5036, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "cPyparsing.pyx":5034
 *                     maxExcLoc = err.loc
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)
 */
        }
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;

      /* "cPyparsing.pyx":5026
 *         matches = []
 *         for e in self.exprs:
 *             try:             # <<<<<<<<<<<<<<
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:
 */
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __pyx_L12_try_end:;
    }

    /* "cPyparsing.pyx":5025
 *         maxException = None
 *         matches = []
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             try:
 *                 loc2 = e.tryParse(instring, loc)
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5041
 *                 matches.append((loc2, e))
 * 
 *         if matches:             # <<<<<<<<<<<<<<
 *             # re-evaluate all matches in descending order of length of match, in case attached actions
 *             # might change whether or how much they match of the input.
 */
  __pyx_t_14 = (PyList_GET_SIZE(__pyx_v_matches) != 0);
  if (__pyx_t_14) {

    /* "cPyparsing.pyx":5044
 *             # re-evaluate all matches in descending order of length of match, in case attached actions
 *             # might change whether or how much they match of the input.
 *             matches.sort(key=itemgetter(0), reverse=True)             # <<<<<<<<<<<<<<
 * 
 *             if not doActions:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_matches, __pyx_n_s_sort); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_itemgetter); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = NULL;
    __pyx_t_15 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_15 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_int_0};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5044, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_key, __pyx_t_8) < 0) __PYX_ERR(0, 5044, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_reverse, Py_True) < 0) __PYX_ERR(0, 5044, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":5046
 *             matches.sort(key=itemgetter(0), reverse=True)
 * 
 *             if not doActions:             # <<<<<<<<<<<<<<
 *                 # no further conditions or parse actions to change the selection of
 *                 # alternative, so the first match will be the best match
 */
    __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_doActions); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 5046, __pyx_L1_error)
    __pyx_t_27 = (!__pyx_t_14);
    if (__pyx_t_27) {

      /* "cPyparsing.pyx":5049
 *                 # no further conditions or parse actions to change the selection of
 *                 # alternative, so the first match will be the best match
 *                 best_expr = matches[0][1]             # <<<<<<<<<<<<<<
 *                 return best_expr._parse(instring, loc, doActions)
 * 
 */
      __pyx_t_8 = __Pyx_GetItemInt_List(__pyx_v_matches, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_GetItemInt(__pyx_t_8, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_best_expr = __pyx_t_9;
      __pyx_t_9 = 0;

      /* "cPyparsing.pyx":5050
 *                 # alternative, so the first match will be the best match
 *                 best_expr = matches[0][1]
 *                 return best_expr._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 * 
 *             longest = -1, None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_best_expr, __pyx_n_s_parse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5050, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_2 = NULL;
      __pyx_t_15 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_15 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_15, 3+__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5050, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_r = __pyx_t_9;
      __pyx_t_9 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":5046
 *             matches.sort(key=itemgetter(0), reverse=True)
 * 
 *             if not doActions:             # <<<<<<<<<<<<<<
 *                 # no further conditions or parse actions to change the selection of
 *                 # alternative, so the first match will be the best match
 */
    }

    /* "cPyparsing.pyx":5052
 *                 return best_expr._parse(instring, loc, doActions)
 * 
 *             longest = -1, None             # <<<<<<<<<<<<<<
 *             for loc1, expr1 in matches:
 *                 if loc1 <= longest[0]:
 */
    __Pyx_INCREF(__pyx_tuple__109);
    __pyx_v_longest = __pyx_tuple__109;

    /* "cPyparsing.pyx":5053
 * 
 *             longest = -1, None
 *             for loc1, expr1 in matches:             # <<<<<<<<<<<<<<
 *                 if loc1 <= longest[0]:
 *                     # already have a longer match than this one will deliver, we are done
 */
    __pyx_t_9 = __pyx_v_matches; __Pyx_INCREF(__pyx_t_9);
    __pyx_t_3 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_9);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5053, __pyx_L1_error)
        #endif
        if (__pyx_t_3 >= __pyx_temp) break;
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_8 = PyList_GET_ITEM(__pyx_t_9, __pyx_t_3); __Pyx_INCREF(__pyx_t_8); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 5053, __pyx_L1_error)
      #else
      __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_9, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      #endif
      if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
        PyObject* sequence = __pyx_t_8;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 5053, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        #else
        __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5053, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5053, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_12 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5053, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_28 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_12);
        index = 0; __pyx_t_2 = __pyx_t_28(__pyx_t_12); if (unlikely(!__pyx_t_2)) goto __pyx_L33_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_1 = __pyx_t_28(__pyx_t_12); if (unlikely(!__pyx_t_1)) goto __pyx_L33_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_28(__pyx_t_12), 2) < 0) __PYX_ERR(0, 5053, __pyx_L1_error)
        __pyx_t_28 = NULL;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L34_unpacking_done;
        __pyx_L33_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_28 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 5053, __pyx_L1_error)
        __pyx_L34_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_loc1, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_expr1, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":5054
 *             longest = -1, None
 *             for loc1, expr1 in matches:
 *                 if loc1 <= longest[0]:             # <<<<<<<<<<<<<<
 *                     # already have a longer match than this one will deliver, we are done
 *                     return longest
 */
      __pyx_t_8 = __Pyx_GetItemInt_Tuple(__pyx_v_longest, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5054, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyObject_RichCompare(__pyx_v_loc1, __pyx_t_8, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5054, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_27 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_27 < 0))) __PYX_ERR(0, 5054, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_27) {

        /* "cPyparsing.pyx":5056
 *                 if loc1 <= longest[0]:
 *                     # already have a longer match than this one will deliver, we are done
 *                     return longest             # <<<<<<<<<<<<<<
 * 
 *                 try:
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_longest);
        __pyx_r = __pyx_v_longest;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L0;

        /* "cPyparsing.pyx":5054
 *             longest = -1, None
 *             for loc1, expr1 in matches:
 *                 if loc1 <= longest[0]:             # <<<<<<<<<<<<<<
 *                     # already have a longer match than this one will deliver, we are done
 *                     return longest
 */
      }

      /* "cPyparsing.pyx":5058
 *                     return longest
 * 
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc2, toks = expr1._parse(instring, loc, doActions)
 *                 except ParseException as err:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        /*try:*/ {

          /* "cPyparsing.pyx":5059
 * 
 *                 try:
 *                     loc2, toks = expr1._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *                 except ParseException as err:
 *                     err.__traceback__ = None
 */
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr1, __pyx_n_s_parse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5059, __pyx_L36_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_2 = NULL;
          __pyx_t_15 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_15 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_15, 3+__pyx_t_15);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5059, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
            PyObject* sequence = __pyx_t_1;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 5059, __pyx_L36_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_2);
            #else
            __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5059, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5059, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_2);
            #endif
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_12 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5059, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_28 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_12);
            index = 0; __pyx_t_8 = __pyx_t_28(__pyx_t_12); if (unlikely(!__pyx_t_8)) goto __pyx_L44_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_8);
            index = 1; __pyx_t_2 = __pyx_t_28(__pyx_t_12); if (unlikely(!__pyx_t_2)) goto __pyx_L44_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_2);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_28(__pyx_t_12), 2) < 0) __PYX_ERR(0, 5059, __pyx_L36_error)
            __pyx_t_28 = NULL;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            goto __pyx_L45_unpacking_done;
            __pyx_L44_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_28 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 5059, __pyx_L36_error)
            __pyx_L45_unpacking_done:;
          }
          __Pyx_XDECREF_SET(__pyx_v_loc2, __pyx_t_8);
          __pyx_t_8 = 0;
          __Pyx_XDECREF_SET(__pyx_v_toks, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "cPyparsing.pyx":5058
 *                     return longest
 * 
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc2, toks = expr1._parse(instring, loc, doActions)
 *                 except ParseException as err:
 */
        }

        /* "cPyparsing.pyx":5066
 *                         maxExcLoc = err.loc
 *                 else:
 *                     if loc2 >= loc1:             # <<<<<<<<<<<<<<
 *                         return loc2, toks
 *                     # didn't match as much as before
 */
        /*else:*/ {
          __pyx_t_1 = PyObject_RichCompare(__pyx_v_loc2, __pyx_v_loc1, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5066, __pyx_L38_except_error)
          __pyx_t_27 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_27 < 0))) __PYX_ERR(0, 5066, __pyx_L38_except_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_27) {

            /* "cPyparsing.pyx":5067
 *                 else:
 *                     if loc2 >= loc1:
 *                         return loc2, toks             # <<<<<<<<<<<<<<
 *                     # didn't match as much as before
 *                     elif loc2 > longest[0]:
 */
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5067, __pyx_L38_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_INCREF(__pyx_v_loc2);
            __Pyx_GIVEREF(__pyx_v_loc2);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_loc2)) __PYX_ERR(0, 5067, __pyx_L38_except_error);
            __Pyx_INCREF(__pyx_v_toks);
            __Pyx_GIVEREF(__pyx_v_toks);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_toks)) __PYX_ERR(0, 5067, __pyx_L38_except_error);
            __pyx_r = __pyx_t_1;
            __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            goto __pyx_L39_except_return;

            /* "cPyparsing.pyx":5066
 *                         maxExcLoc = err.loc
 *                 else:
 *                     if loc2 >= loc1:             # <<<<<<<<<<<<<<
 *                         return loc2, toks
 *                     # didn't match as much as before
 */
          }

          /* "cPyparsing.pyx":5069
 *                         return loc2, toks
 *                     # didn't match as much as before
 *                     elif loc2 > longest[0]:             # <<<<<<<<<<<<<<
 *                         longest = loc2, toks
 * 
 */
          __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_longest, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5069, __pyx_L38_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_2 = PyObject_RichCompare(__pyx_v_loc2, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5069, __pyx_L38_except_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_27 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_27 < 0))) __PYX_ERR(0, 5069, __pyx_L38_except_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (__pyx_t_27) {

            /* "cPyparsing.pyx":5070
 *                     # didn't match as much as before
 *                     elif loc2 > longest[0]:
 *                         longest = loc2, toks             # <<<<<<<<<<<<<<
 * 
 *             if longest != (-1, None):
 */
            __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5070, __pyx_L38_except_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_INCREF(__pyx_v_loc2);
            __Pyx_GIVEREF(__pyx_v_loc2);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_loc2)) __PYX_ERR(0, 5070, __pyx_L38_except_error);
            __Pyx_INCREF(__pyx_v_toks);
            __Pyx_GIVEREF(__pyx_v_toks);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_toks)) __PYX_ERR(0, 5070, __pyx_L38_except_error);
            __Pyx_DECREF_SET(__pyx_v_longest, ((PyObject*)__pyx_t_2));
            __pyx_t_2 = 0;

            /* "cPyparsing.pyx":5069
 *                         return loc2, toks
 *                     # didn't match as much as before
 *                     elif loc2 > longest[0]:             # <<<<<<<<<<<<<<
 *                         longest = loc2, toks
 * 
 */
          }
        }
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L43_try_end;
        __pyx_L36_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
        __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
        __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "cPyparsing.pyx":5060
 *                 try:
 *                     loc2, toks = expr1._parse(instring, loc, doActions)
 *                 except ParseException as err:             # <<<<<<<<<<<<<<
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:
 */
        __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_1, &__pyx_t_8);
        __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5060, __pyx_L38_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_15 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_12);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_ErrRestore(__pyx_t_2, __pyx_t_1, __pyx_t_8);
        __pyx_t_2 = 0; __pyx_t_1 = 0; __pyx_t_8 = 0;
        if (__pyx_t_15) {
          __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 5060, __pyx_L38_except_error)
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_1);
          __Pyx_XGOTREF(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __pyx_v_err = __pyx_t_1;
          /*try:*/ {

            /* "cPyparsing.pyx":5061
 *                     loc2, toks = expr1._parse(instring, loc, doActions)
 *                 except ParseException as err:
 *                     err.__traceback__ = None             # <<<<<<<<<<<<<<
 *                     if err.loc > maxExcLoc:
 *                         maxException = err
 */
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_err, __pyx_n_s_traceback, Py_None) < 0) __PYX_ERR(0, 5061, __pyx_L52_error)

            /* "cPyparsing.pyx":5062
 *                 except ParseException as err:
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                         maxException = err
 *                         maxExcLoc = err.loc
 */
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5062, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_13 = PyObject_RichCompare(__pyx_t_12, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5062, __pyx_L52_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_27 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_27 < 0))) __PYX_ERR(0, 5062, __pyx_L52_error)
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (__pyx_t_27) {

              /* "cPyparsing.pyx":5063
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:
 *                         maxException = err             # <<<<<<<<<<<<<<
 *                         maxExcLoc = err.loc
 *                 else:
 */
              __Pyx_INCREF(__pyx_v_err);
              __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_v_err);

              /* "cPyparsing.pyx":5064
 *                     if err.loc > maxExcLoc:
 *                         maxException = err
 *                         maxExcLoc = err.loc             # <<<<<<<<<<<<<<
 *                 else:
 *                     if loc2 >= loc1:
 */
              __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5064, __pyx_L52_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_13);
              __pyx_t_13 = 0;

              /* "cPyparsing.pyx":5062
 *                 except ParseException as err:
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                         maxException = err
 *                         maxExcLoc = err.loc
 */
            }
          }

          /* "cPyparsing.pyx":5060
 *                 try:
 *                     loc2, toks = expr1._parse(instring, loc, doActions)
 *                 except ParseException as err:             # <<<<<<<<<<<<<<
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
              goto __pyx_L53;
            }
            __pyx_L52_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
              __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_17);
              __pyx_t_15 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_29 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_17);
                __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_18, __pyx_t_17);
              }
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_ErrRestore(__pyx_t_22, __pyx_t_21, __pyx_t_20);
              __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
              __pyx_lineno = __pyx_t_15; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_29;
              goto __pyx_L38_except_error;
            }
            __pyx_L53:;
          }
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L37_exception_handled;
        }
        goto __pyx_L38_except_error;

        /* "cPyparsing.pyx":5058
 *                     return longest
 * 
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc2, toks = expr1._parse(instring, loc, doActions)
 *                 except ParseException as err:
 */
        __pyx_L38_except_error:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
        goto __pyx_L1_error;
        __pyx_L39_except_return:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
        goto __pyx_L0;
        __pyx_L37_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
        __pyx_L43_try_end:;
      }

      /* "cPyparsing.pyx":5053
 * 
 *             longest = -1, None
 *             for loc1, expr1 in matches:             # <<<<<<<<<<<<<<
 *                 if loc1 <= longest[0]:
 *                     # already have a longer match than this one will deliver, we are done
 */
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":5072
 *                         longest = loc2, toks
 * 
 *             if longest != (-1, None):             # <<<<<<<<<<<<<<
 *                 return longest
 * 
 */
    __pyx_t_9 = PyObject_RichCompare(__pyx_v_longest, __pyx_tuple__109, Py_NE); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5072, __pyx_L1_error)
    __pyx_t_27 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_27 < 0))) __PYX_ERR(0, 5072, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_27) {

      /* "cPyparsing.pyx":5073
 * 
 *             if longest != (-1, None):
 *                 return longest             # <<<<<<<<<<<<<<
 * 
 *         if maxException is not None:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_longest);
      __pyx_r = __pyx_v_longest;
      goto __pyx_L0;

      /* "cPyparsing.pyx":5072
 *                         longest = loc2, toks
 * 
 *             if longest != (-1, None):             # <<<<<<<<<<<<<<
 *                 return longest
 * 
 */
    }

    /* "cPyparsing.pyx":5041
 *                 matches.append((loc2, e))
 * 
 *         if matches:             # <<<<<<<<<<<<<<
 *             # re-evaluate all matches in descending order of length of match, in case attached actions
 *             # might change whether or how much they match of the input.
 */
  }

  /* "cPyparsing.pyx":5075
 *                 return longest
 * 
 *         if maxException is not None:             # <<<<<<<<<<<<<<
 *             maxException.msg = self.errmsg
 *             raise maxException
 */
  __pyx_t_27 = (__pyx_v_maxException != Py_None);
  if (unlikely(__pyx_t_27)) {

    /* "cPyparsing.pyx":5076
 * 
 *         if maxException is not None:
 *             maxException.msg = self.errmsg             # <<<<<<<<<<<<<<
 *             raise maxException
 *         else:
 */
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5076, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_maxException, __pyx_n_s_msg, __pyx_t_9) < 0) __PYX_ERR(0, 5076, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":5077
 *         if maxException is not None:
 *             maxException.msg = self.errmsg
 *             raise maxException             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException(instring, loc, "no defined alternatives to match", self)
 */
    __Pyx_Raise(__pyx_v_maxException, 0, 0, 0);
    __PYX_ERR(0, 5077, __pyx_L1_error)

    /* "cPyparsing.pyx":5075
 *                 return longest
 * 
 *         if maxException is not None:             # <<<<<<<<<<<<<<
 *             maxException.msg = self.errmsg
 *             raise maxException
 */
  }

  /* "cPyparsing.pyx":5079
 *             raise maxException
 *         else:
 *             raise ParseException(instring, loc, "no defined alternatives to match", self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5079, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc, __pyx_kp_u_no_defined_alternatives_to_match, __pyx_v_self};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5079, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_9, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __PYX_ERR(0, 5079, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":5021
 *         return self
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_maxExcLoc);
  __Pyx_XDECREF(__pyx_v_maxException);
  __Pyx_XDECREF(__pyx_v_matches);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_loc2);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_best_expr);
  __Pyx_XDECREF(__pyx_v_longest);
  __Pyx_XDECREF(__pyx_v_loc1);
  __Pyx_XDECREF(__pyx_v_expr1);
  __Pyx_XDECREF(__pyx_v_toks);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5082
 * 
 * 
 *     def __ixor__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_7__ixor__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_2Or_6__ixor__, "Or.__ixor__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_7__ixor__ = {"__ixor__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_2Or_7__ixor__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_2Or_6__ixor__};
static PyObject *__pyx_pw_10cPyparsing_2Or_7__ixor__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ixor__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5082, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5082, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__ixor__", 1, 2, 2, 1); __PYX_ERR(0, 5082, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__ixor__") < 0)) __PYX_ERR(0, 5082, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ixor__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5082, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Or.__ixor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or_6__ixor__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_2Or_6__ixor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ixor__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":5083
 * 
 *     def __ixor__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         return self.append(other)  # Or([self, other])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 5083, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5084
 *     def __ixor__(self, other):
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         return self.append(other)  # Or([self, other])
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5084, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5083
 * 
 *     def __ixor__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         return self.append(other)  # Or([self, other])
 */
  }

  /* "cPyparsing.pyx":5085
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         return self.append(other)  # Or([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_append); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5085, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5082
 * 
 * 
 *     def __ixor__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Or.__ixor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5087
 *         return self.append(other)  # Or([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_9__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_2Or_8__str__, "Or.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_9__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_2Or_9__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_2Or_8__str__};
static PyObject *__pyx_pw_10cPyparsing_2Or_9__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5087, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 5087, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5087, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Or.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or_8__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_2Or_7__str___2generator28(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5092
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_41_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5092, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_2Or_7__str___2generator28, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Or___str___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Or.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_2Or_7__str___2generator28(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5092, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 5092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5092, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5092, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5092, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5092, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5092, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5092, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5092, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5092, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5092, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5092, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5087
 *         return self.append(other)  # Or([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_8__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_gb_10cPyparsing_2Or_7__str___2generator28 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":5088
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_name_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 5088, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5089
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":5088
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":5091
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5092
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_pf_10cPyparsing_2Or_7__str___genexpr(NULL, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__110, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__107, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_2, __pyx_kp_u__108); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_3) < 0) __PYX_ERR(0, 5092, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5091
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":5094
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5087
 *         return self.append(other)  # Or([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Or.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_2Or_7__str___2generator28);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5096
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_11checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_2Or_10checkRecursion, "Or.checkRecursion(self, parseElementList)");
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_11checkRecursion = {"checkRecursion", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_2Or_11checkRecursion, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_2Or_10checkRecursion};
static PyObject *__pyx_pw_10cPyparsing_2Or_11checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5096, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseElementList)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5096, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 5096, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 5096, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5096, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Or.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or_10checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_2Or_10checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkRecursion", 1);

  /* "cPyparsing.pyx":5097
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self)) __PYX_ERR(0, 5097, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_subRecCheckList = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5098
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5098, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5098, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 5098, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5098, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5098, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 5098, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5098, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5098, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5099
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5099, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5098
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5096
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Or.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5101
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_13_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_2Or_12_setResultsName, "Or._setResultsName(self, name, listAllMatches=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_13_setResultsName = {"_setResultsName", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_2Or_13_setResultsName, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_2Or_12_setResultsName};
static PyObject *__pyx_pw_10cPyparsing_2Or_13_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_listAllMatches = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_setResultsName (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,&__pyx_n_s_listAllMatches,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5101, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5101, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, 1); __PYX_ERR(0, 5101, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listAllMatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5101, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_setResultsName") < 0)) __PYX_ERR(0, 5101, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_listAllMatches = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5101, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Or._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or_12_setResultsName(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_listAllMatches);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_2Or_15_setResultsName_2generator29(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5104
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_15_setResultsName_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_42_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5104, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_2Or_15_setResultsName_2generator29, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Or__setResultsName_locals_genexp, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5104, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Or._setResultsName.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_2Or_15_setResultsName_2generator29(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5104, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5104, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5104, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5104, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5104, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5104, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5104, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5104, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5104, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5104, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_And); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5104, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5101
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_12_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches) {
  PyObject *__pyx_gb_10cPyparsing_2Or_15_setResultsName_2generator29 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_setResultsName", 1);

  /* "cPyparsing.pyx":5102
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if (not __compat__.collect_all_And_tokens             # <<<<<<<<<<<<<<
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_compat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_collect_all_And_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 5102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = (!__pyx_t_4);
  if (__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }

  /* "cPyparsing.pyx":5103
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):             # <<<<<<<<<<<<<<
 *             if any(isinstance(e, And) for e in self.exprs):
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_diag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_warn_multiple_tokens_in_named_al); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;

  /* "cPyparsing.pyx":5102
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if (not __compat__.collect_all_And_tokens             # <<<<<<<<<<<<<<
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 */
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5104
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_pf_10cPyparsing_2Or_15_setResultsName_genexpr(NULL, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 5104, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":5105
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5105, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5105, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":5107
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(             # <<<<<<<<<<<<<<
 *                     "warn_multiple_tokens_in_named_alternation", name, type(self).__name__),
 *                     stacklevel=3)
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_setting_results_name_1_r_on_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);

      /* "cPyparsing.pyx":5108
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(
 *                     "warn_multiple_tokens_in_named_alternation", name, type(self).__name__),             # <<<<<<<<<<<<<<
 *                     stacklevel=3)
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_self)), __pyx_n_s_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_n_u_warn_multiple_tokens_in_named_al, __pyx_v_name, __pyx_t_7};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 3+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5107, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }

      /* "cPyparsing.pyx":5105
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(
 */
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5105, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(0, 5105, __pyx_L1_error);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":5109
 *                               "in future will return the full list of tokens".format(
 *                     "warn_multiple_tokens_in_named_alternation", name, type(self).__name__),
 *                     stacklevel=3)             # <<<<<<<<<<<<<<
 * 
 *         return super(Or, self)._setResultsName(name, listAllMatches)
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5109, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stacklevel, __pyx_int_3) < 0) __PYX_ERR(0, 5109, __pyx_L1_error)

      /* "cPyparsing.pyx":5105
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(
 */
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5105, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "cPyparsing.pyx":5104
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 */
    }

    /* "cPyparsing.pyx":5102
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if (not __compat__.collect_all_And_tokens             # <<<<<<<<<<<<<<
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 */
  }

  /* "cPyparsing.pyx":5111
 *                     stacklevel=3)
 * 
 *         return super(Or, self)._setResultsName(name, listAllMatches)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Or); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(0, 5111, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 5111, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_name, __pyx_v_listAllMatches};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 2+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5101
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.Or._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_2Or_15_setResultsName_2generator29);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5131
 *         print(number.searchString("123 3.1416 789")) #  Better -> [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10MatchFirst___init__, "MatchFirst.__init__(self, exprs, savelist=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10MatchFirst_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10MatchFirst___init__};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5131, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exprs)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5131, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 5131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_savelist);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5131, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5131, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5131, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_8__init___2generator30(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5134
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_43_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5134, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_10MatchFirst_8__init___2generator30, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_MatchFirst___init___locals_genex, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5134, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_8__init___2generator30(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5134, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5134, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5134, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5134, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5134, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5134, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5134, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5134, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5134, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5134, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5134, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5131
 *         print(number.searchString("123 3.1416 789")) #  Better -> [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  PyObject *__pyx_gb_10cPyparsing_10MatchFirst_8__init___2generator30 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":5132
 *     """
 *     def __init__(self, exprs, savelist=False):
 *         super(MatchFirst, self).__init__(exprs, savelist)             # <<<<<<<<<<<<<<
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MatchFirst); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5132, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5132, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5133
 *     def __init__(self, exprs, savelist=False):
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":5134
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __pyx_pf_10cPyparsing_10MatchFirst_8__init___genexpr(NULL, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 5134, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5133
 *     def __init__(self, exprs, savelist=False):
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5136
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 *             self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 5136, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":5131
 *         print(number.searchString("123 3.1416 789")) #  Better -> [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_10MatchFirst_8__init___2generator30);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5138
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_3streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10MatchFirst_2streamline, "MatchFirst.streamline(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_3streamline = {"streamline", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10MatchFirst_3streamline, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10MatchFirst_2streamline};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_3streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5138, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "streamline") < 0)) __PYX_ERR(0, 5138, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("streamline", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5138, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.MatchFirst.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_2streamline(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_10streamline_2generator31(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5141
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_10streamline_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_44_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5141, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_10MatchFirst_10streamline_2generator31, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_MatchFirst_streamline_locals_gen, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.streamline.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_10streamline_2generator31(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5141, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5141, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5141, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5141, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5141, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5141, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5141, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5141, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5141, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5141, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5138
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_2streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_gb_10cPyparsing_10MatchFirst_10streamline_2generator31 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("streamline", 1);

  /* "cPyparsing.pyx":5139
 * 
 *     def streamline(self):
 *         super(MatchFirst, self).streamline()             # <<<<<<<<<<<<<<
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MatchFirst); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5139, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5139, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5140
 *     def streamline(self):
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:             # <<<<<<<<<<<<<<
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)
 *         return self
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_compat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_collect_all_And_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5140, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":5141
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_pf_10cPyparsing_10MatchFirst_10streamline_genexpr(NULL, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_3) < 0) __PYX_ERR(0, 5141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5140
 *     def streamline(self):
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:             # <<<<<<<<<<<<<<
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)
 *         return self
 */
  }

  /* "cPyparsing.pyx":5142
 *         if __compat__.collect_all_And_tokens:
 *             self.saveAsList = any(e.saveAsList for e in self.exprs)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] add adaptive mode constants
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5138
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_10MatchFirst_10streamline_2generator31);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5149
 * 
 *     # [CPYPARSING] add setAdaptiveMode
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def setAdaptiveMode(
 *         cls,
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_5setAdaptiveMode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10MatchFirst_4setAdaptiveMode, "MatchFirst.setAdaptiveMode(cls, on, usage_weight=1, allow_unused_expr_order=False, adaptive_usage_check_rate=None)\nDO NOT USE UNLESS YOU KNOW WHAT YOU ARE DOING.");
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_5setAdaptiveMode = {"setAdaptiveMode", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10MatchFirst_5setAdaptiveMode, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10MatchFirst_4setAdaptiveMode};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_5setAdaptiveMode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_on = 0;
  PyObject *__pyx_v_usage_weight = 0;
  PyObject *__pyx_v_allow_unused_expr_order = 0;
  PyObject *__pyx_v_adaptive_usage_check_rate = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setAdaptiveMode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_on,&__pyx_n_s_usage_weight,&__pyx_n_s_allow_unused_expr_order,&__pyx_n_s_adaptive_usage_check_rate,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_1)));

    /* "cPyparsing.pyx":5154
 *         on,
 *         usage_weight=1,
 *         allow_unused_expr_order=False,             # <<<<<<<<<<<<<<
 *         # performance-tuned (note: adaptive_usage_check_rate should be prime or None)
 *         adaptive_usage_check_rate=None,
 */
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));

    /* "cPyparsing.pyx":5156
 *         allow_unused_expr_order=False,
 *         # performance-tuned (note: adaptive_usage_check_rate should be prime or None)
 *         adaptive_usage_check_rate=None,             # <<<<<<<<<<<<<<
 *     ):
 *         """DO NOT USE UNLESS YOU KNOW WHAT YOU ARE DOING."""
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5149, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_on)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5149, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("setAdaptiveMode", 0, 2, 5, 1); __PYX_ERR(0, 5149, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_usage_weight);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5149, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_allow_unused_expr_order);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5149, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_adaptive_usage_check_rate);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5149, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "setAdaptiveMode") < 0)) __PYX_ERR(0, 5149, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cls = values[0];
    __pyx_v_on = values[1];
    __pyx_v_usage_weight = values[2];
    __pyx_v_allow_unused_expr_order = values[3];
    __pyx_v_adaptive_usage_check_rate = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setAdaptiveMode", 0, 2, 5, __pyx_nargs); __PYX_ERR(0, 5149, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.MatchFirst.setAdaptiveMode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_4setAdaptiveMode(__pyx_self, __pyx_v_cls, __pyx_v_on, __pyx_v_usage_weight, __pyx_v_allow_unused_expr_order, __pyx_v_adaptive_usage_check_rate);

  /* "cPyparsing.pyx":5149
 * 
 *     # [CPYPARSING] add setAdaptiveMode
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def setAdaptiveMode(
 *         cls,
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_4setAdaptiveMode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_on, PyObject *__pyx_v_usage_weight, PyObject *__pyx_v_allow_unused_expr_order, PyObject *__pyx_v_adaptive_usage_check_rate) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setAdaptiveMode", 1);

  /* "cPyparsing.pyx":5159
 *     ):
 *         """DO NOT USE UNLESS YOU KNOW WHAT YOU ARE DOING."""
 *         cls.adaptive_mode = on             # <<<<<<<<<<<<<<
 *         cls.usage_weight = usage_weight
 *         cls.allow_unused_expr_order = allow_unused_expr_order
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cls, __pyx_n_s_adaptive_mode, __pyx_v_on) < 0) __PYX_ERR(0, 5159, __pyx_L1_error)

  /* "cPyparsing.pyx":5160
 *         """DO NOT USE UNLESS YOU KNOW WHAT YOU ARE DOING."""
 *         cls.adaptive_mode = on
 *         cls.usage_weight = usage_weight             # <<<<<<<<<<<<<<
 *         cls.allow_unused_expr_order = allow_unused_expr_order
 *         cls.adaptive_usage_check_rate = adaptive_usage_check_rate
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cls, __pyx_n_s_usage_weight, __pyx_v_usage_weight) < 0) __PYX_ERR(0, 5160, __pyx_L1_error)

  /* "cPyparsing.pyx":5161
 *         cls.adaptive_mode = on
 *         cls.usage_weight = usage_weight
 *         cls.allow_unused_expr_order = allow_unused_expr_order             # <<<<<<<<<<<<<<
 *         cls.adaptive_usage_check_rate = adaptive_usage_check_rate
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cls, __pyx_n_s_allow_unused_expr_order, __pyx_v_allow_unused_expr_order) < 0) __PYX_ERR(0, 5161, __pyx_L1_error)

  /* "cPyparsing.pyx":5162
 *         cls.usage_weight = usage_weight
 *         cls.allow_unused_expr_order = allow_unused_expr_order
 *         cls.adaptive_usage_check_rate = adaptive_usage_check_rate             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] implement adaptive mode
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cls, __pyx_n_s_adaptive_usage_check_rate, __pyx_v_adaptive_usage_check_rate) < 0) __PYX_ERR(0, 5162, __pyx_L1_error)

  /* "cPyparsing.pyx":5149
 * 
 *     # [CPYPARSING] add setAdaptiveMode
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def setAdaptiveMode(
 *         cls,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.setAdaptiveMode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5165
 * 
 *     # [CPYPARSING] implement adaptive mode
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.adaptive_mode:
 *             if self.expr_order is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_7parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10MatchFirst_6parseImpl, "MatchFirst.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_7parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10MatchFirst_7parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10MatchFirst_6parseImpl};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_7parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5165, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5165, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 5165, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5165, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 5165, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5165, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5165, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 5165, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.MatchFirst.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_6parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_6parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_maxExcLoc = NULL;
  PyObject *__pyx_v_maxException = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_ind_or_e = NULL;
  PyObject *__pyx_v_ind = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_v_usage = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  int __pyx_t_19;
  char const *__pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":5166
 *     # [CPYPARSING] implement adaptive mode
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.adaptive_mode:             # <<<<<<<<<<<<<<
 *             if self.expr_order is None:
 *                 self.expr_order = list(range(len(self.exprs)))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_mode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5167
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.adaptive_mode:
 *             if self.expr_order is None:             # <<<<<<<<<<<<<<
 *                 self.expr_order = list(range(len(self.exprs)))
 *             elif len(self.expr_order) < len(self.exprs):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 == Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":5168
 *         if self.adaptive_mode:
 *             if self.expr_order is None:
 *                 self.expr_order = list(range(len(self.exprs)))             # <<<<<<<<<<<<<<
 *             elif len(self.expr_order) < len(self.exprs):
 *                 self.expr_order += list(range(len(self.expr_order), len(self.exprs)))
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_range); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5168, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5168, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_3 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_expr_order, __pyx_t_3) < 0) __PYX_ERR(0, 5168, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":5167
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.adaptive_mode:
 *             if self.expr_order is None:             # <<<<<<<<<<<<<<
 *                 self.expr_order = list(range(len(self.exprs)))
 *             elif len(self.expr_order) < len(self.exprs):
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":5169
 *             if self.expr_order is None:
 *                 self.expr_order = list(range(len(self.exprs)))
 *             elif len(self.expr_order) < len(self.exprs):             # <<<<<<<<<<<<<<
 *                 self.expr_order += list(range(len(self.expr_order), len(self.exprs)))
 *             if self.adaptive_usage is None:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5169, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5169, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = (__pyx_t_5 < __pyx_t_8);
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":5170
 *                 self.expr_order = list(range(len(self.exprs)))
 *             elif len(self.expr_order) < len(self.exprs):
 *                 self.expr_order += list(range(len(self.expr_order), len(self.exprs)))             # <<<<<<<<<<<<<<
 *             if self.adaptive_usage is None:
 *                 self.adaptive_usage = [0] * len(self.exprs)
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_range); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = PyObject_Length(__pyx_t_6); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = PyObject_Length(__pyx_t_9); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_6, __pyx_t_9};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5170, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_4 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_expr_order, __pyx_t_1) < 0) __PYX_ERR(0, 5170, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":5169
 *             if self.expr_order is None:
 *                 self.expr_order = list(range(len(self.exprs)))
 *             elif len(self.expr_order) < len(self.exprs):             # <<<<<<<<<<<<<<
 *                 self.expr_order += list(range(len(self.expr_order), len(self.exprs)))
 *             if self.adaptive_usage is None:
 */
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":5171
 *             elif len(self.expr_order) < len(self.exprs):
 *                 self.expr_order += list(range(len(self.expr_order), len(self.exprs)))
 *             if self.adaptive_usage is None:             # <<<<<<<<<<<<<<
 *                 self.adaptive_usage = [0] * len(self.exprs)
 *         if self.adaptive_usage is not None and len(self.adaptive_usage) < len(self.exprs):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 == Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":5172
 *                 self.expr_order += list(range(len(self.expr_order), len(self.exprs)))
 *             if self.adaptive_usage is None:
 *                 self.adaptive_usage = [0] * len(self.exprs)             # <<<<<<<<<<<<<<
 *         if self.adaptive_usage is not None and len(self.adaptive_usage) < len(self.exprs):
 *             self.adaptive_usage += [0] * (len(self.exprs) - len(self.adaptive_usage))
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5172, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyList_New(1 * ((__pyx_t_8<0) ? 0:__pyx_t_8)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      { Py_ssize_t __pyx_temp;
        for (__pyx_temp=0; __pyx_temp < __pyx_t_8; __pyx_temp++) {
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_GIVEREF(__pyx_int_0);
          if (__Pyx_PyList_SET_ITEM(__pyx_t_1, __pyx_temp, __pyx_int_0)) __PYX_ERR(0, 5172, __pyx_L1_error);
        }
      }
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage, __pyx_t_1) < 0) __PYX_ERR(0, 5172, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":5171
 *             elif len(self.expr_order) < len(self.exprs):
 *                 self.expr_order += list(range(len(self.expr_order), len(self.exprs)))
 *             if self.adaptive_usage is None:             # <<<<<<<<<<<<<<
 *                 self.adaptive_usage = [0] * len(self.exprs)
 *         if self.adaptive_usage is not None and len(self.adaptive_usage) < len(self.exprs):
 */
    }

    /* "cPyparsing.pyx":5166
 *     # [CPYPARSING] implement adaptive mode
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.adaptive_mode:             # <<<<<<<<<<<<<<
 *             if self.expr_order is None:
 *                 self.expr_order = list(range(len(self.exprs)))
 */
  }

  /* "cPyparsing.pyx":5173
 *             if self.adaptive_usage is None:
 *                 self.adaptive_usage = [0] * len(self.exprs)
 *         if self.adaptive_usage is not None and len(self.adaptive_usage) < len(self.exprs):             # <<<<<<<<<<<<<<
 *             self.adaptive_usage += [0] * (len(self.exprs) - len(self.adaptive_usage))
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_11 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_11) {
  } else {
    __pyx_t_2 = __pyx_t_11;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5173, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5173, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_11 = (__pyx_t_8 < __pyx_t_5);
  __pyx_t_2 = __pyx_t_11;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5174
 *                 self.adaptive_usage = [0] * len(self.exprs)
 *         if self.adaptive_usage is not None and len(self.adaptive_usage) < len(self.exprs):
 *             self.adaptive_usage += [0] * (len(self.exprs) - len(self.adaptive_usage))             # <<<<<<<<<<<<<<
 * 
 *         maxExcLoc = -1
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5174, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5174, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_12 = __Pyx_sub_Py_ssize_t_checking_overflow(__pyx_t_5, __pyx_t_8, &__pyx_t_7);
    if (unlikely(__pyx_t_7)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 5174, __pyx_L1_error)
    }
    __pyx_t_4 = PyList_New(1 * ((__pyx_t_12<0) ? 0:__pyx_t_12)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    { Py_ssize_t __pyx_temp;
      for (__pyx_temp=0; __pyx_temp < __pyx_t_12; __pyx_temp++) {
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_4, __pyx_temp, __pyx_int_0)) __PYX_ERR(0, 5174, __pyx_L1_error);
      }
    }
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage, __pyx_t_3) < 0) __PYX_ERR(0, 5174, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5173
 *             if self.adaptive_usage is None:
 *                 self.adaptive_usage = [0] * len(self.exprs)
 *         if self.adaptive_usage is not None and len(self.adaptive_usage) < len(self.exprs):             # <<<<<<<<<<<<<<
 *             self.adaptive_usage += [0] * (len(self.exprs) - len(self.adaptive_usage))
 * 
 */
  }

  /* "cPyparsing.pyx":5176
 *             self.adaptive_usage += [0] * (len(self.exprs) - len(self.adaptive_usage))
 * 
 *         maxExcLoc = -1             # <<<<<<<<<<<<<<
 *         maxException = None
 *         for i, ind_or_e in enumerate(self.expr_order if self.adaptive_mode else self.exprs):
 */
  __Pyx_INCREF(__pyx_int_neg_1);
  __pyx_v_maxExcLoc = __pyx_int_neg_1;

  /* "cPyparsing.pyx":5177
 * 
 *         maxExcLoc = -1
 *         maxException = None             # <<<<<<<<<<<<<<
 *         for i, ind_or_e in enumerate(self.expr_order if self.adaptive_mode else self.exprs):
 *             if self.adaptive_mode:
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_maxException = Py_None;

  /* "cPyparsing.pyx":5178
 *         maxExcLoc = -1
 *         maxException = None
 *         for i, ind_or_e in enumerate(self.expr_order if self.adaptive_mode else self.exprs):             # <<<<<<<<<<<<<<
 *             if self.adaptive_mode:
 *                 ind = ind_or_e
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_3 = __pyx_int_0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_mode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5178, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __pyx_t_1;
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_12 = 0;
    __pyx_t_13 = NULL;
  } else {
    __pyx_t_12 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5178, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_13)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5178, __pyx_L1_error)
          #endif
          if (__pyx_t_12 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_12); __Pyx_INCREF(__pyx_t_4); __pyx_t_12++; if (unlikely((0 < 0))) __PYX_ERR(0, 5178, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5178, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5178, __pyx_L1_error)
          #endif
          if (__pyx_t_12 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_12); __Pyx_INCREF(__pyx_t_4); __pyx_t_12++; if (unlikely((0 < 0))) __PYX_ERR(0, 5178, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5178, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_13(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5178, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_ind_or_e, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3);
    __pyx_t_3 = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":5179
 *         maxException = None
 *         for i, ind_or_e in enumerate(self.expr_order if self.adaptive_mode else self.exprs):
 *             if self.adaptive_mode:             # <<<<<<<<<<<<<<
 *                 ind = ind_or_e
 *                 try:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_mode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5179, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":5180
 *         for i, ind_or_e in enumerate(self.expr_order if self.adaptive_mode else self.exprs):
 *             if self.adaptive_mode:
 *                 ind = ind_or_e             # <<<<<<<<<<<<<<
 *                 try:
 *                     e = self.exprs[ind]
 */
      __Pyx_INCREF(__pyx_v_ind_or_e);
      __Pyx_XDECREF_SET(__pyx_v_ind, __pyx_v_ind_or_e);

      /* "cPyparsing.pyx":5181
 *             if self.adaptive_mode:
 *                 ind = ind_or_e
 *                 try:             # <<<<<<<<<<<<<<
 *                     e = self.exprs[ind]
 *                 except IndexError:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_16);
        /*try:*/ {

          /* "cPyparsing.pyx":5182
 *                 ind = ind_or_e
 *                 try:
 *                     e = self.exprs[ind]             # <<<<<<<<<<<<<<
 *                 except IndexError:
 *                     if self.allow_unused_expr_order:
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5182, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_ind); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5182, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_9);
          __pyx_t_9 = 0;

          /* "cPyparsing.pyx":5181
 *             if self.adaptive_mode:
 *                 ind = ind_or_e
 *                 try:             # <<<<<<<<<<<<<<
 *                     e = self.exprs[ind]
 *                 except IndexError:
 */
        }
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        goto __pyx_L19_try_end;
        __pyx_L12_error:;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "cPyparsing.pyx":5183
 *                 try:
 *                     e = self.exprs[ind]
 *                 except IndexError:             # <<<<<<<<<<<<<<
 *                     if self.allow_unused_expr_order:
 *                         continue
 */
        __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
        if (__pyx_t_7) {
          __Pyx_AddTraceback("cPyparsing.MatchFirst.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_4, &__pyx_t_6) < 0) __PYX_ERR(0, 5183, __pyx_L14_except_error)
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_6);

          /* "cPyparsing.pyx":5184
 *                     e = self.exprs[ind]
 *                 except IndexError:
 *                     if self.allow_unused_expr_order:             # <<<<<<<<<<<<<<
 *                         continue
 *                     else:
 */
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_allow_unused_expr_order); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5184, __pyx_L14_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5184, __pyx_L14_except_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (likely(__pyx_t_2)) {

            /* "cPyparsing.pyx":5185
 *                 except IndexError:
 *                     if self.allow_unused_expr_order:
 *                         continue             # <<<<<<<<<<<<<<
 *                     else:
 *                         raise
 */
            goto __pyx_L20_except_continue;

            /* "cPyparsing.pyx":5184
 *                     e = self.exprs[ind]
 *                 except IndexError:
 *                     if self.allow_unused_expr_order:             # <<<<<<<<<<<<<<
 *                         continue
 *                     else:
 */
          }

          /* "cPyparsing.pyx":5187
 *                         continue
 *                     else:
 *                         raise             # <<<<<<<<<<<<<<
 *             else:
 *                 ind = i
 */
          /*else*/ {
            __Pyx_GIVEREF(__pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_4);
            __Pyx_XGIVEREF(__pyx_t_6);
            __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_4, __pyx_t_6);
            __pyx_t_9 = 0; __pyx_t_4 = 0; __pyx_t_6 = 0; 
            __PYX_ERR(0, 5187, __pyx_L14_except_error)
          }
          __pyx_L20_except_continue:;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L18_try_continue;
        }
        goto __pyx_L14_except_error;

        /* "cPyparsing.pyx":5181
 *             if self.adaptive_mode:
 *                 ind = ind_or_e
 *                 try:             # <<<<<<<<<<<<<<
 *                     e = self.exprs[ind]
 *                 except IndexError:
 */
        __pyx_L14_except_error:;
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
        goto __pyx_L1_error;
        __pyx_L18_try_continue:;
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
        goto __pyx_L9_continue;
        __pyx_L19_try_end:;
      }

      /* "cPyparsing.pyx":5179
 *         maxException = None
 *         for i, ind_or_e in enumerate(self.expr_order if self.adaptive_mode else self.exprs):
 *             if self.adaptive_mode:             # <<<<<<<<<<<<<<
 *                 ind = ind_or_e
 *                 try:
 */
      goto __pyx_L11;
    }

    /* "cPyparsing.pyx":5189
 *                         raise
 *             else:
 *                 ind = i             # <<<<<<<<<<<<<<
 *                 e = ind_or_e
 *             try:
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_XDECREF_SET(__pyx_v_ind, __pyx_v_i);

      /* "cPyparsing.pyx":5190
 *             else:
 *                 ind = i
 *                 e = ind_or_e             # <<<<<<<<<<<<<<
 *             try:
 *                 ret = e._parse(instring, loc, doActions)
 */
      __Pyx_INCREF(__pyx_v_ind_or_e);
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_v_ind_or_e);
    }
    __pyx_L11:;

    /* "cPyparsing.pyx":5191
 *                 ind = i
 *                 e = ind_or_e
 *             try:             # <<<<<<<<<<<<<<
 *                 ret = e._parse(instring, loc, doActions)
 *             except ParseException as err:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_16, &__pyx_t_15, &__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_14);
      /*try:*/ {

        /* "cPyparsing.pyx":5192
 *                 e = ind_or_e
 *             try:
 *                 ret = e._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *             except ParseException as err:
 *                 if err.loc > maxExcLoc:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5192, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_9 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_9, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5192, __pyx_L23_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __Pyx_XDECREF_SET(__pyx_v_ret, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "cPyparsing.pyx":5191
 *                 ind = i
 *                 e = ind_or_e
 *             try:             # <<<<<<<<<<<<<<
 *                 ret = e._parse(instring, loc, doActions)
 *             except ParseException as err:
 */
      }

      /* "cPyparsing.pyx":5202
 *                     maxExcLoc = len(instring)
 *             else:
 *                 if self.adaptive_usage is not None:             # <<<<<<<<<<<<<<
 *                     self.adaptive_usage[ind] += self.usage_weight
 *                 if self.adaptive_mode and i > 0:
 */
      /*else:*/ {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5202, __pyx_L25_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_2 = (__pyx_t_6 != Py_None);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":5203
 *             else:
 *                 if self.adaptive_usage is not None:
 *                     self.adaptive_usage[ind] += self.usage_weight             # <<<<<<<<<<<<<<
 *                 if self.adaptive_mode and i > 0:
 *                     usage = self.adaptive_usage[ind]
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5203, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_INCREF(__pyx_v_ind);
          __pyx_t_4 = __pyx_v_ind;
          __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5203, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_usage_weight); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5203, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_17 = PyNumber_InPlaceAdd(__pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5203, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely((PyObject_SetItem(__pyx_t_6, __pyx_t_4, __pyx_t_17) < 0))) __PYX_ERR(0, 5203, __pyx_L25_except_error)
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "cPyparsing.pyx":5202
 *                     maxExcLoc = len(instring)
 *             else:
 *                 if self.adaptive_usage is not None:             # <<<<<<<<<<<<<<
 *                     self.adaptive_usage[ind] += self.usage_weight
 *                 if self.adaptive_mode and i > 0:
 */
        }

        /* "cPyparsing.pyx":5204
 *                 if self.adaptive_usage is not None:
 *                     self.adaptive_usage[ind] += self.usage_weight
 *                 if self.adaptive_mode and i > 0:             # <<<<<<<<<<<<<<
 *                     usage = self.adaptive_usage[ind]
 *                     if (
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_mode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5204, __pyx_L25_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 5204, __pyx_L25_except_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (__pyx_t_11) {
        } else {
          __pyx_t_2 = __pyx_t_11;
          goto __pyx_L33_bool_binop_done;
        }
        __pyx_t_6 = PyObject_RichCompare(__pyx_v_i, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5204, __pyx_L25_except_error)
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 5204, __pyx_L25_except_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_2 = __pyx_t_11;
        __pyx_L33_bool_binop_done:;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":5205
 *                     self.adaptive_usage[ind] += self.usage_weight
 *                 if self.adaptive_mode and i > 0:
 *                     usage = self.adaptive_usage[ind]             # <<<<<<<<<<<<<<
 *                     if (
 *                         (
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5205, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_ind); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5205, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_v_usage = __pyx_t_4;
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":5208
 *                     if (
 *                         (
 *                             not self.adaptive_usage_check_rate             # <<<<<<<<<<<<<<
 *                             or usage < self.adaptive_usage_check_rate
 *                             or usage % self.adaptive_usage_check_rate == 0
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage_check_rate); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5208, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 5208, __pyx_L25_except_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_18 = (!__pyx_t_11);
          if (!__pyx_t_18) {
          } else {
            goto __pyx_L37_next_and;
          }

          /* "cPyparsing.pyx":5209
 *                         (
 *                             not self.adaptive_usage_check_rate
 *                             or usage < self.adaptive_usage_check_rate             # <<<<<<<<<<<<<<
 *                             or usage % self.adaptive_usage_check_rate == 0
 *                         )
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage_check_rate); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5209, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = PyObject_RichCompare(__pyx_v_usage, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5209, __pyx_L25_except_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 5209, __pyx_L25_except_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (!__pyx_t_18) {
          } else {
            goto __pyx_L37_next_and;
          }

          /* "cPyparsing.pyx":5210
 *                             not self.adaptive_usage_check_rate
 *                             or usage < self.adaptive_usage_check_rate
 *                             or usage % self.adaptive_usage_check_rate == 0             # <<<<<<<<<<<<<<
 *                         )
 *                         and usage > self.adaptive_usage[self.expr_order[i-1]]
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage_check_rate); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5210, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_4 = PyNumber_Remainder(__pyx_v_usage, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5210, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_18 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_4, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 5210, __pyx_L25_except_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (__pyx_t_18) {
          } else {
            __pyx_t_2 = __pyx_t_18;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_L37_next_and:;

          /* "cPyparsing.pyx":5212
 *                             or usage % self.adaptive_usage_check_rate == 0
 *                         )
 *                         and usage > self.adaptive_usage[self.expr_order[i-1]]             # <<<<<<<<<<<<<<
 *                     ):
 *                         self.expr_order[i-1], self.expr_order[i] = self.expr_order[i], self.expr_order[i-1]
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adaptive_usage); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5212, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5212, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_17 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5212, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_t_17); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5212, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_10); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5212, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = PyObject_RichCompare(__pyx_v_usage, __pyx_t_17, Py_GT); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5212, __pyx_L25_except_error)
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_18 < 0))) __PYX_ERR(0, 5212, __pyx_L25_except_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_2 = __pyx_t_18;
          __pyx_L36_bool_binop_done:;

          /* "cPyparsing.pyx":5206
 *                 if self.adaptive_mode and i > 0:
 *                     usage = self.adaptive_usage[ind]
 *                     if (             # <<<<<<<<<<<<<<
 *                         (
 *                             not self.adaptive_usage_check_rate
 */
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":5214
 *                         and usage > self.adaptive_usage[self.expr_order[i-1]]
 *                     ):
 *                         self.expr_order[i-1], self.expr_order[i] = self.expr_order[i], self.expr_order[i-1]             # <<<<<<<<<<<<<<
 *                 return ret
 * 
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_17 = __Pyx_PyObject_GetItem(__pyx_t_10, __pyx_v_i); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_10 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_10);
            if (unlikely((PyObject_SetItem(__pyx_t_4, __pyx_t_10, __pyx_t_17) < 0))) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr_order); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_17);
            if (unlikely((PyObject_SetItem(__pyx_t_17, __pyx_v_i, __pyx_t_6) < 0))) __PYX_ERR(0, 5214, __pyx_L25_except_error)
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "cPyparsing.pyx":5206
 *                 if self.adaptive_mode and i > 0:
 *                     usage = self.adaptive_usage[ind]
 *                     if (             # <<<<<<<<<<<<<<
 *                         (
 *                             not self.adaptive_usage_check_rate
 */
          }

          /* "cPyparsing.pyx":5204
 *                 if self.adaptive_usage is not None:
 *                     self.adaptive_usage[ind] += self.usage_weight
 *                 if self.adaptive_mode and i > 0:             # <<<<<<<<<<<<<<
 *                     usage = self.adaptive_usage[ind]
 *                     if (
 */
        }

        /* "cPyparsing.pyx":5215
 *                     ):
 *                         self.expr_order[i-1], self.expr_order[i] = self.expr_order[i], self.expr_order[i-1]
 *                 return ret             # <<<<<<<<<<<<<<
 * 
 *         # only got here if no expression matched, raise exception for match that made it the furthest
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_ret);
        __pyx_r = __pyx_v_ret;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L26_except_return;
      }
      __pyx_L23_error:;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "cPyparsing.pyx":5193
 *             try:
 *                 ret = e._parse(instring, loc, doActions)
 *             except ParseException as err:             # <<<<<<<<<<<<<<
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 */
      __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_17, &__pyx_t_10);
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5193, __pyx_L25_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_6, __pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_17, __pyx_t_10);
      __pyx_t_6 = 0; __pyx_t_17 = 0; __pyx_t_10 = 0;
      if (__pyx_t_7) {
        __Pyx_AddTraceback("cPyparsing.MatchFirst.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_10, &__pyx_t_17, &__pyx_t_6) < 0) __PYX_ERR(0, 5193, __pyx_L25_except_error)
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_17);
        __pyx_v_err = __pyx_t_17;
        /*try:*/ {

          /* "cPyparsing.pyx":5194
 *                 ret = e._parse(instring, loc, doActions)
 *             except ParseException as err:
 *                 if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = err
 *                     maxExcLoc = err.loc
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5194, __pyx_L45_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_9 = PyObject_RichCompare(__pyx_t_4, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5194, __pyx_L45_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5194, __pyx_L45_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":5195
 *             except ParseException as err:
 *                 if err.loc > maxExcLoc:
 *                     maxException = err             # <<<<<<<<<<<<<<
 *                     maxExcLoc = err.loc
 *             except IndexError:
 */
            __Pyx_INCREF(__pyx_v_err);
            __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_v_err);

            /* "cPyparsing.pyx":5196
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 *                     maxExcLoc = err.loc             # <<<<<<<<<<<<<<
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:
 */
            __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5196, __pyx_L45_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_9);
            __pyx_t_9 = 0;

            /* "cPyparsing.pyx":5194
 *                 ret = e._parse(instring, loc, doActions)
 *             except ParseException as err:
 *                 if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = err
 *                     maxExcLoc = err.loc
 */
          }
        }

        /* "cPyparsing.pyx":5193
 *             try:
 *                 ret = e._parse(instring, loc, doActions)
 *             except ParseException as err:             # <<<<<<<<<<<<<<
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
            goto __pyx_L46;
          }
          __pyx_L45_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_24, &__pyx_t_25, &__pyx_t_26);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23) < 0)) __Pyx_ErrFetch(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_23);
            __Pyx_XGOTREF(__pyx_t_24);
            __Pyx_XGOTREF(__pyx_t_25);
            __Pyx_XGOTREF(__pyx_t_26);
            __pyx_t_7 = __pyx_lineno; __pyx_t_19 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_XGIVEREF(__pyx_t_25);
              __Pyx_XGIVEREF(__pyx_t_26);
              __Pyx_ExceptionReset(__pyx_t_24, __pyx_t_25, __pyx_t_26);
            }
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_ErrRestore(__pyx_t_21, __pyx_t_22, __pyx_t_23);
            __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0;
            __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_19; __pyx_filename = __pyx_t_20;
            goto __pyx_L25_except_error;
          }
          __pyx_L46:;
        }
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L24_exception_handled;
      }

      /* "cPyparsing.pyx":5197
 *                     maxException = err
 *                     maxExcLoc = err.loc
 *             except IndexError:             # <<<<<<<<<<<<<<
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 */
      __pyx_t_19 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
      if (__pyx_t_19) {
        __Pyx_AddTraceback("cPyparsing.MatchFirst.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_17, &__pyx_t_10) < 0) __PYX_ERR(0, 5197, __pyx_L25_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_10);

        /* "cPyparsing.pyx":5198
 *                     maxExcLoc = err.loc
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)
 */
        __pyx_t_8 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5198, __pyx_L25_except_error)
        __pyx_t_9 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5198, __pyx_L25_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_4 = PyObject_RichCompare(__pyx_t_9, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5198, __pyx_L25_except_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5198, __pyx_L25_except_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":5199
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)             # <<<<<<<<<<<<<<
 *                     maxExcLoc = len(instring)
 *             else:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5199, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_8 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5199, __pyx_L25_except_error)
          __pyx_t_27 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 5199, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_27);
          __pyx_t_28 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 5199, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_28);
          __pyx_t_29 = NULL;
          __pyx_t_19 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_29 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_29)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_29);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
              __pyx_t_19 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_29, __pyx_v_instring, __pyx_t_27, __pyx_t_28, __pyx_v_self};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_19, 4+__pyx_t_19);
            __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
            __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
            __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5199, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":5200
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)             # <<<<<<<<<<<<<<
 *             else:
 *                 if self.adaptive_usage is not None:
 */
          __pyx_t_8 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5200, __pyx_L25_except_error)
          __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5200, __pyx_L25_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":5198
 *                     maxExcLoc = err.loc
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)
 */
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L24_exception_handled;
      }
      goto __pyx_L25_except_error;

      /* "cPyparsing.pyx":5191
 *                 ind = i
 *                 e = ind_or_e
 *             try:             # <<<<<<<<<<<<<<
 *                 ret = e._parse(instring, loc, doActions)
 *             except ParseException as err:
 */
      __pyx_L25_except_error:;
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_15, __pyx_t_14);
      goto __pyx_L1_error;
      __pyx_L26_except_return:;
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_15, __pyx_t_14);
      goto __pyx_L0;
      __pyx_L24_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_15, __pyx_t_14);
    }

    /* "cPyparsing.pyx":5178
 *         maxExcLoc = -1
 *         maxException = None
 *         for i, ind_or_e in enumerate(self.expr_order if self.adaptive_mode else self.exprs):             # <<<<<<<<<<<<<<
 *             if self.adaptive_mode:
 *                 ind = ind_or_e
 */
    __pyx_L9_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {

    /* "cPyparsing.pyx":5219
 *         # only got here if no expression matched, raise exception for match that made it the furthest
 *         else:
 *             if maxException is not None:             # <<<<<<<<<<<<<<
 *                 maxException.msg = self.errmsg
 *                 raise maxException
 */
    __pyx_t_2 = (__pyx_v_maxException != Py_None);
    if (unlikely(__pyx_t_2)) {

      /* "cPyparsing.pyx":5220
 *         else:
 *             if maxException is not None:
 *                 maxException.msg = self.errmsg             # <<<<<<<<<<<<<<
 *                 raise maxException
 *             else:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5220, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_maxException, __pyx_n_s_msg, __pyx_t_1) < 0) __PYX_ERR(0, 5220, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":5221
 *             if maxException is not None:
 *                 maxException.msg = self.errmsg
 *                 raise maxException             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 */
      __Pyx_Raise(__pyx_v_maxException, 0, 0, 0);
      __PYX_ERR(0, 5221, __pyx_L1_error)

      /* "cPyparsing.pyx":5219
 *         # only got here if no expression matched, raise exception for match that made it the furthest
 *         else:
 *             if maxException is not None:             # <<<<<<<<<<<<<<
 *                 maxException.msg = self.errmsg
 *                 raise maxException
 */
    }

    /* "cPyparsing.pyx":5223
 *                 raise maxException
 *             else:
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)             # <<<<<<<<<<<<<<
 * 
 *     def __ior__(self, other):
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_17 = NULL;
      __pyx_t_19 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_17)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_19 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_17, __pyx_v_instring, __pyx_v_loc, __pyx_kp_u_no_defined_alternatives_to_match, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_19, 4+__pyx_t_19);
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 5223, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5165
 * 
 *     # [CPYPARSING] implement adaptive mode
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.adaptive_mode:
 *             if self.expr_order is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_XDECREF(__pyx_t_28);
  __Pyx_XDECREF(__pyx_t_29);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_maxExcLoc);
  __Pyx_XDECREF(__pyx_v_maxException);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_ind_or_e);
  __Pyx_XDECREF(__pyx_v_ind);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_usage);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5225
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ior__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_9__ior__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10MatchFirst_8__ior__, "MatchFirst.__ior__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_9__ior__ = {"__ior__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10MatchFirst_9__ior__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10MatchFirst_8__ior__};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_9__ior__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ior__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5225, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5225, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__ior__", 1, 2, 2, 1); __PYX_ERR(0, 5225, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__ior__") < 0)) __PYX_ERR(0, 5225, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ior__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5225, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__ior__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_8__ior__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_8__ior__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ior__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":5226
 * 
 *     def __ior__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         return self.append(other)  # MatchFirst([self, other])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 5226, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5227
 *     def __ior__(self, other):
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         return self.append(other)  # MatchFirst([self, other])
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5226
 * 
 *     def __ior__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         return self.append(other)  # MatchFirst([self, other])
 */
  }

  /* "cPyparsing.pyx":5228
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         return self.append(other)  # MatchFirst([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_append); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5225
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ior__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__ior__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5230
 *         return self.append(other)  # MatchFirst([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_11__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10MatchFirst_10__str__, "MatchFirst.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_11__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10MatchFirst_11__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10MatchFirst_10__str__};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_11__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5230, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 5230, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5230, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_10__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_7__str___2generator32(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5235
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_45_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5235, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_10MatchFirst_7__str___2generator32, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_MatchFirst___str___locals_genexp, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_7__str___2generator32(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5235, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 5235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5235, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5235, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5235, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5235, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5235, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5235, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5235, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5235, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5235, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5235, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5230
 *         return self.append(other)  # MatchFirst([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_10__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_gb_10cPyparsing_10MatchFirst_7__str___2generator32 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":5231
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_name_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 5231, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5232
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5232, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":5231
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":5234
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5235
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_pf_10cPyparsing_10MatchFirst_7__str___genexpr(NULL, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__111, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__107, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_2, __pyx_kp_u__108); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_3) < 0) __PYX_ERR(0, 5235, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5234
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":5237
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5230
 *         return self.append(other)  # MatchFirst([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_10MatchFirst_7__str___2generator32);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5239
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_13checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10MatchFirst_12checkRecursion, "MatchFirst.checkRecursion(self, parseElementList)");
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_13checkRecursion = {"checkRecursion", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10MatchFirst_13checkRecursion, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10MatchFirst_12checkRecursion};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_13checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5239, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseElementList)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5239, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 5239, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 5239, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5239, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.MatchFirst.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_12checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_12checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkRecursion", 1);

  /* "cPyparsing.pyx":5240
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self)) __PYX_ERR(0, 5240, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_subRecCheckList = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5241
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5241, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5241, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 5241, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5241, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5241, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 5241, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5241, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5241, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5242
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5241
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5239
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5244
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_15_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10MatchFirst_14_setResultsName, "MatchFirst._setResultsName(self, name, listAllMatches=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_15_setResultsName = {"_setResultsName", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10MatchFirst_15_setResultsName, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10MatchFirst_14_setResultsName};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_15_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_listAllMatches = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_setResultsName (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,&__pyx_n_s_listAllMatches,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5244, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5244, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, 1); __PYX_ERR(0, 5244, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listAllMatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5244, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_setResultsName") < 0)) __PYX_ERR(0, 5244, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_listAllMatches = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5244, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.MatchFirst._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_14_setResultsName(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_listAllMatches);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_15_setResultsName_2generator33(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5247
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_15_setResultsName_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_46_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5247, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_10MatchFirst_15_setResultsName_2generator33, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_MatchFirst__setResultsName_local, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst._setResultsName.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_15_setResultsName_2generator33(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5247, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5247, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5247, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5247, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5247, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5247, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5247, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5247, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5247, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5247, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_And); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5244
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_14_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches) {
  PyObject *__pyx_gb_10cPyparsing_10MatchFirst_15_setResultsName_2generator33 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_setResultsName", 1);

  /* "cPyparsing.pyx":5245
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if (not __compat__.collect_all_And_tokens             # <<<<<<<<<<<<<<
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_compat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_collect_all_And_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = (!__pyx_t_4);
  if (__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }

  /* "cPyparsing.pyx":5246
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):             # <<<<<<<<<<<<<<
 *             if any(isinstance(e, And) for e in self.exprs):
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_diag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_warn_multiple_tokens_in_named_al); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;

  /* "cPyparsing.pyx":5245
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if (not __compat__.collect_all_And_tokens             # <<<<<<<<<<<<<<
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 */
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5247
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_pf_10cPyparsing_10MatchFirst_15_setResultsName_genexpr(NULL, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":5248
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":5250
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(             # <<<<<<<<<<<<<<
 *                     "warn_multiple_tokens_in_named_alternation", name, type(self).__name__),
 *                     stacklevel=3)
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_setting_results_name_1_r_on_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5250, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);

      /* "cPyparsing.pyx":5251
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(
 *                     "warn_multiple_tokens_in_named_alternation", name, type(self).__name__),             # <<<<<<<<<<<<<<
 *                     stacklevel=3)
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_self)), __pyx_n_s_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5251, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_n_u_warn_multiple_tokens_in_named_al, __pyx_v_name, __pyx_t_7};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 3+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5250, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }

      /* "cPyparsing.pyx":5248
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(
 */
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(0, 5248, __pyx_L1_error);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":5252
 *                               "in future will return the full list of tokens".format(
 *                     "warn_multiple_tokens_in_named_alternation", name, type(self).__name__),
 *                     stacklevel=3)             # <<<<<<<<<<<<<<
 * 
 *         return super(MatchFirst, self)._setResultsName(name, listAllMatches)
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5252, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stacklevel, __pyx_int_3) < 0) __PYX_ERR(0, 5252, __pyx_L1_error)

      /* "cPyparsing.pyx":5248
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                               "may only return a single token for an And alternative, "
 *                               "in future will return the full list of tokens".format(
 */
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "cPyparsing.pyx":5247
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                               "may only return a single token for an And alternative, "
 */
    }

    /* "cPyparsing.pyx":5245
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if (not __compat__.collect_all_And_tokens             # <<<<<<<<<<<<<<
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 *             if any(isinstance(e, And) for e in self.exprs):
 */
  }

  /* "cPyparsing.pyx":5254
 *                     stacklevel=3)
 * 
 *         return super(MatchFirst, self)._setResultsName(name, listAllMatches)             # <<<<<<<<<<<<<<
 * 
 * # [CPYPARSING] initialize adaptive mode to off
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MatchFirst); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(0, 5254, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 5254, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_name, __pyx_v_listAllMatches};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 2+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5244
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.MatchFirst._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_10MatchFirst_15_setResultsName_2generator33);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5316
 *         - size: 20
 *     """
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Each_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Each___init__, "Each.__init__(self, exprs, savelist=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Each_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Each_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Each___init__};
static PyObject *__pyx_pw_10cPyparsing_4Each_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5316, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exprs)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5316, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 5316, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_savelist);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5316, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5316, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5316, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Each.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Each___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Each_8__init___2generator34(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5318
 *     def __init__(self, exprs, savelist=True):
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.initExprGroups = True
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_8__init___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_47_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5318, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Each_8__init___2generator34, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Each___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5318, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Each.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Each_8__init___2generator34(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5318, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5318, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5318, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5318, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5318, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5318, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5318, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5318, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5318, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5318, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5318, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = (!__pyx_t_5);
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5316
 *         - size: 20
 *     """
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

static PyObject *__pyx_pf_10cPyparsing_4Each___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  PyObject *__pyx_gb_10cPyparsing_4Each_8__init___2generator34 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":5317
 *     """
 *     def __init__(self, exprs, savelist=True):
 *         super(Each, self).__init__(exprs, savelist)             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.skipWhitespace = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Each); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5317, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5317, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5318
 *     def __init__(self, exprs, savelist=True):
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.initExprGroups = True
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_pf_10cPyparsing_4Each_8__init___genexpr(NULL, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 5318, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5319
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.skipWhitespace = True             # <<<<<<<<<<<<<<
 *         self.initExprGroups = True
 *         self.saveAsList = True
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_True) < 0) __PYX_ERR(0, 5319, __pyx_L1_error)

  /* "cPyparsing.pyx":5320
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.skipWhitespace = True
 *         self.initExprGroups = True             # <<<<<<<<<<<<<<
 *         self.saveAsList = True
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_initExprGroups, Py_True) < 0) __PYX_ERR(0, 5320, __pyx_L1_error)

  /* "cPyparsing.pyx":5321
 *         self.skipWhitespace = True
 *         self.initExprGroups = True
 *         self.saveAsList = True             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_True) < 0) __PYX_ERR(0, 5321, __pyx_L1_error)

  /* "cPyparsing.pyx":5316
 *         - size: 20
 *     """
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Each.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_4Each_8__init___2generator34);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5323
 *         self.saveAsList = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Each, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Each_3streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Each_2streamline, "Each.streamline(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Each_3streamline = {"streamline", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Each_3streamline, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Each_2streamline};
static PyObject *__pyx_pw_10cPyparsing_4Each_3streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5323, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "streamline") < 0)) __PYX_ERR(0, 5323, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("streamline", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5323, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Each.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Each_2streamline(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Each_10streamline_2generator35(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5325
 *     def streamline(self):
 *         super(Each, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_10streamline_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_48_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5325, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Each_10streamline_2generator35, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Each_streamline_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5325, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Each.streamline.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Each_10streamline_2generator35(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5325, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5325, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5325, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5325, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5325, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5325, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5325, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5325, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5325, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5325, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5325, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = (!__pyx_t_5);
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5323
 *         self.saveAsList = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Each, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_2streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_gb_10cPyparsing_4Each_10streamline_2generator35 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("streamline", 1);

  /* "cPyparsing.pyx":5324
 * 
 *     def streamline(self):
 *         super(Each, self).streamline()             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         return self
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Each); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5324, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5324, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5325
 *     def streamline(self):
 *         super(Each, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_pf_10cPyparsing_4Each_10streamline_genexpr(NULL, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 5325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5326
 *         super(Each, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5323
 *         self.saveAsList = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Each, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Each.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_4Each_10streamline_2generator35);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5328
 *         return self
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Each_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Each_4parseImpl, "Each.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Each_5parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Each_5parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Each_4parseImpl};
static PyObject *__pyx_pw_10cPyparsing_4Each_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5328, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5328, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 5328, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5328, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 5328, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5328, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5328, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 5328, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Each.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Each_4parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_2generator36(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5330
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))             # <<<<<<<<<<<<<<
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, (Optional, Regex))]
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_9parseImpl_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_49_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5330, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Each_9parseImpl_2generator36, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Each_parseImpl_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5330, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Each.parseImpl.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_2generator36(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5330, __pyx_L1_error)
  __pyx_r = PyDict_New(); if (unlikely(!__pyx_r)) __PYX_ERR(0, 5330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5330, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5330, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5330, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5330, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5330, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5330, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5330, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5330, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5330, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Optional); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5330, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5330, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5330, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(PyDict_SetItem(__pyx_r, (PyObject*)__pyx_t_6, (PyObject*)__pyx_cur_scope->__pyx_v_e))) __PYX_ERR(0, 5330, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_5generator37(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5363
 * 
 *         if tmpReqd:
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_9parseImpl_3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_50_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5363, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Each_9parseImpl_5generator37, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Each_parseImpl_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5363, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Each.parseImpl.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_5generator37(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5363, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 5363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5363, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5363, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5363, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5363, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5363, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5363, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5363, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5363, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 5363, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5328
 *         return self
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_opt1 = NULL;
  PyObject *__pyx_v_opt2 = NULL;
  PyObject *__pyx_v_tmpLoc = NULL;
  PyObject *__pyx_v_tmpReqd = NULL;
  PyObject *__pyx_v_tmpOpt = NULL;
  PyObject *__pyx_v_matchOrder = NULL;
  int __pyx_v_keepMatching;
  PyObject *__pyx_v_tmpExprs = NULL;
  PyObject *__pyx_v_failed = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_missing = NULL;
  PyObject *__pyx_v_resultlist = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_v_finalResults = NULL;
  PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_2generator36 = 0;
  PyObject *__pyx_9genexpr44__pyx_v_e = NULL;
  PyObject *__pyx_9genexpr45__pyx_v_e = NULL;
  PyObject *__pyx_9genexpr46__pyx_v_e = NULL;
  PyObject *__pyx_9genexpr47__pyx_v_e = NULL;
  PyObject *__pyx_9genexpr48__pyx_v_e = NULL;
  PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_5generator37 = 0;
  PyObject *__pyx_9genexpr50__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  int __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  PyObject *(*__pyx_t_17)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":5329
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.initExprGroups:             # <<<<<<<<<<<<<<
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initExprGroups); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5329, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5330
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))             # <<<<<<<<<<<<<<
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, (Optional, Regex))]
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __pyx_pf_10cPyparsing_4Each_9parseImpl_genexpr(NULL, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_opt1map, __pyx_t_1) < 0) __PYX_ERR(0, 5330, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5331
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]             # <<<<<<<<<<<<<<
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, (Optional, Regex))]
 *             self.optionals = opt1 + opt2
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5331, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5331, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5331, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5331, __pyx_L6_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5331, __pyx_L6_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5331, __pyx_L6_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5331, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5331, __pyx_L6_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5331, __pyx_L6_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5331, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          }
        } else {
          __pyx_t_3 = __pyx_t_6(__pyx_t_4);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 5331, __pyx_L6_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr44__pyx_v_e, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Optional); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5331, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = PyObject_IsInstance(__pyx_9genexpr44__pyx_v_e, __pyx_t_3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 5331, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_2) {
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr44__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5331, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 5331, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr44__pyx_v_e); __pyx_9genexpr44__pyx_v_e = 0;
      goto __pyx_L11_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_9genexpr44__pyx_v_e); __pyx_9genexpr44__pyx_v_e = 0;
      goto __pyx_L1_error;
      __pyx_L11_exit_scope:;
    } /* exit inner scope */
    __pyx_v_opt1 = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5332
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, (Optional, Regex))]             # <<<<<<<<<<<<<<
 *             self.optionals = opt1 + opt2
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5332, __pyx_L14_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5332, __pyx_L14_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3);
        __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5332, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5332, __pyx_L14_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5332, __pyx_L14_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5332, __pyx_L14_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5332, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5332, __pyx_L14_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5332, __pyx_L14_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5332, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_6(__pyx_t_3);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 5332, __pyx_L14_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr45__pyx_v_e, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr45__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5332, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 5332, __pyx_L14_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_7) {
        } else {
          __pyx_t_2 = __pyx_t_7;
          goto __pyx_L18_bool_binop_done;
        }
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Optional); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5332, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_Regex); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5332, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = PyObject_IsInstance(__pyx_9genexpr45__pyx_v_e, __pyx_t_4); 
        if (!__pyx_t_9) {
        } else {
          __pyx_t_7 = __pyx_t_9;
          goto __pyx_L20_bool_binop_done;
        }
        __pyx_t_9 = PyObject_IsInstance(__pyx_9genexpr45__pyx_v_e, __pyx_t_8); 
        __pyx_t_7 = __pyx_t_9;
        __pyx_L20_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_9 = (!__pyx_t_7);
        __pyx_t_2 = __pyx_t_9;
        __pyx_L18_bool_binop_done:;
        if (__pyx_t_2) {
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_9genexpr45__pyx_v_e))) __PYX_ERR(0, 5332, __pyx_L14_error)
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_9genexpr45__pyx_v_e); __pyx_9genexpr45__pyx_v_e = 0;
      goto __pyx_L23_exit_scope;
      __pyx_L14_error:;
      __Pyx_XDECREF(__pyx_9genexpr45__pyx_v_e); __pyx_9genexpr45__pyx_v_e = 0;
      goto __pyx_L1_error;
      __pyx_L23_exit_scope:;
    } /* exit inner scope */
    __pyx_v_opt2 = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5333
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, (Optional, Regex))]
 *             self.optionals = opt1 + opt2             # <<<<<<<<<<<<<<
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]
 */
    __pyx_t_1 = PyNumber_Add(__pyx_v_opt1, __pyx_v_opt2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_optionals, __pyx_t_1) < 0) __PYX_ERR(0, 5333, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5334
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, (Optional, Regex))]
 *             self.optionals = opt1 + opt2
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]             # <<<<<<<<<<<<<<
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L26_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5334, __pyx_L26_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5334, __pyx_L26_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5334, __pyx_L26_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5334, __pyx_L26_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5334, __pyx_L26_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5334, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5334, __pyx_L26_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5334, __pyx_L26_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5334, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          }
        } else {
          __pyx_t_3 = __pyx_t_6(__pyx_t_4);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 5334, __pyx_L26_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr46__pyx_v_e, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5334, __pyx_L26_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = PyObject_IsInstance(__pyx_9genexpr46__pyx_v_e, __pyx_t_3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 5334, __pyx_L26_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_2) {
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr46__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5334, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 5334, __pyx_L26_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr46__pyx_v_e); __pyx_9genexpr46__pyx_v_e = 0;
      goto __pyx_L31_exit_scope;
      __pyx_L26_error:;
      __Pyx_XDECREF(__pyx_9genexpr46__pyx_v_e); __pyx_9genexpr46__pyx_v_e = 0;
      goto __pyx_L1_error;
      __pyx_L31_exit_scope:;
    } /* exit inner scope */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_multioptionals, __pyx_t_1) < 0) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5335
 *             self.optionals = opt1 + opt2
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]             # <<<<<<<<<<<<<<
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]
 *             self.required += self.multirequired
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5335, __pyx_L34_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5335, __pyx_L34_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3);
        __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5335, __pyx_L34_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5335, __pyx_L34_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5335, __pyx_L34_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5335, __pyx_L34_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5335, __pyx_L34_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5335, __pyx_L34_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5335, __pyx_L34_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5335, __pyx_L34_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_6(__pyx_t_3);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 5335, __pyx_L34_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr47__pyx_v_e, __pyx_t_4);
        __pyx_t_4 = 0;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5335, __pyx_L34_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyObject_IsInstance(__pyx_9genexpr47__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 5335, __pyx_L34_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_2) {
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr47__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5335, __pyx_L34_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 5335, __pyx_L34_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_9genexpr47__pyx_v_e); __pyx_9genexpr47__pyx_v_e = 0;
      goto __pyx_L39_exit_scope;
      __pyx_L34_error:;
      __Pyx_XDECREF(__pyx_9genexpr47__pyx_v_e); __pyx_9genexpr47__pyx_v_e = 0;
      goto __pyx_L1_error;
      __pyx_L39_exit_scope:;
    } /* exit inner scope */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_multirequired, __pyx_t_1) < 0) __PYX_ERR(0, 5335, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5336
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]             # <<<<<<<<<<<<<<
 *             self.required += self.multirequired
 *             self.initExprGroups = False
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5336, __pyx_L42_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5336, __pyx_L42_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5336, __pyx_L42_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5336, __pyx_L42_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5336, __pyx_L42_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5336, __pyx_L42_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5336, __pyx_L42_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5336, __pyx_L42_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5336, __pyx_L42_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5336, __pyx_L42_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          }
        } else {
          __pyx_t_3 = __pyx_t_6(__pyx_t_4);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 5336, __pyx_L42_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr48__pyx_v_e, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Optional); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5336, __pyx_L42_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L42_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5336, __pyx_L42_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = PyObject_IsInstance(__pyx_9genexpr48__pyx_v_e, __pyx_t_3); 
        if (!__pyx_t_9) {
        } else {
          __pyx_t_2 = __pyx_t_9;
          goto __pyx_L46_bool_binop_done;
        }
        __pyx_t_9 = PyObject_IsInstance(__pyx_9genexpr48__pyx_v_e, __pyx_t_8); 
        if (!__pyx_t_9) {
        } else {
          __pyx_t_2 = __pyx_t_9;
          goto __pyx_L46_bool_binop_done;
        }
        __pyx_t_9 = PyObject_IsInstance(__pyx_9genexpr48__pyx_v_e, __pyx_t_10); 
        __pyx_t_2 = __pyx_t_9;
        __pyx_L46_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_9 = (!__pyx_t_2);
        if (__pyx_t_9) {
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_9genexpr48__pyx_v_e))) __PYX_ERR(0, 5336, __pyx_L42_error)
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr48__pyx_v_e); __pyx_9genexpr48__pyx_v_e = 0;
      goto __pyx_L50_exit_scope;
      __pyx_L42_error:;
      __Pyx_XDECREF(__pyx_9genexpr48__pyx_v_e); __pyx_9genexpr48__pyx_v_e = 0;
      goto __pyx_L1_error;
      __pyx_L50_exit_scope:;
    } /* exit inner scope */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_required, __pyx_t_1) < 0) __PYX_ERR(0, 5336, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5337
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]
 *             self.required += self.multirequired             # <<<<<<<<<<<<<<
 *             self.initExprGroups = False
 *         tmpLoc = loc
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_required); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_multirequired); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_required, __pyx_t_3) < 0) __PYX_ERR(0, 5337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5338
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]
 *             self.required += self.multirequired
 *             self.initExprGroups = False             # <<<<<<<<<<<<<<
 *         tmpLoc = loc
 *         tmpReqd = self.required[:]
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_initExprGroups, Py_False) < 0) __PYX_ERR(0, 5338, __pyx_L1_error)

    /* "cPyparsing.pyx":5329
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.initExprGroups:             # <<<<<<<<<<<<<<
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 */
  }

  /* "cPyparsing.pyx":5339
 *             self.required += self.multirequired
 *             self.initExprGroups = False
 *         tmpLoc = loc             # <<<<<<<<<<<<<<
 *         tmpReqd = self.required[:]
 *         tmpOpt  = self.optionals[:]
 */
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_v_tmpLoc = __pyx_v_loc;

  /* "cPyparsing.pyx":5340
 *             self.initExprGroups = False
 *         tmpLoc = loc
 *         tmpReqd = self.required[:]             # <<<<<<<<<<<<<<
 *         tmpOpt  = self.optionals[:]
 *         matchOrder = []
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_required); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_3, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_tmpReqd = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":5341
 *         tmpLoc = loc
 *         tmpReqd = self.required[:]
 *         tmpOpt  = self.optionals[:]             # <<<<<<<<<<<<<<
 *         matchOrder = []
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_optionals); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_tmpOpt = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5342
 *         tmpReqd = self.required[:]
 *         tmpOpt  = self.optionals[:]
 *         matchOrder = []             # <<<<<<<<<<<<<<
 * 
 *         keepMatching = True
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_matchOrder = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5344
 *         matchOrder = []
 * 
 *         keepMatching = True             # <<<<<<<<<<<<<<
 *         while keepMatching:
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 */
  __pyx_v_keepMatching = 1;

  /* "cPyparsing.pyx":5345
 * 
 *         keepMatching = True
 *         while keepMatching:             # <<<<<<<<<<<<<<
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 *             failed = []
 */
  while (1) {
    if (!__pyx_v_keepMatching) break;

    /* "cPyparsing.pyx":5346
 *         keepMatching = True
 *         while keepMatching:
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired             # <<<<<<<<<<<<<<
 *             failed = []
 *             for e in tmpExprs:
 */
    __pyx_t_3 = PyNumber_Add(__pyx_v_tmpReqd, __pyx_v_tmpOpt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_multioptionals); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_multirequired); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_tmpExprs, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5347
 *         while keepMatching:
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 *             failed = []             # <<<<<<<<<<<<<<
 *             for e in tmpExprs:
 *                 try:
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_failed, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5348
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 *             failed = []
 *             for e in tmpExprs:             # <<<<<<<<<<<<<<
 *                 try:
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 */
    if (likely(PyList_CheckExact(__pyx_v_tmpExprs)) || PyTuple_CheckExact(__pyx_v_tmpExprs)) {
      __pyx_t_3 = __pyx_v_tmpExprs; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_tmpExprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5348, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5348, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5348, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5348, __pyx_L1_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5348, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5348, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 5348, __pyx_L1_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5348, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_6(__pyx_t_3);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 5348, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":5349
 *             failed = []
 *             for e in tmpExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_13);
        /*try:*/ {

          /* "cPyparsing.pyx":5350
 *             for e in tmpExprs:
 *                 try:
 *                     tmpLoc = e.tryParse(instring, tmpLoc)             # <<<<<<<<<<<<<<
 *                 except ParseException:
 *                     failed.append(e)
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5350, __pyx_L55_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_8 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_instring, __pyx_v_tmpLoc};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_14, 2+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5350, __pyx_L55_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_tmpLoc, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":5349
 *             failed = []
 *             for e in tmpExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:
 */
        }

        /* "cPyparsing.pyx":5354
 *                     failed.append(e)
 *                 else:
 *                     matchOrder.append(self.opt1map.get(id(e), e))             # <<<<<<<<<<<<<<
 *                     if e in tmpReqd:
 *                         tmpReqd.remove(e)
 */
        /*else:*/ {
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_opt1map); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5354, __pyx_L57_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5354, __pyx_L57_except_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, __pyx_v_e); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5354, __pyx_L57_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_10 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_1, __pyx_v_e};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_14, 2+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5354, __pyx_L57_except_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_matchOrder, __pyx_t_4); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 5354, __pyx_L57_except_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "cPyparsing.pyx":5355
 *                 else:
 *                     matchOrder.append(self.opt1map.get(id(e), e))
 *                     if e in tmpReqd:             # <<<<<<<<<<<<<<
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:
 */
          __pyx_t_9 = (__Pyx_PySequence_ContainsTF(__pyx_v_e, __pyx_v_tmpReqd, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 5355, __pyx_L57_except_error)
          if (__pyx_t_9) {

            /* "cPyparsing.pyx":5356
 *                     matchOrder.append(self.opt1map.get(id(e), e))
 *                     if e in tmpReqd:
 *                         tmpReqd.remove(e)             # <<<<<<<<<<<<<<
 *                     elif e in tmpOpt:
 *                         tmpOpt.remove(e)
 */
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmpReqd, __pyx_n_s_remove); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5356, __pyx_L57_except_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_1 = NULL;
            __pyx_t_14 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_1)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_1);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
                __pyx_t_14 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_e};
              __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5356, __pyx_L57_except_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

            /* "cPyparsing.pyx":5355
 *                 else:
 *                     matchOrder.append(self.opt1map.get(id(e), e))
 *                     if e in tmpReqd:             # <<<<<<<<<<<<<<
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:
 */
            goto __pyx_L63;
          }

          /* "cPyparsing.pyx":5357
 *                     if e in tmpReqd:
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:             # <<<<<<<<<<<<<<
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):
 */
          __pyx_t_9 = (__Pyx_PySequence_ContainsTF(__pyx_v_e, __pyx_v_tmpOpt, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 5357, __pyx_L57_except_error)
          if (__pyx_t_9) {

            /* "cPyparsing.pyx":5358
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:
 *                         tmpOpt.remove(e)             # <<<<<<<<<<<<<<
 *             if len(failed) == len(tmpExprs):
 *                 keepMatching = False
 */
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmpOpt, __pyx_n_s_remove); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5358, __pyx_L57_except_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_1 = NULL;
            __pyx_t_14 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_1)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_1);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
                __pyx_t_14 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_e};
              __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5358, __pyx_L57_except_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

            /* "cPyparsing.pyx":5357
 *                     if e in tmpReqd:
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:             # <<<<<<<<<<<<<<
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):
 */
          }
          __pyx_L63:;
        }
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L62_try_end;
        __pyx_L55_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "cPyparsing.pyx":5351
 *                 try:
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:             # <<<<<<<<<<<<<<
 *                     failed.append(e)
 *                 else:
 */
        __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_8, &__pyx_t_1);
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5351, __pyx_L57_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_14 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_10);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_ErrRestore(__pyx_t_4, __pyx_t_8, __pyx_t_1);
        __pyx_t_4 = 0; __pyx_t_8 = 0; __pyx_t_1 = 0;
        if (__pyx_t_14) {
          __Pyx_AddTraceback("cPyparsing.Each.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_8, &__pyx_t_4) < 0) __PYX_ERR(0, 5351, __pyx_L57_except_error)
          __Pyx_XGOTREF(__pyx_t_1);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_4);

          /* "cPyparsing.pyx":5352
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:
 *                     failed.append(e)             # <<<<<<<<<<<<<<
 *                 else:
 *                     matchOrder.append(self.opt1map.get(id(e), e))
 */
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_failed, __pyx_v_e); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 5352, __pyx_L57_except_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L56_exception_handled;
        }
        goto __pyx_L57_except_error;

        /* "cPyparsing.pyx":5349
 *             failed = []
 *             for e in tmpExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:
 */
        __pyx_L57_except_error:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
        goto __pyx_L1_error;
        __pyx_L56_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
        __pyx_L62_try_end:;
      }

      /* "cPyparsing.pyx":5348
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 *             failed = []
 *             for e in tmpExprs:             # <<<<<<<<<<<<<<
 *                 try:
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5359
 *                     elif e in tmpOpt:
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):             # <<<<<<<<<<<<<<
 *                 keepMatching = False
 * 
 */
    __pyx_t_5 = __Pyx_PyList_GET_SIZE(__pyx_v_failed); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5359, __pyx_L1_error)
    __pyx_t_16 = PyObject_Length(__pyx_v_tmpExprs); if (unlikely(__pyx_t_16 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5359, __pyx_L1_error)
    __pyx_t_9 = (__pyx_t_5 == __pyx_t_16);
    if (__pyx_t_9) {

      /* "cPyparsing.pyx":5360
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):
 *                 keepMatching = False             # <<<<<<<<<<<<<<
 * 
 *         if tmpReqd:
 */
      __pyx_v_keepMatching = 0;

      /* "cPyparsing.pyx":5359
 *                     elif e in tmpOpt:
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):             # <<<<<<<<<<<<<<
 *                 keepMatching = False
 * 
 */
    }
  }

  /* "cPyparsing.pyx":5362
 *                 keepMatching = False
 * 
 *         if tmpReqd:             # <<<<<<<<<<<<<<
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 */
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_tmpReqd); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 5362, __pyx_L1_error)
  if (unlikely(__pyx_t_9)) {

    /* "cPyparsing.pyx":5363
 * 
 *         if tmpReqd:
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 * 
 */
    __pyx_t_3 = __pyx_pf_10cPyparsing_4Each_9parseImpl_3genexpr(NULL, __pyx_v_tmpReqd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__3, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_missing = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5364
 *         if tmpReqd:
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)             # <<<<<<<<<<<<<<
 * 
 *         # add any unmatched Optionals, in case they have default values defined
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = PyUnicode_Format(__pyx_kp_u_Missing_one_or_more_required_ele, __pyx_v_missing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc, __pyx_t_8};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 3+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 5364, __pyx_L1_error)

    /* "cPyparsing.pyx":5362
 *                 keepMatching = False
 * 
 *         if tmpReqd:             # <<<<<<<<<<<<<<
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 */
  }

  /* "cPyparsing.pyx":5367
 * 
 *         # add any unmatched Optionals, in case they have default values defined
 *         matchOrder += [e for e in self.exprs if isinstance(e, Optional) and e.expr in tmpOpt]             # <<<<<<<<<<<<<<
 * 
 *         resultlist = []
 */
  { /* enter inner scope */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5367, __pyx_L71_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5367, __pyx_L71_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
      __pyx_t_8 = __pyx_t_4; __Pyx_INCREF(__pyx_t_8);
      __pyx_t_16 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_16 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5367, __pyx_L71_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5367, __pyx_L71_error)
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_8))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_8);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5367, __pyx_L71_error)
            #endif
            if (__pyx_t_16 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_16); __Pyx_INCREF(__pyx_t_4); __pyx_t_16++; if (unlikely((0 < 0))) __PYX_ERR(0, 5367, __pyx_L71_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_8, __pyx_t_16); __pyx_t_16++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5367, __pyx_L71_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_8);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5367, __pyx_L71_error)
            #endif
            if (__pyx_t_16 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_16); __Pyx_INCREF(__pyx_t_4); __pyx_t_16++; if (unlikely((0 < 0))) __PYX_ERR(0, 5367, __pyx_L71_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_8, __pyx_t_16); __pyx_t_16++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5367, __pyx_L71_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_6(__pyx_t_8);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 5367, __pyx_L71_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr50__pyx_v_e, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Optional); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5367, __pyx_L71_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyObject_IsInstance(__pyx_9genexpr50__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 5367, __pyx_L71_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {
      } else {
        __pyx_t_9 = __pyx_t_2;
        goto __pyx_L75_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr50__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5367, __pyx_L71_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_4, __pyx_v_tmpOpt, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5367, __pyx_L71_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = __pyx_t_2;
      __pyx_L75_bool_binop_done:;
      if (__pyx_t_9) {
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_9genexpr50__pyx_v_e))) __PYX_ERR(0, 5367, __pyx_L71_error)
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_9genexpr50__pyx_v_e); __pyx_9genexpr50__pyx_v_e = 0;
    goto __pyx_L78_exit_scope;
    __pyx_L71_error:;
    __Pyx_XDECREF(__pyx_9genexpr50__pyx_v_e); __pyx_9genexpr50__pyx_v_e = 0;
    goto __pyx_L1_error;
    __pyx_L78_exit_scope:;
  } /* exit inner scope */
  __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_v_matchOrder, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_matchOrder, ((PyObject*)__pyx_t_8));
  __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5369
 *         matchOrder += [e for e in self.exprs if isinstance(e, Optional) and e.expr in tmpOpt]
 * 
 *         resultlist = []             # <<<<<<<<<<<<<<
 *         for e in matchOrder:
 *             loc, results = e._parse(instring, loc, doActions)
 */
  __pyx_t_8 = PyList_New(0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_v_resultlist = ((PyObject*)__pyx_t_8);
  __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5370
 * 
 *         resultlist = []
 *         for e in matchOrder:             # <<<<<<<<<<<<<<
 *             loc, results = e._parse(instring, loc, doActions)
 *             resultlist.append(results)
 */
  __pyx_t_8 = __pyx_v_matchOrder; __Pyx_INCREF(__pyx_t_8);
  __pyx_t_16 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_8);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5370, __pyx_L1_error)
      #endif
      if (__pyx_t_16 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_16); __Pyx_INCREF(__pyx_t_3); __pyx_t_16++; if (unlikely((0 < 0))) __PYX_ERR(0, 5370, __pyx_L1_error)
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_8, __pyx_t_16); __pyx_t_16++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5371
 *         resultlist = []
 *         for e in matchOrder:
 *             loc, results = e._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *             resultlist.append(results)
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5371, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 3+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5371, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 5371, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5371, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5371, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_10 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5371, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_17 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10);
      index = 0; __pyx_t_4 = __pyx_t_17(__pyx_t_10); if (unlikely(!__pyx_t_4)) goto __pyx_L81_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_1 = __pyx_t_17(__pyx_t_10); if (unlikely(!__pyx_t_1)) goto __pyx_L81_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_17(__pyx_t_10), 2) < 0) __PYX_ERR(0, 5371, __pyx_L1_error)
      __pyx_t_17 = NULL;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L82_unpacking_done;
      __pyx_L81_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_17 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 5371, __pyx_L1_error)
      __pyx_L82_unpacking_done:;
    }
    __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_results, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5372
 *         for e in matchOrder:
 *             loc, results = e._parse(instring, loc, doActions)
 *             resultlist.append(results)             # <<<<<<<<<<<<<<
 * 
 *         finalResults = sum(resultlist, ParseResults([]))
 */
    __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_resultlist, __pyx_v_results); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 5372, __pyx_L1_error)

    /* "cPyparsing.pyx":5370
 * 
 *         resultlist = []
 *         for e in matchOrder:             # <<<<<<<<<<<<<<
 *             loc, results = e._parse(instring, loc, doActions)
 *             resultlist.append(results)
 */
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5374
 *             resultlist.append(results)
 * 
 *         finalResults = sum(resultlist, ParseResults([]))             # <<<<<<<<<<<<<<
 *         return loc, finalResults
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_1};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5374, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_resultlist);
  __Pyx_GIVEREF(__pyx_v_resultlist);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_resultlist)) __PYX_ERR(0, 5374, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_8)) __PYX_ERR(0, 5374, __pyx_L1_error);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_sum, __pyx_t_3, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_finalResults = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5375
 * 
 *         finalResults = sum(resultlist, ParseResults([]))
 *         return loc, finalResults             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_loc)) __PYX_ERR(0, 5375, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_finalResults);
  __Pyx_GIVEREF(__pyx_v_finalResults);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_finalResults)) __PYX_ERR(0, 5375, __pyx_L1_error);
  __pyx_r = __pyx_t_8;
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5328
 *         return self
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.Each.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_opt1);
  __Pyx_XDECREF(__pyx_v_opt2);
  __Pyx_XDECREF(__pyx_v_tmpLoc);
  __Pyx_XDECREF(__pyx_v_tmpReqd);
  __Pyx_XDECREF(__pyx_v_tmpOpt);
  __Pyx_XDECREF(__pyx_v_matchOrder);
  __Pyx_XDECREF(__pyx_v_tmpExprs);
  __Pyx_XDECREF(__pyx_v_failed);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_missing);
  __Pyx_XDECREF(__pyx_v_resultlist);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XDECREF(__pyx_v_finalResults);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_4Each_9parseImpl_2generator36);
  __Pyx_XDECREF(__pyx_9genexpr44__pyx_v_e);
  __Pyx_XDECREF(__pyx_9genexpr45__pyx_v_e);
  __Pyx_XDECREF(__pyx_9genexpr46__pyx_v_e);
  __Pyx_XDECREF(__pyx_9genexpr47__pyx_v_e);
  __Pyx_XDECREF(__pyx_9genexpr48__pyx_v_e);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_4Each_9parseImpl_5generator37);
  __Pyx_XDECREF(__pyx_9genexpr50__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5377
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Each_7__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Each_6__str__, "Each.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Each_7__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Each_7__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Each_6__str__};
static PyObject *__pyx_pw_10cPyparsing_4Each_7__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5377, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 5377, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5377, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Each.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Each_6__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Each_7__str___2generator38(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":5382
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_7__str___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_51_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5382, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Each_7__str___2generator38, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Each___str___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Each.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Each_7__str___2generator38(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5382, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 5382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 5382, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5382, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5382, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5382, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5382, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5382, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 5382, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5382, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5382, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5377
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_gb_10cPyparsing_4Each_7__str___2generator38 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":5378
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_name_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 5378, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5379
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":5378
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":5381
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5382
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_pf_10cPyparsing_4Each_7__str___genexpr(NULL, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__112, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__107, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_2, __pyx_kp_u__108); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_3) < 0) __PYX_ERR(0, 5382, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5381
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":5384
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5377
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Each.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_4Each_7__str___2generator38);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5386
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Each_9checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Each_8checkRecursion, "Each.checkRecursion(self, parseElementList)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Each_9checkRecursion = {"checkRecursion", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Each_9checkRecursion, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Each_8checkRecursion};
static PyObject *__pyx_pw_10cPyparsing_4Each_9checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5386, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseElementList)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5386, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 5386, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 5386, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5386, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Each.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Each_8checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Each_8checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkRecursion", 1);

  /* "cPyparsing.pyx":5387
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self)) __PYX_ERR(0, 5387, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_subRecCheckList = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5388
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5388, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5388, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 5388, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5388, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5388, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 5388, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5388, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5388, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5389
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5389, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5388
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5386
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Each.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5396
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_19ParseElementEnhance___init__, "ParseElementEnhance.__init__(self, expr, savelist=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_19ParseElementEnhance_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_19ParseElementEnhance___init__};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_savelist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_savelist,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5396, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5396, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 5396, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_savelist);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5396, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5396, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5396, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_savelist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_savelist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_expr);

  /* "cPyparsing.pyx":5397
 *     """
 *     def __init__(self, expr, savelist=False):
 *         super(ParseElementEnhance, self).__init__(savelist)             # <<<<<<<<<<<<<<
 *         if isinstance(expr, basestring):
 *             if issubclass(self._literalStringClass, Token):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5397, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5397, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5398
 *     def __init__(self, expr, savelist=False):
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):             # <<<<<<<<<<<<<<
 *             if issubclass(self._literalStringClass, Token):
 *                 expr = self._literalStringClass(expr)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_expr, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":5399
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 *             if issubclass(self._literalStringClass, Token):             # <<<<<<<<<<<<<<
 *                 expr = self._literalStringClass(expr)
 *             else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5399, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Token); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5399, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyObject_IsSubclass(__pyx_t_1, __pyx_t_3); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5399, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":5400
 *         if isinstance(expr, basestring):
 *             if issubclass(self._literalStringClass, Token):
 *                 expr = self._literalStringClass(expr)             # <<<<<<<<<<<<<<
 *             else:
 *                 expr = self._literalStringClass(Literal(expr))
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5400, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_expr};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5400, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":5399
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 *             if issubclass(self._literalStringClass, Token):             # <<<<<<<<<<<<<<
 *                 expr = self._literalStringClass(expr)
 *             else:
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":5402
 *                 expr = self._literalStringClass(expr)
 *             else:
 *                 expr = self._literalStringClass(Literal(expr))             # <<<<<<<<<<<<<<
 *         self.expr = expr
 *         self.strRepr = None
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5402, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_Literal); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5402, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_expr};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5402, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_t_6 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5402, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_3);
      __pyx_t_3 = 0;
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":5398
 *     def __init__(self, expr, savelist=False):
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):             # <<<<<<<<<<<<<<
 *             if issubclass(self._literalStringClass, Token):
 *                 expr = self._literalStringClass(expr)
 */
  }

  /* "cPyparsing.pyx":5403
 *             else:
 *                 expr = self._literalStringClass(Literal(expr))
 *         self.expr = expr             # <<<<<<<<<<<<<<
 *         self.strRepr = None
 *         if expr is not None:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_expr, __pyx_v_expr) < 0) __PYX_ERR(0, 5403, __pyx_L1_error)

  /* "cPyparsing.pyx":5404
 *                 expr = self._literalStringClass(Literal(expr))
 *         self.expr = expr
 *         self.strRepr = None             # <<<<<<<<<<<<<<
 *         if expr is not None:
 *             self.mayIndexError = expr.mayIndexError
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 5404, __pyx_L1_error)

  /* "cPyparsing.pyx":5405
 *         self.expr = expr
 *         self.strRepr = None
 *         if expr is not None:             # <<<<<<<<<<<<<<
 *             self.mayIndexError = expr.mayIndexError
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 */
  __pyx_t_5 = (__pyx_v_expr != Py_None);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":5406
 *         self.strRepr = None
 *         if expr is not None:
 *             self.mayIndexError = expr.mayIndexError             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 *             self.setWhitespaceChars(expr.whiteChars)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_3) < 0) __PYX_ERR(0, 5406, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5407
 *         if expr is not None:
 *             self.mayIndexError = expr.mayIndexError
 *             self.mayReturnEmpty = expr.mayReturnEmpty             # <<<<<<<<<<<<<<
 *             self.setWhitespaceChars(expr.whiteChars)
 *             self.skipWhitespace = expr.skipWhitespace
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_3) < 0) __PYX_ERR(0, 5407, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5408
 *             self.mayIndexError = expr.mayIndexError
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 *             self.setWhitespaceChars(expr.whiteChars)             # <<<<<<<<<<<<<<
 *             self.skipWhitespace = expr.skipWhitespace
 *             self.saveAsList = expr.saveAsList
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5408, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5409
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 *             self.setWhitespaceChars(expr.whiteChars)
 *             self.skipWhitespace = expr.skipWhitespace             # <<<<<<<<<<<<<<
 *             self.saveAsList = expr.saveAsList
 *             self.callPreparse = expr.callPreparse
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_skipWhitespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, __pyx_t_3) < 0) __PYX_ERR(0, 5409, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5410
 *             self.setWhitespaceChars(expr.whiteChars)
 *             self.skipWhitespace = expr.skipWhitespace
 *             self.saveAsList = expr.saveAsList             # <<<<<<<<<<<<<<
 *             self.callPreparse = expr.callPreparse
 *             self.ignoreExprs.extend(expr.ignoreExprs)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_3) < 0) __PYX_ERR(0, 5410, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5411
 *             self.skipWhitespace = expr.skipWhitespace
 *             self.saveAsList = expr.saveAsList
 *             self.callPreparse = expr.callPreparse             # <<<<<<<<<<<<<<
 *             self.ignoreExprs.extend(expr.ignoreExprs)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse, __pyx_t_3) < 0) __PYX_ERR(0, 5411, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5412
 *             self.saveAsList = expr.saveAsList
 *             self.callPreparse = expr.callPreparse
 *             self.ignoreExprs.extend(expr.ignoreExprs)             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_extend); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5412, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5405
 *         self.expr = expr
 *         self.strRepr = None
 *         if expr is not None:             # <<<<<<<<<<<<<<
 *             self.mayIndexError = expr.mayIndexError
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 */
  }

  /* "cPyparsing.pyx":5396
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5421
 *     #     else:
 *     #         return ParseException("", loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_19ParseElementEnhance_2parseImpl, "ParseElementEnhance.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_19ParseElementEnhance_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_19ParseElementEnhance_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5421, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5421, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 5421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5421, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 5421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5421, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5421, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 5421, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":5422
 *     #         return ParseException("", loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_2)) {

    /* "cPyparsing.pyx":5423
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException("", loc, self.errmsg, self)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_parse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_instring)) __PYX_ERR(0, 5423, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_loc);
    __Pyx_GIVEREF(__pyx_v_loc);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_loc)) __PYX_ERR(0, 5423, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_doActions);
    __Pyx_GIVEREF(__pyx_v_doActions);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_doActions)) __PYX_ERR(0, 5423, __pyx_L1_error);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 5423, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":5422
 *     #         return ParseException("", loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         else:
 */
  }

  /* "cPyparsing.pyx":5425
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         else:
 *             raise ParseException("", loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_kp_u__10, __pyx_v_loc, __pyx_t_1, __pyx_v_self};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 5425, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":5421
 *     #     else:
 *     #         return ParseException("", loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5428
 * 
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_5leaveWhitespace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_19ParseElementEnhance_4leaveWhitespace, "ParseElementEnhance.leaveWhitespace(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_5leaveWhitespace = {"leaveWhitespace", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_19ParseElementEnhance_5leaveWhitespace, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_19ParseElementEnhance_4leaveWhitespace};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_5leaveWhitespace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5428, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "leaveWhitespace") < 0)) __PYX_ERR(0, 5428, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("leaveWhitespace", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5428, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_4leaveWhitespace(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_4leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("leaveWhitespace", 1);

  /* "cPyparsing.pyx":5429
 * 
 *     def leaveWhitespace(self):
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         self.expr = self.expr.copy()
 *         if self.expr is not None:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 5429, __pyx_L1_error)

  /* "cPyparsing.pyx":5430
 *     def leaveWhitespace(self):
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.leaveWhitespace()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_expr, __pyx_t_1) < 0) __PYX_ERR(0, 5430, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5431
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.leaveWhitespace()
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":5432
 *         self.expr = self.expr.copy()
 *         if self.expr is not None:
 *             self.expr.leaveWhitespace()             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5432, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5431
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.leaveWhitespace()
 *         return self
 */
  }

  /* "cPyparsing.pyx":5433
 *         if self.expr is not None:
 *             self.expr.leaveWhitespace()
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def ignore(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5428
 * 
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5435
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_7ignore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_19ParseElementEnhance_6ignore, "ParseElementEnhance.ignore(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_7ignore = {"ignore", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_19ParseElementEnhance_7ignore, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_19ParseElementEnhance_6ignore};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_7ignore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ignore (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5435, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5435, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, 1); __PYX_ERR(0, 5435, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "ignore") < 0)) __PYX_ERR(0, 5435, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5435, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_6ignore(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_6ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ignore", 1);

  /* "cPyparsing.pyx":5436
 * 
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 5436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5437
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_other, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5437, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":5438
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)             # <<<<<<<<<<<<<<
 *                 if self.expr is not None:
 *                     self.expr.ignore(self.ignoreExprs[-1])
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(0, 5438, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self)) __PYX_ERR(0, 5438, __pyx_L1_error);
      __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ignore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5438, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":5439
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:             # <<<<<<<<<<<<<<
 *                     self.expr.ignore(self.ignoreExprs[-1])
 *         else:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5439, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = (__pyx_t_1 != Py_None);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":5440
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:
 *                     self.expr.ignore(self.ignoreExprs[-1])             # <<<<<<<<<<<<<<
 *         else:
 *             super(ParseElementEnhance, self).ignore(other)
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5440, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ignore); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5440, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5440, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_4, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5440, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_6};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5440, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":5439
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:             # <<<<<<<<<<<<<<
 *                     self.expr.ignore(self.ignoreExprs[-1])
 *         else:
 */
      }

      /* "cPyparsing.pyx":5437
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:
 */
    }

    /* "cPyparsing.pyx":5436
 * 
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5442
 *                     self.expr.ignore(self.ignoreExprs[-1])
 *         else:
 *             super(ParseElementEnhance, self).ignore(other)             # <<<<<<<<<<<<<<
 *             if self.expr is not None:
 *                 self.expr.ignore(self.ignoreExprs[-1])
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3)) __PYX_ERR(0, 5442, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 5442, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ignore); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5442, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5443
 *         else:
 *             super(ParseElementEnhance, self).ignore(other)
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.ignore(self.ignoreExprs[-1])
 *         return self
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":5444
 *             super(ParseElementEnhance, self).ignore(other)
 *             if self.expr is not None:
 *                 self.expr.ignore(self.ignoreExprs[-1])             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_ignore); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_6, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5444, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":5443
 *         else:
 *             super(ParseElementEnhance, self).ignore(other)
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.ignore(self.ignoreExprs[-1])
 *         return self
 */
    }
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":5445
 *             if self.expr is not None:
 *                 self.expr.ignore(self.ignoreExprs[-1])
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5435
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5447
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_9streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_19ParseElementEnhance_8streamline, "ParseElementEnhance.streamline(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_9streamline = {"streamline", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_19ParseElementEnhance_9streamline, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_19ParseElementEnhance_8streamline};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_9streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5447, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "streamline") < 0)) __PYX_ERR(0, 5447, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("streamline", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5447, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_8streamline(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_8streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("streamline", 1);

  /* "cPyparsing.pyx":5448
 * 
 *     def streamline(self):
 *         super(ParseElementEnhance, self).streamline()             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.streamline()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5448, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5448, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5449
 *     def streamline(self):
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.streamline()
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":5450
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 *             self.expr.streamline()             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_streamline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5449
 *     def streamline(self):
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.streamline()
 *         return self
 */
  }

  /* "cPyparsing.pyx":5451
 *         if self.expr is not None:
 *             self.expr.streamline()
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5447
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5453
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_11checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_19ParseElementEnhance_10checkRecursion, "ParseElementEnhance.checkRecursion(self, parseElementList)");
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_11checkRecursion = {"checkRecursion", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_19ParseElementEnhance_11checkRecursion, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_19ParseElementEnhance_10checkRecursion};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_11checkRecursion(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5453, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parseElementList)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5453, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 5453, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 5453, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5453, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_10checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_10checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkRecursion", 1);

  /* "cPyparsing.pyx":5454
 * 
 *     def checkRecursion(self, parseElementList):
 *         if self in parseElementList:             # <<<<<<<<<<<<<<
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_self, __pyx_v_parseElementList, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 5454, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "cPyparsing.pyx":5455
 *     def checkRecursion(self, parseElementList):
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         if self.expr is not None:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_RecursiveGrammarException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_self)) __PYX_ERR(0, 5455, __pyx_L1_error);
    __pyx_t_5 = PyNumber_Add(__pyx_v_parseElementList, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 5455, __pyx_L1_error)

    /* "cPyparsing.pyx":5454
 * 
 *     def checkRecursion(self, parseElementList):
 *         if self in parseElementList:             # <<<<<<<<<<<<<<
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]
 */
  }

  /* "cPyparsing.pyx":5456
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.checkRecursion(subRecCheckList)
 */
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_self)) __PYX_ERR(0, 5456, __pyx_L1_error);
  __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_subRecCheckList = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":5457
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = (__pyx_t_5 != Py_None);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5458
 *         subRecCheckList = parseElementList[:] + [self]
 *         if self.expr is not None:
 *             self.expr.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 * 
 *     def validate(self, validateTrace=None):
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5458, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5458, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_subRecCheckList};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5458, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":5457
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 */
  }

  /* "cPyparsing.pyx":5453
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5460
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         if validateTrace is None:
 *             validateTrace = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_13validate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_19ParseElementEnhance_12validate, "ParseElementEnhance.validate(self, validateTrace=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_13validate = {"validate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_19ParseElementEnhance_13validate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_19ParseElementEnhance_12validate};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_13validate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_validateTrace = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_validateTrace,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5460, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_validateTrace);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5460, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "validate") < 0)) __PYX_ERR(0, 5460, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_validateTrace = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("validate", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 5460, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_12validate(__pyx_self, __pyx_v_self, __pyx_v_validateTrace);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_12validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace) {
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("validate", 0);
  __Pyx_INCREF(__pyx_v_validateTrace);

  /* "cPyparsing.pyx":5461
 * 
 *     def validate(self, validateTrace=None):
 *         if validateTrace is None:             # <<<<<<<<<<<<<<
 *             validateTrace = []
 *         tmp = validateTrace[:] + [self]
 */
  __pyx_t_1 = (__pyx_v_validateTrace == Py_None);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5462
 *     def validate(self, validateTrace=None):
 *         if validateTrace is None:
 *             validateTrace = []             # <<<<<<<<<<<<<<
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:
 */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5462, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_validateTrace, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":5461
 * 
 *     def validate(self, validateTrace=None):
 *         if validateTrace is None:             # <<<<<<<<<<<<<<
 *             validateTrace = []
 *         tmp = validateTrace[:] + [self]
 */
  }

  /* "cPyparsing.pyx":5463
 *         if validateTrace is None:
 *             validateTrace = []
 *         tmp = validateTrace[:] + [self]             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.validate(tmp)
 */
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_validateTrace, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_self)) __PYX_ERR(0, 5463, __pyx_L1_error);
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_tmp = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":5464
 *             validateTrace = []
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.validate(tmp)
 *         self.checkRecursion([])
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = (__pyx_t_4 != Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5465
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:
 *             self.expr.validate(tmp)             # <<<<<<<<<<<<<<
 *         self.checkRecursion([])
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5465, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_validate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5465, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_tmp};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":5464
 *             validateTrace = []
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.validate(tmp)
 *         self.checkRecursion([])
 */
  }

  /* "cPyparsing.pyx":5466
 *         if self.expr is not None:
 *             self.expr.validate(tmp)
 *         self.checkRecursion([])             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":5460
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         if validateTrace is None:
 *             validateTrace = []
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_validateTrace);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5468
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_15__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_19ParseElementEnhance_14__str__, "ParseElementEnhance.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_15__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_19ParseElementEnhance_15__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_19ParseElementEnhance_14__str__};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_15__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5468, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 5468, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5468, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_14__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_14__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_UCS4 __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":5469
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseElementEnhance, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":5470
 *     def __str__(self):
 *         try:
 *             return super(ParseElementEnhance, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5470, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5470, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5)) __PYX_ERR(0, 5470, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 5470, __pyx_L3_error);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5470, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5470, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5470, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":5469
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseElementEnhance, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":5471
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":5469
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseElementEnhance, self).__str__()
 *         except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":5474
 *             pass
 * 
 *         if self.strRepr is None and self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.expr))
 *         return self.strRepr
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = (__pyx_t_4 != Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":5475
 * 
 *         if self.strRepr is None and self.expr is not None:
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.expr))             # <<<<<<<<<<<<<<
 *         return self.strRepr
 * 
 */
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_10 = 0;
    __pyx_t_11 = 127;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_11;
    __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u__104);
    __pyx_t_10 += 2;
    __Pyx_GIVEREF(__pyx_kp_u__104);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_kp_u__104);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_13 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_12};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5475, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_6), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_11;
    __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_kp_u__13);
    __pyx_t_10 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__13);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_kp_u__13);
    __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __pyx_t_10, __pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_5) < 0) __PYX_ERR(0, 5475, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":5474
 *             pass
 * 
 *         if self.strRepr is None and self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.expr))
 *         return self.strRepr
 */
  }

  /* "cPyparsing.pyx":5476
 *         if self.strRepr is None and self.expr is not None:
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.expr))
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5468
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5501
 *         [['shape', 'SQUARE'], ['color', 'BLACK'], ['posn', 'upper left']]
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10FollowedBy_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10FollowedBy___init__, "FollowedBy.__init__(self, expr)");
static PyMethodDef __pyx_mdef_10cPyparsing_10FollowedBy_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10FollowedBy_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10FollowedBy___init__};
static PyObject *__pyx_pw_10cPyparsing_10FollowedBy_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5501, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5501, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 5501, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5501, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5501, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.FollowedBy.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10FollowedBy___init__(__pyx_self, __pyx_v_self, __pyx_v_expr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10FollowedBy___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":5502
 *     """
 *     def __init__(self, expr):
 *         super(FollowedBy, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5502, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5502, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5503
 *     def __init__(self, expr):
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 5503, __pyx_L1_error)

  /* "cPyparsing.pyx":5501
 *         [['shape', 'SQUARE'], ['color', 'BLACK'], ['posn', 'upper left']]
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.FollowedBy.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5518
 * 
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # by using self._expr.parse and deleting the contents of the returned ParseResults list
 *         # we keep any named results that were defined in the FollowedBy expression
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10FollowedBy_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10FollowedBy_2parseImpl, "FollowedBy.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_10FollowedBy_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10FollowedBy_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10FollowedBy_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_10FollowedBy_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5518, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5518, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 5518, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5518, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 5518, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5518, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5518, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 5518, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.FollowedBy.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10FollowedBy_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10FollowedBy_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":5521
 *         # by using self._expr.parse and deleting the contents of the returned ParseResults list
 *         # we keep any named results that were defined in the FollowedBy expression
 *         _, ret = self.expr._parse(instring, loc, doActions=doActions)             # <<<<<<<<<<<<<<
 *         del ret[:]
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_v_instring);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_instring)) __PYX_ERR(0, 5521, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_loc)) __PYX_ERR(0, 5521, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_doActions, __pyx_v_doActions) < 0) __PYX_ERR(0, 5521, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 5521, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_1);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5521, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5521, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_2 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5521, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
    index = 0; __pyx_t_3 = __pyx_t_5(__pyx_t_2); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_1 = __pyx_t_5(__pyx_t_2); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_2), 2) < 0) __PYX_ERR(0, 5521, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 5521, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5522
 *         # we keep any named results that were defined in the FollowedBy expression
 *         _, ret = self.expr._parse(instring, loc, doActions=doActions)
 *         del ret[:]             # <<<<<<<<<<<<<<
 * 
 *         return loc, ret
 */
  if (__Pyx_PyObject_DelSlice(__pyx_v_ret, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1) < 0) __PYX_ERR(0, 5522, __pyx_L1_error)

  /* "cPyparsing.pyx":5524
 *         del ret[:]
 * 
 *         return loc, ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_loc)) __PYX_ERR(0, 5524, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_ret)) __PYX_ERR(0, 5524, __pyx_L1_error);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5518
 * 
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # by using self._expr.parse and deleting the contents of the returned ParseResults list
 *         # we keep any named results that were defined in the FollowedBy expression
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.FollowedBy.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5555
 * 
 *     """
 *     def __init__(self, expr, retreat=None):             # <<<<<<<<<<<<<<
 *         super(PrecededBy, self).__init__(expr)
 *         self.expr = self.expr().leaveWhitespace()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10PrecededBy_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10PrecededBy___init__, "PrecededBy.__init__(self, expr, retreat=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_10PrecededBy_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10PrecededBy_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10PrecededBy___init__};
static PyObject *__pyx_pw_10cPyparsing_10PrecededBy_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_retreat = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_retreat,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5555, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5555, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 5555, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_retreat);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5555, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5555, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_retreat = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5555, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.PrecededBy.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10PrecededBy___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_retreat);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5576
 *         self.errmsg = "not preceded by " + str(expr)
 *         self.skipWhitespace = False
 *         self.parseAction.append(lambda s, l, t: t.__delitem__(slice(None, None)))             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc=0, doActions=True):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10PrecededBy_8__init___lambda40(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10PrecededBy_8__init___lambda40 = {"lambda40", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10PrecededBy_8__init___lambda40, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10PrecededBy_8__init___lambda40(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda40 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5576, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5576, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda40", 1, 3, 3, 1); __PYX_ERR(0, 5576, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5576, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda40", 1, 3, 3, 2); __PYX_ERR(0, 5576, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda40") < 0)) __PYX_ERR(0, 5576, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda40", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 5576, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.PrecededBy.__init__.lambda40", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda40(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda40(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda40", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_delitem); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_slice__20};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5576, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.PrecededBy.__init__.lambda40", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5555
 * 
 *     """
 *     def __init__(self, expr, retreat=None):             # <<<<<<<<<<<<<<
 *         super(PrecededBy, self).__init__(expr)
 *         self.expr = self.expr().leaveWhitespace()
 */

static PyObject *__pyx_pf_10cPyparsing_10PrecededBy___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_retreat) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_retreat);

  /* "cPyparsing.pyx":5556
 *     """
 *     def __init__(self, expr, retreat=None):
 *         super(PrecededBy, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         self.expr = self.expr().leaveWhitespace()
 *         self.mayReturnEmpty = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PrecededBy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5556, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5556, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5557
 *     def __init__(self, expr, retreat=None):
 *         super(PrecededBy, self).__init__(expr)
 *         self.expr = self.expr().leaveWhitespace()             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_expr, __pyx_t_1) < 0) __PYX_ERR(0, 5557, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5558
 *         super(PrecededBy, self).__init__(expr)
 *         self.expr = self.expr().leaveWhitespace()
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.exact = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 5558, __pyx_L1_error)

  /* "cPyparsing.pyx":5559
 *         self.expr = self.expr().leaveWhitespace()
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.exact = False
 *         if isinstance(expr, str):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 5559, __pyx_L1_error)

  /* "cPyparsing.pyx":5560
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 *         self.exact = False             # <<<<<<<<<<<<<<
 *         if isinstance(expr, str):
 *             retreat = len(expr)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exact, Py_False) < 0) __PYX_ERR(0, 5560, __pyx_L1_error)

  /* "cPyparsing.pyx":5561
 *         self.mayIndexError = False
 *         self.exact = False
 *         if isinstance(expr, str):             # <<<<<<<<<<<<<<
 *             retreat = len(expr)
 *             self.exact = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_expr, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 5561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":5562
 *         self.exact = False
 *         if isinstance(expr, str):
 *             retreat = len(expr)             # <<<<<<<<<<<<<<
 *             self.exact = True
 *         elif isinstance(expr, (Literal, Keyword)):
 */
    __pyx_t_7 = PyObject_Length(__pyx_v_expr); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5562, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_retreat, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5563
 *         if isinstance(expr, str):
 *             retreat = len(expr)
 *             self.exact = True             # <<<<<<<<<<<<<<
 *         elif isinstance(expr, (Literal, Keyword)):
 *             retreat = expr.matchLen
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exact, Py_True) < 0) __PYX_ERR(0, 5563, __pyx_L1_error)

    /* "cPyparsing.pyx":5561
 *         self.mayIndexError = False
 *         self.exact = False
 *         if isinstance(expr, str):             # <<<<<<<<<<<<<<
 *             retreat = len(expr)
 *             self.exact = True
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5564
 *             retreat = len(expr)
 *             self.exact = True
 *         elif isinstance(expr, (Literal, Keyword)):             # <<<<<<<<<<<<<<
 *             retreat = expr.matchLen
 *             self.exact = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Literal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = PyObject_IsInstance(__pyx_v_expr, __pyx_t_1); 
  if (!__pyx_t_8) {
  } else {
    __pyx_t_6 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = PyObject_IsInstance(__pyx_v_expr, __pyx_t_2); 
  __pyx_t_6 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":5565
 *             self.exact = True
 *         elif isinstance(expr, (Literal, Keyword)):
 *             retreat = expr.matchLen             # <<<<<<<<<<<<<<
 *             self.exact = True
 *         elif isinstance(expr, (Word, CharsNotIn)) and expr.maxLen != _MAX_INT:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_retreat, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5566
 *         elif isinstance(expr, (Literal, Keyword)):
 *             retreat = expr.matchLen
 *             self.exact = True             # <<<<<<<<<<<<<<
 *         elif isinstance(expr, (Word, CharsNotIn)) and expr.maxLen != _MAX_INT:
 *             retreat = expr.maxLen
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exact, Py_True) < 0) __PYX_ERR(0, 5566, __pyx_L1_error)

    /* "cPyparsing.pyx":5564
 *             retreat = len(expr)
 *             self.exact = True
 *         elif isinstance(expr, (Literal, Keyword)):             # <<<<<<<<<<<<<<
 *             retreat = expr.matchLen
 *             self.exact = True
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5567
 *             retreat = expr.matchLen
 *             self.exact = True
 *         elif isinstance(expr, (Word, CharsNotIn)) and expr.maxLen != _MAX_INT:             # <<<<<<<<<<<<<<
 *             retreat = expr.maxLen
 *             self.exact = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Word); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyObject_IsInstance(__pyx_v_expr, __pyx_t_1); 
  if (!__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = PyObject_IsInstance(__pyx_v_expr, __pyx_t_2); 
  __pyx_t_8 = __pyx_t_9;
  __pyx_L8_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_6 = __pyx_t_8;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_maxLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __pyx_t_8;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":5568
 *             self.exact = True
 *         elif isinstance(expr, (Word, CharsNotIn)) and expr.maxLen != _MAX_INT:
 *             retreat = expr.maxLen             # <<<<<<<<<<<<<<
 *             self.exact = True
 *         elif isinstance(expr, _PositionToken):
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_maxLen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_retreat, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5569
 *         elif isinstance(expr, (Word, CharsNotIn)) and expr.maxLen != _MAX_INT:
 *             retreat = expr.maxLen
 *             self.exact = True             # <<<<<<<<<<<<<<
 *         elif isinstance(expr, _PositionToken):
 *             retreat = 0
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exact, Py_True) < 0) __PYX_ERR(0, 5569, __pyx_L1_error)

    /* "cPyparsing.pyx":5567
 *             retreat = expr.matchLen
 *             self.exact = True
 *         elif isinstance(expr, (Word, CharsNotIn)) and expr.maxLen != _MAX_INT:             # <<<<<<<<<<<<<<
 *             retreat = expr.maxLen
 *             self.exact = True
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5570
 *             retreat = expr.maxLen
 *             self.exact = True
 *         elif isinstance(expr, _PositionToken):             # <<<<<<<<<<<<<<
 *             retreat = 0
 *             self.exact = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PositionToken); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_expr, __pyx_t_3); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 5570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":5571
 *             self.exact = True
 *         elif isinstance(expr, _PositionToken):
 *             retreat = 0             # <<<<<<<<<<<<<<
 *             self.exact = True
 *         self.retreat = retreat
 */
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_DECREF_SET(__pyx_v_retreat, __pyx_int_0);

    /* "cPyparsing.pyx":5572
 *         elif isinstance(expr, _PositionToken):
 *             retreat = 0
 *             self.exact = True             # <<<<<<<<<<<<<<
 *         self.retreat = retreat
 *         self.errmsg = "not preceded by " + str(expr)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exact, Py_True) < 0) __PYX_ERR(0, 5572, __pyx_L1_error)

    /* "cPyparsing.pyx":5570
 *             retreat = expr.maxLen
 *             self.exact = True
 *         elif isinstance(expr, _PositionToken):             # <<<<<<<<<<<<<<
 *             retreat = 0
 *             self.exact = True
 */
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":5573
 *             retreat = 0
 *             self.exact = True
 *         self.retreat = retreat             # <<<<<<<<<<<<<<
 *         self.errmsg = "not preceded by " + str(expr)
 *         self.skipWhitespace = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_retreat, __pyx_v_retreat) < 0) __PYX_ERR(0, 5573, __pyx_L1_error)

  /* "cPyparsing.pyx":5574
 *             self.exact = True
 *         self.retreat = retreat
 *         self.errmsg = "not preceded by " + str(expr)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.parseAction.append(lambda s, l, t: t.__delitem__(slice(None, None)))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_expr};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_not_preceded_by, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 5574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5575
 *         self.retreat = retreat
 *         self.errmsg = "not preceded by " + str(expr)
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         self.parseAction.append(lambda s, l, t: t.__delitem__(slice(None, None)))
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 5575, __pyx_L1_error)

  /* "cPyparsing.pyx":5576
 *         self.errmsg = "not preceded by " + str(expr)
 *         self.skipWhitespace = False
 *         self.parseAction.append(lambda s, l, t: t.__delitem__(slice(None, None)))             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc=0, doActions=True):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10PrecededBy_8__init___lambda40, 0, __pyx_n_s_PrecededBy___init___locals_lambd, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_t_3); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 5576, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5555
 * 
 *     """
 *     def __init__(self, expr, retreat=None):             # <<<<<<<<<<<<<<
 *         super(PrecededBy, self).__init__(expr)
 *         self.expr = self.expr().leaveWhitespace()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.PrecededBy.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_retreat);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5578
 *         self.parseAction.append(lambda s, l, t: t.__delitem__(slice(None, None)))
 * 
 *     def parseImpl(self, instring, loc=0, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.exact:
 *             if loc < self.retreat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10PrecededBy_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10PrecededBy_2parseImpl, "PrecededBy.parseImpl(self, instring, loc=0, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_10PrecededBy_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10PrecededBy_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10PrecededBy_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_10PrecededBy_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_0)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5578, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5578, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 2, 4, 1); __PYX_ERR(0, 5578, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5578, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5578, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5578, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 5578, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.PrecededBy.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10PrecededBy_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10PrecededBy_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_start = NULL;
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_test_expr = NULL;
  PyObject *__pyx_v_instring_slice = NULL;
  PyObject *__pyx_v_last_expr = NULL;
  PyObject *__pyx_v_offset = NULL;
  PyObject *__pyx_v_pbe = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  long __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  Py_ssize_t __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":5579
 * 
 *     def parseImpl(self, instring, loc=0, doActions=True):
 *         if self.exact:             # <<<<<<<<<<<<<<
 *             if loc < self.retreat:
 *                 raise ParseException(instring, loc, self.errmsg)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exact); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5579, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5580
 *     def parseImpl(self, instring, loc=0, doActions=True):
 *         if self.exact:
 *             if loc < self.retreat:             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg)
 *             start = loc - self.retreat
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_retreat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_loc, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5580, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5580, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__pyx_t_2)) {

      /* "cPyparsing.pyx":5581
 *         if self.exact:
 *             if loc < self.retreat:
 *                 raise ParseException(instring, loc, self.errmsg)             # <<<<<<<<<<<<<<
 *             start = loc - self.retreat
 *             _, ret = self.expr._parse(instring, start)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5581, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 5581, __pyx_L1_error)

      /* "cPyparsing.pyx":5580
 *     def parseImpl(self, instring, loc=0, doActions=True):
 *         if self.exact:
 *             if loc < self.retreat:             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg)
 *             start = loc - self.retreat
 */
    }

    /* "cPyparsing.pyx":5582
 *             if loc < self.retreat:
 *                 raise ParseException(instring, loc, self.errmsg)
 *             start = loc - self.retreat             # <<<<<<<<<<<<<<
 *             _, ret = self.expr._parse(instring, start)
 *         else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_retreat); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyNumber_Subtract(__pyx_v_loc, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_start = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5583
 *                 raise ParseException(instring, loc, self.errmsg)
 *             start = loc - self.retreat
 *             _, ret = self.expr._parse(instring, start)             # <<<<<<<<<<<<<<
 *         else:
 *             # retreat specified a maximum lookbehind window, iterate
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_parse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_start};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 5583, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
      index = 0; __pyx_t_4 = __pyx_t_7(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_3 = __pyx_t_7(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_5), 2) < 0) __PYX_ERR(0, 5583, __pyx_L1_error)
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 5583, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __pyx_v__ = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_ret = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5579
 * 
 *     def parseImpl(self, instring, loc=0, doActions=True):
 *         if self.exact:             # <<<<<<<<<<<<<<
 *             if loc < self.retreat:
 *                 raise ParseException(instring, loc, self.errmsg)
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5586
 *         else:
 *             # retreat specified a maximum lookbehind window, iterate
 *             test_expr = self.expr + StringEnd()             # <<<<<<<<<<<<<<
 *             instring_slice = instring[max(0, loc - self.retreat):loc]
 *             last_expr = ParseException(instring, loc, self.errmsg)
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5586, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_StringEnd); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5586, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5586, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_test_expr = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":5587
 *             # retreat specified a maximum lookbehind window, iterate
 *             test_expr = self.expr + StringEnd()
 *             instring_slice = instring[max(0, loc - self.retreat):loc]             # <<<<<<<<<<<<<<
 *             last_expr = ParseException(instring, loc, self.errmsg)
 *             for offset in range(1, min(loc, self.retreat + 1)+1):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_retreat); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Subtract(__pyx_v_loc, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = 0;
    __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5587, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5587, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_2) {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_5 = __Pyx_PyInt_From_long(__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5587, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __pyx_t_5;
      __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_t_4, &__pyx_v_loc, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_instring_slice = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5588
 *             test_expr = self.expr + StringEnd()
 *             instring_slice = instring[max(0, loc - self.retreat):loc]
 *             last_expr = ParseException(instring, loc, self.errmsg)             # <<<<<<<<<<<<<<
 *             for offset in range(1, min(loc, self.retreat + 1)+1):
 *                 try:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5588, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5588, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5588, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_last_expr = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5589
 *             instring_slice = instring[max(0, loc - self.retreat):loc]
 *             last_expr = ParseException(instring, loc, self.errmsg)
 *             for offset in range(1, min(loc, self.retreat + 1)+1):             # <<<<<<<<<<<<<<
 *                 try:
 *                     # print('trying', offset, instring_slice, repr(instring_slice[loc - offset:]))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_range); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_retreat); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_5, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_v_loc);
    __pyx_t_5 = __pyx_v_loc;
    __pyx_t_10 = PyObject_RichCompare(__pyx_t_1, __pyx_t_5, Py_LT); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5589, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 5589, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__pyx_t_2) {
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_9 = __pyx_t_1;
    } else {
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_9 = __pyx_t_5;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_9, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_int_1, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5589, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4);
      __pyx_t_11 = 0;
      __pyx_t_12 = NULL;
    } else {
      __pyx_t_11 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5589, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5589, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_12)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5589, __pyx_L1_error)
            #endif
            if (__pyx_t_11 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_11); __Pyx_INCREF(__pyx_t_3); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 5589, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5589, __pyx_L1_error)
            #endif
            if (__pyx_t_11 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_11); __Pyx_INCREF(__pyx_t_3); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 5589, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_12(__pyx_t_4);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 5589, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_offset, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":5590
 *             last_expr = ParseException(instring, loc, self.errmsg)
 *             for offset in range(1, min(loc, self.retreat + 1)+1):
 *                 try:             # <<<<<<<<<<<<<<
 *                     # print('trying', offset, instring_slice, repr(instring_slice[loc - offset:]))
 *                     _, ret = test_expr._parse(instring_slice, len(instring_slice) - offset)
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_15);
        /*try:*/ {

          /* "cPyparsing.pyx":5592
 *                 try:
 *                     # print('trying', offset, instring_slice, repr(instring_slice[loc - offset:]))
 *                     _, ret = test_expr._parse(instring_slice, len(instring_slice) - offset)             # <<<<<<<<<<<<<<
 *                 except ParseBaseException as pbe:
 *                     last_expr = pbe
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_test_expr, __pyx_n_s_parse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5592, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_16 = PyObject_Length(__pyx_v_instring_slice); if (unlikely(__pyx_t_16 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5592, __pyx_L9_error)
          __pyx_t_9 = PyInt_FromSsize_t(__pyx_t_16); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5592, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_5 = PyNumber_Subtract(__pyx_t_9, __pyx_v_offset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5592, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = NULL;
          __pyx_t_6 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_6 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_v_instring_slice, __pyx_t_5};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5592, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
            PyObject* sequence = __pyx_t_3;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 5592, __pyx_L9_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_5);
            #else
            __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5592, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5592, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_9 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5592, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
            index = 0; __pyx_t_1 = __pyx_t_7(__pyx_t_9); if (unlikely(!__pyx_t_1)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_1);
            index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_9); if (unlikely(!__pyx_t_5)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_5);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_9), 2) < 0) __PYX_ERR(0, 5592, __pyx_L9_error)
            __pyx_t_7 = NULL;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            goto __pyx_L18_unpacking_done;
            __pyx_L17_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_7 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 5592, __pyx_L9_error)
            __pyx_L18_unpacking_done:;
          }
          __Pyx_XDECREF_SET(__pyx_v__, __pyx_t_1);
          __pyx_t_1 = 0;
          __Pyx_XDECREF_SET(__pyx_v_ret, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "cPyparsing.pyx":5590
 *             last_expr = ParseException(instring, loc, self.errmsg)
 *             for offset in range(1, min(loc, self.retreat + 1)+1):
 *                 try:             # <<<<<<<<<<<<<<
 *                     # print('trying', offset, instring_slice, repr(instring_slice[loc - offset:]))
 *                     _, ret = test_expr._parse(instring_slice, len(instring_slice) - offset)
 */
        }

        /* "cPyparsing.pyx":5596
 *                     last_expr = pbe
 *                 else:
 *                     break             # <<<<<<<<<<<<<<
 *             else:
 *                 raise last_expr
 */
        /*else:*/ {
          goto __pyx_L14_try_break;
        }
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "cPyparsing.pyx":5593
 *                     # print('trying', offset, instring_slice, repr(instring_slice[loc - offset:]))
 *                     _, ret = test_expr._parse(instring_slice, len(instring_slice) - offset)
 *                 except ParseBaseException as pbe:             # <<<<<<<<<<<<<<
 *                     last_expr = pbe
 *                 else:
 */
        __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_5, &__pyx_t_1);
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5593, __pyx_L11_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_6 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_3, __pyx_t_9);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_ErrRestore(__pyx_t_3, __pyx_t_5, __pyx_t_1);
        __pyx_t_3 = 0; __pyx_t_5 = 0; __pyx_t_1 = 0;
        if (__pyx_t_6) {
          __Pyx_AddTraceback("cPyparsing.PrecededBy.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_5, &__pyx_t_3) < 0) __PYX_ERR(0, 5593, __pyx_L11_except_error)
          __Pyx_XGOTREF(__pyx_t_1);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __pyx_v_pbe = __pyx_t_5;
          /*try:*/ {

            /* "cPyparsing.pyx":5594
 *                     _, ret = test_expr._parse(instring_slice, len(instring_slice) - offset)
 *                 except ParseBaseException as pbe:
 *                     last_expr = pbe             # <<<<<<<<<<<<<<
 *                 else:
 *                     break
 */
            __Pyx_INCREF(__pyx_v_pbe);
            __Pyx_DECREF_SET(__pyx_v_last_expr, __pyx_v_pbe);
          }

          /* "cPyparsing.pyx":5593
 *                     # print('trying', offset, instring_slice, repr(instring_slice[loc - offset:]))
 *                     _, ret = test_expr._parse(instring_slice, len(instring_slice) - offset)
 *                 except ParseBaseException as pbe:             # <<<<<<<<<<<<<<
 *                     last_expr = pbe
 *                 else:
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_pbe); __pyx_v_pbe = 0;
              goto __pyx_L25;
            }
            __pyx_L25:;
          }
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L10_exception_handled;
        }
        goto __pyx_L11_except_error;

        /* "cPyparsing.pyx":5590
 *             last_expr = ParseException(instring, loc, self.errmsg)
 *             for offset in range(1, min(loc, self.retreat + 1)+1):
 *                 try:             # <<<<<<<<<<<<<<
 *                     # print('trying', offset, instring_slice, repr(instring_slice[loc - offset:]))
 *                     _, ret = test_expr._parse(instring_slice, len(instring_slice) - offset)
 */
        __pyx_L11_except_error:;
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
        goto __pyx_L1_error;
        __pyx_L14_try_break:;
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
        goto __pyx_L8_break;
        __pyx_L10_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }

      /* "cPyparsing.pyx":5589
 *             instring_slice = instring[max(0, loc - self.retreat):loc]
 *             last_expr = ParseException(instring, loc, self.errmsg)
 *             for offset in range(1, min(loc, self.retreat + 1)+1):             # <<<<<<<<<<<<<<
 *                 try:
 *                     # print('trying', offset, instring_slice, repr(instring_slice[loc - offset:]))
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L26_for_else;
    __pyx_L8_break:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L27_for_end;
    /*else*/ {
      __pyx_L26_for_else:;

      /* "cPyparsing.pyx":5598
 *                     break
 *             else:
 *                 raise last_expr             # <<<<<<<<<<<<<<
 *         return loc, ret
 * 
 */
      __Pyx_Raise(__pyx_v_last_expr, 0, 0, 0);
      __PYX_ERR(0, 5598, __pyx_L1_error)
    }
    __pyx_L27_for_end:;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":5599
 *             else:
 *                 raise last_expr
 *         return loc, ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_loc)) __PYX_ERR(0, 5599, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_ret)) __PYX_ERR(0, 5599, __pyx_L1_error);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5578
 *         self.parseAction.append(lambda s, l, t: t.__delitem__(slice(None, None)))
 * 
 *     def parseImpl(self, instring, loc=0, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.exact:
 *             if loc < self.retreat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.PrecededBy.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_test_expr);
  __Pyx_XDECREF(__pyx_v_instring_slice);
  __Pyx_XDECREF(__pyx_v_last_expr);
  __Pyx_XDECREF(__pyx_v_offset);
  __Pyx_XDECREF(__pyx_v_pbe);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5625
 *         integer = Word(nums) + ~Char(".")
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(NotAny, self).__init__(expr)
 *         # ~ self.leaveWhitespace()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6NotAny_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_6NotAny___init__, "NotAny.__init__(self, expr)");
static PyMethodDef __pyx_mdef_10cPyparsing_6NotAny_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_6NotAny_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_6NotAny___init__};
static PyObject *__pyx_pw_10cPyparsing_6NotAny_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5625, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5625, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 5625, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5625, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5625, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.NotAny.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6NotAny___init__(__pyx_self, __pyx_v_self, __pyx_v_expr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6NotAny___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":5626
 *     """
 *     def __init__(self, expr):
 *         super(NotAny, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         # ~ self.leaveWhitespace()
 *         self.skipWhitespace = False  # do NOT use self.leaveWhitespace(), don't want to propagate to exprs
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_NotAny); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5626, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5626, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5628
 *         super(NotAny, self).__init__(expr)
 *         # ~ self.leaveWhitespace()
 *         self.skipWhitespace = False  # do NOT use self.leaveWhitespace(), don't want to propagate to exprs             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 5628, __pyx_L1_error)

  /* "cPyparsing.pyx":5629
 *         # ~ self.leaveWhitespace()
 *         self.skipWhitespace = False  # do NOT use self.leaveWhitespace(), don't want to propagate to exprs
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 5629, __pyx_L1_error)

  /* "cPyparsing.pyx":5630
 *         self.skipWhitespace = False  # do NOT use self.leaveWhitespace(), don't want to propagate to exprs
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_Found_unwanted_token, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 5630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5625
 *         integer = Word(nums) + ~Char(".")
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(NotAny, self).__init__(expr)
 *         # ~ self.leaveWhitespace()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.NotAny.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5638
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6NotAny_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_6NotAny_2parseImpl, "NotAny.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_6NotAny_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_6NotAny_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_6NotAny_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_6NotAny_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5638, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5638, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 5638, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5638, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 5638, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5638, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5638, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 5638, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.NotAny.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6NotAny_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6NotAny_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":5639
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.expr.canParseNext(instring, loc):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_canParseNext); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_instring, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5639, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_5)) {

    /* "cPyparsing.pyx":5640
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_loc, __pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 5640, __pyx_L1_error)

    /* "cPyparsing.pyx":5639
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if self.expr.canParseNext(instring, loc):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
  }

  /* "cPyparsing.pyx":5641
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_loc)) __PYX_ERR(0, 5641, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(0, 5641, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5638
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.NotAny.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5643
 *         return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6NotAny_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_6NotAny_4__str__, "NotAny.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_6NotAny_5__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_6NotAny_5__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_6NotAny_4__str__};
static PyObject *__pyx_pw_10cPyparsing_6NotAny_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5643, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 5643, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5643, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.NotAny.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6NotAny_4__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6NotAny_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":5644
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_name_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 5644, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5645
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5645, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":5644
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":5647
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "~{" + _ustr(self.expr) + "}"
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5648
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "~{" + _ustr(self.expr) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5648, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_kp_u__113, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__108); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_2) < 0) __PYX_ERR(0, 5648, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":5647
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "~{" + _ustr(self.expr) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":5650
 *             self.strRepr = "~{" + _ustr(self.expr) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * class _MultipleMatch(ParseElementEnhance):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5643
 *         return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.NotAny.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5653
 * 
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_14_MultipleMatch___init__, "_MultipleMatch.__init__(self, expr, stopOn=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_14_MultipleMatch_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_14_MultipleMatch_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_14_MultipleMatch___init__};
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_stopOn = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_stopOn,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5653, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5653, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 5653, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_stopOn);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5653, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5653, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_stopOn = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5653, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14_MultipleMatch___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_stopOn);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_stopOn) {
  PyObject *__pyx_v_ender = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":5654
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):
 *         super(_MultipleMatch, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         self.saveAsList = True
 *         ender = stopOn
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MultipleMatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5654, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5654, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5655
 *     def __init__(self, expr, stopOn=None):
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True             # <<<<<<<<<<<<<<
 *         ender = stopOn
 *         if isinstance(ender, basestring):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_True) < 0) __PYX_ERR(0, 5655, __pyx_L1_error)

  /* "cPyparsing.pyx":5656
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 *         ender = stopOn             # <<<<<<<<<<<<<<
 *         if isinstance(ender, basestring):
 *             ender = self._literalStringClass(ender)
 */
  __Pyx_INCREF(__pyx_v_stopOn);
  __pyx_v_ender = __pyx_v_stopOn;

  /* "cPyparsing.pyx":5657
 *         self.saveAsList = True
 *         ender = stopOn
 *         if isinstance(ender, basestring):             # <<<<<<<<<<<<<<
 *             ender = self._literalStringClass(ender)
 *         self.stopOn(ender)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_ender, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5657, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":5658
 *         ender = stopOn
 *         if isinstance(ender, basestring):
 *             ender = self._literalStringClass(ender)             # <<<<<<<<<<<<<<
 *         self.stopOn(ender)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_ender};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5658, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_ender, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5657
 *         self.saveAsList = True
 *         ender = stopOn
 *         if isinstance(ender, basestring):             # <<<<<<<<<<<<<<
 *             ender = self._literalStringClass(ender)
 *         self.stopOn(ender)
 */
  }

  /* "cPyparsing.pyx":5659
 *         if isinstance(ender, basestring):
 *             ender = self._literalStringClass(ender)
 *         self.stopOn(ender)             # <<<<<<<<<<<<<<
 * 
 *     def stopOn(self, ender):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stopOn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_ender};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5653
 * 
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ender);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5661
 *         self.stopOn(ender)
 * 
 *     def stopOn(self, ender):             # <<<<<<<<<<<<<<
 *         if isinstance(ender, basestring):
 *             ender = self._literalStringClass(ender)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_3stopOn(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_14_MultipleMatch_2stopOn, "_MultipleMatch.stopOn(self, ender)");
static PyMethodDef __pyx_mdef_10cPyparsing_14_MultipleMatch_3stopOn = {"stopOn", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_14_MultipleMatch_3stopOn, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_14_MultipleMatch_2stopOn};
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_3stopOn(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_ender = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stopOn (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_ender,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5661, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ender)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5661, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("stopOn", 1, 2, 2, 1); __PYX_ERR(0, 5661, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stopOn") < 0)) __PYX_ERR(0, 5661, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_ender = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stopOn", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5661, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.stopOn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14_MultipleMatch_2stopOn(__pyx_self, __pyx_v_self, __pyx_v_ender);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch_2stopOn(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ender) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stopOn", 0);
  __Pyx_INCREF(__pyx_v_ender);

  /* "cPyparsing.pyx":5662
 * 
 *     def stopOn(self, ender):
 *         if isinstance(ender, basestring):             # <<<<<<<<<<<<<<
 *             ender = self._literalStringClass(ender)
 *         self.not_ender = ~ender if ender is not None else None
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_ender, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 5662, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5663
 *     def stopOn(self, ender):
 *         if isinstance(ender, basestring):
 *             ender = self._literalStringClass(ender)             # <<<<<<<<<<<<<<
 *         self.not_ender = ~ender if ender is not None else None
 *         return self
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5663, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_ender};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5663, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_ender, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5662
 * 
 *     def stopOn(self, ender):
 *         if isinstance(ender, basestring):             # <<<<<<<<<<<<<<
 *             ender = self._literalStringClass(ender)
 *         self.not_ender = ~ender if ender is not None else None
 */
  }

  /* "cPyparsing.pyx":5664
 *         if isinstance(ender, basestring):
 *             ender = self._literalStringClass(ender)
 *         self.not_ender = ~ender if ender is not None else None             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_2 = (__pyx_v_ender != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = PyNumber_Invert(__pyx_v_ender); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_not_ender, __pyx_t_1) < 0) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5665
 *             ender = self._literalStringClass(ender)
 *         self.not_ender = ~ender if ender is not None else None
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5661
 *         self.stopOn(ender)
 * 
 *     def stopOn(self, ender):             # <<<<<<<<<<<<<<
 *         if isinstance(ender, basestring):
 *             ender = self._literalStringClass(ender)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.stopOn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ender);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5720
 * 
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_14_MultipleMatch_4parseImpl, "_MultipleMatch.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_14_MultipleMatch_5parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_14_MultipleMatch_5parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_14_MultipleMatch_4parseImpl};
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_5parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5720, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5720, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 5720, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5720, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 5720, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5720, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5720, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 5720, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14_MultipleMatch_4parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_self_expr_parse = NULL;
  PyObject *__pyx_v_self_skip_ignorables = NULL;
  PyObject *__pyx_v_check_ender = NULL;
  PyObject *__pyx_v_try_not_ender = NULL;
  PyObject *__pyx_v_tokens = NULL;
  int __pyx_v_hasIgnoreExprs;
  PyObject *__pyx_v_preloc = NULL;
  PyObject *__pyx_v_tmptokens = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":5721
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):
 *         self_expr_parse = self.expr._parse             # <<<<<<<<<<<<<<
 *         self_skip_ignorables = self._skipIgnorables
 *         check_ender = self.not_ender is not None
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self_expr_parse = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5722
 *     def parseImpl(self, instring, loc, doActions=True):
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables             # <<<<<<<<<<<<<<
 *         check_ender = self.not_ender is not None
 *         if check_ender:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_skipIgnorables); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_self_skip_ignorables = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5723
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 *         check_ender = self.not_ender is not None             # <<<<<<<<<<<<<<
 *         if check_ender:
 *             try_not_ender = self.not_ender.tryParse
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_not_ender); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_check_ender = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5724
 *         self_skip_ignorables = self._skipIgnorables
 *         check_ender = self.not_ender is not None
 *         if check_ender:             # <<<<<<<<<<<<<<
 *             try_not_ender = self.not_ender.tryParse
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_check_ender); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5724, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":5725
 *         check_ender = self.not_ender is not None
 *         if check_ender:
 *             try_not_ender = self.not_ender.tryParse             # <<<<<<<<<<<<<<
 * 
 *         # must be at least one (but first see if we are the stopOn sentinel;
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_not_ender); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5725, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5725, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_try_not_ender = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5724
 *         self_skip_ignorables = self._skipIgnorables
 *         check_ender = self.not_ender is not None
 *         if check_ender:             # <<<<<<<<<<<<<<
 *             try_not_ender = self.not_ender.tryParse
 * 
 */
  }

  /* "cPyparsing.pyx":5729
 *         # must be at least one (but first see if we are the stopOn sentinel;
 *         # if so, fail)
 *         if check_ender:             # <<<<<<<<<<<<<<
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_check_ender); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5729, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":5730
 *         # if so, fail)
 *         if check_ender:
 *             try_not_ender(instring, loc)             # <<<<<<<<<<<<<<
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:
 */
    if (unlikely(!__pyx_v_try_not_ender)) { __Pyx_RaiseUnboundLocalError("try_not_ender"); __PYX_ERR(0, 5730, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_v_try_not_ender);
    __pyx_t_2 = __pyx_v_try_not_ender; __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_instring, __pyx_v_loc};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5730, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5729
 *         # must be at least one (but first see if we are the stopOn sentinel;
 *         # if so, fail)
 *         if check_ender:             # <<<<<<<<<<<<<<
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 */
  }

  /* "cPyparsing.pyx":5731
 *         if check_ender:
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *         try:
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_v_instring);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_instring)) __PYX_ERR(0, 5731, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_loc)) __PYX_ERR(0, 5731, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_doActions);
  __Pyx_GIVEREF(__pyx_v_doActions);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_doActions)) __PYX_ERR(0, 5731, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 5731, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_self_expr_parse, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 5731, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_1);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
    index = 0; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L5_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_1 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_1)) goto __pyx_L5_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 5731, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L6_unpacking_done;
    __pyx_L5_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 5731, __pyx_L1_error)
    __pyx_L6_unpacking_done:;
  }
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_v_tokens = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5732
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:             # <<<<<<<<<<<<<<
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while 1:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "cPyparsing.pyx":5733
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:
 *             hasIgnoreExprs = (not not self.ignoreExprs)             # <<<<<<<<<<<<<<
 *             while 1:
 *                 if check_ender:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5733, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5733, __pyx_L7_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_hasIgnoreExprs = (!(!__pyx_t_3));

      /* "cPyparsing.pyx":5734
 *         try:
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while 1:             # <<<<<<<<<<<<<<
 *                 if check_ender:
 *                     try_not_ender(instring, loc)
 */
      while (1) {

        /* "cPyparsing.pyx":5735
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while 1:
 *                 if check_ender:             # <<<<<<<<<<<<<<
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:
 */
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_check_ender); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5735, __pyx_L7_error)
        if (__pyx_t_3) {

          /* "cPyparsing.pyx":5736
 *             while 1:
 *                 if check_ender:
 *                     try_not_ender(instring, loc)             # <<<<<<<<<<<<<<
 *                 if hasIgnoreExprs:
 *                     preloc = self_skip_ignorables(instring, loc)
 */
          if (unlikely(!__pyx_v_try_not_ender)) { __Pyx_RaiseUnboundLocalError("try_not_ender"); __PYX_ERR(0, 5736, __pyx_L7_error) }
          __Pyx_INCREF(__pyx_v_try_not_ender);
          __pyx_t_1 = __pyx_v_try_not_ender; __pyx_t_2 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_instring, __pyx_v_loc};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5736, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "cPyparsing.pyx":5735
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while 1:
 *                 if check_ender:             # <<<<<<<<<<<<<<
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:
 */
        }

        /* "cPyparsing.pyx":5737
 *                 if check_ender:
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:             # <<<<<<<<<<<<<<
 *                     preloc = self_skip_ignorables(instring, loc)
 *                 else:
 */
        if (__pyx_v_hasIgnoreExprs) {

          /* "cPyparsing.pyx":5738
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:
 *                     preloc = self_skip_ignorables(instring, loc)             # <<<<<<<<<<<<<<
 *                 else:
 *                     preloc = loc
 */
          __Pyx_INCREF(__pyx_v_self_skip_ignorables);
          __pyx_t_1 = __pyx_v_self_skip_ignorables; __pyx_t_2 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_instring, __pyx_v_loc};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5738, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_XDECREF_SET(__pyx_v_preloc, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":5737
 *                 if check_ender:
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:             # <<<<<<<<<<<<<<
 *                     preloc = self_skip_ignorables(instring, loc)
 *                 else:
 */
          goto __pyx_L16;
        }

        /* "cPyparsing.pyx":5740
 *                     preloc = self_skip_ignorables(instring, loc)
 *                 else:
 *                     preloc = loc             # <<<<<<<<<<<<<<
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)
 *                 if tmptokens or tmptokens.haskeys():
 */
        /*else*/ {
          __Pyx_INCREF(__pyx_v_loc);
          __Pyx_XDECREF_SET(__pyx_v_preloc, __pyx_v_loc);
        }
        __pyx_L16:;

        /* "cPyparsing.pyx":5741
 *                 else:
 *                     preloc = loc
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                 if tmptokens or tmptokens.haskeys():
 *                     tokens += tmptokens
 */
        __Pyx_INCREF(__pyx_v_self_expr_parse);
        __pyx_t_1 = __pyx_v_self_expr_parse; __pyx_t_2 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 3+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5741, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 5741, __pyx_L7_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          #else
          __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5741, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5741, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_6 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5741, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
          index = 0; __pyx_t_1 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_1)) goto __pyx_L17_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          index = 1; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L17_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_2);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 5741, __pyx_L7_error)
          __pyx_t_7 = NULL;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L18_unpacking_done;
          __pyx_L17_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_7 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 5741, __pyx_L7_error)
          __pyx_L18_unpacking_done:;
        }
        __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_tmptokens, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "cPyparsing.pyx":5742
 *                     preloc = loc
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)
 *                 if tmptokens or tmptokens.haskeys():             # <<<<<<<<<<<<<<
 *                     tokens += tmptokens
 *         except (ParseException, IndexError):
 */
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_tmptokens); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 5742, __pyx_L7_error)
        if (!__pyx_t_11) {
        } else {
          __pyx_t_3 = __pyx_t_11;
          goto __pyx_L20_bool_binop_done;
        }
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmptokens, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5742, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5742, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 5742, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_3 = __pyx_t_11;
        __pyx_L20_bool_binop_done:;
        if (__pyx_t_3) {

          /* "cPyparsing.pyx":5743
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)
 *                 if tmptokens or tmptokens.haskeys():
 *                     tokens += tmptokens             # <<<<<<<<<<<<<<
 *         except (ParseException, IndexError):
 *             pass
 */
          __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_tokens, __pyx_v_tmptokens); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5743, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":5742
 *                     preloc = loc
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)
 *                 if tmptokens or tmptokens.haskeys():             # <<<<<<<<<<<<<<
 *                     tokens += tmptokens
 *         except (ParseException, IndexError):
 */
        }
      }

      /* "cPyparsing.pyx":5732
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:             # <<<<<<<<<<<<<<
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while 1:
 */
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L12_try_end;
    __pyx_L7_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":5744
 *                 if tmptokens or tmptokens.haskeys():
 *                     tokens += tmptokens
 *         except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_2, &__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5744, __pyx_L9_except_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyErr_GivenExceptionMatches2(__pyx_t_4, __pyx_t_6, __pyx_builtin_IndexError);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_2, __pyx_t_1);
    __pyx_t_4 = 0; __pyx_t_2 = 0; __pyx_t_1 = 0;
    if (__pyx_t_5) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L8_exception_handled;
    }
    goto __pyx_L9_except_error;

    /* "cPyparsing.pyx":5732
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:             # <<<<<<<<<<<<<<
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while 1:
 */
    __pyx_L9_except_error:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L8_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    __pyx_L12_try_end:;
  }

  /* "cPyparsing.pyx":5747
 *             pass
 * 
 *         return loc, tokens             # <<<<<<<<<<<<<<
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_loc)) __PYX_ERR(0, 5747, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_tokens);
  __Pyx_GIVEREF(__pyx_v_tokens);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_tokens)) __PYX_ERR(0, 5747, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5720
 * 
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self_expr_parse);
  __Pyx_XDECREF(__pyx_v_self_skip_ignorables);
  __Pyx_XDECREF(__pyx_v_check_ender);
  __Pyx_XDECREF(__pyx_v_try_not_ender);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_preloc);
  __Pyx_XDECREF(__pyx_v_tmptokens);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5749
 *         return loc, tokens
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_7_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_14_MultipleMatch_6_setResultsName, "_MultipleMatch._setResultsName(self, name, listAllMatches=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_14_MultipleMatch_7_setResultsName = {"_setResultsName", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_14_MultipleMatch_7_setResultsName, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_14_MultipleMatch_6_setResultsName};
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_7_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_listAllMatches = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_setResultsName (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,&__pyx_n_s_listAllMatches,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5749, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5749, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, 1); __PYX_ERR(0, 5749, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listAllMatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5749, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_setResultsName") < 0)) __PYX_ERR(0, 5749, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_listAllMatches = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5749, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._MultipleMatch._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14_MultipleMatch_6_setResultsName(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_listAllMatches);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch_6_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_setResultsName", 1);

  /* "cPyparsing.pyx":5750
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:             # <<<<<<<<<<<<<<
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 *                 if isinstance(e, ParserElement) and e.resultsName:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn_ungrouped_named_tokens_in_c); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5750, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":5751
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):             # <<<<<<<<<<<<<<
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(0, 5751, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_exprs, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
      __pyx_t_5 = __pyx_t_4; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5751, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5751, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 5751, __pyx_L1_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5751, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5751, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 5751, __pyx_L1_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5751, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_7(__pyx_t_5);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 5751, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":5752
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 *                 if isinstance(e, ParserElement) and e.resultsName:             # <<<<<<<<<<<<<<
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5752, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = PyObject_IsInstance(__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 5752, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_8) {
      } else {
        __pyx_t_3 = __pyx_t_8;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5752, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 5752, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_3 = __pyx_t_8;
      __pyx_L7_bool_binop_done:;
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":5753
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 *                                                                                        name,
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_warnings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5753, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_warn); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5753, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "cPyparsing.pyx":5754
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",             # <<<<<<<<<<<<<<
 *                                                                                        name,
 *                                                                                        type(self).__name__,
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_setting_results_name_1_r_on_2, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5754, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "cPyparsing.pyx":5756
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 *                                                                                        name,
 *                                                                                        type(self).__name__,             # <<<<<<<<<<<<<<
 *                                                                                        e.resultsName),
 *                                   stacklevel=3)
 */
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_self)), __pyx_n_s_name); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5756, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);

        /* "cPyparsing.pyx":5757
 *                                                                                        name,
 *                                                                                        type(self).__name__,
 *                                                                                        e.resultsName),             # <<<<<<<<<<<<<<
 *                                   stacklevel=3)
 * 
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5757, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = NULL;
        __pyx_t_12 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_12 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_11, __pyx_n_u_warn_ungrouped_named_tokens_in_c, __pyx_v_name, __pyx_t_9, __pyx_t_10};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 4+__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5754, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }

        /* "cPyparsing.pyx":5753
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 *                                                                                        name,
 */
        __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5753, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_4);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4)) __PYX_ERR(0, 5753, __pyx_L1_error);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":5758
 *                                                                                        type(self).__name__,
 *                                                                                        e.resultsName),
 *                                   stacklevel=3)             # <<<<<<<<<<<<<<
 * 
 *         return super(_MultipleMatch, self)._setResultsName(name, listAllMatches)
 */
        __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5758, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_stacklevel, __pyx_int_3) < 0) __PYX_ERR(0, 5758, __pyx_L1_error)

        /* "cPyparsing.pyx":5753
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "             # <<<<<<<<<<<<<<
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 *                                                                                        name,
 */
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5753, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "cPyparsing.pyx":5752
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 *                 if isinstance(e, ParserElement) and e.resultsName:             # <<<<<<<<<<<<<<
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 *                                   "collides with {3!r} on contained expression".format("warn_ungrouped_named_tokens_in_collection",
 */
      }

      /* "cPyparsing.pyx":5751
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):             # <<<<<<<<<<<<<<
 *                 if isinstance(e, ParserElement) and e.resultsName:
 *                     warnings.warn("{0}: setting results name {1!r} on {2} expression "
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":5750
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:             # <<<<<<<<<<<<<<
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 *                 if isinstance(e, ParserElement) and e.resultsName:
 */
  }

  /* "cPyparsing.pyx":5760
 *                                   stacklevel=3)
 * 
 *         return super(_MultipleMatch, self)._setResultsName(name, listAllMatches)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_MultipleMatch); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_10)) __PYX_ERR(0, 5760, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self)) __PYX_ERR(0, 5760, __pyx_L1_error);
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_4, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  __pyx_t_12 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_12 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_v_name, __pyx_v_listAllMatches};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_12, 2+__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5749
 *         return loc, tokens
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing._MultipleMatch._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5789
 *     """
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9OneOrMore_1__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_9OneOrMore___str__, "OneOrMore.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_9OneOrMore_1__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9OneOrMore_1__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_9OneOrMore___str__};
static PyObject *__pyx_pw_10cPyparsing_9OneOrMore_1__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5789, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 5789, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5789, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.OneOrMore.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9OneOrMore___str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9OneOrMore___str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":5790
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_name_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 5790, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5791
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5791, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":5790
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":5793
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + _ustr(self.expr) + "}..."
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5794
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + _ustr(self.expr) + "}..."             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5794, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_kp_u__107, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__114); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_2) < 0) __PYX_ERR(0, 5794, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":5793
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + _ustr(self.expr) + "}..."
 * 
 */
  }

  /* "cPyparsing.pyx":5796
 *             self.strRepr = "{" + _ustr(self.expr) + "}..."
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * class ZeroOrMore(_MultipleMatch):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5789
 *     """
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.OneOrMore.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5809
 *     Example: similar to :class:`OneOrMore`
 *     """
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10ZeroOrMore___init__, "ZeroOrMore.__init__(self, expr, stopOn=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_10ZeroOrMore_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10ZeroOrMore_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10ZeroOrMore___init__};
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_stopOn = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_stopOn,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5809, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5809, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 5809, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_stopOn);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5809, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5809, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_stopOn = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5809, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10ZeroOrMore___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_stopOn);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_stopOn) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":5810
 *     """
 *     def __init__(self, expr, stopOn=None):
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 5810, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self)) __PYX_ERR(0, 5810, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_expr);
  __Pyx_GIVEREF(__pyx_v_expr);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_expr)) __PYX_ERR(0, 5810, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_stopOn, __pyx_v_stopOn) < 0) __PYX_ERR(0, 5810, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":5811
 *     def __init__(self, expr, stopOn=None):
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 5811, __pyx_L1_error)

  /* "cPyparsing.pyx":5809
 *     Example: similar to :class:`OneOrMore`
 *     """
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5823
 *     #         return loc, []
 *     #     return got
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10ZeroOrMore_2parseImpl, "ZeroOrMore.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_10ZeroOrMore_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10ZeroOrMore_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10ZeroOrMore_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5823, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5823, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 5823, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5823, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 5823, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5823, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5823, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 5823, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10ZeroOrMore_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":5824
 *     #     return got
 *     def parseImpl(self, instring, loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":5825
 *     def parseImpl(self, instring, loc, doActions=True):
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *         except (ParseException, IndexError):
 *             return loc, []
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5825, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5825, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5)) __PYX_ERR(0, 5825, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self)) __PYX_ERR(0, 5825, __pyx_L3_error);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5825, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5825, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5825, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":5824
 *     #     return got
 *     def parseImpl(self, instring, loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":5826
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *             return loc, []
 * 
 */
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_6, &__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5826, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_PyErr_GivenExceptionMatches2(__pyx_t_4, __pyx_t_8, __pyx_builtin_IndexError);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_6, __pyx_t_5);
    __pyx_t_4 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0;
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.ZeroOrMore.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(0, 5826, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "cPyparsing.pyx":5827
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):
 *             return loc, []             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_8 = PyList_New(0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5827, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5827, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_v_loc);
      __Pyx_GIVEREF(__pyx_v_loc);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_loc)) __PYX_ERR(0, 5827, __pyx_L5_except_error);
      __Pyx_GIVEREF(__pyx_t_8);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_8)) __PYX_ERR(0, 5827, __pyx_L5_except_error);
      __pyx_t_8 = 0;
      __pyx_r = __pyx_t_9;
      __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":5824
 *     #     return got
 *     def parseImpl(self, instring, loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":5823
 *     #         return loc, []
 *     #     return got
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5829
 *             return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10ZeroOrMore_4__str__, "ZeroOrMore.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10ZeroOrMore_5__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10ZeroOrMore_5__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10ZeroOrMore_4__str__};
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5829, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 5829, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5829, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10ZeroOrMore_4__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":5830
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_name_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 5830, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5831
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5831, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":5830
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":5833
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "[" + _ustr(self.expr) + "]..."
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5834
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "[" + _ustr(self.expr) + "]..."             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5834, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5834, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5834, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_kp_u__2, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5834, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__115); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5834, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_2) < 0) __PYX_ERR(0, 5834, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":5833
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "[" + _ustr(self.expr) + "]..."
 * 
 */
  }

  /* "cPyparsing.pyx":5836
 *             self.strRepr = "[" + _ustr(self.expr) + "]..."
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5829
 *             return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5840
 * 
 * class _NullToken(object):
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 *     __nonzero__ = __bool__
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_NullToken_1__bool__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_NullToken___bool__, "_NullToken.__bool__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_NullToken_1__bool__ = {"__bool__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_NullToken_1__bool__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_NullToken___bool__};
static PyObject *__pyx_pw_10cPyparsing_10_NullToken_1__bool__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__bool__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5840, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__bool__") < 0)) __PYX_ERR(0, 5840, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__bool__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5840, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._NullToken.__bool__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_NullToken___bool__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_NullToken___bool__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__bool__", 1);

  /* "cPyparsing.pyx":5841
 * class _NullToken(object):
 *     def __bool__(self):
 *         return False             # <<<<<<<<<<<<<<
 *     __nonzero__ = __bool__
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5840
 * 
 * class _NullToken(object):
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 *     __nonzero__ = __bool__
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5843
 *         return False
 *     __nonzero__ = __bool__
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_NullToken_3__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_10_NullToken_2__str__, "_NullToken.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_10_NullToken_3__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10_NullToken_3__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_10_NullToken_2__str__};
static PyObject *__pyx_pw_10cPyparsing_10_NullToken_3__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5843, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 5843, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5843, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._NullToken.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_NullToken_2__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_NullToken_2__str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":5844
 *     __nonzero__ = __bool__
 *     def __str__(self):
 *         return ""             # <<<<<<<<<<<<<<
 * 
 * class Optional(ParseElementEnhance):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__10);
  __pyx_r = __pyx_kp_u__10;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5843
 *         return False
 *     __nonzero__ = __bool__
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5885
 *     __optionalNotMatched = _NullToken()
 * 
 *     def __init__(self, expr, default=__optionalNotMatched):             # <<<<<<<<<<<<<<
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 */

static PyObject *__pyx_pf_10cPyparsing_103__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_default);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_default);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_default)) __PYX_ERR(0, 5885, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 5885, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 5885, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Optional_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_8Optional___init__, "Optional.__init__(self, expr, default=__optionalNotMatched)");
static PyMethodDef __pyx_mdef_10cPyparsing_8Optional_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_8Optional_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_8Optional___init__};
static PyObject *__pyx_pw_10cPyparsing_8Optional_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_default = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_default,0};
    __pyx_defaults7 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_default);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5885, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5885, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 5885, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_default);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5885, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5885, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_default = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 5885, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Optional.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8Optional___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_default);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Optional___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":5886
 * 
 *     def __init__(self, expr, default=__optionalNotMatched):
 *         super(Optional, self).__init__(expr, savelist=False)             # <<<<<<<<<<<<<<
 *         self.saveAsList = self.expr.saveAsList
 *         self.defaultValue = default
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Optional); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 5886, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self)) __PYX_ERR(0, 5886, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_expr);
  __Pyx_GIVEREF(__pyx_v_expr);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_expr)) __PYX_ERR(0, 5886, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_savelist, Py_False) < 0) __PYX_ERR(0, 5886, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":5887
 *     def __init__(self, expr, default=__optionalNotMatched):
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList             # <<<<<<<<<<<<<<
 *         self.defaultValue = default
 *         self.mayReturnEmpty = True
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_3) < 0) __PYX_ERR(0, 5887, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5888
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 *         self.defaultValue = default             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue, __pyx_v_default) < 0) __PYX_ERR(0, 5888, __pyx_L1_error)

  /* "cPyparsing.pyx":5889
 *         self.saveAsList = self.expr.saveAsList
 *         self.defaultValue = default
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 5889, __pyx_L1_error)

  /* "cPyparsing.pyx":5885
 *     __optionalNotMatched = _NullToken()
 * 
 *     def __init__(self, expr, default=__optionalNotMatched):             # <<<<<<<<<<<<<<
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Optional.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5912
 *     #         loc, tokens = got
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Optional_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_8Optional_2parseImpl, "Optional.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_8Optional_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_8Optional_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_8Optional_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_8Optional_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5912, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5912, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 5912, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5912, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 5912, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5912, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 5912, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 5912, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Optional.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8Optional_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Optional_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":5913
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":5914
 *     def parseImpl(self, instring, loc, doActions=True):
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not self.__optionalNotMatched:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5914, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_parse); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5914, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5914, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_instring)) __PYX_ERR(0, 5914, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_loc);
      __Pyx_GIVEREF(__pyx_v_loc);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_loc)) __PYX_ERR(0, 5914, __pyx_L3_error);
      __Pyx_INCREF(__pyx_v_doActions);
      __Pyx_GIVEREF(__pyx_v_doActions);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_doActions)) __PYX_ERR(0, 5914, __pyx_L3_error);
      __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5914, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 5914, __pyx_L3_error)
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5914, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
        PyObject* sequence = __pyx_t_7;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 5914, __pyx_L3_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        #else
        __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5914, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5914, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_5 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5914, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
        index = 0; __pyx_t_6 = __pyx_t_8(__pyx_t_5); if (unlikely(!__pyx_t_6)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_4);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_5), 2) < 0) __PYX_ERR(0, 5914, __pyx_L3_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 5914, __pyx_L3_error)
        __pyx_L10_unpacking_done:;
      }
      __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_v_tokens = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":5913
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":5915
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *             if self.defaultValue is not self.__optionalNotMatched:
 *                 if self.expr.resultsName:
 */
    __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_4, &__pyx_t_6);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5915, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches2(__pyx_t_7, __pyx_t_5, __pyx_builtin_IndexError);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_ErrRestore(__pyx_t_7, __pyx_t_4, __pyx_t_6);
    __pyx_t_7 = 0; __pyx_t_4 = 0; __pyx_t_6 = 0;
    if (__pyx_t_9) {
      __Pyx_AddTraceback("cPyparsing.Optional.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 5915, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "cPyparsing.pyx":5916
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not self.__optionalNotMatched:             # <<<<<<<<<<<<<<
 *                 if self.expr.resultsName:
 *                     tokens = ParseResults([self.defaultValue])
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5916, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Optional__optionalNotMatched); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5916, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = (__pyx_t_5 != __pyx_t_10);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (__pyx_t_11) {

        /* "cPyparsing.pyx":5917
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not self.__optionalNotMatched:
 *                 if self.expr.resultsName:             # <<<<<<<<<<<<<<
 *                     tokens = ParseResults([self.defaultValue])
 *                     tokens[self.expr.resultsName] = self.defaultValue
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5917, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5917, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 5917, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (__pyx_t_11) {

          /* "cPyparsing.pyx":5918
 *             if self.defaultValue is not self.__optionalNotMatched:
 *                 if self.expr.resultsName:
 *                     tokens = ParseResults([self.defaultValue])             # <<<<<<<<<<<<<<
 *                     tokens[self.expr.resultsName] = self.defaultValue
 *                 else:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5918, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5918, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = PyList_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5918, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_12);
          if (__Pyx_PyList_SET_ITEM(__pyx_t_13, 0, __pyx_t_12)) __PYX_ERR(0, 5918, __pyx_L5_except_error);
          __pyx_t_12 = 0;
          __pyx_t_12 = NULL;
          __pyx_t_9 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_9 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_13};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5918, __pyx_L5_except_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
          __Pyx_XDECREF_SET(__pyx_v_tokens, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "cPyparsing.pyx":5919
 *                 if self.expr.resultsName:
 *                     tokens = ParseResults([self.defaultValue])
 *                     tokens[self.expr.resultsName] = self.defaultValue             # <<<<<<<<<<<<<<
 *                 else:
 *                     tokens = [self.defaultValue]
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5919, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5919, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5919, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely((PyObject_SetItem(__pyx_v_tokens, __pyx_t_13, __pyx_t_5) < 0))) __PYX_ERR(0, 5919, __pyx_L5_except_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "cPyparsing.pyx":5917
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not self.__optionalNotMatched:
 *                 if self.expr.resultsName:             # <<<<<<<<<<<<<<
 *                     tokens = ParseResults([self.defaultValue])
 *                     tokens[self.expr.resultsName] = self.defaultValue
 */
          goto __pyx_L14;
        }

        /* "cPyparsing.pyx":5921
 *                     tokens[self.expr.resultsName] = self.defaultValue
 *                 else:
 *                     tokens = [self.defaultValue]             # <<<<<<<<<<<<<<
 *             else:
 *                 tokens = []
 */
        /*else*/ {
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5921, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_13 = PyList_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5921, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_5);
          if (__Pyx_PyList_SET_ITEM(__pyx_t_13, 0, __pyx_t_5)) __PYX_ERR(0, 5921, __pyx_L5_except_error);
          __pyx_t_5 = 0;
          __Pyx_XDECREF_SET(__pyx_v_tokens, __pyx_t_13);
          __pyx_t_13 = 0;
        }
        __pyx_L14:;

        /* "cPyparsing.pyx":5916
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not self.__optionalNotMatched:             # <<<<<<<<<<<<<<
 *                 if self.expr.resultsName:
 *                     tokens = ParseResults([self.defaultValue])
 */
        goto __pyx_L13;
      }

      /* "cPyparsing.pyx":5923
 *                     tokens = [self.defaultValue]
 *             else:
 *                 tokens = []             # <<<<<<<<<<<<<<
 *         return loc, tokens
 * 
 */
      /*else*/ {
        __pyx_t_13 = PyList_New(0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5923, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_XDECREF_SET(__pyx_v_tokens, __pyx_t_13);
        __pyx_t_13 = 0;
      }
      __pyx_L13:;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":5913
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "cPyparsing.pyx":5924
 *             else:
 *                 tokens = []
 *         return loc, tokens             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_loc)) __PYX_ERR(0, 5924, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_tokens);
  __Pyx_GIVEREF(__pyx_v_tokens);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_tokens)) __PYX_ERR(0, 5924, __pyx_L1_error);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5912
 *     #         loc, tokens = got
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.Optional.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5926
 *         return loc, tokens
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Optional_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_8Optional_4__str__, "Optional.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_8Optional_5__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_8Optional_5__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_8Optional_4__str__};
static PyObject *__pyx_pw_10cPyparsing_8Optional_5__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5926, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 5926, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5926, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Optional.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8Optional_4__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Optional_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":5927
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_name_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 5927, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5928
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":5927
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":5930
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "[" + _ustr(self.expr) + "]"
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5931
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "[" + _ustr(self.expr) + "]"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5931, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5931, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5931, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_kp_u__2, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5931, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5931, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_2) < 0) __PYX_ERR(0, 5931, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":5930
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "[" + _ustr(self.expr) + "]"
 * 
 */
  }

  /* "cPyparsing.pyx":5933
 *             self.strRepr = "[" + _ustr(self.expr) + "]"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * class SkipTo(ParseElementEnhance):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5926
 *         return loc, tokens
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.Optional.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5994
 *     """
 *     # [CPYPARSING] use kwargs to detect include
 *     def __init__(self, other, ignore=None, failOn=None, **kwargs):             # <<<<<<<<<<<<<<
 *         include_ = kwargs.get("include", False)  # include=False
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6SkipTo_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_6SkipTo___init__, "SkipTo.__init__(self, other, ignore=None, failOn=None, **kwargs)");
static PyMethodDef __pyx_mdef_10cPyparsing_6SkipTo_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_6SkipTo_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_6SkipTo___init__};
static PyObject *__pyx_pw_10cPyparsing_6SkipTo_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_v_ignore = 0;
  PyObject *__pyx_v_failOn = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,&__pyx_n_s_ignore,&__pyx_n_s_failOn,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5994, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5994, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, 1); __PYX_ERR(0, 5994, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5994, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_failOn);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5994, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 5994, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
    __pyx_v_ignore = values[2];
    __pyx_v_failOn = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 5994, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.SkipTo.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6SkipTo___init__(__pyx_self, __pyx_v_self, __pyx_v_other, __pyx_v_ignore, __pyx_v_failOn, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6SkipTo___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_ignore, PyObject *__pyx_v_failOn, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_include_ = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":5995
 *     # [CPYPARSING] use kwargs to detect include
 *     def __init__(self, other, ignore=None, failOn=None, **kwargs):
 *         include_ = kwargs.get("include", False)  # include=False             # <<<<<<<<<<<<<<
 * 
 *         super(SkipTo, self).__init__(other)
 */
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_include, Py_False); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_include_ = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5997
 *         include_ = kwargs.get("include", False)  # include=False
 * 
 *         super(SkipTo, self).__init__(other)             # <<<<<<<<<<<<<<
 *         self.ignoreExpr = ignore
 *         self.mayReturnEmpty = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SkipTo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5997, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 5997, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5998
 * 
 *         super(SkipTo, self).__init__(other)
 *         self.ignoreExpr = ignore             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExpr, __pyx_v_ignore) < 0) __PYX_ERR(0, 5998, __pyx_L1_error)

  /* "cPyparsing.pyx":5999
 *         super(SkipTo, self).__init__(other)
 *         self.ignoreExpr = ignore
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         # [CPYPARSING] include_
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 5999, __pyx_L1_error)

  /* "cPyparsing.pyx":6000
 *         self.ignoreExpr = ignore
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] include_
 *         self.includeMatch = include_
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 6000, __pyx_L1_error)

  /* "cPyparsing.pyx":6002
 *         self.mayIndexError = False
 *         # [CPYPARSING] include_
 *         self.includeMatch = include_             # <<<<<<<<<<<<<<
 *         self.saveAsList = False
 *         if isinstance(failOn, basestring):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_includeMatch, __pyx_v_include_) < 0) __PYX_ERR(0, 6002, __pyx_L1_error)

  /* "cPyparsing.pyx":6003
 *         # [CPYPARSING] include_
 *         self.includeMatch = include_
 *         self.saveAsList = False             # <<<<<<<<<<<<<<
 *         if isinstance(failOn, basestring):
 *             self.failOn = self._literalStringClass(failOn)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_False) < 0) __PYX_ERR(0, 6003, __pyx_L1_error)

  /* "cPyparsing.pyx":6004
 *         self.includeMatch = include_
 *         self.saveAsList = False
 *         if isinstance(failOn, basestring):             # <<<<<<<<<<<<<<
 *             self.failOn = self._literalStringClass(failOn)
 *         else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_failOn, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 6004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":6005
 *         self.saveAsList = False
 *         if isinstance(failOn, basestring):
 *             self.failOn = self._literalStringClass(failOn)             # <<<<<<<<<<<<<<
 *         else:
 *             self.failOn = failOn
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_failOn};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6005, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_failOn, __pyx_t_1) < 0) __PYX_ERR(0, 6005, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6004
 *         self.includeMatch = include_
 *         self.saveAsList = False
 *         if isinstance(failOn, basestring):             # <<<<<<<<<<<<<<
 *             self.failOn = self._literalStringClass(failOn)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":6007
 *             self.failOn = self._literalStringClass(failOn)
 *         else:
 *             self.failOn = failOn             # <<<<<<<<<<<<<<
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_failOn, __pyx_v_failOn) < 0) __PYX_ERR(0, 6007, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":6008
 *         else:
 *             self.failOn = failOn
 *         self.errmsg = "No match found for " + _ustr(self.expr)             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_No_match_found_for, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 6008, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5994
 *     """
 *     # [CPYPARSING] use kwargs to detect include
 *     def __init__(self, other, ignore=None, failOn=None, **kwargs):             # <<<<<<<<<<<<<<
 *         include_ = kwargs.get("include", False)  # include=False
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.SkipTo.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_include_);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6010
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         startloc = loc
 *         instrlen = len(instring)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6SkipTo_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_6SkipTo_2parseImpl, "SkipTo.parseImpl(self, instring, loc, doActions=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_6SkipTo_3parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_6SkipTo_3parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_6SkipTo_2parseImpl};
static PyObject *__pyx_pw_10cPyparsing_6SkipTo_3parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6010, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6010, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 6010, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6010, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 6010, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6010, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 6010, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 6010, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.SkipTo.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6SkipTo_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6SkipTo_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_startloc = NULL;
  Py_ssize_t __pyx_v_instrlen;
  CYTHON_UNUSED PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_expr_parse = NULL;
  PyObject *__pyx_v_self_failOn_canParseNext = NULL;
  PyObject *__pyx_v_self_ignoreExpr_tryParse = NULL;
  PyObject *__pyx_v_tmploc = NULL;
  PyObject *__pyx_v_skiptext = NULL;
  PyObject *__pyx_v_skipresult = NULL;
  PyObject *__pyx_v_mat = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":6011
 * 
 *     def parseImpl(self, instring, loc, doActions=True):
 *         startloc = loc             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         expr = self.expr
 */
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_v_startloc = __pyx_v_loc;

  /* "cPyparsing.pyx":6012
 *     def parseImpl(self, instring, loc, doActions=True):
 *         startloc = loc
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         expr = self.expr
 *         expr_parse = self.expr._parse
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6012, __pyx_L1_error)
  __pyx_v_instrlen = __pyx_t_1;

  /* "cPyparsing.pyx":6013
 *         startloc = loc
 *         instrlen = len(instring)
 *         expr = self.expr             # <<<<<<<<<<<<<<
 *         expr_parse = self.expr._parse
 *         self_failOn_canParseNext = self.failOn.canParseNext if self.failOn is not None else None
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_expr = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6014
 *         instrlen = len(instring)
 *         expr = self.expr
 *         expr_parse = self.expr._parse             # <<<<<<<<<<<<<<
 *         self_failOn_canParseNext = self.failOn.canParseNext if self.failOn is not None else None
 *         self_ignoreExpr_tryParse = self.ignoreExpr.tryParse if self.ignoreExpr is not None else None
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_parse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_expr_parse = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6015
 *         expr = self.expr
 *         expr_parse = self.expr._parse
 *         self_failOn_canParseNext = self.failOn.canParseNext if self.failOn is not None else None             # <<<<<<<<<<<<<<
 *         self_ignoreExpr_tryParse = self.ignoreExpr.tryParse if self.ignoreExpr is not None else None
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failOn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failOn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_canParseNext); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_3 = Py_None;
  }
  __pyx_v_self_failOn_canParseNext = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6016
 *         expr_parse = self.expr._parse
 *         self_failOn_canParseNext = self.failOn.canParseNext if self.failOn is not None else None
 *         self_ignoreExpr_tryParse = self.ignoreExpr.tryParse if self.ignoreExpr is not None else None             # <<<<<<<<<<<<<<
 * 
 *         tmploc = loc
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExpr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__pyx_t_5 != Py_None);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_4) {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExpr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_3 = Py_None;
  }
  __pyx_v_self_ignoreExpr_tryParse = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6018
 *         self_ignoreExpr_tryParse = self.ignoreExpr.tryParse if self.ignoreExpr is not None else None
 * 
 *         tmploc = loc             # <<<<<<<<<<<<<<
 *         while tmploc <= instrlen:
 *             if self_failOn_canParseNext is not None:
 */
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_v_tmploc = __pyx_v_loc;

  /* "cPyparsing.pyx":6019
 * 
 *         tmploc = loc
 *         while tmploc <= instrlen:             # <<<<<<<<<<<<<<
 *             if self_failOn_canParseNext is not None:
 *                 # break if failOn expression matches
 */
  while (1) {
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_instrlen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_tmploc, __pyx_t_3, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6019, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 6019, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!__pyx_t_4) break;

    /* "cPyparsing.pyx":6020
 *         tmploc = loc
 *         while tmploc <= instrlen:
 *             if self_failOn_canParseNext is not None:             # <<<<<<<<<<<<<<
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):
 */
    __pyx_t_4 = (__pyx_v_self_failOn_canParseNext != Py_None);
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":6022
 *             if self_failOn_canParseNext is not None:
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
      __Pyx_INCREF(__pyx_v_self_failOn_canParseNext);
      __pyx_t_3 = __pyx_v_self_failOn_canParseNext; __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_instring, __pyx_v_tmploc};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 6022, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_4) {

        /* "cPyparsing.pyx":6023
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):
 *                     break             # <<<<<<<<<<<<<<
 * 
 *             if self_ignoreExpr_tryParse is not None:
 */
        goto __pyx_L4_break;

        /* "cPyparsing.pyx":6022
 *             if self_failOn_canParseNext is not None:
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
      }

      /* "cPyparsing.pyx":6020
 *         tmploc = loc
 *         while tmploc <= instrlen:
 *             if self_failOn_canParseNext is not None:             # <<<<<<<<<<<<<<
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):
 */
    }

    /* "cPyparsing.pyx":6025
 *                     break
 * 
 *             if self_ignoreExpr_tryParse is not None:             # <<<<<<<<<<<<<<
 *                 # advance past ignore expressions
 *                 while 1:
 */
    __pyx_t_4 = (__pyx_v_self_ignoreExpr_tryParse != Py_None);
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":6027
 *             if self_ignoreExpr_tryParse is not None:
 *                 # advance past ignore expressions
 *                 while 1:             # <<<<<<<<<<<<<<
 *                     try:
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 */
      while (1) {

        /* "cPyparsing.pyx":6028
 *                 # advance past ignore expressions
 *                 while 1:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_9);
          /*try:*/ {

            /* "cPyparsing.pyx":6029
 *                 while 1:
 *                     try:
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)             # <<<<<<<<<<<<<<
 *                     except ParseBaseException:
 *                         break
 */
            __Pyx_INCREF(__pyx_v_self_ignoreExpr_tryParse);
            __pyx_t_3 = __pyx_v_self_ignoreExpr_tryParse; __pyx_t_5 = NULL;
            __pyx_t_6 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
                __pyx_t_6 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_instring, __pyx_v_tmploc};
              __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6029, __pyx_L10_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            }
            __Pyx_DECREF_SET(__pyx_v_tmploc, __pyx_t_2);
            __pyx_t_2 = 0;

            /* "cPyparsing.pyx":6028
 *                 # advance past ignore expressions
 *                 while 1:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:
 */
          }
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L17_try_end;
          __pyx_L10_error:;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "cPyparsing.pyx":6030
 *                     try:
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
          __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_3, &__pyx_t_5);
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6030, __pyx_L12_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_6 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_ErrRestore(__pyx_t_2, __pyx_t_3, __pyx_t_5);
          __pyx_t_2 = 0; __pyx_t_3 = 0; __pyx_t_5 = 0;
          if (__pyx_t_6) {
            __Pyx_AddTraceback("cPyparsing.SkipTo.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 6030, __pyx_L12_except_error)
            __Pyx_XGOTREF(__pyx_t_5);
            __Pyx_XGOTREF(__pyx_t_3);
            __Pyx_XGOTREF(__pyx_t_2);

            /* "cPyparsing.pyx":6031
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:
 *                         break             # <<<<<<<<<<<<<<
 * 
 *             try:
 */
            goto __pyx_L19_except_break;
            __pyx_L19_except_break:;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            goto __pyx_L15_try_break;
          }
          goto __pyx_L12_except_error;

          /* "cPyparsing.pyx":6028
 *                 # advance past ignore expressions
 *                 while 1:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:
 */
          __pyx_L12_except_error:;
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          goto __pyx_L1_error;
          __pyx_L15_try_break:;
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          goto __pyx_L9_break;
          __pyx_L17_try_end:;
        }
      }
      __pyx_L9_break:;

      /* "cPyparsing.pyx":6025
 *                     break
 * 
 *             if self_ignoreExpr_tryParse is not None:             # <<<<<<<<<<<<<<
 *                 # advance past ignore expressions
 *                 while 1:
 */
    }

    /* "cPyparsing.pyx":6033
 *                         break
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)
 *             except (ParseException, IndexError):
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_8, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "cPyparsing.pyx":6034
 * 
 *             try:
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)             # <<<<<<<<<<<<<<
 *             except (ParseException, IndexError):
 *                 # no match, advance loc in string
 */
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6034, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_instring)) __PYX_ERR(0, 6034, __pyx_L20_error);
        __Pyx_INCREF(__pyx_v_tmploc);
        __Pyx_GIVEREF(__pyx_v_tmploc);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_tmploc)) __PYX_ERR(0, 6034, __pyx_L20_error);
        __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6034, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_doActions, Py_False) < 0) __PYX_ERR(0, 6034, __pyx_L20_error)
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 6034, __pyx_L20_error)
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_expr_parse, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6034, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "cPyparsing.pyx":6033
 *                         break
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)
 *             except (ParseException, IndexError):
 */
      }

      /* "cPyparsing.pyx":6040
 *             else:
 *                 # matched skipto expr, done
 *                 break             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
      /*else:*/ {
        goto __pyx_L25_try_break;
      }
      __pyx_L20_error:;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":6035
 *             try:
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)
 *             except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *                 # no match, advance loc in string
 *                 tmploc += 1
 */
      __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_3, &__pyx_t_2);
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6035, __pyx_L22_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_6 = __Pyx_PyErr_GivenExceptionMatches2(__pyx_t_5, __pyx_t_10, __pyx_builtin_IndexError);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_ErrRestore(__pyx_t_5, __pyx_t_3, __pyx_t_2);
      __pyx_t_5 = 0; __pyx_t_3 = 0; __pyx_t_2 = 0;
      if (__pyx_t_6) {
        __Pyx_AddTraceback("cPyparsing.SkipTo.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_5) < 0) __PYX_ERR(0, 6035, __pyx_L22_except_error)
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_5);

        /* "cPyparsing.pyx":6037
 *             except (ParseException, IndexError):
 *                 # no match, advance loc in string
 *                 tmploc += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 # matched skipto expr, done
 */
        __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_v_tmploc, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6037, __pyx_L22_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF_SET(__pyx_v_tmploc, __pyx_t_10);
        __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L21_exception_handled;
      }
      goto __pyx_L22_except_error;

      /* "cPyparsing.pyx":6033
 *                         break
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)
 *             except (ParseException, IndexError):
 */
      __pyx_L22_except_error:;
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L25_try_break:;
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
      goto __pyx_L4_break;
      __pyx_L21_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
    }
  }

  /* "cPyparsing.pyx":6044
 *         else:
 *             # ran off the end of the input string without matching skipto expr, fail
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         # build up return values
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_10, __pyx_v_instring, __pyx_v_loc, __pyx_t_2, __pyx_v_self};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6044, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 6044, __pyx_L1_error)
  }
  __pyx_L4_break:;

  /* "cPyparsing.pyx":6047
 * 
 *         # build up return values
 *         loc = tmploc             # <<<<<<<<<<<<<<
 *         skiptext = instring[startloc:loc]
 *         skipresult = ParseResults(skiptext)
 */
  __Pyx_INCREF(__pyx_v_tmploc);
  __Pyx_DECREF_SET(__pyx_v_loc, __pyx_v_tmploc);

  /* "cPyparsing.pyx":6048
 *         # build up return values
 *         loc = tmploc
 *         skiptext = instring[startloc:loc]             # <<<<<<<<<<<<<<
 *         skipresult = ParseResults(skiptext)
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_startloc, &__pyx_v_loc, NULL, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_skiptext = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":6049
 *         loc = tmploc
 *         skiptext = instring[startloc:loc]
 *         skipresult = ParseResults(skiptext)             # <<<<<<<<<<<<<<
 * 
 *         if self.includeMatch:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_skiptext};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_skipresult = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":6051
 *         skipresult = ParseResults(skiptext)
 * 
 *         if self.includeMatch:             # <<<<<<<<<<<<<<
 *             loc, mat = expr_parse(instring, loc, doActions, callPreParse=False)
 *             skipresult += mat
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_includeMatch); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 6051, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":6052
 * 
 *         if self.includeMatch:
 *             loc, mat = expr_parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *             skipresult += mat
 * 
 */
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6052, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_instring)) __PYX_ERR(0, 6052, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_loc);
    __Pyx_GIVEREF(__pyx_v_loc);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_loc)) __PYX_ERR(0, 6052, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_doActions);
    __Pyx_GIVEREF(__pyx_v_doActions);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_doActions)) __PYX_ERR(0, 6052, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6052, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 6052, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_expr_parse, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6052, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 6052, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6052, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6052, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_10 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6052, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_11 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10);
      index = 0; __pyx_t_3 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_3)) goto __pyx_L31_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_5 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_5)) goto __pyx_L31_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_10), 2) < 0) __PYX_ERR(0, 6052, __pyx_L1_error)
      __pyx_t_11 = NULL;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L32_unpacking_done;
      __pyx_L31_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_11 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 6052, __pyx_L1_error)
      __pyx_L32_unpacking_done:;
    }
    __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_v_mat = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":6053
 *         if self.includeMatch:
 *             loc, mat = expr_parse(instring, loc, doActions, callPreParse=False)
 *             skipresult += mat             # <<<<<<<<<<<<<<
 * 
 *         return loc, skipresult
 */
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_skipresult, __pyx_v_mat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6053, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_skipresult, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":6051
 *         skipresult = ParseResults(skiptext)
 * 
 *         if self.includeMatch:             # <<<<<<<<<<<<<<
 *             loc, mat = expr_parse(instring, loc, doActions, callPreParse=False)
 *             skipresult += mat
 */
  }

  /* "cPyparsing.pyx":6055
 *             skipresult += mat
 * 
 *         return loc, skipresult             # <<<<<<<<<<<<<<
 * 
 * class Forward(ParseElementEnhance):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_loc)) __PYX_ERR(0, 6055, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_skipresult);
  __Pyx_GIVEREF(__pyx_v_skipresult);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_skipresult)) __PYX_ERR(0, 6055, __pyx_L1_error);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6010
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         startloc = loc
 *         instrlen = len(instring)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.SkipTo.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_startloc);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_expr_parse);
  __Pyx_XDECREF(__pyx_v_self_failOn_canParseNext);
  __Pyx_XDECREF(__pyx_v_self_ignoreExpr_tryParse);
  __Pyx_XDECREF(__pyx_v_tmploc);
  __Pyx_XDECREF(__pyx_v_skiptext);
  __Pyx_XDECREF(__pyx_v_skipresult);
  __Pyx_XDECREF(__pyx_v_mat);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6084
 *     parser created using ``Forward``.
 *     """
 *     def __init__(self, other=None):             # <<<<<<<<<<<<<<
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Forward___init__, "Forward.__init__(self, other=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Forward_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Forward___init__};
static PyObject *__pyx_pw_10cPyparsing_7Forward_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6084, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6084, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 6084, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 6084, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Forward.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward___init__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":6085
 *     """
 *     def __init__(self, other=None):
 *         super(Forward, self).__init__(other, savelist=False)             # <<<<<<<<<<<<<<
 * 
 *     def __lshift__(self, other):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Forward); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 6085, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self)) __PYX_ERR(0, 6085, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_other)) __PYX_ERR(0, 6085, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_savelist, Py_False) < 0) __PYX_ERR(0, 6085, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":6084
 *     parser created using ``Forward``.
 *     """
 *     def __init__(self, other=None):             # <<<<<<<<<<<<<<
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Forward.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6087
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 *     def __lshift__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_3__lshift__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Forward_2__lshift__, "Forward.__lshift__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_3__lshift__ = {"__lshift__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Forward_3__lshift__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Forward_2__lshift__};
static PyObject *__pyx_pw_10cPyparsing_7Forward_3__lshift__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__lshift__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6087, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6087, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__lshift__", 1, 2, 2, 1); __PYX_ERR(0, 6087, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__lshift__") < 0)) __PYX_ERR(0, 6087, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__lshift__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6087, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Forward.__lshift__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_2__lshift__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_2__lshift__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__lshift__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":6088
 * 
 *     def __lshift__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         self.expr = other
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 6088, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6089
 *     def __lshift__(self, other):
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         self.expr = other
 *         self.strRepr = None
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6089, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6088
 * 
 *     def __lshift__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = self._literalStringClass(other)
 *         self.expr = other
 */
  }

  /* "cPyparsing.pyx":6090
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 *         self.expr = other             # <<<<<<<<<<<<<<
 *         self.strRepr = None
 *         self.mayIndexError = self.expr.mayIndexError
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_expr, __pyx_v_other) < 0) __PYX_ERR(0, 6090, __pyx_L1_error)

  /* "cPyparsing.pyx":6091
 *             other = self._literalStringClass(other)
 *         self.expr = other
 *         self.strRepr = None             # <<<<<<<<<<<<<<
 *         self.mayIndexError = self.expr.mayIndexError
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 6091, __pyx_L1_error)

  /* "cPyparsing.pyx":6092
 *         self.expr = other
 *         self.strRepr = None
 *         self.mayIndexError = self.expr.mayIndexError             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty
 *         self.setWhitespaceChars(self.expr.whiteChars)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_3) < 0) __PYX_ERR(0, 6092, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6093
 *         self.strRepr = None
 *         self.mayIndexError = self.expr.mayIndexError
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(self.expr.whiteChars)
 *         self.skipWhitespace = self.expr.skipWhitespace
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 6093, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6094
 *         self.mayIndexError = self.expr.mayIndexError
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty
 *         self.setWhitespaceChars(self.expr.whiteChars)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = self.expr.skipWhitespace
 *         self.saveAsList = self.expr.saveAsList
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6095
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty
 *         self.setWhitespaceChars(self.expr.whiteChars)
 *         self.skipWhitespace = self.expr.skipWhitespace             # <<<<<<<<<<<<<<
 *         self.saveAsList = self.expr.saveAsList
 *         self.ignoreExprs.extend(self.expr.ignoreExprs)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_skipWhitespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, __pyx_t_3) < 0) __PYX_ERR(0, 6095, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6096
 *         self.setWhitespaceChars(self.expr.whiteChars)
 *         self.skipWhitespace = self.expr.skipWhitespace
 *         self.saveAsList = self.expr.saveAsList             # <<<<<<<<<<<<<<
 *         self.ignoreExprs.extend(self.expr.ignoreExprs)
 *         return self
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_1) < 0) __PYX_ERR(0, 6096, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6097
 *         self.skipWhitespace = self.expr.skipWhitespace
 *         self.saveAsList = self.expr.saveAsList
 *         self.ignoreExprs.extend(self.expr.ignoreExprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_extend); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6098
 *         self.saveAsList = self.expr.saveAsList
 *         self.ignoreExprs.extend(self.expr.ignoreExprs)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __ilshift__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6087
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 *     def __lshift__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Forward.__lshift__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6100
 *         return self
 * 
 *     def __ilshift__(self, other):             # <<<<<<<<<<<<<<
 *         return self << other
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_5__ilshift__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Forward_4__ilshift__, "Forward.__ilshift__(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_5__ilshift__ = {"__ilshift__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Forward_5__ilshift__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Forward_4__ilshift__};
static PyObject *__pyx_pw_10cPyparsing_7Forward_5__ilshift__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ilshift__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6100, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6100, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__ilshift__", 1, 2, 2, 1); __PYX_ERR(0, 6100, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__ilshift__") < 0)) __PYX_ERR(0, 6100, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ilshift__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6100, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Forward.__ilshift__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_4__ilshift__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_4__ilshift__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ilshift__", 1);

  /* "cPyparsing.pyx":6101
 * 
 *     def __ilshift__(self, other):
 *         return self << other             # <<<<<<<<<<<<<<
 * 
 *     def leaveWhitespace(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Lshift(__pyx_v_self, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6100
 *         return self
 * 
 *     def __ilshift__(self, other):             # <<<<<<<<<<<<<<
 *         return self << other
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.Forward.__ilshift__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6103
 *         return self << other
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         return self
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_7leaveWhitespace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Forward_6leaveWhitespace, "Forward.leaveWhitespace(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_7leaveWhitespace = {"leaveWhitespace", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Forward_7leaveWhitespace, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Forward_6leaveWhitespace};
static PyObject *__pyx_pw_10cPyparsing_7Forward_7leaveWhitespace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6103, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "leaveWhitespace") < 0)) __PYX_ERR(0, 6103, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("leaveWhitespace", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6103, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Forward.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_6leaveWhitespace(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_6leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("leaveWhitespace", 1);

  /* "cPyparsing.pyx":6104
 * 
 *     def leaveWhitespace(self):
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 6104, __pyx_L1_error)

  /* "cPyparsing.pyx":6105
 *     def leaveWhitespace(self):
 *         self.skipWhitespace = False
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6103
 *         return self << other
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         return self
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Forward.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6107
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamlined = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_9streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Forward_8streamline, "Forward.streamline(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_9streamline = {"streamline", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Forward_9streamline, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Forward_8streamline};
static PyObject *__pyx_pw_10cPyparsing_7Forward_9streamline(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6107, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "streamline") < 0)) __PYX_ERR(0, 6107, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("streamline", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6107, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Forward.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_8streamline(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_8streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("streamline", 1);

  /* "cPyparsing.pyx":6108
 * 
 *     def streamline(self):
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamlined = True
 *             if self.expr is not None:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_streamlined); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6108, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":6109
 *     def streamline(self):
 *         if not self.streamlined:
 *             self.streamlined = True             # <<<<<<<<<<<<<<
 *             if self.expr is not None:
 *                 self.expr.streamline()
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_streamlined, Py_True) < 0) __PYX_ERR(0, 6109, __pyx_L1_error)

    /* "cPyparsing.pyx":6110
 *         if not self.streamlined:
 *             self.streamlined = True
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.streamline()
 *         return self
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":6111
 *             self.streamlined = True
 *             if self.expr is not None:
 *                 self.expr.streamline()             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_streamline); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6111, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":6110
 *         if not self.streamlined:
 *             self.streamlined = True
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.streamline()
 *         return self
 */
    }

    /* "cPyparsing.pyx":6108
 * 
 *     def streamline(self):
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamlined = True
 *             if self.expr is not None:
 */
  }

  /* "cPyparsing.pyx":6112
 *             if self.expr is not None:
 *                 self.expr.streamline()
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def validate(self, validateTrace=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6107
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamlined = True
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.Forward.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6114
 *         return self
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         if validateTrace is None:
 *             validateTrace = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_11validate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Forward_10validate, "Forward.validate(self, validateTrace=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_11validate = {"validate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Forward_11validate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Forward_10validate};
static PyObject *__pyx_pw_10cPyparsing_7Forward_11validate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_validateTrace = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_validateTrace,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6114, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_validateTrace);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6114, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "validate") < 0)) __PYX_ERR(0, 6114, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_validateTrace = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("validate", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 6114, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Forward.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_10validate(__pyx_self, __pyx_v_self, __pyx_v_validateTrace);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_10validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace) {
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("validate", 0);
  __Pyx_INCREF(__pyx_v_validateTrace);

  /* "cPyparsing.pyx":6115
 * 
 *     def validate(self, validateTrace=None):
 *         if validateTrace is None:             # <<<<<<<<<<<<<<
 *             validateTrace = []
 * 
 */
  __pyx_t_1 = (__pyx_v_validateTrace == Py_None);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":6116
 *     def validate(self, validateTrace=None):
 *         if validateTrace is None:
 *             validateTrace = []             # <<<<<<<<<<<<<<
 * 
 *         if self not in validateTrace:
 */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_validateTrace, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":6115
 * 
 *     def validate(self, validateTrace=None):
 *         if validateTrace is None:             # <<<<<<<<<<<<<<
 *             validateTrace = []
 * 
 */
  }

  /* "cPyparsing.pyx":6118
 *             validateTrace = []
 * 
 *         if self not in validateTrace:             # <<<<<<<<<<<<<<
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_self, __pyx_v_validateTrace, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 6118, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":6119
 * 
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]             # <<<<<<<<<<<<<<
 *             if self.expr is not None:
 *                 self.expr.validate(tmp)
 */
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_validateTrace, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_self)) __PYX_ERR(0, 6119, __pyx_L1_error);
    __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_tmp = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6120
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.validate(tmp)
 *         self.checkRecursion([])
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = (__pyx_t_4 != Py_None);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":6121
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:
 *                 self.expr.validate(tmp)             # <<<<<<<<<<<<<<
 *         self.checkRecursion([])
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6121, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_validate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6121, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_tmp};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6121, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":6120
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.validate(tmp)
 *         self.checkRecursion([])
 */
    }

    /* "cPyparsing.pyx":6118
 *             validateTrace = []
 * 
 *         if self not in validateTrace:             # <<<<<<<<<<<<<<
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:
 */
  }

  /* "cPyparsing.pyx":6122
 *             if self.expr is not None:
 *                 self.expr.validate(tmp)
 *         self.checkRecursion([])             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":6114
 *         return self
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         if validateTrace is None:
 *             validateTrace = []
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Forward.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_validateTrace);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6124
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_13__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Forward_12__str__, "Forward.__str__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_13__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Forward_13__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Forward_12__str__};
static PyObject *__pyx_pw_10cPyparsing_7Forward_13__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6124, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 6124, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6124, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Forward.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_12__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_12__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "cPyparsing.pyx":6125
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 *         if self.strRepr is not None:
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_name_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 6125, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":6126
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 *         if self.strRepr is not None:
 *             return self.strRepr
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":6125
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 *         if self.strRepr is not None:
 */
  }

  /* "cPyparsing.pyx":6127
 *         if hasattr(self, "name"):
 *             return self.name
 *         if self.strRepr is not None:             # <<<<<<<<<<<<<<
 *             return self.strRepr
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":6128
 *             return self.name
 *         if self.strRepr is not None:
 *             return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *         # [CPYPARSING] return intermediate representation to avoid a massive performance hit
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6128, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":6127
 *         if hasattr(self, "name"):
 *             return self.name
 *         if self.strRepr is not None:             # <<<<<<<<<<<<<<
 *             return self.strRepr
 * 
 */
  }

  /* "cPyparsing.pyx":6131
 * 
 *         # [CPYPARSING] return intermediate representation to avoid a massive performance hit
 *         self.strRepr = self.__class__.__name__ + ": ..."             # <<<<<<<<<<<<<<
 *         return self.strRepr
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__116); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_2) < 0) __PYX_ERR(0, 6131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6132
 *         # [CPYPARSING] return intermediate representation to avoid a massive performance hit
 *         self.strRepr = self.__class__.__name__ + ": ..."
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6124
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Forward.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6134
 *         return self.strRepr
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return super(Forward, self).copy()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_15copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Forward_14copy, "Forward.copy(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_15copy = {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Forward_15copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Forward_14copy};
static PyObject *__pyx_pw_10cPyparsing_7Forward_15copy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6134, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "copy") < 0)) __PYX_ERR(0, 6134, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("copy", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6134, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Forward.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_14copy(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_14copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 1);

  /* "cPyparsing.pyx":6135
 * 
 *     def copy(self):
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             return super(Forward, self).copy()
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6136
 *     def copy(self):
 *         if self.expr is not None:
 *             return super(Forward, self).copy()             # <<<<<<<<<<<<<<
 *         else:
 *             ret = Forward()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Forward); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(0, 6136, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self)) __PYX_ERR(0, 6136, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":6135
 * 
 *     def copy(self):
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             return super(Forward, self).copy()
 *         else:
 */
  }

  /* "cPyparsing.pyx":6138
 *             return super(Forward, self).copy()
 *         else:
 *             ret = Forward()             # <<<<<<<<<<<<<<
 *             ret <<= self
 *             return ret
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Forward); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6138, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_ret = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6139
 *         else:
 *             ret = Forward()
 *             ret <<= self             # <<<<<<<<<<<<<<
 *             return ret
 * 
 */
    __pyx_t_1 = PyNumber_InPlaceLshift(__pyx_v_ret, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6140
 *             ret = Forward()
 *             ret <<= self
 *             return ret             # <<<<<<<<<<<<<<
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_ret);
    __pyx_r = __pyx_v_ret;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":6134
 *         return self.strRepr
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return super(Forward, self).copy()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Forward.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6142
 *             return ret
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_name_set_on_empty_Forward:
 *             if self.expr is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_17_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Forward_16_setResultsName, "Forward._setResultsName(self, name, listAllMatches=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_17_setResultsName = {"_setResultsName", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Forward_17_setResultsName, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Forward_16_setResultsName};
static PyObject *__pyx_pw_10cPyparsing_7Forward_17_setResultsName(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_listAllMatches = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_setResultsName (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,&__pyx_n_s_listAllMatches,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6142, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6142, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, 1); __PYX_ERR(0, 6142, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listAllMatches);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6142, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_setResultsName") < 0)) __PYX_ERR(0, 6142, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_listAllMatches = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_setResultsName", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 6142, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Forward._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_16_setResultsName(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_listAllMatches);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_16_setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_setResultsName", 1);

  /* "cPyparsing.pyx":6143
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_name_set_on_empty_Forward:             # <<<<<<<<<<<<<<
 *             if self.expr is None:
 *                 warnings.warn("{0}: setting results name {0!r} on {1} expression "
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn_name_set_on_empty_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 6143, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":6144
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_name_set_on_empty_Forward:
 *             if self.expr is None:             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {0!r} on {1} expression "
 *                               "that has no contained expression".format("warn_name_set_on_empty_Forward",
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = (__pyx_t_2 == Py_None);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":6145
 *         if __diag__.warn_name_set_on_empty_Forward:
 *             if self.expr is None:
 *                 warnings.warn("{0}: setting results name {0!r} on {1} expression "             # <<<<<<<<<<<<<<
 *                               "that has no contained expression".format("warn_name_set_on_empty_Forward",
 *                                                                         name,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6145, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warn); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6145, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":6146
 *             if self.expr is None:
 *                 warnings.warn("{0}: setting results name {0!r} on {1} expression "
 *                               "that has no contained expression".format("warn_name_set_on_empty_Forward",             # <<<<<<<<<<<<<<
 *                                                                         name,
 *                                                                         type(self).__name__),
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_0_setting_results_name_0_r_on_1, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "cPyparsing.pyx":6148
 *                               "that has no contained expression".format("warn_name_set_on_empty_Forward",
 *                                                                         name,
 *                                                                         type(self).__name__),             # <<<<<<<<<<<<<<
 *                               stacklevel=3)
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_self)), __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6148, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_6, __pyx_n_u_warn_name_set_on_empty_Forward, __pyx_v_name, __pyx_t_5};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6146, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }

      /* "cPyparsing.pyx":6145
 *         if __diag__.warn_name_set_on_empty_Forward:
 *             if self.expr is None:
 *                 warnings.warn("{0}: setting results name {0!r} on {1} expression "             # <<<<<<<<<<<<<<
 *                               "that has no contained expression".format("warn_name_set_on_empty_Forward",
 *                                                                         name,
 */
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6145, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 6145, __pyx_L1_error);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":6149
 *                                                                         name,
 *                                                                         type(self).__name__),
 *                               stacklevel=3)             # <<<<<<<<<<<<<<
 * 
 *         return super(Forward, self)._setResultsName(name, listAllMatches)
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6149, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stacklevel, __pyx_int_3) < 0) __PYX_ERR(0, 6149, __pyx_L1_error)

      /* "cPyparsing.pyx":6145
 *         if __diag__.warn_name_set_on_empty_Forward:
 *             if self.expr is None:
 *                 warnings.warn("{0}: setting results name {0!r} on {1} expression "             # <<<<<<<<<<<<<<
 *                               "that has no contained expression".format("warn_name_set_on_empty_Forward",
 *                                                                         name,
 */
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6145, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":6144
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_name_set_on_empty_Forward:
 *             if self.expr is None:             # <<<<<<<<<<<<<<
 *                 warnings.warn("{0}: setting results name {0!r} on {1} expression "
 *                               "that has no contained expression".format("warn_name_set_on_empty_Forward",
 */
    }

    /* "cPyparsing.pyx":6143
 * 
 *     def _setResultsName(self, name, listAllMatches=False):
 *         if __diag__.warn_name_set_on_empty_Forward:             # <<<<<<<<<<<<<<
 *             if self.expr is None:
 *                 warnings.warn("{0}: setting results name {0!r} on {1} expression "
 */
  }

  /* "cPyparsing.pyx":6151
 *                               stacklevel=3)
 * 
 *         return super(Forward, self)._setResultsName(name, listAllMatches)             # <<<<<<<<<<<<<<
 * 
 * class TokenConverter(ParseElementEnhance):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 6151, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self)) __PYX_ERR(0, 6151, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_name, __pyx_v_listAllMatches};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6142
 *             return ret
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_name_set_on_empty_Forward:
 *             if self.expr is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Forward._setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6157
 *     Abstract subclass of :class:`ParseExpression`, for converting parsed results.
 *     """
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(TokenConverter, self).__init__(expr)  # , savelist)
 *         self.saveAsList = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14TokenConverter_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_14TokenConverter___init__, "TokenConverter.__init__(self, expr, savelist=False)");
static PyMethodDef __pyx_mdef_10cPyparsing_14TokenConverter_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_14TokenConverter_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_14TokenConverter___init__};
static PyObject *__pyx_pw_10cPyparsing_14TokenConverter_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  CYTHON_UNUSED PyObject *__pyx_v_savelist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_savelist,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6157, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6157, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 6157, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_savelist);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6157, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 6157, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 6157, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.TokenConverter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14TokenConverter___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_savelist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14TokenConverter___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, CYTHON_UNUSED PyObject *__pyx_v_savelist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":6158
 *     """
 *     def __init__(self, expr, savelist=False):
 *         super(TokenConverter, self).__init__(expr)  # , savelist)             # <<<<<<<<<<<<<<
 *         self.saveAsList = False
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 6158, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 6158, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6159
 *     def __init__(self, expr, savelist=False):
 *         super(TokenConverter, self).__init__(expr)  # , savelist)
 *         self.saveAsList = False             # <<<<<<<<<<<<<<
 * 
 * class Combine(TokenConverter):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_False) < 0) __PYX_ERR(0, 6159, __pyx_L1_error)

  /* "cPyparsing.pyx":6157
 *     Abstract subclass of :class:`ParseExpression`, for converting parsed results.
 *     """
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(TokenConverter, self).__init__(expr)  # , savelist)
 *         self.saveAsList = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.TokenConverter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6179
 *         print(real.parseString('3. 1416')) # -> Exception: Expected W:(0123...)
 *     """
 *     def __init__(self, expr, joinString="", adjacent=True):             # <<<<<<<<<<<<<<
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Combine_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Combine___init__, "Combine.__init__(self, expr, joinString=u'', adjacent=True)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Combine_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Combine_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Combine___init__};
static PyObject *__pyx_pw_10cPyparsing_7Combine_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_joinString = 0;
  PyObject *__pyx_v_adjacent = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_joinString,&__pyx_n_s_adjacent,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__10)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6179, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6179, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, 1); __PYX_ERR(0, 6179, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_joinString);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6179, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_adjacent);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6179, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 6179, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_joinString = values[2];
    __pyx_v_adjacent = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 6179, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Combine.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Combine___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_joinString, __pyx_v_adjacent);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Combine___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_joinString, PyObject *__pyx_v_adjacent) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":6180
 *     """
 *     def __init__(self, expr, joinString="", adjacent=True):
 *         super(Combine, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 *         if adjacent:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Combine); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 6180, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 6180, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6182
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 *         if adjacent:             # <<<<<<<<<<<<<<
 *             self.leaveWhitespace()
 *         self.adjacent = adjacent
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_adjacent); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 6182, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":6183
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 *         if adjacent:
 *             self.leaveWhitespace()             # <<<<<<<<<<<<<<
 *         self.adjacent = adjacent
 *         self.skipWhitespace = True
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6182
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 *         if adjacent:             # <<<<<<<<<<<<<<
 *             self.leaveWhitespace()
 *         self.adjacent = adjacent
 */
  }

  /* "cPyparsing.pyx":6184
 *         if adjacent:
 *             self.leaveWhitespace()
 *         self.adjacent = adjacent             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.joinString = joinString
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_adjacent, __pyx_v_adjacent) < 0) __PYX_ERR(0, 6184, __pyx_L1_error)

  /* "cPyparsing.pyx":6185
 *             self.leaveWhitespace()
 *         self.adjacent = adjacent
 *         self.skipWhitespace = True             # <<<<<<<<<<<<<<
 *         self.joinString = joinString
 *         self.callPreparse = True
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_True) < 0) __PYX_ERR(0, 6185, __pyx_L1_error)

  /* "cPyparsing.pyx":6186
 *         self.adjacent = adjacent
 *         self.skipWhitespace = True
 *         self.joinString = joinString             # <<<<<<<<<<<<<<
 *         self.callPreparse = True
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_joinString, __pyx_v_joinString) < 0) __PYX_ERR(0, 6186, __pyx_L1_error)

  /* "cPyparsing.pyx":6187
 *         self.skipWhitespace = True
 *         self.joinString = joinString
 *         self.callPreparse = True             # <<<<<<<<<<<<<<
 * 
 *     def ignore(self, other):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse, Py_True) < 0) __PYX_ERR(0, 6187, __pyx_L1_error)

  /* "cPyparsing.pyx":6179
 *         print(real.parseString('3. 1416')) # -> Exception: Expected W:(0123...)
 *     """
 *     def __init__(self, expr, joinString="", adjacent=True):             # <<<<<<<<<<<<<<
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Combine.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6189
 *         self.callPreparse = True
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Combine_3ignore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Combine_2ignore, "Combine.ignore(self, other)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Combine_3ignore = {"ignore", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Combine_3ignore, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Combine_2ignore};
static PyObject *__pyx_pw_10cPyparsing_7Combine_3ignore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ignore (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6189, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6189, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, 1); __PYX_ERR(0, 6189, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "ignore") < 0)) __PYX_ERR(0, 6189, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6189, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Combine.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Combine_2ignore(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Combine_2ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ignore", 1);

  /* "cPyparsing.pyx":6190
 * 
 *     def ignore(self, other):
 *         if self.adjacent:             # <<<<<<<<<<<<<<
 *             ParserElement.ignore(self, other)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adjacent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6191
 *     def ignore(self, other):
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)             # <<<<<<<<<<<<<<
 *         else:
 *             super(Combine, self).ignore(other)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ignore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_self, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6190
 * 
 *     def ignore(self, other):
 *         if self.adjacent:             # <<<<<<<<<<<<<<
 *             ParserElement.ignore(self, other)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":6193
 *             ParserElement.ignore(self, other)
 *         else:
 *             super(Combine, self).ignore(other)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Combine); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 6193, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 6193, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ignore); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6193, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":6194
 *         else:
 *             super(Combine, self).ignore(other)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def postParse(self, instring, loc, tokenlist):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6189
 *         self.callPreparse = True
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Combine.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6196
 *         return self
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Combine_5postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_7Combine_4postParse, "Combine.postParse(self, instring, loc, tokenlist)");
static PyMethodDef __pyx_mdef_10cPyparsing_7Combine_5postParse = {"postParse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7Combine_5postParse, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_7Combine_4postParse};
static PyObject *__pyx_pw_10cPyparsing_7Combine_5postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_tokenlist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6196, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6196, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 6196, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6196, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 6196, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tokenlist)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6196, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 6196, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "postParse") < 0)) __PYX_ERR(0, 6196, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 6196, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Combine.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Combine_4postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Combine_4postParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_v_retToks = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("postParse", 1);

  /* "cPyparsing.pyx":6197
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         retToks = tokenlist.copy()             # <<<<<<<<<<<<<<
 *         del retToks[:]
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_tokenlist, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_retToks = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6198
 *     def postParse(self, instring, loc, tokenlist):
 *         retToks = tokenlist.copy()
 *         del retToks[:]             # <<<<<<<<<<<<<<
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)
 * 
 */
  if (__Pyx_PyObject_DelSlice(__pyx_v_retToks, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1) < 0) __PYX_ERR(0, 6198, __pyx_L1_error)

  /* "cPyparsing.pyx":6199
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)             # <<<<<<<<<<<<<<
 * 
 *         if self.resultsName and retToks.haskeys():
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_tokenlist, __pyx_n_s_asStringList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_joinString); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 6199, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 6199, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_modal, __pyx_t_5) < 0) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_retToks, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_retToks, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6201
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)
 * 
 *         if self.resultsName and retToks.haskeys():             # <<<<<<<<<<<<<<
 *             return [retToks]
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 6201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_retToks, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 6201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":6202
 * 
 *         if self.resultsName and retToks.haskeys():
 *             return [retToks]             # <<<<<<<<<<<<<<
 *         else:
 *             return retToks
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_retToks);
    __Pyx_GIVEREF(__pyx_v_retToks);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_retToks)) __PYX_ERR(0, 6202, __pyx_L1_error);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":6201
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)
 * 
 *         if self.resultsName and retToks.haskeys():             # <<<<<<<<<<<<<<
 *             return [retToks]
 *         else:
 */
  }

  /* "cPyparsing.pyx":6204
 *             return [retToks]
 *         else:
 *             return retToks             # <<<<<<<<<<<<<<
 * 
 * class Group(TokenConverter):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_retToks);
    __pyx_r = __pyx_v_retToks;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":6196
 *         return self
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Combine.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_retToks);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6221
 *         print(func.parseString("fn a, b, 100"))  # -> ['fn', ['a', 'b', '100']]
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Group_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Group___init__, "Group.__init__(self, expr)");
static PyMethodDef __pyx_mdef_10cPyparsing_5Group_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Group_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Group___init__};
static PyObject *__pyx_pw_10cPyparsing_5Group_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6221, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6221, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 6221, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 6221, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6221, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Group.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Group___init__(__pyx_self, __pyx_v_self, __pyx_v_expr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Group___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":6222
 *     """
 *     def __init__(self, expr):
 *         super(Group, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         self.saveAsList = True
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Group); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 6222, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 6222, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6223
 *     def __init__(self, expr):
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True             # <<<<<<<<<<<<<<
 * 
 *     def postParse(self, instring, loc, tokenlist):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_True) < 0) __PYX_ERR(0, 6223, __pyx_L1_error)

  /* "cPyparsing.pyx":6221
 *         print(func.parseString("fn a, b, 100"))  # -> ['fn', ['a', 'b', '100']]
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Group.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6225
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return [tokenlist]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Group_3postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_5Group_2postParse, "Group.postParse(self, instring, loc, tokenlist)");
static PyMethodDef __pyx_mdef_10cPyparsing_5Group_3postParse = {"postParse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5Group_3postParse, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Group_2postParse};
static PyObject *__pyx_pw_10cPyparsing_5Group_3postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_tokenlist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6225, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6225, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 6225, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6225, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 6225, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tokenlist)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6225, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 6225, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "postParse") < 0)) __PYX_ERR(0, 6225, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 6225, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Group.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Group_2postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Group_2postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("postParse", 1);

  /* "cPyparsing.pyx":6226
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         return [tokenlist]             # <<<<<<<<<<<<<<
 * 
 * class Dict(TokenConverter):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_tokenlist);
  __Pyx_GIVEREF(__pyx_v_tokenlist);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_tokenlist)) __PYX_ERR(0, 6226, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6225
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return [tokenlist]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.Group.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6267
 *     See more examples at :class:`ParseResults` of accessing fields by results name.
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Dict_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Dict___init__, "Dict.__init__(self, expr)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Dict_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Dict_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Dict___init__};
static PyObject *__pyx_pw_10cPyparsing_4Dict_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6267, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6267, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 6267, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 6267, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6267, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Dict.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Dict___init__(__pyx_self, __pyx_v_self, __pyx_v_expr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Dict___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":6268
 *     """
 *     def __init__(self, expr):
 *         super(Dict, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         self.saveAsList = True
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 6268, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self)) __PYX_ERR(0, 6268, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6269
 *     def __init__(self, expr):
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True             # <<<<<<<<<<<<<<
 * 
 *     def postParse(self, instring, loc, tokenlist):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_True) < 0) __PYX_ERR(0, 6269, __pyx_L1_error)

  /* "cPyparsing.pyx":6267
 *     See more examples at :class:`ParseResults` of accessing fields by results name.
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Dict.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6271
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Dict_3postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_4Dict_2postParse, "Dict.postParse(self, instring, loc, tokenlist)");
static PyMethodDef __pyx_mdef_10cPyparsing_4Dict_3postParse = {"postParse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_4Dict_3postParse, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_4Dict_2postParse};
static PyObject *__pyx_pw_10cPyparsing_4Dict_3postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_tokenlist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6271, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6271, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 6271, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6271, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 6271, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tokenlist)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6271, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 6271, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "postParse") < 0)) __PYX_ERR(0, 6271, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 6271, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Dict.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Dict_2postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Dict_2postParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_tok = NULL;
  PyObject *__pyx_v_ikey = NULL;
  PyObject *__pyx_v_dictvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("postParse", 1);

  /* "cPyparsing.pyx":6272
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         for i, tok in enumerate(tokenlist):             # <<<<<<<<<<<<<<
 *             if len(tok) == 0:
 *                 continue
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_1 = __pyx_int_0;
  if (likely(PyList_CheckExact(__pyx_v_tokenlist)) || PyTuple_CheckExact(__pyx_v_tokenlist)) {
    __pyx_t_2 = __pyx_v_tokenlist; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_tokenlist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6272, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6272, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 6272, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6272, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6272, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 6272, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6272, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 6272, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_tok, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":6273
 *     def postParse(self, instring, loc, tokenlist):
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             ikey = tok[0]
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_tok); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6273, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_6 == 0);
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":6274
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 *                 continue             # <<<<<<<<<<<<<<
 *             ikey = tok[0]
 *             if isinstance(ikey, int):
 */
      goto __pyx_L3_continue;

      /* "cPyparsing.pyx":6273
 *     def postParse(self, instring, loc, tokenlist):
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             ikey = tok[0]
 */
    }

    /* "cPyparsing.pyx":6275
 *             if len(tok) == 0:
 *                 continue
 *             ikey = tok[0]             # <<<<<<<<<<<<<<
 *             if isinstance(ikey, int):
 *                 ikey = _ustr(tok[0]).strip()
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_tok, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_ikey, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":6276
 *                 continue
 *             ikey = tok[0]
 *             if isinstance(ikey, int):             # <<<<<<<<<<<<<<
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:
 */
    __pyx_t_7 = PyInt_Check(__pyx_v_ikey); 
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":6277
 *             ikey = tok[0]
 *             if isinstance(ikey, int):
 *                 ikey = _ustr(tok[0]).strip()             # <<<<<<<<<<<<<<
 *             if len(tok) == 1:
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ustr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_tok, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_12 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_10};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6277, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      __pyx_t_12 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_12 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_12, 0+__pyx_t_12);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6277, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_ikey, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":6276
 *                 continue
 *             ikey = tok[0]
 *             if isinstance(ikey, int):             # <<<<<<<<<<<<<<
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:
 */
    }

    /* "cPyparsing.pyx":6278
 *             if isinstance(ikey, int):
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:             # <<<<<<<<<<<<<<
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_tok); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6278, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_6 == 1);
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":6279
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)             # <<<<<<<<<<<<<<
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = NULL;
      __pyx_t_12 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_12 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_kp_u__10, __pyx_v_i};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_12, 2+__pyx_t_12);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6279, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      if (unlikely((PyObject_SetItem(__pyx_v_tokenlist, __pyx_v_ikey, __pyx_t_5) < 0))) __PYX_ERR(0, 6279, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":6278
 *             if isinstance(ikey, int):
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:             # <<<<<<<<<<<<<<
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):
 */
      goto __pyx_L7;
    }

    /* "cPyparsing.pyx":6280
 *             if len(tok) == 1:
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):             # <<<<<<<<<<<<<<
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)
 *             else:
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_tok); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6280, __pyx_L1_error)
    __pyx_t_13 = (__pyx_t_6 == 2);
    if (__pyx_t_13) {
    } else {
      __pyx_t_7 = __pyx_t_13;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_tok, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_13 = PyObject_IsInstance(__pyx_t_5, __pyx_t_9); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 6280, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_14 = (!__pyx_t_13);
    __pyx_t_7 = __pyx_t_14;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":6281
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)             # <<<<<<<<<<<<<<
 *             else:
 *                 dictvalue = tok.copy()  # ParseResults(i)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_tok, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_12 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_8, __pyx_v_i};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_12, 2+__pyx_t_12);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6281, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      if (unlikely((PyObject_SetItem(__pyx_v_tokenlist, __pyx_v_ikey, __pyx_t_9) < 0))) __PYX_ERR(0, 6281, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "cPyparsing.pyx":6280
 *             if len(tok) == 1:
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):             # <<<<<<<<<<<<<<
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)
 *             else:
 */
      goto __pyx_L7;
    }

    /* "cPyparsing.pyx":6283
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)
 *             else:
 *                 dictvalue = tok.copy()  # ParseResults(i)             # <<<<<<<<<<<<<<
 *                 del dictvalue[0]
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_tok, __pyx_n_s_copy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6283, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = NULL;
      __pyx_t_12 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_12 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_12, 0+__pyx_t_12);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6283, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_dictvalue, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "cPyparsing.pyx":6284
 *             else:
 *                 dictvalue = tok.copy()  # ParseResults(i)
 *                 del dictvalue[0]             # <<<<<<<<<<<<<<
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)
 */
      if (unlikely((__Pyx_DelItemInt(__pyx_v_dictvalue, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1) < 0))) __PYX_ERR(0, 6284, __pyx_L1_error)

      /* "cPyparsing.pyx":6285
 *                 dictvalue = tok.copy()  # ParseResults(i)
 *                 del dictvalue[0]
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):             # <<<<<<<<<<<<<<
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)
 *                 else:
 */
      __pyx_t_6 = PyObject_Length(__pyx_v_dictvalue); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6285, __pyx_L1_error)
      __pyx_t_14 = (__pyx_t_6 != 1);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_7 = __pyx_t_14;
        goto __pyx_L11_bool_binop_done;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6285, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_14 = PyObject_IsInstance(__pyx_v_dictvalue, __pyx_t_9); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 6285, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (__pyx_t_14) {
      } else {
        __pyx_t_7 = __pyx_t_14;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_dictvalue, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6285, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = NULL;
      __pyx_t_12 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_12 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_12, 0+__pyx_t_12);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6285, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 6285, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_7 = __pyx_t_14;
      __pyx_L11_bool_binop_done:;
      if (__pyx_t_7) {

        /* "cPyparsing.pyx":6286
 *                 del dictvalue[0]
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)             # <<<<<<<<<<<<<<
 *                 else:
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue[0], i)
 */
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6286, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_8 = NULL;
        __pyx_t_12 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_12 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_dictvalue, __pyx_v_i};
          __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_12, 2+__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6286, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        if (unlikely((PyObject_SetItem(__pyx_v_tokenlist, __pyx_v_ikey, __pyx_t_9) < 0))) __PYX_ERR(0, 6286, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "cPyparsing.pyx":6285
 *                 dictvalue = tok.copy()  # ParseResults(i)
 *                 del dictvalue[0]
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):             # <<<<<<<<<<<<<<
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)
 *                 else:
 */
        goto __pyx_L10;
      }

      /* "cPyparsing.pyx":6288
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)
 *                 else:
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue[0], i)             # <<<<<<<<<<<<<<
 * 
 *         if self.resultsName:
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6288, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_dictvalue, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6288, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = NULL;
        __pyx_t_12 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_12 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_8, __pyx_v_i};
          __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_12, 2+__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6288, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        if (unlikely((PyObject_SetItem(__pyx_v_tokenlist, __pyx_v_ikey, __pyx_t_9) < 0))) __PYX_ERR(0, 6288, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __pyx_L10:;
    }
    __pyx_L7:;

    /* "cPyparsing.pyx":6272
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         for i, tok in enumerate(tokenlist):             # <<<<<<<<<<<<<<
 *             if len(tok) == 0:
 *                 continue
 */
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6290
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue[0], i)
 * 
 *         if self.resultsName:             # <<<<<<<<<<<<<<
 *             return [tokenlist]
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 6290, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":6291
 * 
 *         if self.resultsName:
 *             return [tokenlist]             # <<<<<<<<<<<<<<
 *         else:
 *             return tokenlist
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_tokenlist);
    __Pyx_GIVEREF(__pyx_v_tokenlist);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_tokenlist)) __PYX_ERR(0, 6291, __pyx_L1_error);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":6290
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue[0], i)
 * 
 *         if self.resultsName:             # <<<<<<<<<<<<<<
 *             return [tokenlist]
 *         else:
 */
  }

  /* "cPyparsing.pyx":6293
 *             return [tokenlist]
 *         else:
 *             return tokenlist             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_tokenlist);
    __pyx_r = __pyx_v_tokenlist;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":6271
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.Dict.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_tok);
  __Pyx_XDECREF(__pyx_v_ikey);
  __Pyx_XDECREF(__pyx_v_dictvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6318
 *     (See also :class:`delimitedList`.)
 *     """
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return []
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Suppress_1postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_8Suppress_postParse, "Suppress.postParse(self, instring, loc, tokenlist)");
static PyMethodDef __pyx_mdef_10cPyparsing_8Suppress_1postParse = {"postParse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_8Suppress_1postParse, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_8Suppress_postParse};
static PyObject *__pyx_pw_10cPyparsing_8Suppress_1postParse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_tokenlist = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6318, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6318, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 6318, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6318, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 6318, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tokenlist)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6318, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 6318, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "postParse") < 0)) __PYX_ERR(0, 6318, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 6318, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Suppress.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8Suppress_postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Suppress_postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("postParse", 1);

  /* "cPyparsing.pyx":6319
 *     """
 *     def postParse(self, instring, loc, tokenlist):
 *         return []             # <<<<<<<<<<<<<<
 * 
 *     def suppress(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6318
 *     (See also :class:`delimitedList`.)
 *     """
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return []
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.Suppress.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6321
 *         return []
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Suppress_3suppress(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_8Suppress_2suppress, "Suppress.suppress(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_8Suppress_3suppress = {"suppress", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_8Suppress_3suppress, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_8Suppress_2suppress};
static PyObject *__pyx_pw_10cPyparsing_8Suppress_3suppress(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("suppress (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6321, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "suppress") < 0)) __PYX_ERR(0, 6321, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("suppress", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6321, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.Suppress.suppress", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8Suppress_2suppress(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Suppress_2suppress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("suppress", 1);

  /* "cPyparsing.pyx":6322
 * 
 *     def suppress(self):
 *         return self             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6321
 *         return []
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6328
 *     """Wrapper for parse actions, to ensure they are only called once.
 *     """
 *     def __init__(self, methodCall):             # <<<<<<<<<<<<<<
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_8OnlyOnce___init__, "OnlyOnce.__init__(self, methodCall)");
static PyMethodDef __pyx_mdef_10cPyparsing_8OnlyOnce_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_8OnlyOnce_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_8OnlyOnce___init__};
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_methodCall = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_methodCall,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6328, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_methodCall)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6328, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 6328, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 6328, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_methodCall = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6328, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8OnlyOnce___init__(__pyx_self, __pyx_v_self, __pyx_v_methodCall);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_methodCall) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":6329
 *     """
 *     def __init__(self, methodCall):
 *         self.callable = _trim_arity(methodCall)             # <<<<<<<<<<<<<<
 *         self.called = False
 *     def __call__(self, s, l, t):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_trim_arity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_methodCall};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callable, __pyx_t_1) < 0) __PYX_ERR(0, 6329, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6330
 *     def __init__(self, methodCall):
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False             # <<<<<<<<<<<<<<
 *     def __call__(self, s, l, t):
 *         if not self.called:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_called, Py_False) < 0) __PYX_ERR(0, 6330, __pyx_L1_error)

  /* "cPyparsing.pyx":6328
 *     """Wrapper for parse actions, to ensure they are only called once.
 *     """
 *     def __init__(self, methodCall):             # <<<<<<<<<<<<<<
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6331
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 *     def __call__(self, s, l, t):             # <<<<<<<<<<<<<<
 *         if not self.called:
 *             results = self.callable(s, l, t)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_3__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_8OnlyOnce_2__call__, "OnlyOnce.__call__(self, s, l, t)");
static PyMethodDef __pyx_mdef_10cPyparsing_8OnlyOnce_3__call__ = {"__call__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_8OnlyOnce_3__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_8OnlyOnce_2__call__};
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_3__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6331, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6331, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 1, 4, 4, 1); __PYX_ERR(0, 6331, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6331, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 1, 4, 4, 2); __PYX_ERR(0, 6331, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6331, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 1, 4, 4, 3); __PYX_ERR(0, 6331, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__call__") < 0)) __PYX_ERR(0, 6331, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_s = values[1];
    __pyx_v_l = values[2];
    __pyx_v_t = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 6331, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8OnlyOnce_2__call__(__pyx_self, __pyx_v_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 1);

  /* "cPyparsing.pyx":6332
 *         self.called = False
 *     def __call__(self, s, l, t):
 *         if not self.called:             # <<<<<<<<<<<<<<
 *             results = self.callable(s, l, t)
 *             self.called = True
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_called); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6332, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":6333
 *     def __call__(self, s, l, t):
 *         if not self.called:
 *             results = self.callable(s, l, t)             # <<<<<<<<<<<<<<
 *             self.called = True
 *             return results
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callable); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_v_t};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6333, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_results = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6334
 *         if not self.called:
 *             results = self.callable(s, l, t)
 *             self.called = True             # <<<<<<<<<<<<<<
 *             return results
 *         raise ParseException(s, l, "")
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_called, Py_True) < 0) __PYX_ERR(0, 6334, __pyx_L1_error)

    /* "cPyparsing.pyx":6335
 *             results = self.callable(s, l, t)
 *             self.called = True
 *             return results             # <<<<<<<<<<<<<<
 *         raise ParseException(s, l, "")
 *     def reset(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_results);
    __pyx_r = __pyx_v_results;
    goto __pyx_L0;

    /* "cPyparsing.pyx":6332
 *         self.called = False
 *     def __call__(self, s, l, t):
 *         if not self.called:             # <<<<<<<<<<<<<<
 *             results = self.callable(s, l, t)
 *             self.called = True
 */
  }

  /* "cPyparsing.pyx":6336
 *             self.called = True
 *             return results
 *         raise ParseException(s, l, "")             # <<<<<<<<<<<<<<
 *     def reset(self):
 *         self.called = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_kp_u__10};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 6336, __pyx_L1_error)

  /* "cPyparsing.pyx":6331
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 *     def __call__(self, s, l, t):             # <<<<<<<<<<<<<<
 *         if not self.called:
 *             results = self.callable(s, l, t)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6337
 *             return results
 *         raise ParseException(s, l, "")
 *     def reset(self):             # <<<<<<<<<<<<<<
 *         self.called = False
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_5reset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_8OnlyOnce_4reset, "OnlyOnce.reset(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_8OnlyOnce_5reset = {"reset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_8OnlyOnce_5reset, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_8OnlyOnce_4reset};
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_5reset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6337, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "reset") < 0)) __PYX_ERR(0, 6337, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("reset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6337, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.reset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8OnlyOnce_4reset(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce_4reset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reset", 1);

  /* "cPyparsing.pyx":6338
 *         raise ParseException(s, l, "")
 *     def reset(self):
 *         self.called = False             # <<<<<<<<<<<<<<
 * 
 * def traceParseAction(f):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_called, Py_False) < 0) __PYX_ERR(0, 6338, __pyx_L1_error)

  /* "cPyparsing.pyx":6337
 *             return results
 *         raise ParseException(s, l, "")
 *     def reset(self):             # <<<<<<<<<<<<<<
 *         self.called = False
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.reset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6340
 *         self.called = False
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """Decorator for debugging parse actions.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_29traceParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_28traceParseAction, "traceParseAction(f)\nDecorator for debugging parse actions.\n\n    When the parse action is called, this decorator will print\n    ``\">> entering method-name(line:<current_source_line>, <parse_location>, <matched_tokens>)\"``.\n    When the parse action completes, the decorator will print\n    ``\"<<\"`` followed by the returned value, or any exception that the parse action raised.\n\n    Example::\n\n        wd = Word(alphas)\n\n        @traceParseAction\n        def remove_duplicate_chars(tokens):\n            return ''.join(sorted(set(''.join(tokens))))\n\n        wds = OneOrMore(wd).setParseAction(remove_duplicate_chars)\n        print(wds.parseString(\"slkdjs sld sldd sdlf sdljf\"))\n\n    prints::\n\n        >>entering remove_duplicate_chars(line: 'slkdjs sld sldd sdlf sdljf', 0, (['slkdjs', 'sld', 'sldd', 'sdlf', 'sdljf'], {}))\n        <<leaving remove_duplicate_chars (ret: 'dfjkls')\n        ['dfjkls']\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_29traceParseAction = {"traceParseAction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_29traceParseAction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_28traceParseAction};
static PyObject *__pyx_pw_10cPyparsing_29traceParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_f = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("traceParseAction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_f_2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_f_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6340, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "traceParseAction") < 0)) __PYX_ERR(0, 6340, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_f = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("traceParseAction", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6340, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.traceParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_28traceParseAction(__pyx_self, __pyx_v_f);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6366
 *     """
 *     f = _trim_arity(f)
 *     def z(*paArgs):             # <<<<<<<<<<<<<<
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16traceParseAction_1z(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16traceParseAction_1z = {"z", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_10cPyparsing_16traceParseAction_1z, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16traceParseAction_1z(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_paArgs = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("z (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "z", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_paArgs = __pyx_args;
  __pyx_r = __pyx_pf_10cPyparsing_16traceParseAction_z(__pyx_self, __pyx_v_paArgs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_paArgs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16traceParseAction_z(PyObject *__pyx_self, PyObject *__pyx_v_paArgs) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *__pyx_outer_scope;
  PyObject *__pyx_v_thisFunc = NULL;
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  Py_UCS4 __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("z", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":6367
 *     f = _trim_arity(f)
 *     def z(*paArgs):
 *         thisFunc = f.__name__             # <<<<<<<<<<<<<<
 *         s, l, t = paArgs[-3:]
 *         if len(paArgs) > 3:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_f)) { __Pyx_RaiseClosureNameError("f"); __PYX_ERR(0, 6367, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_f, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_thisFunc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6368
 *     def z(*paArgs):
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]             # <<<<<<<<<<<<<<
 *         if len(paArgs) > 3:
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 */
  __pyx_t_1 = __Pyx_PyTuple_GetSlice(__pyx_v_paArgs, -3L, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (1) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 6368, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2); 
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_s = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_l = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_t = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":6369
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 *         if len(paArgs) > 3:             # <<<<<<<<<<<<<<
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 */
  __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(__pyx_v_paArgs); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6369, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 > 3);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":6370
 *         s, l, t = paArgs[-3:]
 *         if len(paArgs) > 3:
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc             # <<<<<<<<<<<<<<
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:
 */
    __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_paArgs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__117); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_v_thisFunc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_thisFunc, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6369
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 *         if len(paArgs) > 3:             # <<<<<<<<<<<<<<
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 */
  }

  /* "cPyparsing.pyx":6371
 *         if len(paArgs) > 3:
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))             # <<<<<<<<<<<<<<
 *         try:
 *             ret = f(*paArgs)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_sys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_stderr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_write); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = 0;
  __pyx_t_7 = 127;
  __Pyx_INCREF(__pyx_kp_u_entering);
  __pyx_t_5 += 11;
  __Pyx_GIVEREF(__pyx_kp_u_entering);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_entering);
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_thisFunc), __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_7;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_kp_u_line_3);
  __pyx_t_5 += 8;
  __Pyx_GIVEREF(__pyx_kp_u_line_3);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_line_3);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_line); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_v_l, __pyx_v_s};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6371, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_2), __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_7;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_INCREF(__pyx_kp_u__118);
  __pyx_t_5 += 3;
  __Pyx_GIVEREF(__pyx_kp_u__118);
  PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_kp_u__118);
  __pyx_t_8 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_IntOrLong(__pyx_v_l), __pyx_n_u_d); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_7;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_INCREF(__pyx_kp_u__3);
  __pyx_t_5 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__3);
  PyTuple_SET_ITEM(__pyx_t_3, 6, __pyx_kp_u__3);
  __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_t), __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_7;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_3, 7, __pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_INCREF(__pyx_kp_u__119);
  __pyx_t_5 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__119);
  PyTuple_SET_ITEM(__pyx_t_3, 8, __pyx_kp_u__119);
  __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_3, 9, __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6371, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6372
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:             # <<<<<<<<<<<<<<
 *             ret = f(*paArgs)
 *         except Exception as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_13);
    /*try:*/ {

      /* "cPyparsing.pyx":6373
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:
 *             ret = f(*paArgs)             # <<<<<<<<<<<<<<
 *         except Exception as exc:
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 */
      if (unlikely(!__pyx_cur_scope->__pyx_v_f)) { __Pyx_RaiseClosureNameError("f"); __PYX_ERR(0, 6373, __pyx_L4_error) }
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_f, __pyx_v_paArgs, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6373, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_ret = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":6372
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:             # <<<<<<<<<<<<<<
 *             ret = f(*paArgs)
 *         except Exception as exc:
 */
    }
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":6374
 *         try:
 *             ret = f(*paArgs)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 *             raise
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("cPyparsing.traceParseAction.z", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_8) < 0) __PYX_ERR(0, 6374, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_v_exc = __pyx_t_4;
      /*try:*/ {

        /* "cPyparsing.pyx":6375
 *             ret = f(*paArgs)
 *         except Exception as exc:
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))             # <<<<<<<<<<<<<<
 *             raise
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 */
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6375, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_stderr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6375, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_write); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6375, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = PyTuple_New(5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6375, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_5 = 0;
        __pyx_t_7 = 127;
        __Pyx_INCREF(__pyx_kp_u_leaving);
        __pyx_t_5 += 10;
        __Pyx_GIVEREF(__pyx_kp_u_leaving);
        PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_kp_u_leaving);
        __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_thisFunc), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6375, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_7;
        __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
        __Pyx_GIVEREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_14);
        __pyx_t_14 = 0;
        __Pyx_INCREF(__pyx_kp_u_exception);
        __pyx_t_5 += 13;
        __Pyx_GIVEREF(__pyx_kp_u_exception);
        PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_kp_u_exception);
        __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_exc), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6375, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_7;
        __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
        __Pyx_GIVEREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_14);
        __pyx_t_14 = 0;
        __Pyx_INCREF(__pyx_kp_u__119);
        __pyx_t_5 += 2;
        __Pyx_GIVEREF(__pyx_kp_u__119);
        PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_kp_u__119);
        __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6375, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_14};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6375, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "cPyparsing.pyx":6376
 *         except Exception as exc:
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 *             raise             # <<<<<<<<<<<<<<
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret
 */
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_4, __pyx_t_8);
        __pyx_t_1 = 0; __pyx_t_4 = 0; __pyx_t_8 = 0; 
        __PYX_ERR(0, 6376, __pyx_L15_error)
      }

      /* "cPyparsing.pyx":6374
 *         try:
 *             ret = f(*paArgs)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 *             raise
 */
      /*finally:*/ {
        __pyx_L15_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __pyx_t_10 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc); __pyx_v_exc = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
          __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
          goto __pyx_L6_except_error;
        }
      }
    }
    goto __pyx_L6_except_error;

    /* "cPyparsing.pyx":6372
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:             # <<<<<<<<<<<<<<
 *             ret = f(*paArgs)
 *         except Exception as exc:
 */
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
    goto __pyx_L1_error;
    __pyx_L9_try_end:;
  }

  /* "cPyparsing.pyx":6377
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 *             raise
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))             # <<<<<<<<<<<<<<
 *         return ret
 *     try:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_sys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_stderr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_write); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = 0;
  __pyx_t_7 = 127;
  __Pyx_INCREF(__pyx_kp_u_leaving);
  __pyx_t_5 += 10;
  __Pyx_GIVEREF(__pyx_kp_u_leaving);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_leaving);
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_thisFunc), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_7;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u_ret_2);
  __pyx_t_5 += 7;
  __Pyx_GIVEREF(__pyx_kp_u_ret_2);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_ret_2);
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_ret), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_7;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u__119);
  __pyx_t_5 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__119);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u__119);
  __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_15 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_15 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_3};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":6378
 *             raise
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret             # <<<<<<<<<<<<<<
 *     try:
 *         z.__name__ = f.__name__
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6366
 *     """
 *     f = _trim_arity(f)
 *     def z(*paArgs):             # <<<<<<<<<<<<<<
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("cPyparsing.traceParseAction.z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_thisFunc);
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6340
 *         self.called = False
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """Decorator for debugging parse actions.
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_28traceParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_f) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *__pyx_cur_scope;
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("traceParseAction", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_52_traceParseAction(__pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6340, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_f = __pyx_v_f;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_f);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_f);

  /* "cPyparsing.pyx":6365
 *         ['dfjkls']
 *     """
 *     f = _trim_arity(f)             # <<<<<<<<<<<<<<
 *     def z(*paArgs):
 *         thisFunc = f.__name__
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_trim_arity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_f};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6365, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_f);
  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_f, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6366
 *     """
 *     f = _trim_arity(f)
 *     def z(*paArgs):             # <<<<<<<<<<<<<<
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16traceParseAction_1z, 0, __pyx_n_s_traceParseAction_locals_z, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__121)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_z = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6379
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret
 *     try:             # <<<<<<<<<<<<<<
 *         z.__name__ = f.__name__
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    /*try:*/ {

      /* "cPyparsing.pyx":6380
 *         return ret
 *     try:
 *         z.__name__ = f.__name__             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         pass
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_f, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6380, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_z, __pyx_n_s_name, __pyx_t_1) < 0) __PYX_ERR(0, 6380, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":6379
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret
 *     try:             # <<<<<<<<<<<<<<
 *         z.__name__ = f.__name__
 *     except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":6381
 *     try:
 *         z.__name__ = f.__name__
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         pass
 *     return z
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_4) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":6379
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret
 *     try:             # <<<<<<<<<<<<<<
 *         z.__name__ = f.__name__
 *     except AttributeError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    __pyx_L8_try_end:;
  }

  /* "cPyparsing.pyx":6383
 *     except AttributeError:
 *         pass
 *     return z             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_z);
  __pyx_r = __pyx_v_z;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6340
 *         self.called = False
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """Decorator for debugging parse actions.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.traceParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_z);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6388
 * # global helpers
 * #
 * def delimitedList(expr, delim=",", combine=False):             # <<<<<<<<<<<<<<
 *     """Helper to define a delimited list of expressions - the delimiter
 *     defaults to ','. By default, the list elements and delimiters can
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_31delimitedList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_30delimitedList, "delimitedList(expr, delim=u',', combine=False)\nHelper to define a delimited list of expressions - the delimiter\n    defaults to ','. By default, the list elements and delimiters can\n    have intervening whitespace, and comments, but this can be\n    overridden by passing ``combine=True`` in the constructor. If\n    ``combine`` is set to ``True``, the matching tokens are\n    returned as a single token string, with the delimiters included;\n    otherwise, the matching tokens are returned as a list of tokens,\n    with the delimiters suppressed.\n\n    Example::\n\n        delimitedList(Word(alphas)).parseString(\"aa,bb,cc\") # -> ['aa', 'bb', 'cc']\n        delimitedList(Word(hexnums), delim=':', combine=True).parseString(\"AA:BB:CC:DD:EE\") # -> ['AA:BB:CC:DD:EE']\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_31delimitedList = {"delimitedList", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_31delimitedList, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_30delimitedList};
static PyObject *__pyx_pw_10cPyparsing_31delimitedList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_delim = 0;
  PyObject *__pyx_v_combine = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delimitedList (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,&__pyx_n_s_delim,&__pyx_n_s_combine,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__34)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6388, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delim);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6388, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_combine);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6388, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "delimitedList") < 0)) __PYX_ERR(0, 6388, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_expr = values[0];
    __pyx_v_delim = values[1];
    __pyx_v_combine = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("delimitedList", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 6388, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.delimitedList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_30delimitedList(__pyx_self, __pyx_v_expr, __pyx_v_delim, __pyx_v_combine);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_30delimitedList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_delim, PyObject *__pyx_v_combine) {
  PyObject *__pyx_v_dlName = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delimitedList", 1);

  /* "cPyparsing.pyx":6403
 *         delimitedList(Word(hexnums), delim=':', combine=True).parseString("AA:BB:CC:DD:EE") # -> ['AA:BB:CC:DD:EE']
 *     """
 *     dlName = _ustr(expr) + " [" + _ustr(delim) + " " + _ustr(expr) + "]..."             # <<<<<<<<<<<<<<
 *     if combine:
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_expr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__122); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_delim};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_expr};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__115); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_dlName = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6404
 *     """
 *     dlName = _ustr(expr) + " [" + _ustr(delim) + " " + _ustr(expr) + "]..."
 *     if combine:             # <<<<<<<<<<<<<<
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)
 *     else:
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_combine); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 6404, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":6405
 *     dlName = _ustr(expr) + " [" + _ustr(delim) + " " + _ustr(expr) + "]..."
 *     if combine:
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)             # <<<<<<<<<<<<<<
 *     else:
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Combine); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 6405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyNumber_Add(__pyx_v_delim, __pyx_v_expr); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6405, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_7 = PyNumber_Add(__pyx_v_expr, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 6405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_7};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6405, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_dlName};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6405, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":6404
 *     """
 *     dlName = _ustr(expr) + " [" + _ustr(delim) + " " + _ustr(expr) + "]..."
 *     if combine:             # <<<<<<<<<<<<<<
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)
 *     else:
 */
  }

  /* "cPyparsing.pyx":6407
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)
 *     else:
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)             # <<<<<<<<<<<<<<
 * 
 * def countedArray(expr, intExpr=None):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_delim};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 6407, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = PyNumber_Add(__pyx_t_7, __pyx_v_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6407, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = PyNumber_Add(__pyx_v_expr, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_dlName};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6407, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":6388
 * # global helpers
 * #
 * def delimitedList(expr, delim=",", combine=False):             # <<<<<<<<<<<<<<
 *     """Helper to define a delimited list of expressions - the delimiter
 *     defaults to ','. By default, the list elements and delimiters can
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.delimitedList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dlName);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6409
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """Helper to define a counted list of expressions.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_33countedArray(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_32countedArray, "countedArray(expr, intExpr=None)\nHelper to define a counted list of expressions.\n\n    This helper defines a pattern of the form::\n\n        integer expr expr expr...\n\n    where the leading integer tells how many expr expressions follow.\n    The matched tokens returns the array of expr tokens as a list - the\n    leading count token is suppressed.\n\n    If ``intExpr`` is specified, it should be a pyparsing expression\n    that produces an integer value.\n\n    Example::\n\n        countedArray(Word(alphas)).parseString('2 ab cd ef')  # -> ['ab', 'cd']\n\n        # in this parser, the leading integer value is given in binary,\n        # '10' indicating that 2 values are in the array\n        binaryConstant = Word('01').setParseAction(lambda t: int(t[0], 2))\n        countedArray(Word(alphas), intExpr=binaryConstant).parseString('10 ab cd ef')  # -> ['ab', 'cd']\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_33countedArray = {"countedArray", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_33countedArray, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_32countedArray};
static PyObject *__pyx_pw_10cPyparsing_33countedArray(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_intExpr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("countedArray (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,&__pyx_n_s_intExpr,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6409, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_intExpr);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6409, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "countedArray") < 0)) __PYX_ERR(0, 6409, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_expr = values[0];
    __pyx_v_intExpr = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("countedArray", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 6409, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.countedArray", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_32countedArray(__pyx_self, __pyx_v_expr, __pyx_v_intExpr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6433
 *     """
 *     arrayExpr = Forward()
 *     def countFieldParseAction(s, l, t):             # <<<<<<<<<<<<<<
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12countedArray_1countFieldParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12countedArray_1countFieldParseAction = {"countFieldParseAction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12countedArray_1countFieldParseAction, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12countedArray_1countFieldParseAction(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("countFieldParseAction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6433, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6433, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("countFieldParseAction", 1, 3, 3, 1); __PYX_ERR(0, 6433, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6433, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("countFieldParseAction", 1, 3, 3, 2); __PYX_ERR(0, 6433, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "countFieldParseAction") < 0)) __PYX_ERR(0, 6433, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("countFieldParseAction", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6433, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.countedArray.countFieldParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12countedArray_countFieldParseAction(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12countedArray_countFieldParseAction(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *__pyx_outer_scope;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("countFieldParseAction", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":6434
 *     arrayExpr = Forward()
 *     def countFieldParseAction(s, l, t):
 *         n = t[0]             # <<<<<<<<<<<<<<
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 *         return []
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6435
 *     def countFieldParseAction(s, l, t):
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))             # <<<<<<<<<<<<<<
 *         return []
 *     if intExpr is None:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_arrayExpr)) { __Pyx_RaiseClosureNameError("arrayExpr"); __PYX_ERR(0, 6435, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_n); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6435, __pyx_L1_error)
  if (!__pyx_t_2) {
    goto __pyx_L4_next_or;
  } else {
  }
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Group); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_And); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (unlikely(!__pyx_cur_scope->__pyx_v_expr)) { __Pyx_RaiseClosureNameError("expr"); __PYX_ERR(0, 6435, __pyx_L1_error) }
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 6435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_expr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_expr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_7, 0, __pyx_cur_scope->__pyx_v_expr)) __PYX_ERR(0, 6435, __pyx_L1_error);
  { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_7, __pyx_v_n); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 6435, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_temp);
    __Pyx_DECREF(__pyx_t_7);
    __pyx_t_7 = __pyx_temp;
  }
  __pyx_t_8 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6435, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6435, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6435, __pyx_L1_error)
  if (!__pyx_t_2) {
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_L4_next_or:;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Group); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6435, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_t_3 = PyNumber_Lshift(__pyx_cur_scope->__pyx_v_arrayExpr, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6436
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 *         return []             # <<<<<<<<<<<<<<
 *     if intExpr is None:
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6433
 *     """
 *     arrayExpr = Forward()
 *     def countFieldParseAction(s, l, t):             # <<<<<<<<<<<<<<
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.countedArray.countFieldParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6438
 *         return []
 *     if intExpr is None:
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))             # <<<<<<<<<<<<<<
 *     else:
 *         intExpr = intExpr.copy()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12countedArray_2lambda41(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12countedArray_2lambda41 = {"lambda41", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_12countedArray_2lambda41, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12countedArray_2lambda41(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda41 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6438, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda41") < 0)) __PYX_ERR(0, 6438, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda41", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6438, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.countedArray.lambda41", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda41(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda41(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda41", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.countedArray.lambda41", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6409
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """Helper to define a counted list of expressions.
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_32countedArray(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_intExpr) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *__pyx_cur_scope;
  PyObject *__pyx_v_countFieldParseAction = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("countedArray", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_53_countedArray(__pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6409, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_expr = __pyx_v_expr;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_expr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_expr);
  __Pyx_INCREF(__pyx_v_intExpr);

  /* "cPyparsing.pyx":6432
 *         countedArray(Word(alphas), intExpr=binaryConstant).parseString('10 ab cd ef')  # -> ['ab', 'cd']
 *     """
 *     arrayExpr = Forward()             # <<<<<<<<<<<<<<
 *     def countFieldParseAction(s, l, t):
 *         n = t[0]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_arrayExpr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6433
 *     """
 *     arrayExpr = Forward()
 *     def countFieldParseAction(s, l, t):             # <<<<<<<<<<<<<<
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12countedArray_1countFieldParseAction, 0, __pyx_n_s_countedArray_locals_countFieldPa, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__124)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_countFieldParseAction = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6437
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 *         return []
 *     if intExpr is None:             # <<<<<<<<<<<<<<
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))
 *     else:
 */
  __pyx_t_5 = (__pyx_v_intExpr == Py_None);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":6438
 *         return []
 *     if intExpr is None:
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))             # <<<<<<<<<<<<<<
 *     else:
 *         intExpr = intExpr.copy()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Word); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_nums); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12countedArray_2lambda41, 0, __pyx_n_s_countedArray_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_intExpr, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6437
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 *         return []
 *     if intExpr is None:             # <<<<<<<<<<<<<<
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))
 *     else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":6440
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))
 *     else:
 *         intExpr = intExpr.copy()             # <<<<<<<<<<<<<<
 *     intExpr.setName("arrayLen")
 *     intExpr.addParseAction(countFieldParseAction, callDuringTry=True)
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_intExpr, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6440, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_intExpr, __pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":6441
 *     else:
 *         intExpr = intExpr.copy()
 *     intExpr.setName("arrayLen")             # <<<<<<<<<<<<<<
 *     intExpr.addParseAction(countFieldParseAction, callDuringTry=True)
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_intExpr, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_arrayLen};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6441, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6442
 *         intExpr = intExpr.copy()
 *     intExpr.setName("arrayLen")
 *     intExpr.addParseAction(countFieldParseAction, callDuringTry=True)             # <<<<<<<<<<<<<<
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_intExpr, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_countFieldParseAction);
  __Pyx_GIVEREF(__pyx_v_countFieldParseAction);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_countFieldParseAction)) __PYX_ERR(0, 6442, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_callDuringTry, Py_True) < 0) __PYX_ERR(0, 6442, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cPyparsing.pyx":6443
 *     intExpr.setName("arrayLen")
 *     intExpr.addParseAction(countFieldParseAction, callDuringTry=True)
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')             # <<<<<<<<<<<<<<
 * 
 * def _flatten(L):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyNumber_Add(__pyx_v_intExpr, __pyx_cur_scope->__pyx_v_arrayExpr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ustr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_expr};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_len, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__67); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6409
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """Helper to define a counted list of expressions.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.countedArray", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_countFieldParseAction);
  __Pyx_XDECREF(__pyx_v_intExpr);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6445
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')
 * 
 * def _flatten(L):             # <<<<<<<<<<<<<<
 *     ret = []
 *     for i in L:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_35_flatten(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_34_flatten, "_flatten(L)");
static PyMethodDef __pyx_mdef_10cPyparsing_35_flatten = {"_flatten", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_35_flatten, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_34_flatten};
static PyObject *__pyx_pw_10cPyparsing_35_flatten(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_L = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_flatten (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_L,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_L)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6445, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_flatten") < 0)) __PYX_ERR(0, 6445, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_L = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_flatten", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6445, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._flatten", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_34_flatten(__pyx_self, __pyx_v_L);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_34_flatten(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_L) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_flatten", 1);

  /* "cPyparsing.pyx":6446
 * 
 * def _flatten(L):
 *     ret = []             # <<<<<<<<<<<<<<
 *     for i in L:
 *         if isinstance(i, list):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ret = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6447
 * def _flatten(L):
 *     ret = []
 *     for i in L:             # <<<<<<<<<<<<<<
 *         if isinstance(i, list):
 *             ret.extend(_flatten(i))
 */
  if (likely(PyList_CheckExact(__pyx_v_L)) || PyTuple_CheckExact(__pyx_v_L)) {
    __pyx_t_1 = __pyx_v_L; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6447, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6447, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6447, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6447, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6447, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6447, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6447, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 6447, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6448
 *     ret = []
 *     for i in L:
 *         if isinstance(i, list):             # <<<<<<<<<<<<<<
 *             ret.extend(_flatten(i))
 *         else:
 */
    __pyx_t_5 = PyList_Check(__pyx_v_i); 
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":6449
 *     for i in L:
 *         if isinstance(i, list):
 *             ret.extend(_flatten(i))             # <<<<<<<<<<<<<<
 *         else:
 *             ret.append(i)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_flatten); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6449, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_i};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6449, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_t_9 = __Pyx_PyList_Extend(__pyx_v_ret, __pyx_t_4); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 6449, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":6448
 *     ret = []
 *     for i in L:
 *         if isinstance(i, list):             # <<<<<<<<<<<<<<
 *             ret.extend(_flatten(i))
 *         else:
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":6451
 *             ret.extend(_flatten(i))
 *         else:
 *             ret.append(i)             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
    /*else*/ {
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_v_i); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 6451, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "cPyparsing.pyx":6447
 * def _flatten(L):
 *     ret = []
 *     for i in L:             # <<<<<<<<<<<<<<
 *         if isinstance(i, list):
 *             ret.extend(_flatten(i))
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6452
 *         else:
 *             ret.append(i)
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * def matchPreviousLiteral(expr):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6445
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')
 * 
 * def _flatten(L):             # <<<<<<<<<<<<<<
 *     ret = []
 *     for i in L:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing._flatten", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6454
 *     return ret
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_37matchPreviousLiteral(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_36matchPreviousLiteral, "matchPreviousLiteral(expr)\nHelper to define an expression that is indirectly defined from\n    the tokens matched in a previous expression, that is, it looks for\n    a 'repeat' of a previous expression.  For example::\n\n        first = Word(nums)\n        second = matchPreviousLiteral(first)\n        matchExpr = first + \":\" + second\n\n    will match ``\"1:1\"``, but not ``\"1:2\"``.  Because this\n    matches a previous literal, will also match the leading\n    ``\"1:1\"`` in ``\"1:10\"``. If this is not desired, use\n    :class:`matchPreviousExpr`. Do *not* use with packrat parsing\n    enabled.\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_37matchPreviousLiteral = {"matchPreviousLiteral", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_37matchPreviousLiteral, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_36matchPreviousLiteral};
static PyObject *__pyx_pw_10cPyparsing_37matchPreviousLiteral(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_expr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matchPreviousLiteral (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6454, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "matchPreviousLiteral") < 0)) __PYX_ERR(0, 6454, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_expr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("matchPreviousLiteral", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6454, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.matchPreviousLiteral", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_36matchPreviousLiteral(__pyx_self, __pyx_v_expr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6470
 *     """
 *     rep = Forward()
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater = {"copyTokenToRepeater", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copyTokenToRepeater (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6470, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6470, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, 1); __PYX_ERR(0, 6470, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6470, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, 2); __PYX_ERR(0, 6470, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "copyTokenToRepeater") < 0)) __PYX_ERR(0, 6470, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6470, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.matchPreviousLiteral.copyTokenToRepeater", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_20matchPreviousLiteral_copyTokenToRepeater(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_2generator39(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":6477
 *                 # flatten t tokens
 *                 tflat = _flatten(t.asList())
 *                 rep << And(Literal(tt) for tt in tflat)             # <<<<<<<<<<<<<<
 *         else:
 *             rep << Empty()
 */

static PyObject *__pyx_pf_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_55_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6477, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_2generator39, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_matchPreviousLiteral_locals_copy, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 6477, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.matchPreviousLiteral.copyTokenToRepeater.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_2generator39(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 6477, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 6477, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6477, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6477, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6477, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6477, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6477, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6477, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6477, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 6477, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_tt);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_tt, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Literal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_tt};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6477, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 6477, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6470
 *     """
 *     rep = Forward()
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */

static PyObject *__pyx_pf_10cPyparsing_20matchPreviousLiteral_copyTokenToRepeater(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *__pyx_outer_scope;
  PyObject *__pyx_v_tflat = NULL;
  PyObject *__pyx_gb_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_2generator39 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copyTokenToRepeater", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":6471
 *     rep = Forward()
 *     def copyTokenToRepeater(s, l, t):
 *         if t:             # <<<<<<<<<<<<<<
 *             if len(t) == 1:
 *                 rep << t[0]
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 6471, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":6472
 *     def copyTokenToRepeater(s, l, t):
 *         if t:
 *             if len(t) == 1:             # <<<<<<<<<<<<<<
 *                 rep << t[0]
 *             else:
 */
    __pyx_t_2 = PyObject_Length(__pyx_v_t); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6472, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 == 1);
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":6473
 *         if t:
 *             if len(t) == 1:
 *                 rep << t[0]             # <<<<<<<<<<<<<<
 *             else:
 *                 # flatten t tokens
 */
      if (unlikely(!__pyx_cur_scope->__pyx_v_rep)) { __Pyx_RaiseClosureNameError("rep"); __PYX_ERR(0, 6473, __pyx_L1_error) }
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6473, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyNumber_Lshift(__pyx_cur_scope->__pyx_v_rep, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6473, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":6472
 *     def copyTokenToRepeater(s, l, t):
 *         if t:
 *             if len(t) == 1:             # <<<<<<<<<<<<<<
 *                 rep << t[0]
 *             else:
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":6476
 *             else:
 *                 # flatten t tokens
 *                 tflat = _flatten(t.asList())             # <<<<<<<<<<<<<<
 *                 rep << And(Literal(tt) for tt in tflat)
 *         else:
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_flatten); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_asList); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6476, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_t_6 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6476, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_v_tflat = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":6477
 *                 # flatten t tokens
 *                 tflat = _flatten(t.asList())
 *                 rep << And(Literal(tt) for tt in tflat)             # <<<<<<<<<<<<<<
 *         else:
 *             rep << Empty()
 */
      if (unlikely(!__pyx_cur_scope->__pyx_v_rep)) { __Pyx_RaiseClosureNameError("rep"); __PYX_ERR(0, 6477, __pyx_L1_error) }
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_And); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6477, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __pyx_pf_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_genexpr(NULL, __pyx_v_tflat); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6477, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6477, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_3 = PyNumber_Lshift(__pyx_cur_scope->__pyx_v_rep, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6477, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":6471
 *     rep = Forward()
 *     def copyTokenToRepeater(s, l, t):
 *         if t:             # <<<<<<<<<<<<<<
 *             if len(t) == 1:
 *                 rep << t[0]
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":6479
 *                 rep << And(Literal(tt) for tt in tflat)
 *         else:
 *             rep << Empty()             # <<<<<<<<<<<<<<
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))
 */
  /*else*/ {
    if (unlikely(!__pyx_cur_scope->__pyx_v_rep)) { __Pyx_RaiseClosureNameError("rep"); __PYX_ERR(0, 6479, __pyx_L1_error) }
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = PyNumber_Lshift(__pyx_cur_scope->__pyx_v_rep, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":6470
 *     """
 *     rep = Forward()
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.matchPreviousLiteral.copyTokenToRepeater", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tflat);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_2generator39);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6454
 *     return ret
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */

static PyObject *__pyx_pf_10cPyparsing_36matchPreviousLiteral(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *__pyx_cur_scope;
  PyObject *__pyx_v_copyTokenToRepeater = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matchPreviousLiteral", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral(__pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6454, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":6469
 *     enabled.
 *     """
 *     rep = Forward()             # <<<<<<<<<<<<<<
 *     def copyTokenToRepeater(s, l, t):
 *         if t:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6469, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_rep = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6470
 *     """
 *     rep = Forward()
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater, 0, __pyx_n_s_matchPreviousLiteral_locals_copy_2, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__126)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_copyTokenToRepeater = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6480
 *         else:
 *             rep << Empty()
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)             # <<<<<<<<<<<<<<
 *     rep.setName('(prev) ' + _ustr(expr))
 *     return rep
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_copyTokenToRepeater);
  __Pyx_GIVEREF(__pyx_v_copyTokenToRepeater);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_copyTokenToRepeater)) __PYX_ERR(0, 6480, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_callDuringTry, Py_True) < 0) __PYX_ERR(0, 6480, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":6481
 *             rep << Empty()
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))             # <<<<<<<<<<<<<<
 *     return rep
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rep, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ustr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_expr};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6481, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_prev, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6481, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":6482
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))
 *     return rep             # <<<<<<<<<<<<<<
 * 
 * def matchPreviousExpr(expr):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_rep);
  __pyx_r = __pyx_cur_scope->__pyx_v_rep;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6454
 *     return ret
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.matchPreviousLiteral", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_copyTokenToRepeater);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6484
 *     return rep
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_39matchPreviousExpr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_38matchPreviousExpr, "matchPreviousExpr(expr)\nHelper to define an expression that is indirectly defined from\n    the tokens matched in a previous expression, that is, it looks for\n    a 'repeat' of a previous expression.  For example::\n\n        first = Word(nums)\n        second = matchPreviousExpr(first)\n        matchExpr = first + \":\" + second\n\n    will match ``\"1:1\"``, but not ``\"1:2\"``.  Because this\n    matches by expressions, will *not* match the leading ``\"1:1\"``\n    in ``\"1:10\"``; the expressions are evaluated first, and then\n    compared, so ``\"1\"`` is compared with ``\"10\"``. Do *not* use\n    with packrat parsing enabled.\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_39matchPreviousExpr = {"matchPreviousExpr", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_39matchPreviousExpr, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_38matchPreviousExpr};
static PyObject *__pyx_pw_10cPyparsing_39matchPreviousExpr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_expr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matchPreviousExpr (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6484, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "matchPreviousExpr") < 0)) __PYX_ERR(0, 6484, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_expr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("matchPreviousExpr", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6484, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_38matchPreviousExpr(__pyx_self, __pyx_v_expr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6502
 *     e2 = expr.copy()
 *     rep <<= e2
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater = {"copyTokenToRepeater", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copyTokenToRepeater (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6502, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6502, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, 1); __PYX_ERR(0, 6502, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6502, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, 2); __PYX_ERR(0, 6502, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "copyTokenToRepeater") < 0)) __PYX_ERR(0, 6502, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6502, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr.copyTokenToRepeater", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_17matchPreviousExpr_copyTokenToRepeater(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6504
 *     def copyTokenToRepeater(s, l, t):
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):             # <<<<<<<<<<<<<<
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens = {"mustMatchTheseTokens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mustMatchTheseTokens (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6504, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6504, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mustMatchTheseTokens", 1, 3, 3, 1); __PYX_ERR(0, 6504, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6504, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mustMatchTheseTokens", 1, 3, 3, 2); __PYX_ERR(0, 6504, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mustMatchTheseTokens") < 0)) __PYX_ERR(0, 6504, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mustMatchTheseTokens", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6504, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr.copyTokenToRepeater.mustMatchTheseTokens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_mustMatchTheseTokens(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_mustMatchTheseTokens(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *__pyx_outer_scope;
  PyObject *__pyx_v_theseTokens = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mustMatchTheseTokens", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":6505
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):
 *             theseTokens = _flatten(t.asList())             # <<<<<<<<<<<<<<
 *             if theseTokens != matchTokens:
 *                 raise ParseException('', 0, '')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_flatten); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_asList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_theseTokens = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6506
 *         def mustMatchTheseTokens(s, l, t):
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:             # <<<<<<<<<<<<<<
 *                 raise ParseException('', 0, '')
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_matchTokens)) { __Pyx_RaiseClosureNameError("matchTokens"); __PYX_ERR(0, 6506, __pyx_L1_error) }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_theseTokens, __pyx_cur_scope->__pyx_v_matchTokens, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6506, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 6506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_7)) {

    /* "cPyparsing.pyx":6507
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 *                 raise ParseException('', 0, '')             # <<<<<<<<<<<<<<
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__127, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 6507, __pyx_L1_error)

    /* "cPyparsing.pyx":6506
 *         def mustMatchTheseTokens(s, l, t):
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:             # <<<<<<<<<<<<<<
 *                 raise ParseException('', 0, '')
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 */
  }

  /* "cPyparsing.pyx":6504
 *     def copyTokenToRepeater(s, l, t):
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):             # <<<<<<<<<<<<<<
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr.copyTokenToRepeater.mustMatchTheseTokens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_theseTokens);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6502
 *     e2 = expr.copy()
 *     rep <<= e2
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):
 */

static PyObject *__pyx_pf_10cPyparsing_17matchPreviousExpr_copyTokenToRepeater(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *__pyx_cur_scope;
  PyObject *__pyx_v_mustMatchTheseTokens = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copyTokenToRepeater", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater(__pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6502, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);

  /* "cPyparsing.pyx":6503
 *     rep <<= e2
 *     def copyTokenToRepeater(s, l, t):
 *         matchTokens = _flatten(t.asList())             # <<<<<<<<<<<<<<
 *         def mustMatchTheseTokens(s, l, t):
 *             theseTokens = _flatten(t.asList())
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_flatten); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_asList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_matchTokens = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6504
 *     def copyTokenToRepeater(s, l, t):
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):             # <<<<<<<<<<<<<<
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens, 0, __pyx_n_s_matchPreviousExpr_locals_copyTok, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__129)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_mustMatchTheseTokens = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6508
 *             if theseTokens != matchTokens:
 *                 raise ParseException('', 0, '')
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)             # <<<<<<<<<<<<<<
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))
 */
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep)) { __Pyx_RaiseClosureNameError("rep"); __PYX_ERR(0, 6508, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_mustMatchTheseTokens);
  __Pyx_GIVEREF(__pyx_v_mustMatchTheseTokens);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_mustMatchTheseTokens)) __PYX_ERR(0, 6508, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_callDuringTry, Py_True) < 0) __PYX_ERR(0, 6508, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":6502
 *     e2 = expr.copy()
 *     rep <<= e2
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr.copyTokenToRepeater", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mustMatchTheseTokens);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6484
 *     return rep
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */

static PyObject *__pyx_pf_10cPyparsing_38matchPreviousExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *__pyx_cur_scope;
  PyObject *__pyx_v_e2 = NULL;
  PyObject *__pyx_v_copyTokenToRepeater = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matchPreviousExpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6484, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":6499
 *     with packrat parsing enabled.
 *     """
 *     rep = Forward()             # <<<<<<<<<<<<<<
 *     e2 = expr.copy()
 *     rep <<= e2
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_rep = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6500
 *     """
 *     rep = Forward()
 *     e2 = expr.copy()             # <<<<<<<<<<<<<<
 *     rep <<= e2
 *     def copyTokenToRepeater(s, l, t):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_e2 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6501
 *     rep = Forward()
 *     e2 = expr.copy()
 *     rep <<= e2             # <<<<<<<<<<<<<<
 *     def copyTokenToRepeater(s, l, t):
 *         matchTokens = _flatten(t.asList())
 */
  __pyx_t_1 = PyNumber_InPlaceLshift(__pyx_cur_scope->__pyx_v_rep, __pyx_v_e2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_rep);
  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_rep, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6502
 *     e2 = expr.copy()
 *     rep <<= e2
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater, 0, __pyx_n_s_matchPreviousExpr_locals_copyTok_2, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__131)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_copyTokenToRepeater = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6509
 *                 raise ParseException('', 0, '')
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)             # <<<<<<<<<<<<<<
 *     rep.setName('(prev) ' + _ustr(expr))
 *     return rep
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_copyTokenToRepeater);
  __Pyx_GIVEREF(__pyx_v_copyTokenToRepeater);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_copyTokenToRepeater)) __PYX_ERR(0, 6509, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_callDuringTry, Py_True) < 0) __PYX_ERR(0, 6509, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":6510
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))             # <<<<<<<<<<<<<<
 *     return rep
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rep, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ustr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_expr};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_prev, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":6511
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))
 *     return rep             # <<<<<<<<<<<<<<
 * 
 * def _escapeRegexRangeChars(s):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_rep);
  __pyx_r = __pyx_cur_scope->__pyx_v_rep;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6484
 *     return rep
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e2);
  __Pyx_XDECREF(__pyx_v_copyTokenToRepeater);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6513
 *     return rep
 * 
 * def _escapeRegexRangeChars(s):             # <<<<<<<<<<<<<<
 *     # ~  escape these chars: ^-[]
 *     for c in r"\^-[]":
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_41_escapeRegexRangeChars(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_40_escapeRegexRangeChars, "_escapeRegexRangeChars(s)");
static PyMethodDef __pyx_mdef_10cPyparsing_41_escapeRegexRangeChars = {"_escapeRegexRangeChars", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_41_escapeRegexRangeChars, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_40_escapeRegexRangeChars};
static PyObject *__pyx_pw_10cPyparsing_41_escapeRegexRangeChars(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_escapeRegexRangeChars (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6513, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_escapeRegexRangeChars") < 0)) __PYX_ERR(0, 6513, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_s = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_escapeRegexRangeChars", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6513, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._escapeRegexRangeChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_40_escapeRegexRangeChars(__pyx_self, __pyx_v_s);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_40_escapeRegexRangeChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  Py_UCS4 __pyx_v_c;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  unsigned char const *__pyx_t_1;
  unsigned char const *__pyx_t_2;
  unsigned char const *__pyx_t_3;
  unsigned char const *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_escapeRegexRangeChars", 0);
  __Pyx_INCREF(__pyx_v_s);

  /* "cPyparsing.pyx":6515
 * def _escapeRegexRangeChars(s):
 *     # ~  escape these chars: ^-[]
 *     for c in r"\^-[]":             # <<<<<<<<<<<<<<
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")
 */
  __pyx_t_2 = ((unsigned char const *)((char const *)"\\^-[]"));
  __pyx_t_3 = (__pyx_t_2 + 5);
  for (__pyx_t_4 = __pyx_t_2; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
    __pyx_t_1 = __pyx_t_4;
    __pyx_v_c = (__pyx_t_1[0]);

    /* "cPyparsing.pyx":6516
 *     # ~  escape these chars: ^-[]
 *     for c in r"\^-[]":
 *         s = s.replace(c, _bslash + c)             # <<<<<<<<<<<<<<
 *     s = s.replace("\n", r"\n")
 *     s = s.replace("\t", r"\t")
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 6516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_bslash); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = PyNumber_Add(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    __pyx_t_11 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_11 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_t_7, __pyx_t_10};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_11, 2+__pyx_t_11);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_5);
    __pyx_t_5 = 0;
  }

  /* "cPyparsing.pyx":6517
 *     for c in r"\^-[]":
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")             # <<<<<<<<<<<<<<
 *     s = s.replace("\t", r"\t")
 *     return _ustr(s)
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_replace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__132, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "cPyparsing.pyx":6518
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")
 *     s = s.replace("\t", r"\t")             # <<<<<<<<<<<<<<
 *     return _ustr(s)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__133, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":6519
 *     s = s.replace("\n", r"\n")
 *     s = s.replace("\t", r"\t")
 *     return _ustr(s)             # <<<<<<<<<<<<<<
 * 
 * def oneOf(strs, caseless=False, useRegex=True, asKeyword=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ustr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_10 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_s};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6513
 *     return rep
 * 
 * def _escapeRegexRangeChars(s):             # <<<<<<<<<<<<<<
 *     # ~  escape these chars: ^-[]
 *     for c in r"\^-[]":
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing._escapeRegexRangeChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6521
 *     return _ustr(s)
 * 
 * def oneOf(strs, caseless=False, useRegex=True, asKeyword=False):             # <<<<<<<<<<<<<<
 *     """Helper to quickly define a set of alternative Literals, and makes
 *     sure to do longest-first testing when there is a conflict,
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_43oneOf(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_42oneOf, "oneOf(strs, caseless=False, useRegex=True, asKeyword=False)\nHelper to quickly define a set of alternative Literals, and makes\n    sure to do longest-first testing when there is a conflict,\n    regardless of the input order, but returns\n    a :class:`MatchFirst` for best performance.\n\n    Parameters:\n\n     - strs - a string of space-delimited literals, or a collection of\n       string literals\n     - caseless - (default= ``False``) - treat all literals as\n       caseless\n     - useRegex - (default= ``True``) - as an optimization, will\n       generate a Regex object; otherwise, will generate\n       a :class:`MatchFirst` object (if ``caseless=True`` or ``asKeyword=True``, or if\n       creating a :class:`Regex` raises an exception)\n     - asKeyword - (default=``False``) - enforce Keyword-style matching on the\n       generated expressions\n\n    Example::\n\n        comp_oper = oneOf(\"< = > <= >= !=\")\n        var = Word(alphas)\n        number = Word(nums)\n        term = var | number\n        comparison_expr = term + comp_oper + term\n        print(comparison_expr.searchString(\"B = 12  AA=23 B<=AA AA>12\"))\n\n    prints::\n\n        [['B', '=', '12'], ['AA', '=', '23'], ['B', '<=', 'AA'], ['AA', '>', '12']]\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_43oneOf = {"oneOf", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_43oneOf, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_42oneOf};
static PyObject *__pyx_pw_10cPyparsing_43oneOf(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_strs = 0;
  PyObject *__pyx_v_caseless = 0;
  PyObject *__pyx_v_useRegex = 0;
  PyObject *__pyx_v_asKeyword = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("oneOf (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_strs,&__pyx_n_s_caseless,&__pyx_n_s_useRegex,&__pyx_n_s_asKeyword,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_strs)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6521, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_caseless);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6521, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_useRegex);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6521, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_asKeyword);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6521, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "oneOf") < 0)) __PYX_ERR(0, 6521, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_strs = values[0];
    __pyx_v_caseless = values[1];
    __pyx_v_useRegex = values[2];
    __pyx_v_asKeyword = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("oneOf", 0, 1, 4, __pyx_nargs); __PYX_ERR(0, 6521, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.oneOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_42oneOf(__pyx_self, __pyx_v_strs, __pyx_v_caseless, __pyx_v_useRegex, __pyx_v_asKeyword);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6558
 * 
 *     if caseless:
 *         isequal = (lambda a, b: a.upper() == b.upper())             # <<<<<<<<<<<<<<
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 *         parseElementClass = CaselessKeyword if asKeyword else CaselessLiteral
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5oneOf_lambda43(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5oneOf_lambda43 = {"lambda43", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5oneOf_lambda43, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5oneOf_lambda43(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda43 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b_2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_a)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6558, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_b_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6558, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda43", 1, 2, 2, 1); __PYX_ERR(0, 6558, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda43") < 0)) __PYX_ERR(0, 6558, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda43", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6558, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda43", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda43(__pyx_self, __pyx_v_a, __pyx_v_b);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda43(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda43", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_a, __pyx_n_s_upper); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6558, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_b, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6558, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6558, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda43", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6559
 *     if caseless:
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))             # <<<<<<<<<<<<<<
 *         parseElementClass = CaselessKeyword if asKeyword else CaselessLiteral
 *     else:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5oneOf_1lambda44(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5oneOf_1lambda44 = {"lambda44", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5oneOf_1lambda44, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5oneOf_1lambda44(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda44 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b_2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_a)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6559, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_b_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6559, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda44", 1, 2, 2, 1); __PYX_ERR(0, 6559, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda44") < 0)) __PYX_ERR(0, 6559, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda44", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6559, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda44", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda44(__pyx_self, __pyx_v_a, __pyx_v_b);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda44(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda44", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_b, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_startswith); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_a, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda44", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6562
 *         parseElementClass = CaselessKeyword if asKeyword else CaselessLiteral
 *     else:
 *         isequal = (lambda a, b: a == b)             # <<<<<<<<<<<<<<
 *         masks = (lambda a, b: b.startswith(a))
 *         parseElementClass = Keyword if asKeyword else Literal
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5oneOf_2lambda45(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5oneOf_2lambda45 = {"lambda45", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5oneOf_2lambda45, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5oneOf_2lambda45(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda45 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b_2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_a)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6562, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_b_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6562, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda45", 1, 2, 2, 1); __PYX_ERR(0, 6562, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda45") < 0)) __PYX_ERR(0, 6562, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda45", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6562, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda45", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda45(__pyx_self, __pyx_v_a, __pyx_v_b);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda45(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda45", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_a, __pyx_v_b, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6562, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda45", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6563
 *     else:
 *         isequal = (lambda a, b: a == b)
 *         masks = (lambda a, b: b.startswith(a))             # <<<<<<<<<<<<<<
 *         parseElementClass = Keyword if asKeyword else Literal
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5oneOf_3lambda46(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5oneOf_3lambda46 = {"lambda46", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_5oneOf_3lambda46, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5oneOf_3lambda46(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda46 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b_2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_a)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6563, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_b_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6563, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda46", 1, 2, 2, 1); __PYX_ERR(0, 6563, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda46") < 0)) __PYX_ERR(0, 6563, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda46", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6563, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda46", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda46(__pyx_self, __pyx_v_a, __pyx_v_b);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda46(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda46", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_b, __pyx_n_s_startswith); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_a};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda46", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5oneOf_6generator40(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":6598
 *         try:
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 */

static PyObject *__pyx_pf_10cPyparsing_5oneOf_4genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_59_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6598, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5oneOf_6generator40, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_oneOf_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 6598, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5oneOf_6generator40(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 6598, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 6598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 6598, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6598, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6598, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6598, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6598, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6598, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6598, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6598, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 6598, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_sym);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_sym, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_sym};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 6598, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5oneOf_9generator41(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":6600
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 */

static PyObject *__pyx_pf_10cPyparsing_5oneOf_7genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_60_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6600, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5oneOf_9generator41, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_oneOf_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 6600, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5oneOf_9generator41(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 6600, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 6600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 6600, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6600, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6600, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6600, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6600, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6600, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6600, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6600, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 6600, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_sym);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_sym, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_escape); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sym};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6600, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 6600, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5oneOf_12generator42(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":6606
 * 
 *     # last resort, just use MatchFirst
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 * 
 * def dictOf(key, value):
 */

static PyObject *__pyx_pf_10cPyparsing_5oneOf_10genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_61_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6606, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5oneOf_12generator42, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_oneOf_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 6606, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5oneOf_12generator42(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 6606, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 6606, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6606, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6606, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6606, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6606, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6606, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6606, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6606, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 6606, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_sym);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_sym, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_parseElementClass)) { __Pyx_RaiseClosureNameError("parseElementClass"); __PYX_ERR(0, 6606, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_parseElementClass);
    __pyx_t_5 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_parseElementClass; __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_sym};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 6606, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6521
 *     return _ustr(s)
 * 
 * def oneOf(strs, caseless=False, useRegex=True, asKeyword=False):             # <<<<<<<<<<<<<<
 *     """Helper to quickly define a set of alternative Literals, and makes
 *     sure to do longest-first testing when there is a conflict,
 */

static PyObject *__pyx_pf_10cPyparsing_42oneOf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_strs, PyObject *__pyx_v_caseless, PyObject *__pyx_v_useRegex, PyObject *__pyx_v_asKeyword) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *__pyx_cur_scope;
  PyObject *__pyx_v_isequal = NULL;
  PyObject *__pyx_v_masks = NULL;
  PyObject *__pyx_v_symbols = NULL;
  long __pyx_v_i;
  PyObject *__pyx_v_cur = NULL;
  PyObject *__pyx_v_j = NULL;
  PyObject *__pyx_v_other = NULL;
  PyObject *__pyx_gb_10cPyparsing_5oneOf_6generator40 = 0;
  PyObject *__pyx_gb_10cPyparsing_5oneOf_9generator41 = 0;
  PyObject *__pyx_gb_10cPyparsing_5oneOf_12generator42 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  long __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("oneOf", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_58_oneOf(__pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6521, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":6553
 *         [['B', '=', '12'], ['AA', '=', '23'], ['B', '<=', 'AA'], ['AA', '>', '12']]
 *     """
 *     if isinstance(caseless, basestring):             # <<<<<<<<<<<<<<
 *         warnings.warn("More than one string argument passed to oneOf, pass "
 *                       "choices as a list or space-delimited string", stacklevel=2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_caseless, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 6553, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6554
 *     """
 *     if isinstance(caseless, basestring):
 *         warnings.warn("More than one string argument passed to oneOf, pass "             # <<<<<<<<<<<<<<
 *                       "choices as a list or space-delimited string", stacklevel=2)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6554, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6554, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":6555
 *     if isinstance(caseless, basestring):
 *         warnings.warn("More than one string argument passed to oneOf, pass "
 *                       "choices as a list or space-delimited string", stacklevel=2)             # <<<<<<<<<<<<<<
 * 
 *     if caseless:
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 6555, __pyx_L1_error)

    /* "cPyparsing.pyx":6554
 *     """
 *     if isinstance(caseless, basestring):
 *         warnings.warn("More than one string argument passed to oneOf, pass "             # <<<<<<<<<<<<<<
 *                       "choices as a list or space-delimited string", stacklevel=2)
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__134, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6554, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6553
 *         [['B', '=', '12'], ['AA', '=', '23'], ['B', '<=', 'AA'], ['AA', '>', '12']]
 *     """
 *     if isinstance(caseless, basestring):             # <<<<<<<<<<<<<<
 *         warnings.warn("More than one string argument passed to oneOf, pass "
 *                       "choices as a list or space-delimited string", stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":6557
 *                       "choices as a list or space-delimited string", stacklevel=2)
 * 
 *     if caseless:             # <<<<<<<<<<<<<<
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_caseless); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6557, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6558
 * 
 *     if caseless:
 *         isequal = (lambda a, b: a.upper() == b.upper())             # <<<<<<<<<<<<<<
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 *         parseElementClass = CaselessKeyword if asKeyword else CaselessLiteral
 */
    __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5oneOf_lambda43, 0, __pyx_n_s_oneOf_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6558, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_isequal = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6559
 *     if caseless:
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))             # <<<<<<<<<<<<<<
 *         parseElementClass = CaselessKeyword if asKeyword else CaselessLiteral
 *     else:
 */
    __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5oneOf_1lambda44, 0, __pyx_n_s_oneOf_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_masks = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6560
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 *         parseElementClass = CaselessKeyword if asKeyword else CaselessLiteral             # <<<<<<<<<<<<<<
 *     else:
 *         isequal = (lambda a, b: a == b)
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_asKeyword); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6560, __pyx_L1_error)
    if (__pyx_t_2) {
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CaselessKeyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1;
      __pyx_t_1 = 0;
    } else {
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CaselessLiteral); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_cur_scope->__pyx_v_parseElementClass = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6557
 *                       "choices as a list or space-delimited string", stacklevel=2)
 * 
 *     if caseless:             # <<<<<<<<<<<<<<
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":6562
 *         parseElementClass = CaselessKeyword if asKeyword else CaselessLiteral
 *     else:
 *         isequal = (lambda a, b: a == b)             # <<<<<<<<<<<<<<
 *         masks = (lambda a, b: b.startswith(a))
 *         parseElementClass = Keyword if asKeyword else Literal
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5oneOf_2lambda45, 0, __pyx_n_s_oneOf_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_isequal = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6563
 *     else:
 *         isequal = (lambda a, b: a == b)
 *         masks = (lambda a, b: b.startswith(a))             # <<<<<<<<<<<<<<
 *         parseElementClass = Keyword if asKeyword else Literal
 * 
 */
    __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5oneOf_3lambda46, 0, __pyx_n_s_oneOf_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_masks = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6564
 *         isequal = (lambda a, b: a == b)
 *         masks = (lambda a, b: b.startswith(a))
 *         parseElementClass = Keyword if asKeyword else Literal             # <<<<<<<<<<<<<<
 * 
 *     symbols = []
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_asKeyword); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6564, __pyx_L1_error)
    if (__pyx_t_2) {
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1;
      __pyx_t_1 = 0;
    } else {
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Literal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_cur_scope->__pyx_v_parseElementClass = __pyx_t_4;
    __pyx_t_4 = 0;
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":6566
 *         parseElementClass = Keyword if asKeyword else Literal
 * 
 *     symbols = []             # <<<<<<<<<<<<<<
 *     if isinstance(strs, basestring):
 *         symbols = strs.split()
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_symbols = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":6567
 * 
 *     symbols = []
 *     if isinstance(strs, basestring):             # <<<<<<<<<<<<<<
 *         symbols = strs.split()
 *     elif isinstance(strs, Iterable):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_basestring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_strs, __pyx_t_4); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 6567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6568
 *     symbols = []
 *     if isinstance(strs, basestring):
 *         symbols = strs.split()             # <<<<<<<<<<<<<<
 *     elif isinstance(strs, Iterable):
 *         symbols = list(strs)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_strs, __pyx_n_s_split); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_symbols, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6567
 * 
 *     symbols = []
 *     if isinstance(strs, basestring):             # <<<<<<<<<<<<<<
 *         symbols = strs.split()
 *     elif isinstance(strs, Iterable):
 */
    goto __pyx_L5;
  }

  /* "cPyparsing.pyx":6569
 *     if isinstance(strs, basestring):
 *         symbols = strs.split()
 *     elif isinstance(strs, Iterable):             # <<<<<<<<<<<<<<
 *         symbols = list(strs)
 *     else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Iterable); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_strs, __pyx_t_4); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 6569, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6570
 *         symbols = strs.split()
 *     elif isinstance(strs, Iterable):
 *         symbols = list(strs)             # <<<<<<<<<<<<<<
 *     else:
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",
 */
    __pyx_t_4 = PySequence_List(__pyx_v_strs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_symbols, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6569
 *     if isinstance(strs, basestring):
 *         symbols = strs.split()
 *     elif isinstance(strs, Iterable):             # <<<<<<<<<<<<<<
 *         symbols = list(strs)
 *     else:
 */
    goto __pyx_L5;
  }

  /* "cPyparsing.pyx":6572
 *         symbols = list(strs)
 *     else:
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",             # <<<<<<<<<<<<<<
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_warnings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_warn); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":6573
 *     else:
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",
 *                       SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *     if not symbols:
 *         return NoMatch()
 */
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 6573, __pyx_L1_error)

    /* "cPyparsing.pyx":6572
 *         symbols = list(strs)
 *     else:
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",             # <<<<<<<<<<<<<<
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__135, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L5:;

  /* "cPyparsing.pyx":6574
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:             # <<<<<<<<<<<<<<
 *         return NoMatch()
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_symbols); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6574, __pyx_L1_error)
  __pyx_t_6 = (!__pyx_t_2);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":6575
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:
 *         return NoMatch()             # <<<<<<<<<<<<<<
 * 
 *     if not asKeyword:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_NoMatch); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6575, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":6574
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:             # <<<<<<<<<<<<<<
 *         return NoMatch()
 * 
 */
  }

  /* "cPyparsing.pyx":6577
 *         return NoMatch()
 * 
 *     if not asKeyword:             # <<<<<<<<<<<<<<
 *         # if not producing keywords, need to reorder to take care to avoid masking
 *         # longer choices with shorter ones
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_asKeyword); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 6577, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_6);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6580
 *         # if not producing keywords, need to reorder to take care to avoid masking
 *         # longer choices with shorter ones
 *         i = 0             # <<<<<<<<<<<<<<
 *         while i < len(symbols) - 1:
 *             cur = symbols[i]
 */
    __pyx_v_i = 0;

    /* "cPyparsing.pyx":6581
 *         # longer choices with shorter ones
 *         i = 0
 *         while i < len(symbols) - 1:             # <<<<<<<<<<<<<<
 *             cur = symbols[i]
 *             for j, other in enumerate(symbols[i + 1:]):
 */
    while (1) {
      __pyx_t_5 = 0;
      __pyx_t_7 = PyObject_Length(__pyx_v_symbols); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6581, __pyx_L1_error)
      __pyx_t_8 = __Pyx_sub_const_Py_ssize_t_checking_overflow(__pyx_t_7, 1, &__pyx_t_5);
      if (unlikely(__pyx_t_5)) {
        PyErr_SetString(PyExc_OverflowError, "value too large");
        __PYX_ERR(0, 6581, __pyx_L1_error)
      }
      __pyx_t_2 = (__pyx_v_i < __pyx_t_8);
      if (!__pyx_t_2) break;

      /* "cPyparsing.pyx":6582
 *         i = 0
 *         while i < len(symbols) - 1:
 *             cur = symbols[i]             # <<<<<<<<<<<<<<
 *             for j, other in enumerate(symbols[i + 1:]):
 *                 if isequal(other, cur):
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_symbols, __pyx_v_i, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6582, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF_SET(__pyx_v_cur, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":6583
 *         while i < len(symbols) - 1:
 *             cur = symbols[i]
 *             for j, other in enumerate(symbols[i + 1:]):             # <<<<<<<<<<<<<<
 *                 if isequal(other, cur):
 *                     del symbols[i + j + 1]
 */
      __Pyx_INCREF(__pyx_int_0);
      __pyx_t_3 = __pyx_int_0;
      __pyx_t_5 = 0;
      __pyx_t_9 = __Pyx_add_const_long_checking_overflow(__pyx_v_i, 1, &__pyx_t_5);
      if (unlikely(__pyx_t_5)) {
        PyErr_SetString(PyExc_OverflowError, "value too large");
        __PYX_ERR(0, 6583, __pyx_L1_error)
      }
      __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_symbols, __pyx_t_9, 0, NULL, NULL, NULL, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_8 = 0;
        __pyx_t_10 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6583, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6583, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_10)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6583, __pyx_L1_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 6583, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6583, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6583, __pyx_L1_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 6583, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6583, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_10(__pyx_t_1);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 6583, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_v_other, __pyx_t_4);
        __pyx_t_4 = 0;
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_3);
        __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6583, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3);
        __pyx_t_3 = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":6584
 *             cur = symbols[i]
 *             for j, other in enumerate(symbols[i + 1:]):
 *                 if isequal(other, cur):             # <<<<<<<<<<<<<<
 *                     del symbols[i + j + 1]
 *                     break
 */
        __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6584, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_other)) __PYX_ERR(0, 6584, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_cur);
        __Pyx_GIVEREF(__pyx_v_cur);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_cur)) __PYX_ERR(0, 6584, __pyx_L1_error);
        __pyx_t_11 = __Pyx_PyObject_Call(__pyx_v_isequal, __pyx_t_4, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6584, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6584, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":6585
 *             for j, other in enumerate(symbols[i + 1:]):
 *                 if isequal(other, cur):
 *                     del symbols[i + j + 1]             # <<<<<<<<<<<<<<
 *                     break
 *                 elif masks(cur, other):
 */
          __pyx_t_11 = __Pyx_PyInt_From_long(__pyx_v_i); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_4 = PyNumber_Add(__pyx_t_11, __pyx_v_j); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely((PyObject_DelItem(__pyx_v_symbols, __pyx_t_11) < 0))) __PYX_ERR(0, 6585, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "cPyparsing.pyx":6586
 *                 if isequal(other, cur):
 *                     del symbols[i + j + 1]
 *                     break             # <<<<<<<<<<<<<<
 *                 elif masks(cur, other):
 *                     del symbols[i + j + 1]
 */
          goto __pyx_L11_break;

          /* "cPyparsing.pyx":6584
 *             cur = symbols[i]
 *             for j, other in enumerate(symbols[i + 1:]):
 *                 if isequal(other, cur):             # <<<<<<<<<<<<<<
 *                     del symbols[i + j + 1]
 *                     break
 */
        }

        /* "cPyparsing.pyx":6587
 *                     del symbols[i + j + 1]
 *                     break
 *                 elif masks(cur, other):             # <<<<<<<<<<<<<<
 *                     del symbols[i + j + 1]
 *                     symbols.insert(i, other)
 */
        __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6587, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_INCREF(__pyx_v_cur);
        __Pyx_GIVEREF(__pyx_v_cur);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_v_cur)) __PYX_ERR(0, 6587, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_v_other)) __PYX_ERR(0, 6587, __pyx_L1_error);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_masks, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6587, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6587, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":6588
 *                     break
 *                 elif masks(cur, other):
 *                     del symbols[i + j + 1]             # <<<<<<<<<<<<<<
 *                     symbols.insert(i, other)
 *                     break
 */
          __pyx_t_4 = __Pyx_PyInt_From_long(__pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6588, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = PyNumber_Add(__pyx_t_4, __pyx_v_j); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6588, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_11, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6588, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely((PyObject_DelItem(__pyx_v_symbols, __pyx_t_4) < 0))) __PYX_ERR(0, 6588, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "cPyparsing.pyx":6589
 *                 elif masks(cur, other):
 *                     del symbols[i + j + 1]
 *                     symbols.insert(i, other)             # <<<<<<<<<<<<<<
 *                     break
 *             else:
 */
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_symbols, __pyx_n_s_insert); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = __Pyx_PyInt_From_long(__pyx_v_i); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_11))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_11);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_11, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_t_12, __pyx_v_other};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6589, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "cPyparsing.pyx":6590
 *                     del symbols[i + j + 1]
 *                     symbols.insert(i, other)
 *                     break             # <<<<<<<<<<<<<<
 *             else:
 *                 i += 1
 */
          goto __pyx_L11_break;

          /* "cPyparsing.pyx":6587
 *                     del symbols[i + j + 1]
 *                     break
 *                 elif masks(cur, other):             # <<<<<<<<<<<<<<
 *                     del symbols[i + j + 1]
 *                     symbols.insert(i, other)
 */
        }

        /* "cPyparsing.pyx":6583
 *         while i < len(symbols) - 1:
 *             cur = symbols[i]
 *             for j, other in enumerate(symbols[i + 1:]):             # <<<<<<<<<<<<<<
 *                 if isequal(other, cur):
 *                     del symbols[i + j + 1]
 */
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L13_for_else;
      __pyx_L11_break:;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L14_for_end;
      /*else*/ {
        __pyx_L13_for_else:;

        /* "cPyparsing.pyx":6592
 *                     break
 *             else:
 *                 i += 1             # <<<<<<<<<<<<<<
 * 
 *     if not (caseless or asKeyword) and useRegex:
 */
        __pyx_t_5 = 0;
        __pyx_t_9 = __Pyx_add_const_long_checking_overflow(__pyx_v_i, 1, &__pyx_t_5);
        if (unlikely(__pyx_t_5)) {
          PyErr_SetString(PyExc_OverflowError, "value too large");
          __PYX_ERR(0, 6592, __pyx_L1_error)
        }
        __pyx_v_i = __pyx_t_9;
      }
      __pyx_L14_for_end:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }

    /* "cPyparsing.pyx":6577
 *         return NoMatch()
 * 
 *     if not asKeyword:             # <<<<<<<<<<<<<<
 *         # if not producing keywords, need to reorder to take care to avoid masking
 *         # longer choices with shorter ones
 */
  }

  /* "cPyparsing.pyx":6594
 *                 i += 1
 * 
 *     if not (caseless or asKeyword) and useRegex:             # <<<<<<<<<<<<<<
 *         # ~ print (strs, "->", "|".join([_escapeRegexChars(sym) for sym in symbols]))
 *         try:
 */
  __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_caseless); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 6594, __pyx_L1_error)
  if (!__pyx_t_14) {
  } else {
    __pyx_t_6 = __pyx_t_14;
    goto __pyx_L18_bool_binop_done;
  }
  __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_asKeyword); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 6594, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_14;
  __pyx_L18_bool_binop_done:;
  __pyx_t_14 = (!__pyx_t_6);
  if (__pyx_t_14) {
  } else {
    __pyx_t_2 = __pyx_t_14;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_useRegex); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 6594, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_14;
  __pyx_L16_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6596
 *     if not (caseless or asKeyword) and useRegex:
 *         # ~ print (strs, "->", "|".join([_escapeRegexChars(sym) for sym in symbols]))
 *         try:             # <<<<<<<<<<<<<<
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      /*try:*/ {

        /* "cPyparsing.pyx":6597
 *         # ~ print (strs, "->", "|".join([_escapeRegexChars(sym) for sym in symbols]))
 *         try:
 *             if len(symbols) == len("".join(symbols)):             # <<<<<<<<<<<<<<
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 */
        __pyx_t_8 = PyObject_Length(__pyx_v_symbols); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6597, __pyx_L20_error)
        __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__10, __pyx_v_symbols); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6597, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 6597, __pyx_L20_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_2 = (__pyx_t_8 == __pyx_t_7);
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":6598
 *         try:
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
          __Pyx_XDECREF(__pyx_r);
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Regex); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6598, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = __pyx_pf_10cPyparsing_5oneOf_4genexpr(NULL, __pyx_v_symbols); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6598, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = __Pyx_Generator_Next(__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6598, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6598, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyUnicode_Format(__pyx_kp_u_s_5, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6598, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_12};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6598, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6598, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__111, __pyx_v_symbols); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6598, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_1};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6598, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_r = __pyx_t_3;
          __pyx_t_3 = 0;
          goto __pyx_L24_try_return;

          /* "cPyparsing.pyx":6597
 *         # ~ print (strs, "->", "|".join([_escapeRegexChars(sym) for sym in symbols]))
 *         try:
 *             if len(symbols) == len("".join(symbols)):             # <<<<<<<<<<<<<<
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 */
        }

        /* "cPyparsing.pyx":6600
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 */
        /*else*/ {
          __Pyx_XDECREF(__pyx_r);
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Regex); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6600, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = __pyx_pf_10cPyparsing_5oneOf_7genexpr(NULL, __pyx_v_symbols); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6600, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_11 = __Pyx_Generator_Next(__pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6600, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyUnicode_Join(__pyx_kp_u__136, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6600, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_12};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6600, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6600, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyUnicode_Join(__pyx_kp_u__111, __pyx_v_symbols); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6600, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_12 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_4};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6600, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __pyx_r = __pyx_t_3;
          __pyx_t_3 = 0;
          goto __pyx_L24_try_return;
        }

        /* "cPyparsing.pyx":6596
 *     if not (caseless or asKeyword) and useRegex:
 *         # ~ print (strs, "->", "|".join([_escapeRegexChars(sym) for sym in symbols]))
 *         try:             # <<<<<<<<<<<<<<
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
      }
      __pyx_L20_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":6601
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 *         except Exception:             # <<<<<<<<<<<<<<
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 *                     SyntaxWarning, stacklevel=2)
 */
      __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_5) {
        __Pyx_AddTraceback("cPyparsing.oneOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_4) < 0) __PYX_ERR(0, 6601, __pyx_L22_except_error)
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_4);

        /* "cPyparsing.pyx":6602
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",             # <<<<<<<<<<<<<<
 *                     SyntaxWarning, stacklevel=2)
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_warnings); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6602, __pyx_L22_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_warn); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6602, __pyx_L22_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

        /* "cPyparsing.pyx":6603
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 *                     SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 * 
 *     # last resort, just use MatchFirst
 */
        __pyx_t_12 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6603, __pyx_L22_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 6603, __pyx_L22_except_error)

        /* "cPyparsing.pyx":6602
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",             # <<<<<<<<<<<<<<
 *                     SyntaxWarning, stacklevel=2)
 * 
 */
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__137, __pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 6602, __pyx_L22_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L21_exception_handled;
      }
      goto __pyx_L22_except_error;

      /* "cPyparsing.pyx":6596
 *     if not (caseless or asKeyword) and useRegex:
 *         # ~ print (strs, "->", "|".join([_escapeRegexChars(sym) for sym in symbols]))
 *         try:             # <<<<<<<<<<<<<<
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
      __pyx_L22_except_error:;
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
      goto __pyx_L1_error;
      __pyx_L24_try_return:;
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
      goto __pyx_L0;
      __pyx_L21_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
    }

    /* "cPyparsing.pyx":6594
 *                 i += 1
 * 
 *     if not (caseless or asKeyword) and useRegex:             # <<<<<<<<<<<<<<
 *         # ~ print (strs, "->", "|".join([_escapeRegexChars(sym) for sym in symbols]))
 *         try:
 */
  }

  /* "cPyparsing.pyx":6606
 * 
 *     # last resort, just use MatchFirst
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 * 
 * def dictOf(key, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_MatchFirst); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_13 = __pyx_pf_10cPyparsing_5oneOf_10genexpr(((PyObject*)__pyx_cur_scope), __pyx_v_symbols); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 6606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_12 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_13};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__111, __pyx_v_symbols); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_1};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6521
 *     return _ustr(s)
 * 
 * def oneOf(strs, caseless=False, useRegex=True, asKeyword=False):             # <<<<<<<<<<<<<<
 *     """Helper to quickly define a set of alternative Literals, and makes
 *     sure to do longest-first testing when there is a conflict,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.oneOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_isequal);
  __Pyx_XDECREF(__pyx_v_masks);
  __Pyx_XDECREF(__pyx_v_symbols);
  __Pyx_XDECREF(__pyx_v_cur);
  __Pyx_XDECREF(__pyx_v_j);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_5oneOf_6generator40);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_5oneOf_9generator41);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_5oneOf_12generator42);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6608
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))
 * 
 * def dictOf(key, value):             # <<<<<<<<<<<<<<
 *     """Helper to easily and clearly define a dictionary by specifying
 *     the respective patterns for the key and value.  Takes care of
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_45dictOf(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_44dictOf, "dictOf(key, value)\nHelper to easily and clearly define a dictionary by specifying\n    the respective patterns for the key and value.  Takes care of\n    defining the :class:`Dict`, :class:`ZeroOrMore`, and\n    :class:`Group` tokens in the proper order.  The key pattern\n    can include delimiting markers or punctuation, as long as they are\n    suppressed, thereby leaving the significant key text.  The value\n    pattern can include named results, so that the :class:`Dict` results\n    can include named token fields.\n\n    Example::\n\n        text = \"shape: SQUARE posn: upper left color: light blue texture: burlap\"\n        attr_expr = (label + Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join))\n        print(OneOrMore(attr_expr).parseString(text).dump())\n\n        attr_label = label\n        attr_value = Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join)\n\n        # similar to Dict, but simpler call format\n        result = dictOf(attr_label, attr_value).parseString(text)\n        print(result.dump())\n        print(result['shape'])\n        print(result.shape)  # object attribute access works too\n        print(result.asDict())\n\n    prints::\n\n        [['shape', 'SQUARE'], ['posn', 'upper left'], ['color', 'light blue'], ['texture', 'burlap']]\n        - color: light blue\n        - posn: upper left\n        - shape: SQUARE\n        - texture: burlap\n        SQUARE\n        SQUARE\n        {'color': 'light blue', 'shape': 'SQUARE', 'posn': 'upper left', 'texture': 'burlap'}\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_45dictOf = {"dictOf", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_45dictOf, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_44dictOf};
static PyObject *__pyx_pw_10cPyparsing_45dictOf(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dictOf (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6608, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6608, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("dictOf", 1, 2, 2, 1); __PYX_ERR(0, 6608, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dictOf") < 0)) __PYX_ERR(0, 6608, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = values[0];
    __pyx_v_value = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dictOf", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 6608, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.dictOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_44dictOf(__pyx_self, __pyx_v_key, __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_44dictOf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dictOf", 1);

  /* "cPyparsing.pyx":6645
 *         {'color': 'light blue', 'shape': 'SQUARE', 'posn': 'upper left', 'texture': 'burlap'}
 *     """
 *     return Dict(OneOrMore(Group(key + value)))             # <<<<<<<<<<<<<<
 * 
 * def originalTextFor(expr, asString=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_Group); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyNumber_Add(__pyx_v_key, __pyx_v_value); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 6645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6645, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6645, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6645, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6608
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))
 * 
 * def dictOf(key, value):             # <<<<<<<<<<<<<<
 *     """Helper to easily and clearly define a dictionary by specifying
 *     the respective patterns for the key and value.  Takes care of
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.dictOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6647
 *     return Dict(OneOrMore(Group(key + value)))
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """Helper to return the original, untokenized text for a given
 *     expression.  Useful to restore the parsed fields of an HTML start
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_47originalTextFor(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_46originalTextFor, "originalTextFor(expr, asString=True)\nHelper to return the original, untokenized text for a given\n    expression.  Useful to restore the parsed fields of an HTML start\n    tag into the raw tag text itself, or to revert separate tokens with\n    intervening whitespace back to the original matching input text. By\n    default, returns astring containing the original parsed text.\n\n    If the optional ``asString`` argument is passed as\n    ``False``, then the return value is\n    a :class:`ParseResults` containing any results names that\n    were originally matched, and a single token containing the original\n    matched text from the input string.  So if the expression passed to\n    :class:`originalTextFor` contains expressions with defined\n    results names, you must set ``asString`` to ``False`` if you\n    want to preserve those results name values.\n\n    Example::\n\n        src = \"this is test <b> bold <i>text</i> </b> normal text \"\n        for tag in (\"b\", \"i\"):\n            opener, closer = makeHTMLTags(tag)\n            patt = originalTextFor(opener + SkipTo(closer) + closer)\n            print(patt.searchString(src)[0])\n\n    prints::\n\n        ['<b> bold <i>text</i> </b>']\n        ['<i>text</i>']\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_47originalTextFor = {"originalTextFor", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_47originalTextFor, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_46originalTextFor};
static PyObject *__pyx_pw_10cPyparsing_47originalTextFor(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_asString = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("originalTextFor (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,&__pyx_n_s_asString,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6647, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_asString);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6647, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "originalTextFor") < 0)) __PYX_ERR(0, 6647, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_expr = values[0];
    __pyx_v_asString = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("originalTextFor", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 6647, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.originalTextFor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_46originalTextFor(__pyx_self, __pyx_v_expr, __pyx_v_asString);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6683
 *         extractText = lambda s, l, t: s[t._original_start: t._original_end]
 *     else:
 *         def extractText(s, l, t):             # <<<<<<<<<<<<<<
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_1extractText(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15originalTextFor_1extractText = {"extractText", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15originalTextFor_1extractText, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_1extractText(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extractText (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6683, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6683, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("extractText", 1, 3, 3, 1); __PYX_ERR(0, 6683, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6683, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("extractText", 1, 3, 3, 2); __PYX_ERR(0, 6683, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "extractText") < 0)) __PYX_ERR(0, 6683, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extractText", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6683, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.originalTextFor.extractText", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15originalTextFor_extractText(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15originalTextFor_extractText(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extractText", 1);

  /* "cPyparsing.pyx":6684
 *     else:
 *         def extractText(s, l, t):
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]             # <<<<<<<<<<<<<<
 *     matchExpr.setParseAction(extractText)
 *     matchExpr.ignoreExprs = expr.ignoreExprs
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_original_start};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_n_u_original_end};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_s, 0, 0, &__pyx_t_1, &__pyx_t_2, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 6684, __pyx_L1_error);
  __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetSlice(__pyx_v_t, __pyx_t_2, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1) < 0) __PYX_ERR(0, 6684, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6683
 *         extractText = lambda s, l, t: s[t._original_start: t._original_end]
 *     else:
 *         def extractText(s, l, t):             # <<<<<<<<<<<<<<
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.originalTextFor.extractText", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6676
 *         ['<i>text</i>']
 *     """
 *     locMarker = Empty().setParseAction(lambda s, loc, t: loc)             # <<<<<<<<<<<<<<
 *     endlocMarker = locMarker.copy()
 *     endlocMarker.callPreparse = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_2lambda50(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15originalTextFor_2lambda50 = {"lambda50", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15originalTextFor_2lambda50, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_2lambda50(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda50 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_loc,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6676, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6676, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda50", 1, 3, 3, 1); __PYX_ERR(0, 6676, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6676, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda50", 1, 3, 3, 2); __PYX_ERR(0, 6676, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda50") < 0)) __PYX_ERR(0, 6676, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_loc = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda50", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6676, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.originalTextFor.lambda50", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda50(__pyx_self, __pyx_v_s, __pyx_v_loc, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda50(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda50", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_r = __pyx_v_loc;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6681
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:
 *         extractText = lambda s, l, t: s[t._original_start: t._original_end]             # <<<<<<<<<<<<<<
 *     else:
 *         def extractText(s, l, t):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_3lambda51(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15originalTextFor_3lambda51 = {"lambda51", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_15originalTextFor_3lambda51, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_3lambda51(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda51 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6681, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6681, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda51", 1, 3, 3, 1); __PYX_ERR(0, 6681, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6681, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda51", 1, 3, 3, 2); __PYX_ERR(0, 6681, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda51") < 0)) __PYX_ERR(0, 6681, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda51", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6681, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.originalTextFor.lambda51", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda51(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda51(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda51", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_original_start); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_original_end); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_s, 0, 0, &__pyx_t_1, &__pyx_t_2, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.originalTextFor.lambda51", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6647
 *     return Dict(OneOrMore(Group(key + value)))
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """Helper to return the original, untokenized text for a given
 *     expression.  Useful to restore the parsed fields of an HTML start
 */

static PyObject *__pyx_pf_10cPyparsing_46originalTextFor(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_asString) {
  PyObject *__pyx_v_locMarker = NULL;
  PyObject *__pyx_v_endlocMarker = NULL;
  PyObject *__pyx_v_matchExpr = NULL;
  PyObject *__pyx_v_extractText = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("originalTextFor", 1);

  /* "cPyparsing.pyx":6676
 *         ['<i>text</i>']
 *     """
 *     locMarker = Empty().setParseAction(lambda s, loc, t: loc)             # <<<<<<<<<<<<<<
 *     endlocMarker = locMarker.copy()
 *     endlocMarker.callPreparse = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15originalTextFor_2lambda50, 0, __pyx_n_s_originalTextFor_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_locMarker = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6677
 *     """
 *     locMarker = Empty().setParseAction(lambda s, loc, t: loc)
 *     endlocMarker = locMarker.copy()             # <<<<<<<<<<<<<<
 *     endlocMarker.callPreparse = False
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_locMarker, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_endlocMarker = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6678
 *     locMarker = Empty().setParseAction(lambda s, loc, t: loc)
 *     endlocMarker = locMarker.copy()
 *     endlocMarker.callPreparse = False             # <<<<<<<<<<<<<<
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_endlocMarker, __pyx_n_s_callPreparse, Py_False) < 0) __PYX_ERR(0, 6678, __pyx_L1_error)

  /* "cPyparsing.pyx":6679
 *     endlocMarker = locMarker.copy()
 *     endlocMarker.callPreparse = False
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")             # <<<<<<<<<<<<<<
 *     if asString:
 *         extractText = lambda s, l, t: s[t._original_start: t._original_end]
 */
  __Pyx_INCREF(__pyx_v_locMarker);
  __pyx_t_3 = __pyx_v_locMarker; __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_original_start};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_INCREF(__pyx_v_endlocMarker);
  __pyx_t_2 = __pyx_v_endlocMarker; __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_original_end};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_matchExpr = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6680
 *     endlocMarker.callPreparse = False
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:             # <<<<<<<<<<<<<<
 *         extractText = lambda s, l, t: s[t._original_start: t._original_end]
 *     else:
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_asString); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 6680, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":6681
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:
 *         extractText = lambda s, l, t: s[t._original_start: t._original_end]             # <<<<<<<<<<<<<<
 *     else:
 *         def extractText(s, l, t):
 */
    __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15originalTextFor_3lambda51, 0, __pyx_n_s_originalTextFor_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_extractText = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":6680
 *     endlocMarker.callPreparse = False
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:             # <<<<<<<<<<<<<<
 *         extractText = lambda s, l, t: s[t._original_start: t._original_end]
 *     else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":6683
 *         extractText = lambda s, l, t: s[t._original_start: t._original_end]
 *     else:
 *         def extractText(s, l, t):             # <<<<<<<<<<<<<<
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15originalTextFor_1extractText, 0, __pyx_n_s_originalTextFor_locals_extractTe, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__138)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_extractText = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":6685
 *         def extractText(s, l, t):
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)             # <<<<<<<<<<<<<<
 *     matchExpr.ignoreExprs = expr.ignoreExprs
 *     return matchExpr
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchExpr, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_extractText};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6686
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 *     matchExpr.ignoreExprs = expr.ignoreExprs             # <<<<<<<<<<<<<<
 *     return matchExpr
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_matchExpr, __pyx_n_s_ignoreExprs, __pyx_t_2) < 0) __PYX_ERR(0, 6686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6687
 *     matchExpr.setParseAction(extractText)
 *     matchExpr.ignoreExprs = expr.ignoreExprs
 *     return matchExpr             # <<<<<<<<<<<<<<
 * 
 * def ungroup(expr):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_matchExpr);
  __pyx_r = __pyx_v_matchExpr;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6647
 *     return Dict(OneOrMore(Group(key + value)))
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """Helper to return the original, untokenized text for a given
 *     expression.  Useful to restore the parsed fields of an HTML start
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.originalTextFor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_locMarker);
  __Pyx_XDECREF(__pyx_v_endlocMarker);
  __Pyx_XDECREF(__pyx_v_matchExpr);
  __Pyx_XDECREF(__pyx_v_extractText);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6689
 *     return matchExpr
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """Helper to undo pyparsing's default grouping of And expressions,
 *     even if all but one are non-empty.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_49ungroup(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_48ungroup, "ungroup(expr)\nHelper to undo pyparsing's default grouping of And expressions,\n    even if all but one are non-empty.\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_49ungroup = {"ungroup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_49ungroup, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_48ungroup};
static PyObject *__pyx_pw_10cPyparsing_49ungroup(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_expr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ungroup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6689, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "ungroup") < 0)) __PYX_ERR(0, 6689, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_expr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ungroup", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6689, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ungroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_48ungroup(__pyx_self, __pyx_v_expr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6693
 *     even if all but one are non-empty.
 *     """
 *     return TokenConverter(expr).addParseAction(lambda t: t[0])             # <<<<<<<<<<<<<<
 * 
 * def locatedExpr(expr):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7ungroup_lambda52(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7ungroup_lambda52 = {"lambda52", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_7ungroup_lambda52, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7ungroup_lambda52(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda52 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6693, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda52") < 0)) __PYX_ERR(0, 6693, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda52", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6693, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.ungroup.lambda52", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda52(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda52(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda52", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ungroup.lambda52", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6689
 *     return matchExpr
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """Helper to undo pyparsing's default grouping of And expressions,
 *     even if all but one are non-empty.
 */

static PyObject *__pyx_pf_10cPyparsing_48ungroup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ungroup", 1);

  /* "cPyparsing.pyx":6693
 *     even if all but one are non-empty.
 *     """
 *     return TokenConverter(expr).addParseAction(lambda t: t[0])             # <<<<<<<<<<<<<<
 * 
 * def locatedExpr(expr):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_expr};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7ungroup_lambda52, 0, __pyx_n_s_ungroup_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6689
 *     return matchExpr
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """Helper to undo pyparsing's default grouping of And expressions,
 *     even if all but one are non-empty.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ungroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6695
 *     return TokenConverter(expr).addParseAction(lambda t: t[0])
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to decorate a returned token with its starting and ending
 *     locations in the input string.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_51locatedExpr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_50locatedExpr, "locatedExpr(expr)\nHelper to decorate a returned token with its starting and ending\n    locations in the input string.\n\n    This helper adds the following results names:\n\n     - locn_start = location where matched expression begins\n     - locn_end = location where matched expression ends\n     - value = the actual parsed results\n\n    Be careful if the input text contains ``<TAB>`` characters, you\n    may want to call :class:`ParserElement.parseWithTabs`\n\n    Example::\n\n        wd = Word(alphas)\n        for match in locatedExpr(wd).searchString(\"ljsdf123lksdjjf123lkkjj1222\"):\n            print(match)\n\n    prints::\n\n        [[0, 'ljsdf', 5]]\n        [[8, 'lksdjjf', 15]]\n        [[18, 'lkkjj', 23]]\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_51locatedExpr = {"locatedExpr", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_51locatedExpr, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_50locatedExpr};
static PyObject *__pyx_pw_10cPyparsing_51locatedExpr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_expr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("locatedExpr (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6695, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "locatedExpr") < 0)) __PYX_ERR(0, 6695, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_expr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("locatedExpr", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6695, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.locatedExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_50locatedExpr(__pyx_self, __pyx_v_expr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6720
 *         [[18, 'lkkjj', 23]]
 *     """
 *     locator = Empty().setParseAction(lambda s, l, t: l)             # <<<<<<<<<<<<<<
 *     return Group(locator("locn_start") + expr("value") + locator.copy().leaveWhitespace()("locn_end"))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11locatedExpr_lambda53(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11locatedExpr_lambda53 = {"lambda53", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11locatedExpr_lambda53, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11locatedExpr_lambda53(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda53 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6720, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6720, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda53", 1, 3, 3, 1); __PYX_ERR(0, 6720, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6720, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda53", 1, 3, 3, 2); __PYX_ERR(0, 6720, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda53") < 0)) __PYX_ERR(0, 6720, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda53", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6720, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.locatedExpr.lambda53", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda53(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda53(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda53", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6695
 *     return TokenConverter(expr).addParseAction(lambda t: t[0])
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to decorate a returned token with its starting and ending
 *     locations in the input string.
 */

static PyObject *__pyx_pf_10cPyparsing_50locatedExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_v_locator = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("locatedExpr", 1);

  /* "cPyparsing.pyx":6720
 *         [[18, 'lkkjj', 23]]
 *     """
 *     locator = Empty().setParseAction(lambda s, l, t: l)             # <<<<<<<<<<<<<<
 *     return Group(locator("locn_start") + expr("value") + locator.copy().leaveWhitespace()("locn_end"))
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11locatedExpr_lambda53, 0, __pyx_n_s_locatedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_locator = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6721
 *     """
 *     locator = Empty().setParseAction(lambda s, l, t: l)
 *     return Group(locator("locn_start") + expr("value") + locator.copy().leaveWhitespace()("locn_end"))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Group); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_locator);
  __pyx_t_4 = __pyx_v_locator; __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_n_u_locn_start};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_INCREF(__pyx_v_expr);
  __pyx_t_6 = __pyx_v_expr; __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_value};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyNumber_Add(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_locator, __pyx_n_s_copy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 6721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_t_8 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_n_u_locn_end};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6695
 *     return TokenConverter(expr).addParseAction(lambda t: t[0])
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to decorate a returned token with its starting and ending
 *     locations in the input string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.locatedExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_locator);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6738
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""Helper to easily define string ranges for use in Word
 *     construction. Borrows syntax from regexp '[]' string range
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_53srange(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_52srange, "srange(s)\nHelper to easily define string ranges for use in Word\n    construction. Borrows syntax from regexp '[]' string range\n    definitions::\n\n        srange(\"[0-9]\")   -> \"0123456789\"\n        srange(\"[a-z]\")   -> \"abcdefghijklmnopqrstuvwxyz\"\n        srange(\"[a-z$_]\") -> \"abcdefghijklmnopqrstuvwxyz$_\"\n\n    The input string must be enclosed in []'s, and the returned string\n    is the expanded character set joined into a single string. The\n    values enclosed in the []'s may be:\n\n     - a single character\n     - an escaped character with a leading backslash (such as ``\\-``\n       or ``\\]``)\n     - an escaped hex character with a leading ``'\\x'``\n       (``\\x21``, which is a ``'!'`` character) (``\\0x##``\n       is also supported for backwards compatibility)\n     - an escaped octal character with a leading ``'\\0'``\n       (``\\041``, which is a ``'!'`` character)\n     - a range of any of the above, separated by a dash (``'a-z'``,\n       etc.)\n     - any combination of the above (``'aeiouy'``,\n       ``'a-zA-Z0-9_$'``, etc.)\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_53srange = {"srange", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_53srange, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_52srange};
static PyObject *__pyx_pw_10cPyparsing_53srange(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("srange (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6738, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "srange") < 0)) __PYX_ERR(0, 6738, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_s = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("srange", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6738, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.srange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_52srange(__pyx_self, __pyx_v_s);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6764
 *        ``'a-zA-Z0-9_$'``, etc.)
 *     """
 *     _expanded = lambda p: p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6srange_lambda57(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_6srange_lambda57 = {"lambda57", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_6srange_lambda57, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_6srange_lambda57(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_p = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda57 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_p,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6764, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda57") < 0)) __PYX_ERR(0, 6764, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_p = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda57", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6764, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.srange.lambda57", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda57(__pyx_self, __pyx_v_p);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_6srange_8lambda57_2generator43(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

static PyObject *__pyx_pf_10cPyparsing_6srange_8lambda57_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_63_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6764, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_6srange_8lambda57_2generator43, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_srange_locals_lambda_locals_gene, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.srange.lambda57.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_6srange_8lambda57_2generator43(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 6764, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 6764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 6764, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6764, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6764, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6764, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6764, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6764, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6764, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6764, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 6764, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_unichr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_c};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda57(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_p) {
  PyObject *__pyx_gb_10cPyparsing_6srange_8lambda57_2generator43 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  long __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  long __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda57", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_p, __pyx_t_2); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 6764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {
    __Pyx_INCREF(__pyx_v_p);
    __pyx_t_1 = __pyx_v_p;
  } else {
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_range); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_p, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_Ord(__pyx_t_6); if (unlikely(__pyx_t_7 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyInt_From_long(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = 0;
    __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_p, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = __Pyx_PyObject_Ord(__pyx_t_9); if (unlikely(__pyx_t_7 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_t_7, 1, &__pyx_t_8);
    if (unlikely(__pyx_t_8)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 6764, __pyx_L1_error)
    }
    __pyx_t_9 = __Pyx_PyInt_From_long(__pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_6, __pyx_t_9};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = __pyx_pf_10cPyparsing_6srange_8lambda57_genexpr(NULL, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.srange.lambda57", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_6srange_8lambda57_2generator43);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_6srange_3generator44(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":6766
 *     _expanded = lambda p: p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         return ""
 */

static PyObject *__pyx_pf_10cPyparsing_6srange_1genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_64_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6766, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_6srange_3generator44, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_srange_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 6766, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.srange.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_6srange_3generator44(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 6766, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 6766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 6766, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6766, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6766, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6766, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6766, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6766, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 6766, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6766, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 6766, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_part);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_part, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v__expanded)) { __Pyx_RaiseClosureNameError("_expanded"); __PYX_ERR(0, 6766, __pyx_L1_error) }
    __pyx_t_4 = __pyx_lambda_funcdef_lambda57(__pyx_cur_scope->__pyx_outer_scope->__pyx_v__expanded, __pyx_cur_scope->__pyx_v_part); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 6766, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6738
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""Helper to easily define string ranges for use in Word
 *     construction. Borrows syntax from regexp '[]' string range
 */

static PyObject *__pyx_pf_10cPyparsing_52srange(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *__pyx_cur_scope;
  PyObject *__pyx_gb_10cPyparsing_6srange_3generator44 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("srange", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_62_srange(__pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6738, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":6764
 *        ``'a-zA-Z0-9_$'``, etc.)
 *     """
 *     _expanded = lambda p: p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_6srange_lambda57, 0, __pyx_n_s_srange_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v__expanded = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6765
 *     """
 *     _expanded = lambda p: p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "cPyparsing.pyx":6766
 *     _expanded = lambda p: p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         return ""
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_reBracketExpr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6766, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_parseString); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6766, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_s};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6766, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_body); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6766, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __pyx_pf_10cPyparsing_6srange_1genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6766, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6766, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6766, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":6765
 *     """
 *     _expanded = lambda p: p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":6767
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.srange", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_5) < 0) __PYX_ERR(0, 6767, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);

      /* "cPyparsing.pyx":6768
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:
 *         return ""             # <<<<<<<<<<<<<<
 * 
 * def matchOnlyAtCol(n):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__10);
      __pyx_r = __pyx_kp_u__10;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":6765
 *     """
 *     _expanded = lambda p: p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":6738
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""Helper to easily define string ranges for use in Word
 *     construction. Borrows syntax from regexp '[]' string range
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.srange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_6srange_3generator44);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6770
 *         return ""
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """Helper method for defining parse actions that require matching at
 *     a specific column in the input text.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_55matchOnlyAtCol(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_54matchOnlyAtCol, "matchOnlyAtCol(n)\nHelper method for defining parse actions that require matching at\n    a specific column in the input text.\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_55matchOnlyAtCol = {"matchOnlyAtCol", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_55matchOnlyAtCol, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_54matchOnlyAtCol};
static PyObject *__pyx_pw_10cPyparsing_55matchOnlyAtCol(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_n = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matchOnlyAtCol (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6770, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "matchOnlyAtCol") < 0)) __PYX_ERR(0, 6770, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_n = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("matchOnlyAtCol", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6770, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.matchOnlyAtCol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_54matchOnlyAtCol(__pyx_self, __pyx_v_n);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6774
 *     a specific column in the input text.
 *     """
 *     def verifyCol(strg, locn, toks):             # <<<<<<<<<<<<<<
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14matchOnlyAtCol_1verifyCol(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_14matchOnlyAtCol_1verifyCol = {"verifyCol", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_14matchOnlyAtCol_1verifyCol, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_14matchOnlyAtCol_1verifyCol(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_strg = 0;
  PyObject *__pyx_v_locn = 0;
  CYTHON_UNUSED PyObject *__pyx_v_toks = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("verifyCol (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_strg,&__pyx_n_s_locn,&__pyx_n_s_toks,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_strg)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6774, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_locn)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6774, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("verifyCol", 1, 3, 3, 1); __PYX_ERR(0, 6774, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_toks)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6774, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("verifyCol", 1, 3, 3, 2); __PYX_ERR(0, 6774, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "verifyCol") < 0)) __PYX_ERR(0, 6774, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_strg = values[0];
    __pyx_v_locn = values[1];
    __pyx_v_toks = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("verifyCol", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6774, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.matchOnlyAtCol.verifyCol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14matchOnlyAtCol_verifyCol(__pyx_self, __pyx_v_strg, __pyx_v_locn, __pyx_v_toks);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14matchOnlyAtCol_verifyCol(PyObject *__pyx_self, PyObject *__pyx_v_strg, PyObject *__pyx_v_locn, CYTHON_UNUSED PyObject *__pyx_v_toks) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("verifyCol", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":6775
 *     """
 *     def verifyCol(strg, locn, toks):
 *         if col(locn, strg) != n:             # <<<<<<<<<<<<<<
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 *     return verifyCol
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_locn, __pyx_v_strg};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6775, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_n)) { __Pyx_RaiseClosureNameError("n"); __PYX_ERR(0, 6775, __pyx_L1_error) }
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_cur_scope->__pyx_v_n, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6775, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 6775, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_5)) {

    /* "cPyparsing.pyx":6776
 *     def verifyCol(strg, locn, toks):
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)             # <<<<<<<<<<<<<<
 *     return verifyCol
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6776, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(!__pyx_cur_scope->__pyx_v_n)) { __Pyx_RaiseClosureNameError("n"); __PYX_ERR(0, 6776, __pyx_L1_error) }
    __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_matched_token_not_at_column_d, __pyx_cur_scope->__pyx_v_n); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6776, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_6, __pyx_v_strg, __pyx_v_locn, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6776, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 6776, __pyx_L1_error)

    /* "cPyparsing.pyx":6775
 *     """
 *     def verifyCol(strg, locn, toks):
 *         if col(locn, strg) != n:             # <<<<<<<<<<<<<<
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 *     return verifyCol
 */
  }

  /* "cPyparsing.pyx":6774
 *     a specific column in the input text.
 *     """
 *     def verifyCol(strg, locn, toks):             # <<<<<<<<<<<<<<
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.matchOnlyAtCol.verifyCol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6770
 *         return ""
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """Helper method for defining parse actions that require matching at
 *     a specific column in the input text.
 */

static PyObject *__pyx_pf_10cPyparsing_54matchOnlyAtCol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_n) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *__pyx_cur_scope;
  PyObject *__pyx_v_verifyCol = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matchOnlyAtCol", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol(__pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6770, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_n = __pyx_v_n;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_n);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_n);

  /* "cPyparsing.pyx":6774
 *     a specific column in the input text.
 *     """
 *     def verifyCol(strg, locn, toks):             # <<<<<<<<<<<<<<
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_14matchOnlyAtCol_1verifyCol, 0, __pyx_n_s_matchOnlyAtCol_locals_verifyCol, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__140)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_verifyCol = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6777
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 *     return verifyCol             # <<<<<<<<<<<<<<
 * 
 * def replaceWith(replStr):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_verifyCol);
  __pyx_r = __pyx_v_verifyCol;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6770
 *         return ""
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """Helper method for defining parse actions that require matching at
 *     a specific column in the input text.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.matchOnlyAtCol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_verifyCol);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6779
 *     return verifyCol
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """Helper method for common parse actions that simply return
 *     a literal value.  Especially useful when used with
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_57replaceWith(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_56replaceWith, "replaceWith(replStr)\nHelper method for common parse actions that simply return\n    a literal value.  Especially useful when used with\n    :class:`transformString<ParserElement.transformString>` ().\n\n    Example::\n\n        num = Word(nums).setParseAction(lambda toks: int(toks[0]))\n        na = oneOf(\"N/A NA\").setParseAction(replaceWith(math.nan))\n        term = na | num\n\n        OneOrMore(term).parseString(\"324 234 N/A 234\") # -> [324, 234, nan, 234]\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_57replaceWith = {"replaceWith", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_57replaceWith, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_56replaceWith};
static PyObject *__pyx_pw_10cPyparsing_57replaceWith(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_replStr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("replaceWith (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_replStr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_replStr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6779, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "replaceWith") < 0)) __PYX_ERR(0, 6779, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_replStr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("replaceWith", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6779, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.replaceWith", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_56replaceWith(__pyx_self, __pyx_v_replStr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6792
 *         OneOrMore(term).parseString("324 234 N/A 234") # -> [324, 234, nan, 234]
 *     """
 *     return lambda s, l, t: [replStr]             # <<<<<<<<<<<<<<
 * 
 * def removeQuotes(s, l, t):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11replaceWith_lambda60(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11replaceWith_lambda60 = {"lambda60", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11replaceWith_lambda60, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11replaceWith_lambda60(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda60 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6792, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6792, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda60", 1, 3, 3, 1); __PYX_ERR(0, 6792, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6792, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda60", 1, 3, 3, 2); __PYX_ERR(0, 6792, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda60") < 0)) __PYX_ERR(0, 6792, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda60", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6792, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.replaceWith.lambda60", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda60(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda60(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda60", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_replStr)) { __Pyx_RaiseClosureNameError("replStr"); __PYX_ERR(0, 6792, __pyx_L1_error) }
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_replStr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_replStr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_cur_scope->__pyx_v_replStr)) __PYX_ERR(0, 6792, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.replaceWith.lambda60", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6779
 *     return verifyCol
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """Helper method for common parse actions that simply return
 *     a literal value.  Especially useful when used with
 */

static PyObject *__pyx_pf_10cPyparsing_56replaceWith(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_replStr) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("replaceWith", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_66_replaceWith(__pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6779, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_replStr = __pyx_v_replStr;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_replStr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_replStr);

  /* "cPyparsing.pyx":6792
 *         OneOrMore(term).parseString("324 234 N/A 234") # -> [324, 234, nan, 234]
 *     """
 *     return lambda s, l, t: [replStr]             # <<<<<<<<<<<<<<
 * 
 * def removeQuotes(s, l, t):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11replaceWith_lambda60, 0, __pyx_n_s_replaceWith_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6779
 *     return verifyCol
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """Helper method for common parse actions that simply return
 *     a literal value.  Especially useful when used with
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.replaceWith", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6794
 *     return lambda s, l, t: [replStr]
 * 
 * def removeQuotes(s, l, t):             # <<<<<<<<<<<<<<
 *     """Helper parse action for removing quotation marks from parsed
 *     quoted strings.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_59removeQuotes(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_58removeQuotes, "removeQuotes(s, l, t)\nHelper parse action for removing quotation marks from parsed\n    quoted strings.\n\n    Example::\n\n        # by default, quotation marks are included in parsed results\n        quotedString.parseString(\"'Now is the Winter of our Discontent'\") # -> [\"'Now is the Winter of our Discontent'\"]\n\n        # use removeQuotes to strip quotation marks from parsed results\n        quotedString.setParseAction(removeQuotes)\n        quotedString.parseString(\"'Now is the Winter of our Discontent'\") # -> [\"Now is the Winter of our Discontent\"]\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_59removeQuotes = {"removeQuotes", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_59removeQuotes, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_58removeQuotes};
static PyObject *__pyx_pw_10cPyparsing_59removeQuotes(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("removeQuotes (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6794, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6794, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("removeQuotes", 1, 3, 3, 1); __PYX_ERR(0, 6794, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6794, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("removeQuotes", 1, 3, 3, 2); __PYX_ERR(0, 6794, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "removeQuotes") < 0)) __PYX_ERR(0, 6794, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("removeQuotes", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6794, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.removeQuotes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_58removeQuotes(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_58removeQuotes(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("removeQuotes", 1);

  /* "cPyparsing.pyx":6807
 *         quotedString.parseString("'Now is the Winter of our Discontent'") # -> ["Now is the Winter of our Discontent"]
 *     """
 *     return t[0][1:-1]             # <<<<<<<<<<<<<<
 * 
 * def tokenMap(func, *args):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_1, 1, -1L, NULL, NULL, &__pyx_slice__141, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6794
 *     return lambda s, l, t: [replStr]
 * 
 * def removeQuotes(s, l, t):             # <<<<<<<<<<<<<<
 *     """Helper parse action for removing quotation marks from parsed
 *     quoted strings.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.removeQuotes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6809
 *     return t[0][1:-1]
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """Helper to define a parse action by mapping a function to all
 *     elements of a ParseResults list. If any additional args are passed,
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_61tokenMap(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_60tokenMap, "tokenMap(func, *args)\nHelper to define a parse action by mapping a function to all\n    elements of a ParseResults list. If any additional args are passed,\n    they are forwarded to the given function as additional arguments\n    after the token, as in\n    ``hex_integer = Word(hexnums).setParseAction(tokenMap(int, 16))``,\n    which will convert the parsed data to an integer using base 16.\n\n    Example (compare the last to example in :class:`ParserElement.transformString`::\n\n        hex_ints = OneOrMore(Word(hexnums)).setParseAction(tokenMap(int, 16))\n        hex_ints.runTests('''\n            00 11 22 aa FF 0a 0d 1a\n            ''')\n\n        upperword = Word(alphas).setParseAction(tokenMap(str.upper))\n        OneOrMore(upperword).runTests('''\n            my kingdom for a horse\n            ''')\n\n        wd = Word(alphas).setParseAction(tokenMap(str.title))\n        OneOrMore(wd).setParseAction(' '.join).runTests('''\n            now is the winter of our discontent made glorious summer by this sun of york\n            ''')\n\n    prints::\n\n        00 11 22 aa FF 0a 0d 1a\n        [0, 17, 34, 170, 255, 10, 13, 26]\n\n        my kingdom for a horse\n        ['MY', 'KINGDOM', 'FOR', 'A', 'HORSE']\n\n        now is the winter of our discontent made glorious summer by this sun of york\n        ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_61tokenMap = {"tokenMap", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_61tokenMap, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_60tokenMap};
static PyObject *__pyx_pw_10cPyparsing_61tokenMap(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_func = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tokenMap (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_func,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_func)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6809, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "tokenMap") < 0)) __PYX_ERR(0, 6809, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_func = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("tokenMap", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 6809, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_CLEAR(__pyx_v_args);
  __Pyx_AddTraceback("cPyparsing.tokenMap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_60tokenMap(__pyx_self, __pyx_v_func, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6845
 *         ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']
 *     """
 *     def pa(s, l, t):             # <<<<<<<<<<<<<<
 *         return [func(tokn, *args) for tokn in t]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8tokenMap_1pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8tokenMap_1pa = {"pa", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_8tokenMap_1pa, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_8tokenMap_1pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pa (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6845, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6845, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 1); __PYX_ERR(0, 6845, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6845, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 2); __PYX_ERR(0, 6845, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pa") < 0)) __PYX_ERR(0, 6845, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6845, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.tokenMap.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8tokenMap_pa(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8tokenMap_pa(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *__pyx_outer_scope;
  PyObject *__pyx_9genexpr58__pyx_v_tokn = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pa", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":6846
 *     """
 *     def pa(s, l, t):
 *         return [func(tokn, *args) for tokn in t]             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6846, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_t)) || PyTuple_CheckExact(__pyx_v_t)) {
      __pyx_t_2 = __pyx_v_t; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6846, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6846, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6846, __pyx_L5_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 6846, __pyx_L5_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6846, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6846, __pyx_L5_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 6846, __pyx_L5_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6846, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 6846, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr58__pyx_v_tokn, __pyx_t_5);
      __pyx_t_5 = 0;
      if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 6846, __pyx_L5_error) }
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6846, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_9genexpr58__pyx_v_tokn);
      __Pyx_GIVEREF(__pyx_9genexpr58__pyx_v_tokn);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_9genexpr58__pyx_v_tokn)) __PYX_ERR(0, 6846, __pyx_L5_error);
      if (unlikely(!__pyx_cur_scope->__pyx_v_args)) { __Pyx_RaiseClosureNameError("args"); __PYX_ERR(0, 6846, __pyx_L5_error) }
      if (unlikely(__pyx_cur_scope->__pyx_v_args == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 6846, __pyx_L5_error)
      }
      __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_cur_scope->__pyx_v_args); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6846, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_func, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6846, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 6846, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_9genexpr58__pyx_v_tokn); __pyx_9genexpr58__pyx_v_tokn = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_9genexpr58__pyx_v_tokn); __pyx_9genexpr58__pyx_v_tokn = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6845
 *         ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']
 *     """
 *     def pa(s, l, t):             # <<<<<<<<<<<<<<
 *         return [func(tokn, *args) for tokn in t]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.tokenMap.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_9genexpr58__pyx_v_tokn);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6809
 *     return t[0][1:-1]
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """Helper to define a parse action by mapping a function to all
 *     elements of a ParseResults list. If any additional args are passed,
 */

static PyObject *__pyx_pf_10cPyparsing_60tokenMap(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_args) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *__pyx_cur_scope;
  PyObject *__pyx_v_pa = 0;
  PyObject *__pyx_v_func_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tokenMap", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_67_tokenMap(__pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6809, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_func = __pyx_v_func;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);
  __pyx_cur_scope->__pyx_v_args = __pyx_v_args;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_args);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_args);

  /* "cPyparsing.pyx":6845
 *         ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']
 *     """
 *     def pa(s, l, t):             # <<<<<<<<<<<<<<
 *         return [func(tokn, *args) for tokn in t]
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_8tokenMap_1pa, 0, __pyx_n_s_tokenMap_locals_pa, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__143)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pa = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6848
 *         return [func(tokn, *args) for tokn in t]
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "cPyparsing.pyx":6849
 * 
 *     try:
 *         func_name = getattr(func, '__name__',             # <<<<<<<<<<<<<<
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 */
      __pyx_t_1 = __pyx_cur_scope->__pyx_v_func;
      __Pyx_INCREF(__pyx_t_1);

      /* "cPyparsing.pyx":6850
 *     try:
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         func_name = str(func)
 */
      __pyx_t_5 = __pyx_cur_scope->__pyx_v_func;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_GetAttr(__pyx_t_5, __pyx_n_u_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6850, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6850, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":6849
 * 
 *     try:
 *         func_name = getattr(func, '__name__',             # <<<<<<<<<<<<<<
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 */
      __pyx_t_6 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_name, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6849, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_func_name = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "cPyparsing.pyx":6848
 *         return [func(tokn, *args) for tokn in t]
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":6851
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 *     except Exception:             # <<<<<<<<<<<<<<
 *         func_name = str(func)
 *     pa.__name__ = func_name
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.tokenMap", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(0, 6851, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_1);

      /* "cPyparsing.pyx":6852
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 *         func_name = str(func)             # <<<<<<<<<<<<<<
 *     pa.__name__ = func_name
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_str); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6852, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_cur_scope->__pyx_v_func};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6852, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_func_name, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":6848
 *         return [func(tokn, *args) for tokn in t]
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_L8_try_end:;
  }

  /* "cPyparsing.pyx":6853
 *     except Exception:
 *         func_name = str(func)
 *     pa.__name__ = func_name             # <<<<<<<<<<<<<<
 * 
 *     return pa
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_pa, __pyx_n_s_name, __pyx_v_func_name) < 0) __PYX_ERR(0, 6853, __pyx_L1_error)

  /* "cPyparsing.pyx":6855
 *     pa.__name__ = func_name
 * 
 *     return pa             # <<<<<<<<<<<<<<
 * 
 * upcaseTokens = tokenMap(lambda t: _ustr(t).upper())
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pa);
  __pyx_r = __pyx_v_pa;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6809
 *     return t[0][1:-1]
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """Helper to define a parse action by mapping a function to all
 *     elements of a ParseResults list. If any additional args are passed,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.tokenMap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pa);
  __Pyx_XDECREF(__pyx_v_func_name);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6865
 * Deprecated in favor of :class:`pyparsing_common.downcaseTokens`"""
 * 
 * def _makeTags(tagStr, xml,             # <<<<<<<<<<<<<<
 *               suppress_LT=Suppress("<"),
 *               suppress_GT=Suppress(">")):
 */

static PyObject *__pyx_pf_10cPyparsing_105__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_suppress_LT);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_suppress_LT);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_suppress_LT)) __PYX_ERR(0, 6865, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_suppress_GT);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_suppress_GT);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_suppress_GT)) __PYX_ERR(0, 6865, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 6865, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 6865, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_63_makeTags(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_62_makeTags, "_makeTags(tagStr, xml, suppress_LT=Suppress(u'<'), suppress_GT=Suppress(u'>'))\nInternal helper to construct opening and closing tag expressions, given a tag name");
static PyMethodDef __pyx_mdef_10cPyparsing_63_makeTags = {"_makeTags", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_63_makeTags, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_62_makeTags};
static PyObject *__pyx_pw_10cPyparsing_63_makeTags(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_tagStr = 0;
  PyObject *__pyx_v_xml = 0;
  PyObject *__pyx_v_suppress_LT = 0;
  PyObject *__pyx_v_suppress_GT = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_makeTags (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tagStr,&__pyx_n_s_xml,&__pyx_n_s_suppress_LT,&__pyx_n_s_suppress_GT,0};
    __pyx_defaults8 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_suppress_LT);
    values[3] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_suppress_GT);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tagStr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6865, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_xml)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6865, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_makeTags", 0, 2, 4, 1); __PYX_ERR(0, 6865, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_suppress_LT);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6865, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_suppress_GT);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6865, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_makeTags") < 0)) __PYX_ERR(0, 6865, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_tagStr = values[0];
    __pyx_v_xml = values[1];
    __pyx_v_suppress_LT = values[2];
    __pyx_v_suppress_GT = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_makeTags", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 6865, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._makeTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_62_makeTags(__pyx_self, __pyx_v_tagStr, __pyx_v_xml, __pyx_v_suppress_LT, __pyx_v_suppress_GT);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6881
 *                    + tagStr("tag")
 *                    + Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue)))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')             # <<<<<<<<<<<<<<
 *                    + suppress_GT)
 *     else:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_lambda63(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9_makeTags_lambda63 = {"lambda63", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9_makeTags_lambda63, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_lambda63(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda63 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6881, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6881, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda63", 1, 3, 3, 1); __PYX_ERR(0, 6881, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6881, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda63", 1, 3, 3, 2); __PYX_ERR(0, 6881, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda63") < 0)) __PYX_ERR(0, 6881, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda63", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6881, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda63", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda63(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda63(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda63", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_kp_u__144, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6881, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda63", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6889
 *                    + Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens)
 *                                            + Optional(Suppress("=") + tagAttrValue))))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')             # <<<<<<<<<<<<<<
 *                    + suppress_GT)
 *     closeTag = Combine(_L("</") + tagStr + ">", adjacent=False)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_1lambda64(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9_makeTags_1lambda64 = {"lambda64", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9_makeTags_1lambda64, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_1lambda64(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda64 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6889, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6889, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda64", 1, 3, 3, 1); __PYX_ERR(0, 6889, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6889, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda64", 1, 3, 3, 2); __PYX_ERR(0, 6889, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda64") < 0)) __PYX_ERR(0, 6889, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda64", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6889, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda64(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda64(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda64", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_kp_u__144, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6889, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6895
 *     openTag.setName("<%s>" % resname)
 *     # add start<tagname> results name in parse action now that ungrouped names are not reported at two levels
 *     openTag.addParseAction(lambda t: t.__setitem__("start" + "".join(resname.replace(":", " ").title().split()), t.copy()))             # <<<<<<<<<<<<<<
 *     closeTag = closeTag("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)
 *     openTag.tag = resname
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_2lambda65(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9_makeTags_2lambda65 = {"lambda65", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_9_makeTags_2lambda65, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_2lambda65(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda65 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6895, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda65") < 0)) __PYX_ERR(0, 6895, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda65", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6895, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda65", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda65(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda65(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda65", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_setitem); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(!__pyx_cur_scope->__pyx_v_resname)) { __Pyx_RaiseClosureNameError("resname"); __PYX_ERR(0, 6895, __pyx_L1_error) }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_resname, __pyx_n_s_replace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__146, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_title); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_split); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_n_u_start, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda65", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6865
 * Deprecated in favor of :class:`pyparsing_common.downcaseTokens`"""
 * 
 * def _makeTags(tagStr, xml,             # <<<<<<<<<<<<<<
 *               suppress_LT=Suppress("<"),
 *               suppress_GT=Suppress(">")):
 */

static PyObject *__pyx_pf_10cPyparsing_62_makeTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr, PyObject *__pyx_v_xml, PyObject *__pyx_v_suppress_LT, PyObject *__pyx_v_suppress_GT) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *__pyx_cur_scope;
  PyObject *__pyx_v_tagAttrName = NULL;
  PyObject *__pyx_v_tagAttrValue = NULL;
  PyObject *__pyx_v_openTag = NULL;
  PyObject *__pyx_v_closeTag = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_makeTags", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_68__makeTags(__pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6865, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __Pyx_INCREF(__pyx_v_tagStr);

  /* "cPyparsing.pyx":6869
 *               suppress_GT=Suppress(">")):
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):             # <<<<<<<<<<<<<<
 *         resname = tagStr
 *         tagStr = Keyword(tagStr, caseless=not xml)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_tagStr, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 6869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6870
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):
 *         resname = tagStr             # <<<<<<<<<<<<<<
 *         tagStr = Keyword(tagStr, caseless=not xml)
 *     else:
 */
    __Pyx_INCREF(__pyx_v_tagStr);
    __Pyx_GIVEREF(__pyx_v_tagStr);
    __pyx_cur_scope->__pyx_v_resname = __pyx_v_tagStr;

    /* "cPyparsing.pyx":6871
 *     if isinstance(tagStr, basestring):
 *         resname = tagStr
 *         tagStr = Keyword(tagStr, caseless=not xml)             # <<<<<<<<<<<<<<
 *     else:
 *         resname = tagStr.name
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_tagStr);
    __Pyx_GIVEREF(__pyx_v_tagStr);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_tagStr)) __PYX_ERR(0, 6871, __pyx_L1_error);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_xml); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6871, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_caseless, __pyx_t_5) < 0) __PYX_ERR(0, 6871, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_tagStr, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":6869
 *               suppress_GT=Suppress(">")):
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):             # <<<<<<<<<<<<<<
 *         resname = tagStr
 *         tagStr = Keyword(tagStr, caseless=not xml)
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":6873
 *         tagStr = Keyword(tagStr, caseless=not xml)
 *     else:
 *         resname = tagStr.name             # <<<<<<<<<<<<<<
 * 
 *     tagAttrName = Word(alphas, alphanums + "_-:")
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_tagStr, __pyx_n_s_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_cur_scope->__pyx_v_resname = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":6875
 *         resname = tagStr.name
 * 
 *     tagAttrName = Word(alphas, alphanums + "_-:")             # <<<<<<<<<<<<<<
 *     if xml:
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Word); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_alphas); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_alphanums); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__147); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_t_3, __pyx_t_6};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_tagAttrName = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":6876
 * 
 *     tagAttrName = Word(alphas, alphanums + "_-:")
 *     if xml:             # <<<<<<<<<<<<<<
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = (suppress_LT
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_xml); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 6876, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":6877
 *     tagAttrName = Word(alphas, alphanums + "_-:")
 *     if xml:
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)             # <<<<<<<<<<<<<<
 *         openTag = (suppress_LT
 *                    + tagStr("tag")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_dblQuotedString); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_removeQuotes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_tagAttrValue = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":6879
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = (suppress_LT
 *                    + tagStr("tag")             # <<<<<<<<<<<<<<
 *                    + Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue)))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')
 */
    __Pyx_INCREF(__pyx_v_tagStr);
    __pyx_t_3 = __pyx_v_tagStr; __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_tag};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6879, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_v_suppress_LT, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":6880
 *         openTag = (suppress_LT
 *                    + tagStr("tag")
 *                    + Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue)))             # <<<<<<<<<<<<<<
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')
 *                    + suppress_GT)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Dict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_kp_u__148};
      __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __pyx_t_11 = PyNumber_Add(__pyx_v_tagAttrName, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_Add(__pyx_t_11, __pyx_v_tagAttrValue); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_10};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_9 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":6881
 *                    + tagStr("tag")
 *                    + Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue)))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')             # <<<<<<<<<<<<<<
 *                    + suppress_GT)
 *     else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_Optional); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, Py_False)) __PYX_ERR(0, 6881, __pyx_L1_error);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_default, __pyx_t_8) < 0) __PYX_ERR(0, 6881, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__149, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_n_u_empty};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9_makeTags_lambda63, 0, __pyx_n_s_makeTags_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_3};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_t_8 = PyNumber_Add(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":6882
 *                    + Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue)))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')
 *                    + suppress_GT)             # <<<<<<<<<<<<<<
 *     else:
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printables, excludeChars=">")
 */
    __pyx_t_5 = PyNumber_Add(__pyx_t_8, __pyx_v_suppress_GT); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6882, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_openTag = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":6876
 * 
 *     tagAttrName = Word(alphas, alphanums + "_-:")
 *     if xml:             # <<<<<<<<<<<<<<
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = (suppress_LT
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":6884
 *                    + suppress_GT)
 *     else:
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printables, excludeChars=">")             # <<<<<<<<<<<<<<
 *         openTag = (suppress_LT
 *                    + tagStr("tag")
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_quotedString); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6884, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_removeQuotes); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_8};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6884, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Word); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_printables); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8)) __PYX_ERR(0, 6884, __pyx_L1_error);
    __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_excludeChars, __pyx_kp_u__27) < 0) __PYX_ERR(0, 6884, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyNumber_Or(__pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_tagAttrValue = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "cPyparsing.pyx":6886
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printables, excludeChars=">")
 *         openTag = (suppress_LT
 *                    + tagStr("tag")             # <<<<<<<<<<<<<<
 *                    + Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens)
 *                                            + Optional(Suppress("=") + tagAttrValue))))
 */
    __Pyx_INCREF(__pyx_v_tagStr);
    __pyx_t_1 = __pyx_v_tagStr; __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_n_u_tag};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6886, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = PyNumber_Add(__pyx_v_suppress_LT, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":6887
 *         openTag = (suppress_LT
 *                    + tagStr("tag")
 *                    + Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens)             # <<<<<<<<<<<<<<
 *                                            + Optional(Suppress("=") + tagAttrValue))))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_tagAttrName, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_downcaseTokens); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_13 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_12};
      __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6887, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }

    /* "cPyparsing.pyx":6888
 *                    + tagStr("tag")
 *                    + Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens)
 *                                            + Optional(Suppress("=") + tagAttrValue))))             # <<<<<<<<<<<<<<
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')
 *                    + suppress_GT)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_Optional); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_15 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_15)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_15);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_kp_u__148};
      __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 6888, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    }
    __pyx_t_14 = PyNumber_Add(__pyx_t_13, __pyx_v_tagAttrValue); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_14};
      __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 6888, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
    __pyx_t_12 = PyNumber_Add(__pyx_t_10, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 6888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_12};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6887, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_9 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6887, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6887, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }

    /* "cPyparsing.pyx":6887
 *         openTag = (suppress_LT
 *                    + tagStr("tag")
 *                    + Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens)             # <<<<<<<<<<<<<<
 *                                            + Optional(Suppress("=") + tagAttrValue))))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')
 */
    __pyx_t_5 = PyNumber_Add(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":6889
 *                    + Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens)
 *                                            + Optional(Suppress("=") + tagAttrValue))))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')             # <<<<<<<<<<<<<<
 *                    + suppress_GT)
 *     closeTag = Combine(_L("</") + tagStr + ">", adjacent=False)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Optional); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, Py_False)) __PYX_ERR(0, 6889, __pyx_L1_error);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_default, __pyx_t_6) < 0) __PYX_ERR(0, 6889, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__149, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_empty};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6889, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9_makeTags_1lambda64, 0, __pyx_n_s_makeTags_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6889, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":6890
 *                                            + Optional(Suppress("=") + tagAttrValue))))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')
 *                    + suppress_GT)             # <<<<<<<<<<<<<<
 *     closeTag = Combine(_L("</") + tagStr + ">", adjacent=False)
 * 
 */
    __pyx_t_8 = PyNumber_Add(__pyx_t_6, __pyx_v_suppress_GT); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6890, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_openTag = __pyx_t_8;
    __pyx_t_8 = 0;
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":6891
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')
 *                    + suppress_GT)
 *     closeTag = Combine(_L("</") + tagStr + ">", adjacent=False)             # <<<<<<<<<<<<<<
 * 
 *     openTag.setName("<%s>" % resname)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_Combine); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_L_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_kp_u__28};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyNumber_Add(__pyx_t_6, __pyx_v_tagStr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__27); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 6891, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_adjacent, Py_False) < 0) __PYX_ERR(0, 6891, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_closeTag = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6893
 *     closeTag = Combine(_L("</") + tagStr + ">", adjacent=False)
 * 
 *     openTag.setName("<%s>" % resname)             # <<<<<<<<<<<<<<
 *     # add start<tagname> results name in parse action now that ungrouped names are not reported at two levels
 *     openTag.addParseAction(lambda t: t.__setitem__("start" + "".join(resname.replace(":", " ").title().split()), t.copy()))
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_openTag, __pyx_n_s_setName); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_9, __pyx_cur_scope->__pyx_v_resname); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6893, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6895
 *     openTag.setName("<%s>" % resname)
 *     # add start<tagname> results name in parse action now that ungrouped names are not reported at two levels
 *     openTag.addParseAction(lambda t: t.__setitem__("start" + "".join(resname.replace(":", " ").title().split()), t.copy()))             # <<<<<<<<<<<<<<
 *     closeTag = closeTag("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)
 *     openTag.tag = resname
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_openTag, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9_makeTags_2lambda65, 0, __pyx_n_s_makeTags_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6896
 *     # add start<tagname> results name in parse action now that ungrouped names are not reported at two levels
 *     openTag.addParseAction(lambda t: t.__setitem__("start" + "".join(resname.replace(":", " ").title().split()), t.copy()))
 *     closeTag = closeTag("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)             # <<<<<<<<<<<<<<
 *     openTag.tag = resname
 *     closeTag.tag = resname
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_resname, __pyx_n_s_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__146, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_title); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_split); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_n_u_end, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_v_closeTag);
  __pyx_t_3 = __pyx_v_closeTag; __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_10, __pyx_cur_scope->__pyx_v_resname); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_closeTag, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6897
 *     openTag.addParseAction(lambda t: t.__setitem__("start" + "".join(resname.replace(":", " ").title().split()), t.copy()))
 *     closeTag = closeTag("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)
 *     openTag.tag = resname             # <<<<<<<<<<<<<<
 *     closeTag.tag = resname
 *     openTag.tag_body = SkipTo(closeTag())
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_openTag, __pyx_n_s_tag, __pyx_cur_scope->__pyx_v_resname) < 0) __PYX_ERR(0, 6897, __pyx_L1_error)

  /* "cPyparsing.pyx":6898
 *     closeTag = closeTag("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)
 *     openTag.tag = resname
 *     closeTag.tag = resname             # <<<<<<<<<<<<<<
 *     openTag.tag_body = SkipTo(closeTag())
 *     return openTag, closeTag
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_closeTag, __pyx_n_s_tag, __pyx_cur_scope->__pyx_v_resname) < 0) __PYX_ERR(0, 6898, __pyx_L1_error)

  /* "cPyparsing.pyx":6899
 *     openTag.tag = resname
 *     closeTag.tag = resname
 *     openTag.tag_body = SkipTo(closeTag())             # <<<<<<<<<<<<<<
 *     return openTag, closeTag
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_SkipTo); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_closeTag);
  __pyx_t_5 = __pyx_v_closeTag; __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_openTag, __pyx_n_s_tag_body, __pyx_t_1) < 0) __PYX_ERR(0, 6899, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6900
 *     closeTag.tag = resname
 *     openTag.tag_body = SkipTo(closeTag())
 *     return openTag, closeTag             # <<<<<<<<<<<<<<
 * 
 * def makeHTMLTags(tagStr):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_openTag);
  __Pyx_GIVEREF(__pyx_v_openTag);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_openTag)) __PYX_ERR(0, 6900, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_closeTag);
  __Pyx_GIVEREF(__pyx_v_closeTag);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_closeTag)) __PYX_ERR(0, 6900, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6865
 * Deprecated in favor of :class:`pyparsing_common.downcaseTokens`"""
 * 
 * def _makeTags(tagStr, xml,             # <<<<<<<<<<<<<<
 *               suppress_LT=Suppress("<"),
 *               suppress_GT=Suppress(">")):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("cPyparsing._makeTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tagAttrName);
  __Pyx_XDECREF(__pyx_v_tagAttrValue);
  __Pyx_XDECREF(__pyx_v_openTag);
  __Pyx_XDECREF(__pyx_v_closeTag);
  __Pyx_XDECREF(__pyx_v_tagStr);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6902
 *     return openTag, closeTag
 * 
 * def makeHTMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """Helper to construct opening and closing tag expressions for HTML,
 *     given a tag name. Matches tags in either upper or lower case,
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_65makeHTMLTags(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_64makeHTMLTags, "makeHTMLTags(tagStr)\nHelper to construct opening and closing tag expressions for HTML,\n    given a tag name. Matches tags in either upper or lower case,\n    attributes with namespaces and with quoted or unquoted values.\n\n    Example::\n\n        text = '<td>More info at the <a href=\"https://github.com/pyparsing/pyparsing/wiki\">pyparsing</a> wiki page</td>'\n        # makeHTMLTags returns pyparsing expressions for the opening and\n        # closing tags as a 2-tuple\n        a, a_end = makeHTMLTags(\"A\")\n        link_expr = a + SkipTo(a_end)(\"link_text\") + a_end\n\n        for link in link_expr.searchString(text):\n            # attributes in the <A> tag (like \"href\" shown here) are\n            # also accessible as named results\n            print(link.link_text, '->', link.href)\n\n    prints::\n\n        pyparsing -> https://github.com/pyparsing/pyparsing/wiki\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_65makeHTMLTags = {"makeHTMLTags", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_65makeHTMLTags, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_64makeHTMLTags};
static PyObject *__pyx_pw_10cPyparsing_65makeHTMLTags(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_tagStr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makeHTMLTags (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tagStr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tagStr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6902, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "makeHTMLTags") < 0)) __PYX_ERR(0, 6902, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_tagStr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("makeHTMLTags", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6902, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.makeHTMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_64makeHTMLTags(__pyx_self, __pyx_v_tagStr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_64makeHTMLTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("makeHTMLTags", 1);

  /* "cPyparsing.pyx":6924
 *         pyparsing -> https://github.com/pyparsing/pyparsing/wiki
 *     """
 *     return _makeTags(tagStr, False)             # <<<<<<<<<<<<<<
 * 
 * def makeXMLTags(tagStr):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_makeTags); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_tagStr, Py_False};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6902
 *     return openTag, closeTag
 * 
 * def makeHTMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """Helper to construct opening and closing tag expressions for HTML,
 *     given a tag name. Matches tags in either upper or lower case,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.makeHTMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6926
 *     return _makeTags(tagStr, False)
 * 
 * def makeXMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """Helper to construct opening and closing tag expressions for XML,
 *     given a tag name. Matches tags only in the given upper/lower case.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_67makeXMLTags(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_66makeXMLTags, "makeXMLTags(tagStr)\nHelper to construct opening and closing tag expressions for XML,\n    given a tag name. Matches tags only in the given upper/lower case.\n\n    Example: similar to :class:`makeHTMLTags`\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_67makeXMLTags = {"makeXMLTags", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_67makeXMLTags, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_66makeXMLTags};
static PyObject *__pyx_pw_10cPyparsing_67makeXMLTags(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_tagStr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makeXMLTags (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tagStr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tagStr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6926, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "makeXMLTags") < 0)) __PYX_ERR(0, 6926, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_tagStr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("makeXMLTags", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6926, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.makeXMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_66makeXMLTags(__pyx_self, __pyx_v_tagStr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_66makeXMLTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("makeXMLTags", 1);

  /* "cPyparsing.pyx":6932
 *     Example: similar to :class:`makeHTMLTags`
 *     """
 *     return _makeTags(tagStr, True)             # <<<<<<<<<<<<<<
 * 
 * # [CPYPARSING] withAttribute must be a class
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_makeTags); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_tagStr, Py_True};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6926
 *     return _makeTags(tagStr, False)
 * 
 * def makeXMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """Helper to construct opening and closing tag expressions for XML,
 *     given a tag name. Matches tags only in the given upper/lower case.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.makeXMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6938
 *     ANY_VALUE = object()
 * 
 *     def __call__(self, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         """Helper to create a validating parse action to be used with start
 *         tags created with :class:`makeXMLTags` or
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_17BaseWithAttribute_1__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_17BaseWithAttribute___call__, "BaseWithAttribute.__call__(self, *args, **attrDict)\nHelper to create a validating parse action to be used with start\n        tags created with :class:`makeXMLTags` or\n        :class:`makeHTMLTags`. Use ``withAttribute`` to qualify\n        a starting tag with a required attribute value, to avoid false\n        matches on common tags such as ``<TD>`` or ``<DIV>``.\n\n        Call ``withAttribute`` with a series of attribute names and\n        values. Specify the list of filter attributes names and values as:\n\n         - keyword arguments, as in ``(align=\"right\")``, or\n         - as an explicit dict with ``**`` operator, when an attribute\n           name is also a Python reserved word, as in ``**{\"class\":\"Customer\", \"align\":\"right\"}``\n         - a list of name-value tuples, as in ``((\"ns1:class\", \"Customer\"), (\"ns2:align\", \"right\"))``\n\n        For attribute names with a namespace prefix, you must use the second\n        form.  Attribute names are matched insensitive to upper/lower case.\n\n        If just testing for ``class`` (with or without a namespace), use\n        :class:`withClass`.\n\n        To verify that the attribute exists, but without specifying a value,\n        pass ``withAttribute.ANY_VALUE`` as the value.\n\n        Example::\n\n            html = '''\n                <div>\n                Some text\n                <div type=\"grid\">1 4 0 1 0</div>\n                <div type=\"graph\">1,3 2,3 1,1</div>\n                <div>this has no type</div>\n                </div>\n\n            '''\n            div,div_end = makeHTMLTags(\"div\")\n\n            # only match div tag having a type attribute with value \"grid\"\n            div_grid = div().setParseAction(withAttribute(type=\"grid\"))\n            grid_expr = div_grid + SkipTo(div | div_end)(\"body\")\n            for grid_header in grid_expr.searchString(html):\n                print(grid_header.body)\n\n            # construct a match with any div tag having a typ""e attribute, regardless of the value\n            div_any_type = div().setParseAction(withAttribute(type=withAttribute.ANY_VALUE))\n            div_expr = div_any_type + SkipTo(div | div_end)(\"body\")\n            for div_header in div_expr.searchString(html):\n                print(div_header.body)\n\n        prints::\n\n            1 4 0 1 0\n\n            1 4 0 1 0\n            1,3 2,3 1,1\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_17BaseWithAttribute_1__call__ = {"__call__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_17BaseWithAttribute_1__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_17BaseWithAttribute___call__};
static PyObject *__pyx_pw_10cPyparsing_17BaseWithAttribute_1__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_attrDict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_attrDict = PyDict_New(); if (unlikely(!__pyx_v_attrDict)) return NULL;
  __Pyx_GOTREF(__pyx_v_attrDict);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_attrDict); __pyx_v_attrDict = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6938, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_attrDict, values + 0, used_pos_args, "__call__") < 0)) __PYX_ERR(0, 6938, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 6938, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_attrDict); __pyx_v_attrDict = 0;
  __Pyx_AddTraceback("cPyparsing.BaseWithAttribute.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_17BaseWithAttribute___call__(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_attrDict);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_attrDict);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6999
 *             attrs = attrDict.items()
 *         attrs = [(k, v) for k, v in attrs]
 *         def pa(s, l, tokens):             # <<<<<<<<<<<<<<
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_17BaseWithAttribute_8__call___1pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_17BaseWithAttribute_8__call___1pa = {"pa", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_17BaseWithAttribute_8__call___1pa, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_17BaseWithAttribute_8__call___1pa(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_tokens = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pa (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_tokens,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6999, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6999, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 1); __PYX_ERR(0, 6999, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tokens)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6999, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 2); __PYX_ERR(0, 6999, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pa") < 0)) __PYX_ERR(0, 6999, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_tokens = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 6999, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.BaseWithAttribute.__call__.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_17BaseWithAttribute_8__call___pa(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_tokens);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_17BaseWithAttribute_8__call___pa(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_tokens) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *__pyx_outer_scope;
  PyObject *__pyx_v_attrName = NULL;
  PyObject *__pyx_v_attrValue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_UCS4 __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pa", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":7000
 *         attrs = [(k, v) for k, v in attrs]
 *         def pa(s, l, tokens):
 *             for attrName, attrValue in attrs:             # <<<<<<<<<<<<<<
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_attrs)) { __Pyx_RaiseClosureNameError("attrs"); __PYX_ERR(0, 7000, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_attrs)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_attrs)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_v_attrs; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_attrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7000, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7000, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7000, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 7000, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7000, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7000, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 7000, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7000, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 7000, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 7000, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7000, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7000, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7000, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 7000, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 7000, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_attrName, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_attrValue, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":7001
 *         def pa(s, l, tokens):
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:             # <<<<<<<<<<<<<<
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != withAttribute.ANY_VALUE and tokens[attrName] != attrValue:
 */
    __pyx_t_9 = (__Pyx_PySequence_ContainsTF(__pyx_v_attrName, __pyx_v_tokens, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 7001, __pyx_L1_error)
    if (unlikely(__pyx_t_9)) {

      /* "cPyparsing.pyx":7002
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)             # <<<<<<<<<<<<<<
 *                 if attrValue != withAttribute.ANY_VALUE and tokens[attrName] != attrValue:
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = PyNumber_Add(__pyx_kp_u_no_matching_attribute, __pyx_v_attrName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_v_s, __pyx_v_l, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_10, 3+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7002, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 7002, __pyx_L1_error)

      /* "cPyparsing.pyx":7001
 *         def pa(s, l, tokens):
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:             # <<<<<<<<<<<<<<
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != withAttribute.ANY_VALUE and tokens[attrName] != attrValue:
 */
    }

    /* "cPyparsing.pyx":7003
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != withAttribute.ANY_VALUE and tokens[attrName] != attrValue:             # <<<<<<<<<<<<<<
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 *                                                 (attrName, tokens[attrName], attrValue))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_withAttribute); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ANY_VALUE); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_attrValue, __pyx_t_6, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7003, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 7003, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_11) {
    } else {
      __pyx_t_9 = __pyx_t_11;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_tokens, __pyx_v_attrName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyObject_RichCompare(__pyx_t_4, __pyx_v_attrValue, Py_NE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7003, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 7003, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = __pyx_t_11;
    __pyx_L9_bool_binop_done:;
    if (unlikely(__pyx_t_9)) {

      /* "cPyparsing.pyx":7004
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != withAttribute.ANY_VALUE and tokens[attrName] != attrValue:
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %             # <<<<<<<<<<<<<<
 *                                                 (attrName, tokens[attrName], attrValue))
 *         return pa
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7004, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyTuple_New(7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7004, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = 0;
      __pyx_t_13 = 127;
      __Pyx_INCREF(__pyx_kp_u_attribute);
      __pyx_t_12 += 11;
      __Pyx_GIVEREF(__pyx_kp_u_attribute);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_attribute);

      /* "cPyparsing.pyx":7005
 *                 if attrValue != withAttribute.ANY_VALUE and tokens[attrName] != attrValue:
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 *                                                 (attrName, tokens[attrName], attrValue))             # <<<<<<<<<<<<<<
 *         return pa
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_attrName), __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7005, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_13;
      __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_INCREF(__pyx_kp_u_has_value);
      __pyx_t_12 += 13;
      __Pyx_GIVEREF(__pyx_kp_u_has_value);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u_has_value);
      __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_tokens, __pyx_v_attrName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7005, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_7), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7005, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_13;
      __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u_must_be);
      __pyx_t_12 += 12;
      __Pyx_GIVEREF(__pyx_kp_u_must_be);
      PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_kp_u_must_be);
      __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_attrValue), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7005, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_13;
      __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_5, 5, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u__150);
      __pyx_t_12 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__150);
      PyTuple_SET_ITEM(__pyx_t_5, 6, __pyx_kp_u__150);

      /* "cPyparsing.pyx":7004
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != withAttribute.ANY_VALUE and tokens[attrName] != attrValue:
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %             # <<<<<<<<<<<<<<
 *                                                 (attrName, tokens[attrName], attrValue))
 *         return pa
 */
      __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_5, 7, __pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7004, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_t_14};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 3+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7004, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(0, 7004, __pyx_L1_error)

      /* "cPyparsing.pyx":7003
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != withAttribute.ANY_VALUE and tokens[attrName] != attrValue:             # <<<<<<<<<<<<<<
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 *                                                 (attrName, tokens[attrName], attrValue))
 */
    }

    /* "cPyparsing.pyx":7000
 *         attrs = [(k, v) for k, v in attrs]
 *         def pa(s, l, tokens):
 *             for attrName, attrValue in attrs:             # <<<<<<<<<<<<<<
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":6999
 *             attrs = attrDict.items()
 *         attrs = [(k, v) for k, v in attrs]
 *         def pa(s, l, tokens):             # <<<<<<<<<<<<<<
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("cPyparsing.BaseWithAttribute.__call__.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_attrName);
  __Pyx_XDECREF(__pyx_v_attrValue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":6938
 *     ANY_VALUE = object()
 * 
 *     def __call__(self, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         """Helper to create a validating parse action to be used with start
 *         tags created with :class:`makeXMLTags` or
 */

static PyObject *__pyx_pf_10cPyparsing_17BaseWithAttribute___call__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_attrDict) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *__pyx_cur_scope;
  PyObject *__pyx_v_pa = 0;
  PyObject *__pyx_9genexpr59__pyx_v_k = NULL;
  PyObject *__pyx_9genexpr59__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_69___call__(__pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 6938, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":6994
 *             1,3 2,3 1,1
 *         """
 *         if args:             # <<<<<<<<<<<<<<
 *             attrs = args[:]
 *         else:
 */
  __pyx_t_1 = (PyTuple_GET_SIZE(__pyx_v_args) != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":6995
 *         """
 *         if args:
 *             attrs = args[:]             # <<<<<<<<<<<<<<
 *         else:
 *             attrs = attrDict.items()
 */
    __pyx_t_2 = __Pyx_PyTuple_GetSlice(__pyx_v_args, 0, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6995, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_v_attrs = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":6994
 *             1,3 2,3 1,1
 *         """
 *         if args:             # <<<<<<<<<<<<<<
 *             attrs = args[:]
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":6997
 *             attrs = args[:]
 *         else:
 *             attrs = attrDict.items()             # <<<<<<<<<<<<<<
 *         attrs = [(k, v) for k, v in attrs]
 *         def pa(s, l, tokens):
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_attrDict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_v_attrs = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":6998
 *         else:
 *             attrs = attrDict.items()
 *         attrs = [(k, v) for k, v in attrs]             # <<<<<<<<<<<<<<
 *         def pa(s, l, tokens):
 *             for attrName, attrValue in attrs:
 */
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6998, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_attrs)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_attrs)) {
      __pyx_t_3 = __pyx_cur_scope->__pyx_v_attrs; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_attrs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6998, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6998, __pyx_L6_error)
    }
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6998, __pyx_L6_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 6998, __pyx_L6_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6998, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 6998, __pyx_L6_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 6998, __pyx_L6_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6998, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 6998, __pyx_L6_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 6998, __pyx_L6_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        #else
        __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 6998, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 6998, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6998, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
        index = 0; __pyx_t_7 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_7)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_8 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 2) < 0) __PYX_ERR(0, 6998, __pyx_L6_error)
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 6998, __pyx_L6_error)
        __pyx_L10_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr59__pyx_v_k, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_9genexpr59__pyx_v_v, __pyx_t_8);
      __pyx_t_8 = 0;
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6998, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_9genexpr59__pyx_v_k);
      __Pyx_GIVEREF(__pyx_9genexpr59__pyx_v_k);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_9genexpr59__pyx_v_k)) __PYX_ERR(0, 6998, __pyx_L6_error);
      __Pyx_INCREF(__pyx_9genexpr59__pyx_v_v);
      __Pyx_GIVEREF(__pyx_9genexpr59__pyx_v_v);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_9genexpr59__pyx_v_v)) __PYX_ERR(0, 6998, __pyx_L6_error);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 6998, __pyx_L6_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_9genexpr59__pyx_v_k); __pyx_9genexpr59__pyx_v_k = 0;
    __Pyx_XDECREF(__pyx_9genexpr59__pyx_v_v); __pyx_9genexpr59__pyx_v_v = 0;
    goto __pyx_L12_exit_scope;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_9genexpr59__pyx_v_k); __pyx_9genexpr59__pyx_v_k = 0;
    __Pyx_XDECREF(__pyx_9genexpr59__pyx_v_v); __pyx_9genexpr59__pyx_v_v = 0;
    goto __pyx_L1_error;
    __pyx_L12_exit_scope:;
  } /* exit inner scope */
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_attrs);
  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_attrs, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6999
 *             attrs = attrDict.items()
 *         attrs = [(k, v) for k, v in attrs]
 *         def pa(s, l, tokens):             # <<<<<<<<<<<<<<
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_17BaseWithAttribute_8__call___1pa, 0, __pyx_n_s_BaseWithAttribute___call___local, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__152)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_pa = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7006
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 *                                                 (attrName, tokens[attrName], attrValue))
 *         return pa             # <<<<<<<<<<<<<<
 * 
 * # [CPYPARSING] set withAttribute
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pa);
  __pyx_r = __pyx_v_pa;
  goto __pyx_L0;

  /* "cPyparsing.pyx":6938
 *     ANY_VALUE = object()
 * 
 *     def __call__(self, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         """Helper to create a validating parse action to be used with start
 *         tags created with :class:`makeXMLTags` or
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.BaseWithAttribute.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pa);
  __Pyx_XDECREF(__pyx_9genexpr59__pyx_v_k);
  __Pyx_XDECREF(__pyx_9genexpr59__pyx_v_v);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7011
 * withAttribute = BaseWithAttribute()
 * 
 * def withClass(classname, namespace=''):             # <<<<<<<<<<<<<<
 *     """Simplified version of :class:`withAttribute` when
 *     matching on a div class - made difficult because ``class`` is
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_69withClass(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_68withClass, "withClass(classname, namespace=u'')\nSimplified version of :class:`withAttribute` when\n    matching on a div class - made difficult because ``class`` is\n    a reserved word in Python.\n\n    Example::\n\n        html = '''\n            <div>\n            Some text\n            <div class=\"grid\">1 4 0 1 0</div>\n            <div class=\"graph\">1,3 2,3 1,1</div>\n            <div>this &lt;div&gt; has no class</div>\n            </div>\n\n        '''\n        div,div_end = makeHTMLTags(\"div\")\n        div_grid = div().setParseAction(withClass(\"grid\"))\n\n        grid_expr = div_grid + SkipTo(div | div_end)(\"body\")\n        for grid_header in grid_expr.searchString(html):\n            print(grid_header.body)\n\n        div_any_type = div().setParseAction(withClass(withAttribute.ANY_VALUE))\n        div_expr = div_any_type + SkipTo(div | div_end)(\"body\")\n        for div_header in div_expr.searchString(html):\n            print(div_header.body)\n\n    prints::\n\n        1 4 0 1 0\n\n        1 4 0 1 0\n        1,3 2,3 1,1\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_69withClass = {"withClass", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_69withClass, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_68withClass};
static PyObject *__pyx_pw_10cPyparsing_69withClass(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_classname = 0;
  PyObject *__pyx_v_namespace = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("withClass (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_classname,&__pyx_n_s_namespace,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__10)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_classname)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7011, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_namespace);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7011, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "withClass") < 0)) __PYX_ERR(0, 7011, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_classname = values[0];
    __pyx_v_namespace = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("withClass", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 7011, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.withClass", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_68withClass(__pyx_self, __pyx_v_classname, __pyx_v_namespace);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_68withClass(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_classname, PyObject *__pyx_v_namespace) {
  PyObject *__pyx_v_classattr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("withClass", 1);

  /* "cPyparsing.pyx":7046
 *         1,3 2,3 1,1
 *     """
 *     classattr = "%s:class" % namespace if namespace else "class"             # <<<<<<<<<<<<<<
 *     return withAttribute(**{classattr: classname})
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_namespace); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 7046, __pyx_L1_error)
  if (__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_class, __pyx_v_namespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_n_u_class_2);
    __pyx_t_1 = __pyx_n_u_class_2;
  }
  __pyx_v_classattr = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7047
 *     """
 *     classattr = "%s:class" % namespace if namespace else "class"
 *     return withAttribute(**{classattr: classname})             # <<<<<<<<<<<<<<
 * 
 * opAssoc = SimpleNamespace()
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_withAttribute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(PyDict_Contains(__pyx_t_3, __pyx_v_classattr))) {
    __Pyx_RaiseDoubleKeywordsError("function", __pyx_v_classattr); __PYX_ERR(0, 7047, __pyx_L1_error)
  } else {
    if (PyDict_SetItem(__pyx_t_3, __pyx_v_classattr, __pyx_v_classname) < 0) __PYX_ERR(0, 7047, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7011
 * withAttribute = BaseWithAttribute()
 * 
 * def withClass(classname, namespace=''):             # <<<<<<<<<<<<<<
 *     """Simplified version of :class:`withAttribute` when
 *     matching on a div class - made difficult because ``class`` is
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.withClass", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_classattr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7053
 * opAssoc.RIGHT = object()
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):             # <<<<<<<<<<<<<<
 *     """Helper method for constructing grammars of expressions made up of
 *     operators working in a precedence hierarchy.  Operators may be unary
 */

static PyObject *__pyx_pf_10cPyparsing_107__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_lpar);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_lpar);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_lpar)) __PYX_ERR(0, 7053, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_rpar);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_rpar);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_rpar)) __PYX_ERR(0, 7053, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 7053, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 7053, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_71infixNotation(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_70infixNotation, "infixNotation(baseExpr, opList, lpar=Suppress(u'('), rpar=Suppress(u')'))\nHelper method for constructing grammars of expressions made up of\n    operators working in a precedence hierarchy.  Operators may be unary\n    or binary, left- or right-associative.  Parse actions can also be\n    attached to operator expressions. The generated parser will also\n    recognize the use of parentheses to override operator precedences\n    (see example below).\n\n    Note: if you define a deep operator list, you may see performance\n    issues when using infixNotation. See\n    :class:`ParserElement.enablePackrat` for a mechanism to potentially\n    improve your parser performance.\n\n    Parameters:\n     - baseExpr - expression representing the most basic element for the\n       nested\n     - opList - list of tuples, one for each operator precedence level\n       in the expression grammar; each tuple is of the form ``(opExpr,\n       numTerms, rightLeftAssoc, parseAction)``, where:\n\n       - opExpr is the pyparsing expression for the operator; may also\n         be a string, which will be converted to a Literal; if numTerms\n         is 3, opExpr is a tuple of two expressions, for the two\n         operators separating the 3 terms\n       - numTerms is the number of terms for this operator (must be 1,\n         2, or 3)\n       - rightLeftAssoc is the indicator whether the operator is right\n         or left associative, using the pyparsing-defined constants\n         ``opAssoc.RIGHT`` and ``opAssoc.LEFT``.\n       - parseAction is the parse action to be associated with\n         expressions matching this operator expression (the parse action\n         tuple member may be omitted); if the parse action is passed\n         a tuple or list of functions, this is equivalent to calling\n         ``setParseAction(*fn)``\n         (:class:`ParserElement.setParseAction`)\n     - lpar - expression for matching left-parentheses\n       (default= ``Suppress('(')``)\n     - rpar - expr""ession for matching right-parentheses\n       (default= ``Suppress(')')``)\n\n    Example::\n\n        # simple example of four-function arithmetic with ints and\n        # variable names\n        integer = pyparsing_common.signed_integer\n        varname = pyparsing_common.identifier\n\n        arith_expr = infixNotation(integer | varname,\n            [\n            ('-', 1, opAssoc.RIGHT),\n            (oneOf('* /'), 2, opAssoc.LEFT),\n            (oneOf('+ -'), 2, opAssoc.LEFT),\n            ])\n\n        arith_expr.runTests('''\n            5+3*6\n            (5+3)*6\n            -2--11\n            ''', fullDump=False)\n\n    prints::\n\n        5+3*6\n        [[5, '+', [3, '*', 6]]]\n\n        (5+3)*6\n        [[[5, '+', 3], '*', 6]]\n\n        -2--11\n        [[['-', 2], '-', ['-', 11]]]\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_71infixNotation = {"infixNotation", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_71infixNotation, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_70infixNotation};
static PyObject *__pyx_pw_10cPyparsing_71infixNotation(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_baseExpr = 0;
  PyObject *__pyx_v_opList = 0;
  PyObject *__pyx_v_lpar = 0;
  PyObject *__pyx_v_rpar = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("infixNotation (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_baseExpr,&__pyx_n_s_opList,&__pyx_n_s_lpar,&__pyx_n_s_rpar,0};
    __pyx_defaults9 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_lpar);
    values[3] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_rpar);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_baseExpr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7053, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_opList)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7053, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("infixNotation", 0, 2, 4, 1); __PYX_ERR(0, 7053, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lpar);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7053, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_rpar);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7053, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "infixNotation") < 0)) __PYX_ERR(0, 7053, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_baseExpr = values[0];
    __pyx_v_opList = values[1];
    __pyx_v_lpar = values[2];
    __pyx_v_rpar = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("infixNotation", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 7053, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.infixNotation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_70infixNotation(__pyx_self, __pyx_v_baseExpr, __pyx_v_opList, __pyx_v_lpar, __pyx_v_rpar);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7126
 *     # captive version of FollowedBy that does not do parse actions or capture results names
 *     class _FB(FollowedBy):
 *         def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *             self.expr.tryParse(instring, loc)
 *             return loc, []
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13infixNotation_3_FB_1parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13infixNotation_3_FB_1parseImpl = {"parseImpl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13infixNotation_3_FB_1parseImpl, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13infixNotation_3_FB_1parseImpl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7126, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instring)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7126, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 7126, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_loc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7126, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 7126, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_doActions);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7126, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "parseImpl") < 0)) __PYX_ERR(0, 7126, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 7126, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.infixNotation._FB.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13infixNotation_3_FB_parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13infixNotation_3_FB_parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parseImpl", 1);

  /* "cPyparsing.pyx":7127
 *     class _FB(FollowedBy):
 *         def parseImpl(self, instring, loc, doActions=True):
 *             self.expr.tryParse(instring, loc)             # <<<<<<<<<<<<<<
 *             return loc, []
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_instring, __pyx_v_loc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7128
 *         def parseImpl(self, instring, loc, doActions=True):
 *             self.expr.tryParse(instring, loc)
 *             return loc, []             # <<<<<<<<<<<<<<
 * 
 *     ret = Forward()
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_loc)) __PYX_ERR(0, 7128, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(0, 7128, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7126
 *     # captive version of FollowedBy that does not do parse actions or capture results names
 *     class _FB(FollowedBy):
 *         def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *             self.expr.tryParse(instring, loc)
 *             return loc, []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.infixNotation._FB.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7053
 * opAssoc.RIGHT = object()
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):             # <<<<<<<<<<<<<<
 *     """Helper method for constructing grammars of expressions made up of
 *     operators working in a precedence hierarchy.  Operators may be unary
 */

static PyObject *__pyx_pf_10cPyparsing_70infixNotation(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_baseExpr, PyObject *__pyx_v_opList, PyObject *__pyx_v_lpar, PyObject *__pyx_v_rpar) {
  PyObject *__pyx_v__FB = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_lastExpr = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_operDef = NULL;
  PyObject *__pyx_v_opExpr = NULL;
  PyObject *__pyx_v_arity = NULL;
  PyObject *__pyx_v_rightLeftAssoc = NULL;
  PyObject *__pyx_v_pa = NULL;
  PyObject *__pyx_v_termName = NULL;
  PyObject *__pyx_v_opExpr1 = NULL;
  PyObject *__pyx_v_opExpr2 = NULL;
  PyObject *__pyx_v_thisExpr = NULL;
  PyObject *__pyx_v_matchExpr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  int __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("infixNotation", 1);

  /* "cPyparsing.pyx":7125
 *     """
 *     # captive version of FollowedBy that does not do parse actions or capture results names
 *     class _FB(FollowedBy):             # <<<<<<<<<<<<<<
 *         def parseImpl(self, instring, loc, doActions=True):
 *             self.expr.tryParse(instring, loc)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 7125, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_1, __pyx_n_s_FB, __pyx_n_s_infixNotation_locals__FB, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__pyx_t_1 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_4, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 7125, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7126
 *     # captive version of FollowedBy that does not do parse actions or capture results names
 *     class _FB(FollowedBy):
 *         def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *             self.expr.tryParse(instring, loc)
 *             return loc, []
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13infixNotation_3_FB_1parseImpl, 0, __pyx_n_s_infixNotation_locals__FB_parseIm, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__154)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 7126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7125
 *     """
 *     # captive version of FollowedBy that does not do parse actions or capture results names
 *     class _FB(FollowedBy):             # <<<<<<<<<<<<<<
 *         def parseImpl(self, instring, loc, doActions=True):
 *             self.expr.tryParse(instring, loc)
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_FB, __pyx_t_1, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v__FB = __pyx_t_2;
  __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7130
 *             return loc, []
 * 
 *     ret = Forward()             # <<<<<<<<<<<<<<
 *     lastExpr = baseExpr | (lpar + ret + rpar)
 *     for i, operDef in enumerate(opList):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Forward); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7131
 * 
 *     ret = Forward()
 *     lastExpr = baseExpr | (lpar + ret + rpar)             # <<<<<<<<<<<<<<
 *     for i, operDef in enumerate(opList):
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None, ))[:4]
 */
  __pyx_t_1 = PyNumber_Add(__pyx_v_lpar, __pyx_v_ret); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_rpar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Or(__pyx_v_baseExpr, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_lastExpr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7132
 *     ret = Forward()
 *     lastExpr = baseExpr | (lpar + ret + rpar)
 *     for i, operDef in enumerate(opList):             # <<<<<<<<<<<<<<
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None, ))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_1 = __pyx_int_0;
  if (likely(PyList_CheckExact(__pyx_v_opList)) || PyTuple_CheckExact(__pyx_v_opList)) {
    __pyx_t_3 = __pyx_v_opList; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_opList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7132, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7132, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 7132, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7132, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7132, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 7132, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7132, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_7(__pyx_t_3);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 7132, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_operDef, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":7133
 *     lastExpr = baseExpr | (lpar + ret + rpar)
 *     for i, operDef in enumerate(opList):
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None, ))[:4]             # <<<<<<<<<<<<<<
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:
 */
    __pyx_t_4 = PyNumber_Add(__pyx_v_operDef, __pyx_tuple__57); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 4, NULL, NULL, &__pyx_slice__81, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 4)) {
        if (size > 4) __Pyx_RaiseTooManyValuesError(4);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 7133, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 2); 
        __pyx_t_10 = PyTuple_GET_ITEM(sequence, 3); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_9 = PyList_GET_ITEM(sequence, 2); 
        __pyx_t_10 = PyList_GET_ITEM(sequence, 3); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_10);
      #else
      {
        Py_ssize_t i;
        PyObject** temps[4] = {&__pyx_t_4,&__pyx_t_8,&__pyx_t_9,&__pyx_t_10};
        for (i=0; i < 4; i++) {
          PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 7133, __pyx_L1_error)
          __Pyx_GOTREF(item);
          *(temps[i]) = item;
        }
      }
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      PyObject** temps[4] = {&__pyx_t_4,&__pyx_t_8,&__pyx_t_9,&__pyx_t_10};
      __pyx_t_11 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_11);
      for (index=0; index < 4; index++) {
        PyObject* item = __pyx_t_12(__pyx_t_11); if (unlikely(!item)) goto __pyx_L5_unpacking_failed;
        __Pyx_GOTREF(item);
        *(temps[index]) = item;
      }
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_11), 4) < 0) __PYX_ERR(0, 7133, __pyx_L1_error)
      __pyx_t_12 = NULL;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 7133, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_opExpr, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_arity, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_XDECREF_SET(__pyx_v_rightLeftAssoc, __pyx_t_9);
    __pyx_t_9 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pa, __pyx_t_10);
    __pyx_t_10 = 0;

    /* "cPyparsing.pyx":7134
 *     for i, operDef in enumerate(opList):
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None, ))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr             # <<<<<<<<<<<<<<
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:
 */
    __pyx_t_10 = PyObject_RichCompare(__pyx_v_arity, __pyx_int_3, Py_LT); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7134, __pyx_L1_error)
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 7134, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__pyx_t_13) {
      __pyx_t_10 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_term, __pyx_v_opExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7134, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_2 = __pyx_t_10;
      __pyx_t_10 = 0;
    } else {
      __pyx_t_10 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_s_term, __pyx_v_opExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7134, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_2 = __pyx_t_10;
      __pyx_t_10 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_termName, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":7135
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None, ))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:             # <<<<<<<<<<<<<<
 *             if opExpr is None or len(opExpr) != 2:
 *                 raise ValueError(
 */
    __pyx_t_13 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_arity, __pyx_int_3, 3, 0)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 7135, __pyx_L1_error)
    if (__pyx_t_13) {

      /* "cPyparsing.pyx":7136
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     "if numterms=3, opExpr must be a tuple or list of two expressions")
 */
      __pyx_t_14 = (__pyx_v_opExpr == Py_None);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_13 = __pyx_t_14;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_15 = PyObject_Length(__pyx_v_opExpr); if (unlikely(__pyx_t_15 == ((Py_ssize_t)-1))) __PYX_ERR(0, 7136, __pyx_L1_error)
      __pyx_t_14 = (__pyx_t_15 != 2);
      __pyx_t_13 = __pyx_t_14;
      __pyx_L9_bool_binop_done:;
      if (unlikely(__pyx_t_13)) {

        /* "cPyparsing.pyx":7137
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     "if numterms=3, opExpr must be a tuple or list of two expressions")
 *             opExpr1, opExpr2 = opExpr
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__156, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7137, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(0, 7137, __pyx_L1_error)

        /* "cPyparsing.pyx":7136
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     "if numterms=3, opExpr must be a tuple or list of two expressions")
 */
      }

      /* "cPyparsing.pyx":7139
 *                 raise ValueError(
 *                     "if numterms=3, opExpr must be a tuple or list of two expressions")
 *             opExpr1, opExpr2 = opExpr             # <<<<<<<<<<<<<<
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_opExpr))) || (PyList_CheckExact(__pyx_v_opExpr))) {
        PyObject* sequence = __pyx_v_opExpr;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 7139, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_10 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_10);
        #else
        __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7139, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_10 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7139, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_v_opExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7139, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
        index = 0; __pyx_t_2 = __pyx_t_12(__pyx_t_9); if (unlikely(!__pyx_t_2)) goto __pyx_L11_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_10 = __pyx_t_12(__pyx_t_9); if (unlikely(!__pyx_t_10)) goto __pyx_L11_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_10);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_9), 2) < 0) __PYX_ERR(0, 7139, __pyx_L1_error)
        __pyx_t_12 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L12_unpacking_done;
        __pyx_L11_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_12 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 7139, __pyx_L1_error)
        __pyx_L12_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_opExpr1, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_opExpr2, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "cPyparsing.pyx":7135
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None, ))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:             # <<<<<<<<<<<<<<
 *             if opExpr is None or len(opExpr) != 2:
 *                 raise ValueError(
 */
    }

    /* "cPyparsing.pyx":7140
 *                     "if numterms=3, opExpr must be a tuple or list of two expressions")
 *             opExpr1, opExpr2 = opExpr
 *         thisExpr = Forward().setName(termName)             # <<<<<<<<<<<<<<
 *         if rightLeftAssoc == opAssoc.LEFT:
 *             if arity == 1:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Forward); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_termName};
      __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_thisExpr, __pyx_t_10);
    __pyx_t_10 = 0;

    /* "cPyparsing.pyx":7141
 *             opExpr1, opExpr2 = opExpr
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:             # <<<<<<<<<<<<<<
 *             if arity == 1:
 *                 matchExpr = _FB(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_opAssoc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_LEFT); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyObject_RichCompare(__pyx_v_rightLeftAssoc, __pyx_t_9, Py_EQ); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 7141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__pyx_t_13) {

      /* "cPyparsing.pyx":7142
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:
 *             if arity == 1:             # <<<<<<<<<<<<<<
 *                 matchExpr = _FB(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:
 */
      __pyx_t_13 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_arity, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 7142, __pyx_L1_error)
      if (__pyx_t_13) {

        /* "cPyparsing.pyx":7143
 *         if rightLeftAssoc == opAssoc.LEFT:
 *             if arity == 1:
 *                 matchExpr = _FB(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))             # <<<<<<<<<<<<<<
 *             elif arity == 2:
 *                 if opExpr is not None:
 */
        __pyx_t_10 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7143, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_v__FB, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7143, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Group); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7143, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7143, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_11 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_opExpr};
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7143, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_t_4 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7143, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_4};
          __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7143, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __pyx_t_2 = PyNumber_Add(__pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7143, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "cPyparsing.pyx":7142
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:
 *             if arity == 1:             # <<<<<<<<<<<<<<
 *                 matchExpr = _FB(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:
 */
        goto __pyx_L14;
      }

      /* "cPyparsing.pyx":7144
 *             if arity == 1:
 *                 matchExpr = _FB(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:             # <<<<<<<<<<<<<<
 *                 if opExpr is not None:
 *                     matchExpr = _FB(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 */
      __pyx_t_13 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_arity, __pyx_int_2, 2, 0)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 7144, __pyx_L1_error)
      if (__pyx_t_13) {

        /* "cPyparsing.pyx":7145
 *                 matchExpr = _FB(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:
 *                 if opExpr is not None:             # <<<<<<<<<<<<<<
 *                     matchExpr = _FB(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 *                 else:
 */
        __pyx_t_13 = (__pyx_v_opExpr != Py_None);
        if (__pyx_t_13) {

          /* "cPyparsing.pyx":7146
 *             elif arity == 2:
 *                 if opExpr is not None:
 *                     matchExpr = _FB(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))             # <<<<<<<<<<<<<<
 *                 else:
 *                     matchExpr = _FB(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))
 */
          __pyx_t_2 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7146, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_10 = PyNumber_Add(__pyx_t_2, __pyx_v_lastExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7146, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_v__FB, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7146, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7146, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7146, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_11 = PyNumber_Add(__pyx_v_opExpr, __pyx_v_lastExpr); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7146, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_16 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_16)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_t_11};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7146, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_t_8 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7146, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_8};
            __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7146, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
          __pyx_t_9 = PyNumber_Add(__pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7146, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_9);
          __pyx_t_9 = 0;

          /* "cPyparsing.pyx":7145
 *                 matchExpr = _FB(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:
 *                 if opExpr is not None:             # <<<<<<<<<<<<<<
 *                     matchExpr = _FB(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 *                 else:
 */
          goto __pyx_L15;
        }

        /* "cPyparsing.pyx":7148
 *                     matchExpr = _FB(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 *                 else:
 *                     matchExpr = _FB(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))             # <<<<<<<<<<<<<<
 *             elif arity == 3:
 *                 matchExpr = (_FB(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 */
        /*else*/ {
          __pyx_t_9 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_lastExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7148, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_v__FB, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7148, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Group); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7148, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7148, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_lastExpr};
            __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7148, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_4 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7148, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_4};
            __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7148, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          __pyx_t_2 = PyNumber_Add(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7148, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_2);
          __pyx_t_2 = 0;
        }
        __pyx_L15:;

        /* "cPyparsing.pyx":7144
 *             if arity == 1:
 *                 matchExpr = _FB(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:             # <<<<<<<<<<<<<<
 *                 if opExpr is not None:
 *                     matchExpr = _FB(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 */
        goto __pyx_L14;
      }

      /* "cPyparsing.pyx":7149
 *                 else:
 *                     matchExpr = _FB(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))
 *             elif arity == 3:             # <<<<<<<<<<<<<<
 *                 matchExpr = (_FB(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 *                              + Group(lastExpr + OneOrMore(opExpr1 + lastExpr + opExpr2 + lastExpr)))
 */
      __pyx_t_13 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_arity, __pyx_int_3, 3, 0)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 7149, __pyx_L1_error)
      if (likely(__pyx_t_13)) {

        /* "cPyparsing.pyx":7150
 *                     matchExpr = _FB(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))
 *             elif arity == 3:
 *                 matchExpr = (_FB(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)             # <<<<<<<<<<<<<<
 *                              + Group(lastExpr + OneOrMore(opExpr1 + lastExpr + opExpr2 + lastExpr)))
 *             else:
 */
        if (unlikely(!__pyx_v_opExpr1)) { __Pyx_RaiseUnboundLocalError("opExpr1"); __PYX_ERR(0, 7150, __pyx_L1_error) }
        __pyx_t_2 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7150, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = PyNumber_Add(__pyx_t_2, __pyx_v_lastExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7150, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_v_opExpr2)) { __Pyx_RaiseUnboundLocalError("opExpr2"); __PYX_ERR(0, 7150, __pyx_L1_error) }
        __pyx_t_2 = PyNumber_Add(__pyx_t_9, __pyx_v_opExpr2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7150, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = PyNumber_Add(__pyx_t_2, __pyx_v_lastExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7150, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_v__FB, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7150, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "cPyparsing.pyx":7151
 *             elif arity == 3:
 *                 matchExpr = (_FB(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 *                              + Group(lastExpr + OneOrMore(opExpr1 + lastExpr + opExpr2 + lastExpr)))             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 */
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_Group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(!__pyx_v_opExpr1)) { __Pyx_RaiseUnboundLocalError("opExpr1"); __PYX_ERR(0, 7151, __pyx_L1_error) }
        __pyx_t_11 = PyNumber_Add(__pyx_v_opExpr1, __pyx_v_lastExpr); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (unlikely(!__pyx_v_opExpr2)) { __Pyx_RaiseUnboundLocalError("opExpr2"); __PYX_ERR(0, 7151, __pyx_L1_error) }
        __pyx_t_16 = PyNumber_Add(__pyx_t_11, __pyx_v_opExpr2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 7151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = PyNumber_Add(__pyx_t_16, __pyx_v_lastExpr); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __pyx_t_16 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_16)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_16);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_t_11};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7151, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_t_8 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_8};
          __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7151, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __pyx_t_10 = PyNumber_Add(__pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "cPyparsing.pyx":7149
 *                 else:
 *                     matchExpr = _FB(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))
 *             elif arity == 3:             # <<<<<<<<<<<<<<
 *                 matchExpr = (_FB(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 *                              + Group(lastExpr + OneOrMore(opExpr1 + lastExpr + opExpr2 + lastExpr)))
 */
        goto __pyx_L14;
      }

      /* "cPyparsing.pyx":7153
 *                              + Group(lastExpr + OneOrMore(opExpr1 + lastExpr + opExpr2 + lastExpr)))
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")             # <<<<<<<<<<<<<<
 *         elif rightLeftAssoc == opAssoc.RIGHT:
 *             if arity == 1:
 */
      /*else*/ {
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__157, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7153, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_Raise(__pyx_t_10, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __PYX_ERR(0, 7153, __pyx_L1_error)
      }
      __pyx_L14:;

      /* "cPyparsing.pyx":7141
 *             opExpr1, opExpr2 = opExpr
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:             # <<<<<<<<<<<<<<
 *             if arity == 1:
 *                 matchExpr = _FB(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 */
      goto __pyx_L13;
    }

    /* "cPyparsing.pyx":7154
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         elif rightLeftAssoc == opAssoc.RIGHT:             # <<<<<<<<<<<<<<
 *             if arity == 1:
 *                 # try to avoid LR with this extra test
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_opAssoc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_RIGHT); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyObject_RichCompare(__pyx_v_rightLeftAssoc, __pyx_t_9, Py_EQ); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7154, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 7154, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (likely(__pyx_t_13)) {

      /* "cPyparsing.pyx":7155
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         elif rightLeftAssoc == opAssoc.RIGHT:
 *             if arity == 1:             # <<<<<<<<<<<<<<
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):
 */
      __pyx_t_13 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_arity, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 7155, __pyx_L1_error)
      if (__pyx_t_13) {

        /* "cPyparsing.pyx":7157
 *             if arity == 1:
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):             # <<<<<<<<<<<<<<
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = _FB(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 */
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_Optional); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7157, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_13 = PyObject_IsInstance(__pyx_v_opExpr, __pyx_t_10); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 7157, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_14 = (!__pyx_t_13);
        if (__pyx_t_14) {

          /* "cPyparsing.pyx":7158
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):
 *                     opExpr = Optional(opExpr)             # <<<<<<<<<<<<<<
 *                 matchExpr = _FB(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Optional); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7158, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_2 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_opExpr};
            __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7158, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_opExpr, __pyx_t_10);
          __pyx_t_10 = 0;

          /* "cPyparsing.pyx":7157
 *             if arity == 1:
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):             # <<<<<<<<<<<<<<
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = _FB(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 */
        }

        /* "cPyparsing.pyx":7159
 *                 if not isinstance(opExpr, Optional):
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = _FB(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)             # <<<<<<<<<<<<<<
 *             elif arity == 2:
 *                 if opExpr is not None:
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_opExpr, __pyx_n_s_expr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = PyNumber_Add(__pyx_t_10, __pyx_v_thisExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_v__FB, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Group); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = PyNumber_Add(__pyx_v_opExpr, __pyx_v_thisExpr); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_8};
          __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7159, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __pyx_t_2 = PyNumber_Add(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "cPyparsing.pyx":7155
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         elif rightLeftAssoc == opAssoc.RIGHT:
 *             if arity == 1:             # <<<<<<<<<<<<<<
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):
 */
        goto __pyx_L16;
      }

      /* "cPyparsing.pyx":7160
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = _FB(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:             # <<<<<<<<<<<<<<
 *                 if opExpr is not None:
 *                     matchExpr = _FB(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 */
      __pyx_t_14 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_arity, __pyx_int_2, 2, 0)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 7160, __pyx_L1_error)
      if (__pyx_t_14) {

        /* "cPyparsing.pyx":7161
 *                 matchExpr = _FB(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:
 *                 if opExpr is not None:             # <<<<<<<<<<<<<<
 *                     matchExpr = _FB(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 *                 else:
 */
        __pyx_t_14 = (__pyx_v_opExpr != Py_None);
        if (__pyx_t_14) {

          /* "cPyparsing.pyx":7162
 *             elif arity == 2:
 *                 if opExpr is not None:
 *                     matchExpr = _FB(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))             # <<<<<<<<<<<<<<
 *                 else:
 *                     matchExpr = _FB(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))
 */
          __pyx_t_2 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7162, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_9 = PyNumber_Add(__pyx_t_2, __pyx_v_thisExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7162, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_v__FB, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7162, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_Group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7162, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7162, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = PyNumber_Add(__pyx_v_opExpr, __pyx_v_thisExpr); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7162, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_16 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_16)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_t_11};
            __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7162, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_4 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7162, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_4};
            __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7162, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
          __pyx_t_10 = PyNumber_Add(__pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7162, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_10);
          __pyx_t_10 = 0;

          /* "cPyparsing.pyx":7161
 *                 matchExpr = _FB(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:
 *                 if opExpr is not None:             # <<<<<<<<<<<<<<
 *                     matchExpr = _FB(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 *                 else:
 */
          goto __pyx_L18;
        }

        /* "cPyparsing.pyx":7164
 *                     matchExpr = _FB(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 *                 else:
 *                     matchExpr = _FB(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))             # <<<<<<<<<<<<<<
 *             elif arity == 3:
 *                 matchExpr = (_FB(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 */
        /*else*/ {
          __pyx_t_10 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_thisExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7164, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_v__FB, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7164, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Group); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7164, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7164, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_11 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_thisExpr};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7164, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_t_8 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7164, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_8};
            __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7164, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          __pyx_t_2 = PyNumber_Add(__pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7164, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_2);
          __pyx_t_2 = 0;
        }
        __pyx_L18:;

        /* "cPyparsing.pyx":7160
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = _FB(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:             # <<<<<<<<<<<<<<
 *                 if opExpr is not None:
 *                     matchExpr = _FB(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 */
        goto __pyx_L16;
      }

      /* "cPyparsing.pyx":7165
 *                 else:
 *                     matchExpr = _FB(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))
 *             elif arity == 3:             # <<<<<<<<<<<<<<
 *                 matchExpr = (_FB(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 *                              + Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr))
 */
      __pyx_t_14 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_arity, __pyx_int_3, 3, 0)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 7165, __pyx_L1_error)
      if (likely(__pyx_t_14)) {

        /* "cPyparsing.pyx":7166
 *                     matchExpr = _FB(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))
 *             elif arity == 3:
 *                 matchExpr = (_FB(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)             # <<<<<<<<<<<<<<
 *                              + Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr))
 *             else:
 */
        if (unlikely(!__pyx_v_opExpr1)) { __Pyx_RaiseUnboundLocalError("opExpr1"); __PYX_ERR(0, 7166, __pyx_L1_error) }
        __pyx_t_2 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7166, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_10 = PyNumber_Add(__pyx_t_2, __pyx_v_thisExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7166, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_v_opExpr2)) { __Pyx_RaiseUnboundLocalError("opExpr2"); __PYX_ERR(0, 7166, __pyx_L1_error) }
        __pyx_t_2 = PyNumber_Add(__pyx_t_10, __pyx_v_opExpr2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7166, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = PyNumber_Add(__pyx_t_2, __pyx_v_thisExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7166, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_v__FB, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7166, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "cPyparsing.pyx":7167
 *             elif arity == 3:
 *                 matchExpr = (_FB(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 *                              + Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr))             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 */
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (unlikely(!__pyx_v_opExpr1)) { __Pyx_RaiseUnboundLocalError("opExpr1"); __PYX_ERR(0, 7167, __pyx_L1_error) }
        __pyx_t_8 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_4 = PyNumber_Add(__pyx_t_8, __pyx_v_thisExpr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_v_opExpr2)) { __Pyx_RaiseUnboundLocalError("opExpr2"); __PYX_ERR(0, 7167, __pyx_L1_error) }
        __pyx_t_8 = PyNumber_Add(__pyx_t_4, __pyx_v_opExpr2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_t_8, __pyx_v_thisExpr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_4};
          __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7167, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_t_9 = PyNumber_Add(__pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "cPyparsing.pyx":7165
 *                 else:
 *                     matchExpr = _FB(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))
 *             elif arity == 3:             # <<<<<<<<<<<<<<
 *                 matchExpr = (_FB(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 *                              + Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr))
 */
        goto __pyx_L16;
      }

      /* "cPyparsing.pyx":7169
 *                              + Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr))
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")
 */
      /*else*/ {
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__157, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7169, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_Raise(__pyx_t_9, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __PYX_ERR(0, 7169, __pyx_L1_error)
      }
      __pyx_L16:;

      /* "cPyparsing.pyx":7154
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         elif rightLeftAssoc == opAssoc.RIGHT:             # <<<<<<<<<<<<<<
 *             if arity == 1:
 *                 # try to avoid LR with this extra test
 */
      goto __pyx_L13;
    }

    /* "cPyparsing.pyx":7171
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")             # <<<<<<<<<<<<<<
 *         if pa:
 *             if isinstance(pa, (tuple, list)):
 */
    /*else*/ {
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__158, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7171, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_Raise(__pyx_t_9, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __PYX_ERR(0, 7171, __pyx_L1_error)
    }
    __pyx_L13:;

    /* "cPyparsing.pyx":7172
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")
 *         if pa:             # <<<<<<<<<<<<<<
 *             if isinstance(pa, (tuple, list)):
 *                 matchExpr.setParseAction(*pa)
 */
    __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_pa); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 7172, __pyx_L1_error)
    if (__pyx_t_14) {

      /* "cPyparsing.pyx":7173
 *             raise ValueError("operator must indicate right or left associativity")
 *         if pa:
 *             if isinstance(pa, (tuple, list)):             # <<<<<<<<<<<<<<
 *                 matchExpr.setParseAction(*pa)
 *             else:
 */
      __pyx_t_13 = PyTuple_Check(__pyx_v_pa); 
      if (!__pyx_t_13) {
      } else {
        __pyx_t_14 = __pyx_t_13;
        goto __pyx_L21_bool_binop_done;
      }
      __pyx_t_13 = PyList_Check(__pyx_v_pa); 
      __pyx_t_14 = __pyx_t_13;
      __pyx_L21_bool_binop_done:;
      if (__pyx_t_14) {

        /* "cPyparsing.pyx":7174
 *         if pa:
 *             if isinstance(pa, (tuple, list)):
 *                 matchExpr.setParseAction(*pa)             # <<<<<<<<<<<<<<
 *             else:
 *                 matchExpr.setParseAction(pa)
 */
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchExpr, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7174, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = __Pyx_PySequence_Tuple(__pyx_v_pa); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7174, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7174, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":7173
 *             raise ValueError("operator must indicate right or left associativity")
 *         if pa:
 *             if isinstance(pa, (tuple, list)):             # <<<<<<<<<<<<<<
 *                 matchExpr.setParseAction(*pa)
 *             else:
 */
        goto __pyx_L20;
      }

      /* "cPyparsing.pyx":7176
 *                 matchExpr.setParseAction(*pa)
 *             else:
 *                 matchExpr.setParseAction(pa)             # <<<<<<<<<<<<<<
 *         thisExpr <<= (matchExpr.setName(termName) | lastExpr)
 *         lastExpr = thisExpr
 */
      /*else*/ {
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchExpr, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7176, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_pa};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_L20:;

      /* "cPyparsing.pyx":7172
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")
 *         if pa:             # <<<<<<<<<<<<<<
 *             if isinstance(pa, (tuple, list)):
 *                 matchExpr.setParseAction(*pa)
 */
    }

    /* "cPyparsing.pyx":7177
 *             else:
 *                 matchExpr.setParseAction(pa)
 *         thisExpr <<= (matchExpr.setName(termName) | lastExpr)             # <<<<<<<<<<<<<<
 *         lastExpr = thisExpr
 *     ret <<= lastExpr
 */
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchExpr, __pyx_n_s_setName); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_9 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_termName};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7177, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __pyx_t_10 = PyNumber_Or(__pyx_t_2, __pyx_v_lastExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_InPlaceLshift(__pyx_v_thisExpr, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF_SET(__pyx_v_thisExpr, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":7178
 *                 matchExpr.setParseAction(pa)
 *         thisExpr <<= (matchExpr.setName(termName) | lastExpr)
 *         lastExpr = thisExpr             # <<<<<<<<<<<<<<
 *     ret <<= lastExpr
 *     return ret
 */
    __Pyx_INCREF(__pyx_v_thisExpr);
    __Pyx_DECREF_SET(__pyx_v_lastExpr, __pyx_v_thisExpr);

    /* "cPyparsing.pyx":7132
 *     ret = Forward()
 *     lastExpr = baseExpr | (lpar + ret + rpar)
 *     for i, operDef in enumerate(opList):             # <<<<<<<<<<<<<<
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None, ))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7179
 *         thisExpr <<= (matchExpr.setName(termName) | lastExpr)
 *         lastExpr = thisExpr
 *     ret <<= lastExpr             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
  __pyx_t_1 = PyNumber_InPlaceLshift(__pyx_v_ret, __pyx_v_lastExpr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7180
 *         lastExpr = thisExpr
 *     ret <<= lastExpr
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * operatorPrecedence = infixNotation
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7053
 * opAssoc.RIGHT = object()
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):             # <<<<<<<<<<<<<<
 *     """Helper method for constructing grammars of expressions made up of
 *     operators working in a precedence hierarchy.  Operators may be unary
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("cPyparsing.infixNotation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__FB);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_lastExpr);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_operDef);
  __Pyx_XDECREF(__pyx_v_opExpr);
  __Pyx_XDECREF(__pyx_v_arity);
  __Pyx_XDECREF(__pyx_v_rightLeftAssoc);
  __Pyx_XDECREF(__pyx_v_pa);
  __Pyx_XDECREF(__pyx_v_termName);
  __Pyx_XDECREF(__pyx_v_opExpr1);
  __Pyx_XDECREF(__pyx_v_opExpr2);
  __Pyx_XDECREF(__pyx_v_thisExpr);
  __Pyx_XDECREF(__pyx_v_matchExpr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7192
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """Helper method for defining nested lists enclosed in opening and
 *     closing delimiters ("(" and ")" are the default).
 */

static PyObject *__pyx_pf_10cPyparsing_109__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject*)__pyx_kp_u__22));
  __Pyx_GIVEREF(((PyObject*)__pyx_kp_u__22));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject*)__pyx_kp_u__22))) __PYX_ERR(0, 7192, __pyx_L1_error);
  __Pyx_INCREF(((PyObject*)__pyx_kp_u__13));
  __Pyx_GIVEREF(((PyObject*)__pyx_kp_u__13));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject*)__pyx_kp_u__13))) __PYX_ERR(0, 7192, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None)) __PYX_ERR(0, 7192, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_ignoreExpr);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_ignoreExpr);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_ignoreExpr)) __PYX_ERR(0, 7192, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 7192, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 7192, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_73nestedExpr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_72nestedExpr, "nestedExpr(opener=u'(', closer=u')', content=None, ignoreExpr=quotedString.copy())\nHelper method for defining nested lists enclosed in opening and\n    closing delimiters (\"(\" and \")\" are the default).\n\n    Parameters:\n     - opener - opening character for a nested list\n       (default= ``\"(\"``); can also be a pyparsing expression\n     - closer - closing character for a nested list\n       (default= ``\")\"``); can also be a pyparsing expression\n     - content - expression for items within the nested lists\n       (default= ``None``)\n     - ignoreExpr - expression for ignoring opening and closing\n       delimiters (default= :class:`quotedString`)\n\n    If an expression is not provided for the content argument, the\n    nested expression will capture all whitespace-delimited content\n    between delimiters as a list of separate values.\n\n    Use the ``ignoreExpr`` argument to define expressions that may\n    contain opening or closing characters that should not be treated as\n    opening or closing characters for nesting, such as quotedString or\n    a comment expression.  Specify multiple expressions using an\n    :class:`Or` or :class:`MatchFirst`. The default is\n    :class:`quotedString`, but if no expressions are to be ignored, then\n    pass ``None`` for this argument.\n\n    Example::\n\n        data_type = oneOf(\"void int short long char float double\")\n        decl_data_type = Combine(data_type + Optional(Word('*')))\n        ident = Word(alphas+'_', alphanums+'_')\n        number = pyparsing_common.number\n        arg = Group(decl_data_type + ident)\n        LPAR, RPAR = map(Suppress, \"()\")\n\n        code_body = nestedExpr('{', '}', ignoreExpr=(quotedString | cStyleComment))\n\n        c_function = (decl_data_type(\"type\")\n                      + ident(\"name\")\n                      + LPAR + Optional(delimitedList(arg), [])(\"args\") + RPAR\n                      + code_body(\"body\"))\n        c_function.ignore(cStyleComment)\n""\n        source_code = '''\n            int is_odd(int x) {\n                return (x%2);\n            }\n\n            int dec_to_hex(char hchar) {\n                if (hchar >= '0' && hchar <= '9') {\n                    return (ord(hchar)-ord('0'));\n                } else {\n                    return (10+ord(hchar)-ord('A'));\n                }\n            }\n        '''\n        for func in c_function.searchString(source_code):\n            print(\"%(name)s (%(type)s) args: %(args)s\" % func)\n\n\n    prints::\n\n        is_odd (int) args: [['int', 'x']]\n        dec_to_hex (int) args: [['char', 'hchar']]\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_73nestedExpr = {"nestedExpr", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_73nestedExpr, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_72nestedExpr};
static PyObject *__pyx_pw_10cPyparsing_73nestedExpr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_opener = 0;
  PyObject *__pyx_v_closer = 0;
  PyObject *__pyx_v_content = 0;
  PyObject *__pyx_v_ignoreExpr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nestedExpr (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_opener,&__pyx_n_s_closer,&__pyx_n_s_content,&__pyx_n_s_ignoreExpr,0};
    __pyx_defaults10 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self);
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__22)));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__13)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_ignoreExpr);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_opener);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7192, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_closer);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7192, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_content);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7192, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignoreExpr);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7192, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nestedExpr") < 0)) __PYX_ERR(0, 7192, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_opener = values[0];
    __pyx_v_closer = values[1];
    __pyx_v_content = values[2];
    __pyx_v_ignoreExpr = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nestedExpr", 0, 0, 4, __pyx_nargs); __PYX_ERR(0, 7192, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.nestedExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_72nestedExpr(__pyx_self, __pyx_v_opener, __pyx_v_closer, __pyx_v_content, __pyx_v_ignoreExpr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7268
 *                                                               + ParserElement.DEFAULT_WHITE_CHARS, exact=1)
 *                                                  )
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_lambda66(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10nestedExpr_lambda66 = {"lambda66", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10nestedExpr_lambda66, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_lambda66(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda66 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7268, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda66") < 0)) __PYX_ERR(0, 7268, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda66", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7268, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda66", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda66(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda66(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda66", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda66", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7273
 *                                                          + closer
 *                                                          + ParserElement.DEFAULT_WHITE_CHARS
 *                                                          ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *             else:
 *                 if ignoreExpr is not None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_1lambda67(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10nestedExpr_1lambda67 = {"lambda67", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10nestedExpr_1lambda67, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_1lambda67(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda67 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7273, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda67") < 0)) __PYX_ERR(0, 7273, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda67", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7273, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda67", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda67(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda67(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda67", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda67", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7280
 *                                                  + ~Literal(closer)
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *                 else:
 *                     content = (Combine(OneOrMore(~Literal(opener)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_2lambda68(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10nestedExpr_2lambda68 = {"lambda68", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10nestedExpr_2lambda68, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_2lambda68(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda68 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7280, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda68") < 0)) __PYX_ERR(0, 7280, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda68", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7280, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda68", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda68(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda68(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda68", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda68", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7285
 *                                                  + ~Literal(closer)
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_3lambda69(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10nestedExpr_3lambda69 = {"lambda69", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_10nestedExpr_3lambda69, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_3lambda69(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda69 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7285, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda69") < 0)) __PYX_ERR(0, 7285, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda69", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7285, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda69", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda69(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda69(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda69", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda69", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7192
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """Helper method for defining nested lists enclosed in opening and
 *     closing delimiters ("(" and ")" are the default).
 */

static PyObject *__pyx_pf_10cPyparsing_72nestedExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_opener, PyObject *__pyx_v_closer, PyObject *__pyx_v_content, PyObject *__pyx_v_ignoreExpr) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  Py_UCS4 __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nestedExpr", 0);
  __Pyx_INCREF(__pyx_v_content);

  /* "cPyparsing.pyx":7257
 *         dec_to_hex (int) args: [['char', 'hchar']]
 *     """
 *     if opener == closer:             # <<<<<<<<<<<<<<
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_opener, __pyx_v_closer, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7257, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 7257, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_2)) {

    /* "cPyparsing.pyx":7258
 *     """
 *     if opener == closer:
 *         raise ValueError("opening and closing strings cannot be the same")             # <<<<<<<<<<<<<<
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__159, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 7258, __pyx_L1_error)

    /* "cPyparsing.pyx":7257
 *         dec_to_hex (int) args: [['char', 'hchar']]
 *     """
 *     if opener == closer:             # <<<<<<<<<<<<<<
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:
 */
  }

  /* "cPyparsing.pyx":7259
 *     if opener == closer:
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:             # <<<<<<<<<<<<<<
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:
 */
  __pyx_t_2 = (__pyx_v_content == Py_None);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":7260
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):             # <<<<<<<<<<<<<<
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_IsInstance(__pyx_v_opener, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 7260, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_IsInstance(__pyx_v_closer, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 7260, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L6_bool_binop_done:;
    if (likely(__pyx_t_2)) {

      /* "cPyparsing.pyx":7261
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:             # <<<<<<<<<<<<<<
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr
 */
      __pyx_t_4 = PyObject_Length(__pyx_v_opener); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 7261, __pyx_L1_error)
      __pyx_t_3 = (__pyx_t_4 == 1);
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_4 = PyObject_Length(__pyx_v_closer); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 7261, __pyx_L1_error)
      __pyx_t_3 = (__pyx_t_4 == 1);
      __pyx_t_2 = __pyx_t_3;
      __pyx_L9_bool_binop_done:;
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":7262
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + CharsNotIn(opener
 */
        __pyx_t_2 = (__pyx_v_ignoreExpr != Py_None);
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":7263
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr             # <<<<<<<<<<<<<<
 *                                                  + CharsNotIn(opener
 *                                                               + closer
 */
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_Combine); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7263, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7263, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_9 = PyNumber_Invert(__pyx_v_ignoreExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7263, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);

          /* "cPyparsing.pyx":7264
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + CharsNotIn(opener             # <<<<<<<<<<<<<<
 *                                                               + closer
 *                                                               + ParserElement.DEFAULT_WHITE_CHARS, exact=1)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7264, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);

          /* "cPyparsing.pyx":7265
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + CharsNotIn(opener
 *                                                               + closer             # <<<<<<<<<<<<<<
 *                                                               + ParserElement.DEFAULT_WHITE_CHARS, exact=1)
 *                                                  )
 */
          __pyx_t_11 = PyNumber_Add(__pyx_v_opener, __pyx_v_closer); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7265, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);

          /* "cPyparsing.pyx":7266
 *                                                  + CharsNotIn(opener
 *                                                               + closer
 *                                                               + ParserElement.DEFAULT_WHITE_CHARS, exact=1)             # <<<<<<<<<<<<<<
 *                                                  )
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7266, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 7266, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyNumber_Add(__pyx_t_11, __pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7266, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "cPyparsing.pyx":7264
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + CharsNotIn(opener             # <<<<<<<<<<<<<<
 *                                                               + closer
 *                                                               + ParserElement.DEFAULT_WHITE_CHARS, exact=1)
 */
          __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 7264, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_12);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12)) __PYX_ERR(0, 7264, __pyx_L1_error);
          __pyx_t_12 = 0;

          /* "cPyparsing.pyx":7266
 *                                                  + CharsNotIn(opener
 *                                                               + closer
 *                                                               + ParserElement.DEFAULT_WHITE_CHARS, exact=1)             # <<<<<<<<<<<<<<
 *                                                  )
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __pyx_t_12 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7266, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_exact, __pyx_int_1) < 0) __PYX_ERR(0, 7266, __pyx_L1_error)

          /* "cPyparsing.pyx":7264
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + CharsNotIn(opener             # <<<<<<<<<<<<<<
 *                                                               + closer
 *                                                               + ParserElement.DEFAULT_WHITE_CHARS, exact=1)
 */
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, __pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7264, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyNumber_Add(__pyx_t_9, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7264, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_12};
            __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7263, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_t_8 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7263, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }

          /* "cPyparsing.pyx":7268
 *                                                               + ParserElement.DEFAULT_WHITE_CHARS, exact=1)
 *                                                  )
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7268, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10nestedExpr_lambda66, 0, __pyx_n_s_nestedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7268, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_7 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7268, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_content, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":7262
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + CharsNotIn(opener
 */
          goto __pyx_L11;
        }

        /* "cPyparsing.pyx":7270
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener             # <<<<<<<<<<<<<<
 *                                                          + closer
 *                                                          + ParserElement.DEFAULT_WHITE_CHARS
 */
        /*else*/ {
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7270, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_copy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7270, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_14, 0+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7270, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }

          /* "cPyparsing.pyx":7273
 *                                                          + closer
 *                                                          + ParserElement.DEFAULT_WHITE_CHARS
 *                                                          ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *             else:
 *                 if ignoreExpr is not None:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7270, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);

          /* "cPyparsing.pyx":7271
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener
 *                                                          + closer             # <<<<<<<<<<<<<<
 *                                                          + ParserElement.DEFAULT_WHITE_CHARS
 *                                                          ).setParseAction(lambda t: t[0].strip()))
 */
          __pyx_t_8 = PyNumber_Add(__pyx_v_opener, __pyx_v_closer); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7271, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);

          /* "cPyparsing.pyx":7272
 *                     content = (empty.copy() + CharsNotIn(opener
 *                                                          + closer
 *                                                          + ParserElement.DEFAULT_WHITE_CHARS             # <<<<<<<<<<<<<<
 *                                                          ).setParseAction(lambda t: t[0].strip()))
 *             else:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7272, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7272, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyNumber_Add(__pyx_t_8, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7272, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_12};
            __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7270, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }

          /* "cPyparsing.pyx":7273
 *                                                          + closer
 *                                                          + ParserElement.DEFAULT_WHITE_CHARS
 *                                                          ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *             else:
 *                 if ignoreExpr is not None:
 */
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7273, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10nestedExpr_1lambda67, 0, __pyx_n_s_nestedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7273, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_12 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_6};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7273, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }

          /* "cPyparsing.pyx":7270
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener             # <<<<<<<<<<<<<<
 *                                                          + closer
 *                                                          + ParserElement.DEFAULT_WHITE_CHARS
 */
          __pyx_t_7 = PyNumber_Add(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7270, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF_SET(__pyx_v_content, __pyx_t_7);
          __pyx_t_7 = 0;
        }
        __pyx_L11:;

        /* "cPyparsing.pyx":7261
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:             # <<<<<<<<<<<<<<
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr
 */
        goto __pyx_L8;
      }

      /* "cPyparsing.pyx":7275
 *                                                          ).setParseAction(lambda t: t[0].strip()))
 *             else:
 *                 if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + ~Literal(opener)
 */
      /*else*/ {
        __pyx_t_2 = (__pyx_v_ignoreExpr != Py_None);
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":7276
 *             else:
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr             # <<<<<<<<<<<<<<
 *                                                  + ~Literal(opener)
 *                                                  + ~Literal(closer)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Combine); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7276, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7276, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_11 = PyNumber_Invert(__pyx_v_ignoreExpr); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7276, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);

          /* "cPyparsing.pyx":7277
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + ~Literal(opener)             # <<<<<<<<<<<<<<
 *                                                  + ~Literal(closer)
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 */
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Literal); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7277, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_13 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_opener};
            __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7277, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
          __pyx_t_9 = PyNumber_Invert(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7277, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = PyNumber_Add(__pyx_t_11, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7277, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":7278
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + ~Literal(opener)
 *                                                  + ~Literal(closer)             # <<<<<<<<<<<<<<
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_Literal); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7278, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_13 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_11))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_11);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_11, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_closer};
            __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7278, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          }
          __pyx_t_11 = PyNumber_Invert(__pyx_t_9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7278, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = PyNumber_Add(__pyx_t_8, __pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7278, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "cPyparsing.pyx":7279
 *                                                  + ~Literal(opener)
 *                                                  + ~Literal(closer)
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))             # <<<<<<<<<<<<<<
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7279, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7279, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 7279, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7279, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_13);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_13)) __PYX_ERR(0, 7279, __pyx_L1_error);
          __pyx_t_13 = 0;
          __pyx_t_13 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 7279, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_exact, __pyx_int_1) < 0) __PYX_ERR(0, 7279, __pyx_L1_error)
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_8, __pyx_t_13); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7279, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = PyNumber_Add(__pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 7279, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_13};
            __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7276, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          }
          __pyx_t_12 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_6};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7276, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }

          /* "cPyparsing.pyx":7280
 *                                                  + ~Literal(closer)
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *                 else:
 *                     content = (Combine(OneOrMore(~Literal(opener)
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7280, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10nestedExpr_2lambda68, 0, __pyx_n_s_nestedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7280, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_6 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
            __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7280, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_content, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "cPyparsing.pyx":7275
 *                                                          ).setParseAction(lambda t: t[0].strip()))
 *             else:
 *                 if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *                     content = (Combine(OneOrMore(~ignoreExpr
 *                                                  + ~Literal(opener)
 */
          goto __pyx_L12;
        }

        /* "cPyparsing.pyx":7285
 *                                                  + ~Literal(closer)
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 */
        /*else*/ {

          /* "cPyparsing.pyx":7282
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 *                     content = (Combine(OneOrMore(~Literal(opener)             # <<<<<<<<<<<<<<
 *                                                  + ~Literal(closer)
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 */
          __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Combine); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7282, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7282, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_Literal); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7282, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_9 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_opener};
            __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 7282, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
          __pyx_t_10 = PyNumber_Invert(__pyx_t_13); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7282, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "cPyparsing.pyx":7283
 *                 else:
 *                     content = (Combine(OneOrMore(~Literal(opener)
 *                                                  + ~Literal(closer)             # <<<<<<<<<<<<<<
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Literal); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7283, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_8 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_closer};
            __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 7283, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
          __pyx_t_9 = PyNumber_Invert(__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7283, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = PyNumber_Add(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 7283, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":7284
 *                     content = (Combine(OneOrMore(~Literal(opener)
 *                                                  + ~Literal(closer)
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))             # <<<<<<<<<<<<<<
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *         else:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7284, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7284, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7284, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7284, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_GIVEREF(__pyx_t_8);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8)) __PYX_ERR(0, 7284, __pyx_L1_error);
          __pyx_t_8 = 0;
          __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7284, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_exact, __pyx_int_1) < 0) __PYX_ERR(0, 7284, __pyx_L1_error)
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_8); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7284, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = PyNumber_Add(__pyx_t_13, __pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7284, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_8};
            __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7282, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          }
          __pyx_t_12 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_6};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7282, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }

          /* "cPyparsing.pyx":7285
 *                                                  + ~Literal(closer)
 *                                                  + CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7285, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10nestedExpr_3lambda69, 0, __pyx_n_s_nestedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7285, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_6 = NULL;
          __pyx_t_14 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
              __pyx_t_14 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_1};
            __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7285, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_content, __pyx_t_7);
          __pyx_t_7 = 0;
        }
        __pyx_L12:;
      }
      __pyx_L8:;

      /* "cPyparsing.pyx":7260
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):             # <<<<<<<<<<<<<<
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":7287
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")             # <<<<<<<<<<<<<<
 *     ret = Forward()
 *     if ignoreExpr is not None:
 */
    /*else*/ {
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__160, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7287, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __PYX_ERR(0, 7287, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "cPyparsing.pyx":7259
 *     if opener == closer:
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:             # <<<<<<<<<<<<<<
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:
 */
  }

  /* "cPyparsing.pyx":7288
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 *     ret = Forward()             # <<<<<<<<<<<<<<
 *     if ignoreExpr is not None:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Forward); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_14, 0+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_v_ret = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "cPyparsing.pyx":7289
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 *     ret = Forward()
 *     if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ignoreExpr != Py_None);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":7290
 *     ret = Forward()
 *     if ignoreExpr is not None:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))             # <<<<<<<<<<<<<<
 *     else:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ret | content)  + Suppress(closer))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Group); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_12 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_opener};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_8 = PyNumber_Or(__pyx_v_ignoreExpr, __pyx_v_ret); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_11 = PyNumber_Or(__pyx_t_8, __pyx_v_content); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_11};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
    __pyx_t_12 = PyNumber_Add(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_closer};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = PyNumber_Add(__pyx_t_12, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_1};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = PyNumber_InPlaceLshift(__pyx_v_ret, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":7289
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 *     ret = Forward()
 *     if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))
 *     else:
 */
    goto __pyx_L13;
  }

  /* "cPyparsing.pyx":7292
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))
 *     else:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ret | content)  + Suppress(closer))             # <<<<<<<<<<<<<<
 *     ret.setName('nested %s%s expression' % (opener, closer))
 *     return ret
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_Group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_12 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_opener};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_11 = PyNumber_Or(__pyx_v_ret, __pyx_v_content); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_8 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_11};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
    __pyx_t_12 = PyNumber_Add(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_closer};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = PyNumber_Add(__pyx_t_12, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_1};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_7 = PyNumber_InPlaceLshift(__pyx_v_ret, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_7);
    __pyx_t_7 = 0;
  }
  __pyx_L13:;

  /* "cPyparsing.pyx":7293
 *     else:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ret | content)  + Suppress(closer))
 *     ret.setName('nested %s%s expression' % (opener, closer))             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ret, __pyx_n_s_setName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = 0;
  __pyx_t_15 = 127;
  __Pyx_INCREF(__pyx_kp_u_nested);
  __pyx_t_4 += 7;
  __Pyx_GIVEREF(__pyx_kp_u_nested);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_nested);
  __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_opener), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_15 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_15) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_15;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_closer), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_15 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_15) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_15;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_6);
  __pyx_t_6 = 0;
  __Pyx_INCREF(__pyx_kp_u_expression);
  __pyx_t_4 += 11;
  __Pyx_GIVEREF(__pyx_kp_u_expression);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u_expression);
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_1, 4, __pyx_t_4, __pyx_t_15); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_6};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":7294
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ret | content)  + Suppress(closer))
 *     ret.setName('nested %s%s expression' % (opener, closer))
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7192
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """Helper method for defining nested lists enclosed in opening and
 *     closing delimiters ("(" and ")" are the default).
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.nestedExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_content);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7296
 *     return ret
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """Helper method for defining space-delimited indentation blocks,
 *     such as those used to define block statements in Python source code.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_75indentedBlock(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_74indentedBlock, "indentedBlock(blockStatementExpr, indentStack, indent=True)\nHelper method for defining space-delimited indentation blocks,\n    such as those used to define block statements in Python source code.\n\n    Parameters:\n\n     - blockStatementExpr - expression defining syntax of statement that\n       is repeated within the indented block\n     - indentStack - list created by caller to manage indentation stack\n       (multiple statementWithIndentedBlock expressions within a single\n       grammar should share a common indentStack)\n     - indent - boolean indicating whether block must be indented beyond\n       the current level; set to False for block of left-most\n       statements (default= ``True``)\n\n    A valid block must contain at least one ``blockStatement``.\n\n    Example::\n\n        data = '''\n        def A(z):\n          A1\n          B = 100\n          G = A2\n          A2\n          A3\n        B\n        def BB(a,b,c):\n          BB1\n          def BBA():\n            bba1\n            bba2\n            bba3\n        C\n        D\n        def spam(x,y):\n             def eggs(z):\n                 pass\n        '''\n\n\n        indentStack = [1]\n        stmt = Forward()\n\n        identifier = Word(alphas, alphanums)\n        funcDecl = (\"def\" + identifier + Group(\"(\" + Optional(delimitedList(identifier)) + \")\") + \":\")\n        func_body = indentedBlock(stmt, indentStack)\n        funcDef = Group(funcDecl + func_body)\n\n        rvalue = Forward()\n        funcCall = Group(identifier + \"(\" + Optional(delimitedList(rvalue)) + \")\")\n        rvalue << (funcCall | identifier | Word(nums))\n        assignment = Group(identifier + \"=\" + rvalue)\n        stmt << (funcDef | assignment | identifier)\n\n        module_body = OneOrMore(stmt)\n\n        parseTree = module_body.parseString(data)\n        parseTree.pprint()\n\n    prints::\n\n        [['def',\n          'A',\n          ['(', 'z', ')'],\n          ':',\n          [['A1'], [['B', '=""', '100']], [['G', '=', 'A2']], ['A2'], ['A3']]],\n         'B',\n         ['def',\n          'BB',\n          ['(', 'a', 'b', 'c', ')'],\n          ':',\n          [['BB1'], [['def', 'BBA', ['(', ')'], ':', [['bba1'], ['bba2'], ['bba3']]]]]],\n         'C',\n         'D',\n         ['def',\n          'spam',\n          ['(', 'x', 'y', ')'],\n          ':',\n          [[['def', 'eggs', ['(', 'z', ')'], ':', [['pass']]]]]]]\n    ");
static PyMethodDef __pyx_mdef_10cPyparsing_75indentedBlock = {"indentedBlock", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_75indentedBlock, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_74indentedBlock};
static PyObject *__pyx_pw_10cPyparsing_75indentedBlock(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_blockStatementExpr = 0;
  PyObject *__pyx_v_indentStack = 0;
  PyObject *__pyx_v_indent = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("indentedBlock (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_blockStatementExpr,&__pyx_n_s_indentStack,&__pyx_n_s_indent,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_blockStatementExpr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7296, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_indentStack)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7296, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("indentedBlock", 0, 2, 3, 1); __PYX_ERR(0, 7296, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_indent);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7296, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "indentedBlock") < 0)) __PYX_ERR(0, 7296, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_blockStatementExpr = values[0];
    __pyx_v_indentStack = values[1];
    __pyx_v_indent = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("indentedBlock", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 7296, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.indentedBlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_74indentedBlock(__pyx_self, __pyx_v_blockStatementExpr, __pyx_v_indentStack, __pyx_v_indent);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7379
 *     backup_stack = indentStack[:]
 * 
 *     def reset_stack():             # <<<<<<<<<<<<<<
 *         indentStack[:] = backup_stack
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_1reset_stack(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13indentedBlock_1reset_stack = {"reset_stack", (PyCFunction)__pyx_pw_10cPyparsing_13indentedBlock_1reset_stack, METH_NOARGS, 0};
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_1reset_stack(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reset_stack (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_10cPyparsing_13indentedBlock_reset_stack(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_reset_stack(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reset_stack", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":7380
 * 
 *     def reset_stack():
 *         indentStack[:] = backup_stack             # <<<<<<<<<<<<<<
 * 
 *     def checkPeerIndent(s, l, t):
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_backup_stack)) { __Pyx_RaiseClosureNameError("backup_stack"); __PYX_ERR(0, 7380, __pyx_L1_error) }
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 7380, __pyx_L1_error) }
  if (__Pyx_PyObject_SetSlice(__pyx_cur_scope->__pyx_v_indentStack, __pyx_cur_scope->__pyx_v_backup_stack, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1) < 0) __PYX_ERR(0, 7380, __pyx_L1_error)

  /* "cPyparsing.pyx":7379
 *     backup_stack = indentStack[:]
 * 
 *     def reset_stack():             # <<<<<<<<<<<<<<
 *         indentStack[:] = backup_stack
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.indentedBlock.reset_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7382
 *         indentStack[:] = backup_stack
 * 
 *     def checkPeerIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s): return
 *         curCol = col(l, s)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_3checkPeerIndent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13indentedBlock_3checkPeerIndent = {"checkPeerIndent", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13indentedBlock_3checkPeerIndent, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_3checkPeerIndent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkPeerIndent (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7382, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7382, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkPeerIndent", 1, 3, 3, 1); __PYX_ERR(0, 7382, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7382, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkPeerIndent", 1, 3, 3, 2); __PYX_ERR(0, 7382, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkPeerIndent") < 0)) __PYX_ERR(0, 7382, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkPeerIndent", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 7382, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkPeerIndent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13indentedBlock_2checkPeerIndent(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_2checkPeerIndent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_outer_scope;
  PyObject *__pyx_v_curCol = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkPeerIndent", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":7383
 * 
 *     def checkPeerIndent(s, l, t):
 *         if l >= len(s): return             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_s); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 7383, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_l, __pyx_t_2, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 7383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":7384
 *     def checkPeerIndent(s, l, t):
 *         if l >= len(s): return
 *         curCol = col(l, s)             # <<<<<<<<<<<<<<
 *         if curCol != indentStack[-1]:
 *             if curCol > indentStack[-1]:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_l, __pyx_v_s};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_curCol = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7385
 *         if l >= len(s): return
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:             # <<<<<<<<<<<<<<
 *             if curCol > indentStack[-1]:
 *                 raise ParseException(s, l, "illegal nesting")
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 7385, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_indentStack, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_curCol, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7385, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 7385, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":7386
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:
 *             if curCol > indentStack[-1]:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, "illegal nesting")
 *             raise ParseException(s, l, "not a peer entry")
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 7386, __pyx_L1_error) }
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_indentStack, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_curCol, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7386, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 7386, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__pyx_t_4)) {

      /* "cPyparsing.pyx":7387
 *         if curCol != indentStack[-1]:
 *             if curCol > indentStack[-1]:
 *                 raise ParseException(s, l, "illegal nesting")             # <<<<<<<<<<<<<<
 *             raise ParseException(s, l, "not a peer entry")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_kp_u_illegal_nesting};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7387, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 7387, __pyx_L1_error)

      /* "cPyparsing.pyx":7386
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:
 *             if curCol > indentStack[-1]:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, "illegal nesting")
 *             raise ParseException(s, l, "not a peer entry")
 */
    }

    /* "cPyparsing.pyx":7388
 *             if curCol > indentStack[-1]:
 *                 raise ParseException(s, l, "illegal nesting")
 *             raise ParseException(s, l, "not a peer entry")             # <<<<<<<<<<<<<<
 * 
 *     def checkSubIndent(s, l, t):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_kp_u_not_a_peer_entry};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 7388, __pyx_L1_error)

    /* "cPyparsing.pyx":7385
 *         if l >= len(s): return
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:             # <<<<<<<<<<<<<<
 *             if curCol > indentStack[-1]:
 *                 raise ParseException(s, l, "illegal nesting")
 */
  }

  /* "cPyparsing.pyx":7382
 *         indentStack[:] = backup_stack
 * 
 *     def checkPeerIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s): return
 *         curCol = col(l, s)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkPeerIndent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_curCol);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7390
 *             raise ParseException(s, l, "not a peer entry")
 * 
 *     def checkSubIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_5checkSubIndent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13indentedBlock_5checkSubIndent = {"checkSubIndent", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13indentedBlock_5checkSubIndent, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_5checkSubIndent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkSubIndent (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7390, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7390, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkSubIndent", 1, 3, 3, 1); __PYX_ERR(0, 7390, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7390, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkSubIndent", 1, 3, 3, 2); __PYX_ERR(0, 7390, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkSubIndent") < 0)) __PYX_ERR(0, 7390, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkSubIndent", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 7390, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkSubIndent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13indentedBlock_4checkSubIndent(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_4checkSubIndent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_outer_scope;
  PyObject *__pyx_v_curCol = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkSubIndent", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":7391
 * 
 *     def checkSubIndent(s, l, t):
 *         curCol = col(l, s)             # <<<<<<<<<<<<<<
 *         if curCol > indentStack[-1]:
 *             indentStack.append(curCol)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_l, __pyx_v_s};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_curCol = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7392
 *     def checkSubIndent(s, l, t):
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:             # <<<<<<<<<<<<<<
 *             indentStack.append(curCol)
 *         else:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 7392, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_indentStack, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_curCol, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 7392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(__pyx_t_5)) {

    /* "cPyparsing.pyx":7393
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 *             indentStack.append(curCol)             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException(s, l, "not a subentry")
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 7393, __pyx_L1_error) }
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_cur_scope->__pyx_v_indentStack, __pyx_v_curCol); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 7393, __pyx_L1_error)

    /* "cPyparsing.pyx":7392
 *     def checkSubIndent(s, l, t):
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:             # <<<<<<<<<<<<<<
 *             indentStack.append(curCol)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":7395
 *             indentStack.append(curCol)
 *         else:
 *             raise ParseException(s, l, "not a subentry")             # <<<<<<<<<<<<<<
 * 
 *     def checkUnindent(s, l, t):
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_s, __pyx_v_l, __pyx_kp_u_not_a_subentry};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 7395, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":7390
 *             raise ParseException(s, l, "not a peer entry")
 * 
 *     def checkSubIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkSubIndent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_curCol);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7397
 *             raise ParseException(s, l, "not a subentry")
 * 
 *     def checkUnindent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s): return
 *         curCol = col(l, s)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_7checkUnindent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13indentedBlock_7checkUnindent = {"checkUnindent", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13indentedBlock_7checkUnindent, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_7checkUnindent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkUnindent (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7397, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7397, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkUnindent", 1, 3, 3, 1); __PYX_ERR(0, 7397, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7397, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("checkUnindent", 1, 3, 3, 2); __PYX_ERR(0, 7397, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "checkUnindent") < 0)) __PYX_ERR(0, 7397, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkUnindent", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 7397, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkUnindent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13indentedBlock_6checkUnindent(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_6checkUnindent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_outer_scope;
  PyObject *__pyx_v_curCol = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkUnindent", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":7398
 * 
 *     def checkUnindent(s, l, t):
 *         if l >= len(s): return             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if not(indentStack and curCol in indentStack):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_s); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 7398, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_l, __pyx_t_2, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 7398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":7399
 *     def checkUnindent(s, l, t):
 *         if l >= len(s): return
 *         curCol = col(l, s)             # <<<<<<<<<<<<<<
 *         if not(indentStack and curCol in indentStack):
 *             raise ParseException(s, l, "not an unindent")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_l, __pyx_v_s};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7399, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_curCol = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7400
 *         if l >= len(s): return
 *         curCol = col(l, s)
 *         if not(indentStack and curCol in indentStack):             # <<<<<<<<<<<<<<
 *             raise ParseException(s, l, "not an unindent")
 *         if curCol < indentStack[-1]:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 7400, __pyx_L1_error) }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_indentStack); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 7400, __pyx_L1_error)
  if (__pyx_t_7) {
  } else {
    __pyx_t_4 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 7400, __pyx_L1_error) }
  __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_v_curCol, __pyx_cur_scope->__pyx_v_indentStack, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 7400, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_7;
  __pyx_L5_bool_binop_done:;
  __pyx_t_7 = (!__pyx_t_4);
  if (unlikely(__pyx_t_7)) {

    /* "cPyparsing.pyx":7401
 *         curCol = col(l, s)
 *         if not(indentStack and curCol in indentStack):
 *             raise ParseException(s, l, "not an unindent")             # <<<<<<<<<<<<<<
 *         if curCol < indentStack[-1]:
 *             indentStack.pop()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_kp_u_not_an_unindent};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7401, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 7401, __pyx_L1_error)

    /* "cPyparsing.pyx":7400
 *         if l >= len(s): return
 *         curCol = col(l, s)
 *         if not(indentStack and curCol in indentStack):             # <<<<<<<<<<<<<<
 *             raise ParseException(s, l, "not an unindent")
 *         if curCol < indentStack[-1]:
 */
  }

  /* "cPyparsing.pyx":7402
 *         if not(indentStack and curCol in indentStack):
 *             raise ParseException(s, l, "not an unindent")
 *         if curCol < indentStack[-1]:             # <<<<<<<<<<<<<<
 *             indentStack.pop()
 * 
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 7402, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_indentStack, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_curCol, __pyx_t_3, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 7402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":7403
 *             raise ParseException(s, l, "not an unindent")
 *         if curCol < indentStack[-1]:
 *             indentStack.pop()             # <<<<<<<<<<<<<<
 * 
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress(), stopOn=StringEnd())
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 7403, __pyx_L1_error) }
    __pyx_t_2 = __Pyx_PyObject_Pop(__pyx_cur_scope->__pyx_v_indentStack); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":7402
 *         if not(indentStack and curCol in indentStack):
 *             raise ParseException(s, l, "not an unindent")
 *         if curCol < indentStack[-1]:             # <<<<<<<<<<<<<<
 *             indentStack.pop()
 * 
 */
  }

  /* "cPyparsing.pyx":7397
 *             raise ParseException(s, l, "not a subentry")
 * 
 *     def checkUnindent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s): return
 *         curCol = col(l, s)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkUnindent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_curCol);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7418
 *                        + OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL), stopOn=StringEnd())
 *                        + UNDENT)
 *     smExpr.setFailAction(lambda a, b, c, d: reset_stack())             # <<<<<<<<<<<<<<
 *     blockStatementExpr.ignore(_bslash + LineEnd())
 *     return smExpr.setName('indented block')
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_8lambda70(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13indentedBlock_8lambda70 = {"lambda70", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_13indentedBlock_8lambda70, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_8lambda70(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_a = 0;
  CYTHON_UNUSED PyObject *__pyx_v_b = 0;
  CYTHON_UNUSED PyObject *__pyx_v_c = 0;
  CYTHON_UNUSED PyObject *__pyx_v_d = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda70 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b_2,&__pyx_n_s_c,&__pyx_n_s_d,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_a)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7418, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_b_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7418, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda70", 1, 4, 4, 1); __PYX_ERR(0, 7418, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_c)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7418, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda70", 1, 4, 4, 2); __PYX_ERR(0, 7418, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_d)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7418, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda70", 1, 4, 4, 3); __PYX_ERR(0, 7418, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda70") < 0)) __PYX_ERR(0, 7418, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
    __pyx_v_c = values[2];
    __pyx_v_d = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda70", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 7418, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.indentedBlock.lambda70", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda70(__pyx_self, __pyx_v_a, __pyx_v_b, __pyx_v_c, __pyx_v_d);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda70(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_a, CYTHON_UNUSED PyObject *__pyx_v_b, CYTHON_UNUSED PyObject *__pyx_v_c, CYTHON_UNUSED PyObject *__pyx_v_d) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda70", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_reset_stack)) { __Pyx_RaiseClosureNameError("reset_stack"); __PYX_ERR(0, 7418, __pyx_L1_error) }
  __pyx_t_1 = __pyx_pf_10cPyparsing_13indentedBlock_reset_stack(__pyx_cur_scope->__pyx_v_reset_stack); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.indentedBlock.lambda70", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7296
 *     return ret
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """Helper method for defining space-delimited indentation blocks,
 *     such as those used to define block statements in Python source code.
 */

static PyObject *__pyx_pf_10cPyparsing_74indentedBlock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_blockStatementExpr, PyObject *__pyx_v_indentStack, PyObject *__pyx_v_indent) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_cur_scope;
  PyObject *__pyx_v_checkPeerIndent = 0;
  PyObject *__pyx_v_checkSubIndent = 0;
  PyObject *__pyx_v_checkUnindent = 0;
  PyObject *__pyx_v_NL = NULL;
  PyObject *__pyx_v_INDENT = NULL;
  PyObject *__pyx_v_PEER = NULL;
  PyObject *__pyx_v_UNDENT = NULL;
  PyObject *__pyx_v_smExpr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("indentedBlock", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_70_indentedBlock(__pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 7296, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_indentStack = __pyx_v_indentStack;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_indentStack);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_indentStack);

  /* "cPyparsing.pyx":7377
 *           [[['def', 'eggs', ['(', 'z', ')'], ':', [['pass']]]]]]]
 *     """
 *     backup_stack = indentStack[:]             # <<<<<<<<<<<<<<
 * 
 *     def reset_stack():
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_indentStack, 0, 0, NULL, NULL, &__pyx_slice__20, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_backup_stack = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7379
 *     backup_stack = indentStack[:]
 * 
 *     def reset_stack():             # <<<<<<<<<<<<<<
 *         indentStack[:] = backup_stack
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13indentedBlock_1reset_stack, 0, __pyx_n_s_indentedBlock_locals_reset_stack, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__161)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_reset_stack = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7382
 *         indentStack[:] = backup_stack
 * 
 *     def checkPeerIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s): return
 *         curCol = col(l, s)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13indentedBlock_3checkPeerIndent, 0, __pyx_n_s_indentedBlock_locals_checkPeerIn, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__163)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_checkPeerIndent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7390
 *             raise ParseException(s, l, "not a peer entry")
 * 
 *     def checkSubIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13indentedBlock_5checkSubIndent, 0, __pyx_n_s_indentedBlock_locals_checkSubInd, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__164)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_checkSubIndent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7397
 *             raise ParseException(s, l, "not a subentry")
 * 
 *     def checkUnindent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s): return
 *         curCol = col(l, s)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13indentedBlock_7checkUnindent, 0, __pyx_n_s_indentedBlock_locals_checkUninde, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__165)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_checkUnindent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7405
 *             indentStack.pop()
 * 
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress(), stopOn=StringEnd())             # <<<<<<<<<<<<<<
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')
 *     PEER   = Empty().setParseAction(checkPeerIndent).setName('')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_LineEnd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u__166};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_suppress); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 7405, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_StringEnd); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stopOn, __pyx_t_3) < 0) __PYX_ERR(0, 7405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_NL = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7406
 * 
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress(), stopOn=StringEnd())
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')             # <<<<<<<<<<<<<<
 *     PEER   = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Empty); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_checkSubIndent};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_setName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_INDENT};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_v_INDENT = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7407
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress(), stopOn=StringEnd())
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')
 *     PEER   = Empty().setParseAction(checkPeerIndent).setName('')             # <<<<<<<<<<<<<<
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 *     if indent:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_checkPeerIndent};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_u__10};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_PEER = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7408
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')
 *     PEER   = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')             # <<<<<<<<<<<<<<
 *     if indent:
 *         smExpr = Group(Optional(NL)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_checkUnindent};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_UNINDENT};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_UNDENT = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7409
 *     PEER   = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 *     if indent:             # <<<<<<<<<<<<<<
 *         smExpr = Group(Optional(NL)
 *                        + INDENT
 */
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_indent); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 7409, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":7410
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 *     if indent:
 *         smExpr = Group(Optional(NL)             # <<<<<<<<<<<<<<
 *                        + INDENT
 *                        + OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL), stopOn=StringEnd())
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Group); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Optional); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_NL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }

    /* "cPyparsing.pyx":7411
 *     if indent:
 *         smExpr = Group(Optional(NL)
 *                        + INDENT             # <<<<<<<<<<<<<<
 *                        + OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL), stopOn=StringEnd())
 *                        + UNDENT)
 */
    __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_v_INDENT); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":7412
 *         smExpr = Group(Optional(NL)
 *                        + INDENT
 *                        + OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL), stopOn=StringEnd())             # <<<<<<<<<<<<<<
 *                        + UNDENT)
 *     else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_Group); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_9 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_blockStatementExpr};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7412, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = PyNumber_Add(__pyx_v_PEER, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Optional); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_NL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7412, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_9 = PyNumber_Add(__pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_9);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_9)) __PYX_ERR(0, 7412, __pyx_L1_error);
    __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_StringEnd); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7412, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_stopOn, __pyx_t_6) < 0) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyNumber_Add(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":7413
 *                        + INDENT
 *                        + OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL), stopOn=StringEnd())
 *                        + UNDENT)             # <<<<<<<<<<<<<<
 *     else:
 *         smExpr = Group(Optional(NL)
 */
    __pyx_t_6 = PyNumber_Add(__pyx_t_9, __pyx_v_UNDENT); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_smExpr = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":7409
 *     PEER   = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 *     if indent:             # <<<<<<<<<<<<<<
 *         smExpr = Group(Optional(NL)
 *                        + INDENT
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":7415
 *                        + UNDENT)
 *     else:
 *         smExpr = Group(Optional(NL)             # <<<<<<<<<<<<<<
 *                        + OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL), stopOn=StringEnd())
 *                        + UNDENT)
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Group); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Optional); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_NL};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }

    /* "cPyparsing.pyx":7416
 *     else:
 *         smExpr = Group(Optional(NL)
 *                        + OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL), stopOn=StringEnd())             # <<<<<<<<<<<<<<
 *                        + UNDENT)
 *     smExpr.setFailAction(lambda a, b, c, d: reset_stack())
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Group); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_blockStatementExpr};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = PyNumber_Add(__pyx_v_PEER, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_NL};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 7416, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_StringEnd); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stopOn, __pyx_t_1) < 0) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":7417
 *         smExpr = Group(Optional(NL)
 *                        + OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL), stopOn=StringEnd())
 *                        + UNDENT)             # <<<<<<<<<<<<<<
 *     smExpr.setFailAction(lambda a, b, c, d: reset_stack())
 *     blockStatementExpr.ignore(_bslash + LineEnd())
 */
    __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_UNDENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_smExpr = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":7418
 *                        + OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL), stopOn=StringEnd())
 *                        + UNDENT)
 *     smExpr.setFailAction(lambda a, b, c, d: reset_stack())             # <<<<<<<<<<<<<<
 *     blockStatementExpr.ignore(_bslash + LineEnd())
 *     return smExpr.setName('indented block')
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_smExpr, __pyx_n_s_setFailAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13indentedBlock_8lambda70, 0, __pyx_n_s_indentedBlock_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7419
 *                        + UNDENT)
 *     smExpr.setFailAction(lambda a, b, c, d: reset_stack())
 *     blockStatementExpr.ignore(_bslash + LineEnd())             # <<<<<<<<<<<<<<
 *     return smExpr.setName('indented block')
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_blockStatementExpr, __pyx_n_s_ignore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_bslash); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_LineEnd); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7420
 *     smExpr.setFailAction(lambda a, b, c, d: reset_stack())
 *     blockStatementExpr.ignore(_bslash + LineEnd())
 *     return smExpr.setName('indented block')             # <<<<<<<<<<<<<<
 * 
 * alphas8bit = srange(r"[\0xc0-\0xd6\0xd8-\0xf6\0xf8-\0xff]")
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_smExpr, __pyx_n_s_setName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_u_indented_block};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7296
 *     return ret
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """Helper method for defining space-delimited indentation blocks,
 *     such as those used to define block statements in Python source code.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.indentedBlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_checkPeerIndent);
  __Pyx_XDECREF(__pyx_v_checkSubIndent);
  __Pyx_XDECREF(__pyx_v_checkUnindent);
  __Pyx_XDECREF(__pyx_v_NL);
  __Pyx_XDECREF(__pyx_v_INDENT);
  __Pyx_XDECREF(__pyx_v_PEER);
  __Pyx_XDECREF(__pyx_v_UNDENT);
  __Pyx_XDECREF(__pyx_v_smExpr);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7428
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) +");").setName("common HTML entity")
 * def replaceHTMLEntity(t):             # <<<<<<<<<<<<<<
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_77replaceHTMLEntity(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_76replaceHTMLEntity, "replaceHTMLEntity(t)\nHelper parser action to replace common HTML entities with their special characters");
static PyMethodDef __pyx_mdef_10cPyparsing_77replaceHTMLEntity = {"replaceHTMLEntity", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_77replaceHTMLEntity, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_76replaceHTMLEntity};
static PyObject *__pyx_pw_10cPyparsing_77replaceHTMLEntity(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("replaceHTMLEntity (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7428, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "replaceHTMLEntity") < 0)) __PYX_ERR(0, 7428, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("replaceHTMLEntity", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7428, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.replaceHTMLEntity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_76replaceHTMLEntity(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_76replaceHTMLEntity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("replaceHTMLEntity", 1);

  /* "cPyparsing.pyx":7430
 * def replaceHTMLEntity(t):
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)             # <<<<<<<<<<<<<<
 * 
 * # it's easy to get these comment structures wrong - they're very common, so may as well make them available
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_htmlEntityMap); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_entity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7428
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) +");").setName("common HTML entity")
 * def replaceHTMLEntity(t):             # <<<<<<<<<<<<<<
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.replaceHTMLEntity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7629
 *     fraction = (signed_integer().setParseAction(convertToFloat) + '/' + signed_integer().setParseAction(convertToFloat)).setName("fraction")
 *     """fractional expression of an integer divided by an integer, returns a float"""
 *     fraction.addParseAction(lambda t: t[0]/t[-1])             # <<<<<<<<<<<<<<
 * 
 *     mixed_integer = (fraction | signed_integer + Optional(Optional('-').suppress() + fraction)).setName("fraction or mixed integer-fraction")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_6lambda71(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_6lambda71 = {"lambda71", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_16pyparsing_common_6lambda71, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_6lambda71(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda71 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7629, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda71") < 0)) __PYX_ERR(0, 7629, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda71", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7629, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda71", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda71(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda71(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda71", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda71", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7661
 *                            + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 *                            ).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)             # <<<<<<<<<<<<<<
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_7lambda72(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_7lambda72 = {"lambda72", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_16pyparsing_common_7lambda72, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_7lambda72(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda72 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7661, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda72") < 0)) __PYX_ERR(0, 7661, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda72", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7661, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda72", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda72(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_16pyparsing_common_8lambda72_2generator45(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_8lambda72_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_71_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 7661, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_16pyparsing_common_8lambda72_2generator45, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_pyparsing_common_lambda_locals_g, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 7661, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda72.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_16pyparsing_common_8lambda72_2generator45(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 7661, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 7661, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7661, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7661, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 7661, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7661, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7661, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 7661, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7661, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 7661, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_tt);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_tt, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ipv6_part); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_matches); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_tt};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7661, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 7661, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_8) {
      __Pyx_INCREF(__pyx_int_1);
      __pyx_r = __pyx_int_1;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 7661, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda72(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_gb_10cPyparsing_16pyparsing_common_8lambda72_2generator45 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda72", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_pf_10cPyparsing_16pyparsing_common_8lambda72_genexpr(NULL, __pyx_v_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, __pyx_int_8, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda72", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_16pyparsing_common_8lambda72_2generator45);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7756
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 * 
 *     upcaseTokens = staticmethod(tokenMap(lambda t: _ustr(t).upper()))             # <<<<<<<<<<<<<<
 *     """Parse action to convert tokens to upper case."""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_8lambda74(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_8lambda74 = {"lambda74", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_16pyparsing_common_8lambda74, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_8lambda74(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda74 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7756, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda74") < 0)) __PYX_ERR(0, 7756, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda74", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7756, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda74", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda74(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda74(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda74", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_t};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda74", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7759
 *     """Parse action to convert tokens to upper case."""
 * 
 *     downcaseTokens = staticmethod(tokenMap(lambda t: _ustr(t).lower()))             # <<<<<<<<<<<<<<
 *     """Parse action to convert tokens to lower case."""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_9lambda75(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_9lambda75 = {"lambda75", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_16pyparsing_common_9lambda75, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_9lambda75(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda75 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7759, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda75") < 0)) __PYX_ERR(0, 7759, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_t = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda75", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7759, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda75", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda75(__pyx_self, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda75(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda75", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_t};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_lower); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda75", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7669
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDate(fmt="%Y-%m-%d"):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_1convertToDate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_16pyparsing_common_convertToDate, "pyparsing_common.convertToDate(fmt=u'%Y-%m-%d')\n\n        Helper to create a parse action for converting parsed date string to Python datetime.date\n\n        Params -\n         - fmt - format to be passed to datetime.strptime (default= ``\"%Y-%m-%d\"``)\n\n        Example::\n\n            date_expr = pyparsing_common.iso8601_date.copy()\n            date_expr.setParseAction(pyparsing_common.convertToDate())\n            print(date_expr.parseString(\"1999-12-31\"))\n\n        prints::\n\n            [datetime.date(1999, 12, 31)]\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_1convertToDate = {"convertToDate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_16pyparsing_common_1convertToDate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_16pyparsing_common_convertToDate};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_1convertToDate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_fmt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convertToDate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fmt,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u_Y_m_d)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fmt);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7669, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "convertToDate") < 0)) __PYX_ERR(0, 7669, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_fmt = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("convertToDate", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 7669, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_convertToDate(__pyx_self, __pyx_v_fmt);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7687
 *             [datetime.date(1999, 12, 31)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn = {"cvt_fn", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cvt_fn (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7687, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7687, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, 1); __PYX_ERR(0, 7687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7687, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, 2); __PYX_ERR(0, 7687, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "cvt_fn") < 0)) __PYX_ERR(0, 7687, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 7687, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_13convertToDate_cvt_fn(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_13convertToDate_cvt_fn(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *__pyx_outer_scope;
  PyObject *__pyx_v_ve = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cvt_fn", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":7688
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":7689
 *         def cvt_fn(s, l, t):
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()             # <<<<<<<<<<<<<<
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_datetime); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7689, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_strptime); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7689, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7689, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(!__pyx_cur_scope->__pyx_v_fmt)) { __Pyx_RaiseClosureNameError("fmt"); __PYX_ERR(0, 7689, __pyx_L3_error) }
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_t_6, __pyx_cur_scope->__pyx_v_fmt};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 2+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7689, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_date); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7689, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7689, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":7688
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":7690
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_9) {
      __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 7690, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_ve = __pyx_t_7;
      /*try:*/ {

        /* "cPyparsing.pyx":7691
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))             # <<<<<<<<<<<<<<
 *         return cvt_fn
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7691, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_str); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7691, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        __pyx_t_9 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
            __pyx_t_9 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_ve};
          __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7691, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
        __pyx_t_11 = NULL;
        __pyx_t_9 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_9 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_11, __pyx_v_s, __pyx_v_l, __pyx_t_10};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_9, 3+__pyx_t_9);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7691, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(0, 7691, __pyx_L14_error)
      }

      /* "cPyparsing.pyx":7690
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn
 */
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_9 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ve); __pyx_v_ve = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          }
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":7688
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":7687
 *             [datetime.date(1999, 12, 31)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ve);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7669
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDate(fmt="%Y-%m-%d"):
 *         """
 */

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_convertToDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fmt) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *__pyx_cur_scope;
  PyObject *__pyx_v_cvt_fn = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convertToDate", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_72_convertToDate(__pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 7669, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_fmt = __pyx_v_fmt;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fmt);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fmt);

  /* "cPyparsing.pyx":7687
 *             [datetime.date(1999, 12, 31)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn, 0, __pyx_n_s_pyparsing_common_convertToDate_l, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__168)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cvt_fn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7692
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cvt_fn);
  __pyx_r = __pyx_v_cvt_fn;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7669
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDate(fmt="%Y-%m-%d"):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cvt_fn);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7694
 *         return cvt_fn
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):
 *         """Helper to create a parse action for converting parsed
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_3convertToDatetime(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_16pyparsing_common_2convertToDatetime, "pyparsing_common.convertToDatetime(fmt=u'%Y-%m-%dT%H:%M:%S.%f')\nHelper to create a parse action for converting parsed\n        datetime string to Python datetime.datetime\n\n        Params -\n         - fmt - format to be passed to datetime.strptime (default= ``\"%Y-%m-%dT%H:%M:%S.%f\"``)\n\n        Example::\n\n            dt_expr = pyparsing_common.iso8601_datetime.copy()\n            dt_expr.setParseAction(pyparsing_common.convertToDatetime())\n            print(dt_expr.parseString(\"1999-12-31T23:59:59.999\"))\n\n        prints::\n\n            [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_3convertToDatetime = {"convertToDatetime", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_16pyparsing_common_3convertToDatetime, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_16pyparsing_common_2convertToDatetime};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_3convertToDatetime(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_fmt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convertToDatetime (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fmt,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u_Y_m_dT_H_M_S_f)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fmt);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7694, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "convertToDatetime") < 0)) __PYX_ERR(0, 7694, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_fmt = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("convertToDatetime", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 7694, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_2convertToDatetime(__pyx_self, __pyx_v_fmt);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7712
 *             [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn = {"cvt_fn", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cvt_fn (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7712, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7712, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, 1); __PYX_ERR(0, 7712, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_t)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7712, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, 2); __PYX_ERR(0, 7712, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "cvt_fn") < 0)) __PYX_ERR(0, 7712, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 7712, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_17convertToDatetime_cvt_fn(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_17convertToDatetime_cvt_fn(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *__pyx_outer_scope;
  PyObject *__pyx_v_ve = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cvt_fn", 1);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":7713
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":7714
 *         def cvt_fn(s, l, t):
 *             try:
 *                 return datetime.strptime(t[0], fmt)             # <<<<<<<<<<<<<<
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_datetime); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7714, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strptime); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7714, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7714, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(!__pyx_cur_scope->__pyx_v_fmt)) { __Pyx_RaiseClosureNameError("fmt"); __PYX_ERR(0, 7714, __pyx_L3_error) }
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_5, __pyx_cur_scope->__pyx_v_fmt};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7714, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":7713
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":7715
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_5) < 0) __PYX_ERR(0, 7715, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_ve = __pyx_t_6;
      /*try:*/ {

        /* "cPyparsing.pyx":7716
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))             # <<<<<<<<<<<<<<
 *         return cvt_fn
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7716, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_str); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7716, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_ve};
          __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7716, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
        __pyx_t_11 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_11, __pyx_v_s, __pyx_v_l, __pyx_t_10};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_8, 3+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 7716, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __Pyx_Raise(__pyx_t_7, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __PYX_ERR(0, 7716, __pyx_L14_error)
      }

      /* "cPyparsing.pyx":7715
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn
 */
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_8 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ve); __pyx_v_ve = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          }
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":7713
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":7712
 *             [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ve);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7694
 *         return cvt_fn
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):
 *         """Helper to create a parse action for converting parsed
 */

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_2convertToDatetime(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fmt) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *__pyx_cur_scope;
  PyObject *__pyx_v_cvt_fn = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convertToDatetime", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_73_convertToDatetime(__pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 7694, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_fmt = __pyx_v_fmt;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fmt);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fmt);

  /* "cPyparsing.pyx":7712
 *             [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn, 0, __pyx_n_s_pyparsing_common_convertToDateti, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__169)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cvt_fn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7717
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn             # <<<<<<<<<<<<<<
 * 
 *     iso8601_date = Regex(r'(?P<year>\d{4})(?:-(?P<month>\d\d)(?:-(?P<day>\d\d))?)?').setName("ISO8601 date")
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cvt_fn);
  __pyx_r = __pyx_v_cvt_fn;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7694
 *         return cvt_fn
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):
 *         """Helper to create a parse action for converting parsed
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cvt_fn);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7729
 * 
 *     _html_stripper = anyOpenTag.suppress() | anyCloseTag.suppress()
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def stripHTMLTags(s, l, tokens):
 *         """Parse action to remove HTML tags from web page HTML source
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_5stripHTMLTags(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_16pyparsing_common_4stripHTMLTags, "pyparsing_common.stripHTMLTags(s, l, tokens)\nParse action to remove HTML tags from web page HTML source\n\n        Example::\n\n            # strip HTML links from normal text\n            text = '<td>More info at the <a href=\"https://github.com/pyparsing/pyparsing/wiki\">pyparsing</a> wiki page</td>'\n            td, td_end = makeHTMLTags(\"TD\")\n            table_text = td + SkipTo(td_end).setParseAction(pyparsing_common.stripHTMLTags)(\"body\") + td_end\n            print(table_text.parseString(text).body)\n\n        Prints::\n\n            More info at the pyparsing wiki page\n        ");
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_5stripHTMLTags = {"stripHTMLTags", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_16pyparsing_common_5stripHTMLTags, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_16pyparsing_common_4stripHTMLTags};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_5stripHTMLTags(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_tokens = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stripHTMLTags (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_tokens,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7729, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7729, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("stripHTMLTags", 1, 3, 3, 1); __PYX_ERR(0, 7729, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tokens)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7729, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("stripHTMLTags", 1, 3, 3, 2); __PYX_ERR(0, 7729, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stripHTMLTags") < 0)) __PYX_ERR(0, 7729, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_tokens = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stripHTMLTags", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 7729, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.stripHTMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_4stripHTMLTags(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_tokens);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_4stripHTMLTags(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_tokens) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stripHTMLTags", 1);

  /* "cPyparsing.pyx":7745
 *             More info at the pyparsing wiki page
 *         """
 *         return pyparsing_common._html_stripper.transformString(tokens[0])             # <<<<<<<<<<<<<<
 * 
 *     _commasepitem = Combine(OneOrMore(~Literal(",")
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_html_stripper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_transformString); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7729
 * 
 *     _html_stripper = anyOpenTag.suppress() | anyCloseTag.suppress()
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def stripHTMLTags(s, l, tokens):
 *         """Parse action to remove HTML tags from web page HTML source
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.stripHTMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7764
 * 
 * class _lazyclassproperty(object):
 *     def __init__(self, fn):             # <<<<<<<<<<<<<<
 *         self.fn = fn
 *         self.__doc__ = fn.__doc__
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18_lazyclassproperty_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18_lazyclassproperty___init__, "_lazyclassproperty.__init__(self, fn)");
static PyMethodDef __pyx_mdef_10cPyparsing_18_lazyclassproperty_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18_lazyclassproperty_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18_lazyclassproperty___init__};
static PyObject *__pyx_pw_10cPyparsing_18_lazyclassproperty_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fn = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_fn,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7764, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fn)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7764, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 7764, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 7764, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_fn = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 7764, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._lazyclassproperty.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18_lazyclassproperty___init__(__pyx_self, __pyx_v_self, __pyx_v_fn);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18_lazyclassproperty___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fn) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":7765
 * class _lazyclassproperty(object):
 *     def __init__(self, fn):
 *         self.fn = fn             # <<<<<<<<<<<<<<
 *         self.__doc__ = fn.__doc__
 *         self.__name__ = fn.__name__
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_fn, __pyx_v_fn) < 0) __PYX_ERR(0, 7765, __pyx_L1_error)

  /* "cPyparsing.pyx":7766
 *     def __init__(self, fn):
 *         self.fn = fn
 *         self.__doc__ = fn.__doc__             # <<<<<<<<<<<<<<
 *         self.__name__ = fn.__name__
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_fn, __pyx_n_s_doc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_doc, __pyx_t_1) < 0) __PYX_ERR(0, 7766, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7767
 *         self.fn = fn
 *         self.__doc__ = fn.__doc__
 *         self.__name__ = fn.__name__             # <<<<<<<<<<<<<<
 * 
 *     def __get__(self, obj, cls):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_fn, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_t_1) < 0) __PYX_ERR(0, 7767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7764
 * 
 * class _lazyclassproperty(object):
 *     def __init__(self, fn):             # <<<<<<<<<<<<<<
 *         self.fn = fn
 *         self.__doc__ = fn.__doc__
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._lazyclassproperty.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7769
 *         self.__name__ = fn.__name__
 * 
 *     def __get__(self, obj, cls):             # <<<<<<<<<<<<<<
 *         if cls is None:
 *             cls = type(obj)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18_lazyclassproperty_3__get__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_18_lazyclassproperty_2__get__, "_lazyclassproperty.__get__(self, obj, cls)");
static PyMethodDef __pyx_mdef_10cPyparsing_18_lazyclassproperty_3__get__ = {"__get__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_18_lazyclassproperty_3__get__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_18_lazyclassproperty_2__get__};
static PyObject *__pyx_pw_10cPyparsing_18_lazyclassproperty_3__get__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_obj = 0;
  PyObject *__pyx_v_cls = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_obj,&__pyx_n_s_cls,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7769, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7769, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__get__", 1, 3, 3, 1); __PYX_ERR(0, 7769, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7769, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__get__", 1, 3, 3, 2); __PYX_ERR(0, 7769, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__get__") < 0)) __PYX_ERR(0, 7769, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_obj = values[1];
    __pyx_v_cls = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__get__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 7769, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing._lazyclassproperty.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18_lazyclassproperty_2__get__(__pyx_self, __pyx_v_self, __pyx_v_obj, __pyx_v_cls);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_18_lazyclassproperty_7__get___2generator46(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":7772
 *         if cls is None:
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])             # <<<<<<<<<<<<<<
 *                                               for superclass in cls.__mro__[1:]):
 *             cls._intern = {}
 */

static PyObject *__pyx_pf_10cPyparsing_18_lazyclassproperty_7__get___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_75_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 7772, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_18_lazyclassproperty_7__get___2generator46, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_lazyclassproperty___get___local, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 7772, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing._lazyclassproperty.__get__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_18_lazyclassproperty_7__get___2generator46(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 7772, __pyx_L1_error)

  /* "cPyparsing.pyx":7773
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])
 *                                               for superclass in cls.__mro__[1:]):             # <<<<<<<<<<<<<<
 *             cls._intern = {}
 *         attrname = self.fn.__name__
 */
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 7773, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7773, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7773, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 7773, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7773, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7773, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 7773, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7773, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 7773, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_superclass);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_superclass, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":7772
 *         if cls is None:
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])             # <<<<<<<<<<<<<<
 *                                               for superclass in cls.__mro__[1:]):
 *             cls._intern = {}
 */
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_cls)) { __Pyx_RaiseClosureNameError("cls"); __PYX_ERR(0, 7772, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_cls, __pyx_n_s_intern); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_GetAttr3(__pyx_cur_scope->__pyx_v_superclass, __pyx_n_u_intern, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = (__pyx_t_4 == __pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_7) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }

    /* "cPyparsing.pyx":7773
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])
 *                                               for superclass in cls.__mro__[1:]):             # <<<<<<<<<<<<<<
 *             cls._intern = {}
 *         attrname = self.fn.__name__
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {

    /* "cPyparsing.pyx":7772
 *         if cls is None:
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])             # <<<<<<<<<<<<<<
 *                                               for superclass in cls.__mro__[1:]):
 *             cls._intern = {}
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7769
 *         self.__name__ = fn.__name__
 * 
 *     def __get__(self, obj, cls):             # <<<<<<<<<<<<<<
 *         if cls is None:
 *             cls = type(obj)
 */

static PyObject *__pyx_pf_10cPyparsing_18_lazyclassproperty_2__get__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_cls) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *__pyx_cur_scope;
  PyObject *__pyx_v_attrname = NULL;
  PyObject *__pyx_gb_10cPyparsing_18_lazyclassproperty_7__get___2generator46 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_74___get__(__pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 7769, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_cls = __pyx_v_cls;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_cls);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_cls);

  /* "cPyparsing.pyx":7770
 * 
 *     def __get__(self, obj, cls):
 *         if cls is None:             # <<<<<<<<<<<<<<
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_cls == Py_None);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":7771
 *     def __get__(self, obj, cls):
 *         if cls is None:
 *             cls = type(obj)             # <<<<<<<<<<<<<<
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])
 *                                               for superclass in cls.__mro__[1:]):
 */
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_obj)));
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_cls);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_cls, ((PyObject *)Py_TYPE(__pyx_v_obj)));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_v_obj)));

    /* "cPyparsing.pyx":7770
 * 
 *     def __get__(self, obj, cls):
 *         if cls is None:             # <<<<<<<<<<<<<<
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])
 */
  }

  /* "cPyparsing.pyx":7772
 *         if cls is None:
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])             # <<<<<<<<<<<<<<
 *                                               for superclass in cls.__mro__[1:]):
 *             cls._intern = {}
 */
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_cls;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_HasAttr(__pyx_t_2, __pyx_n_u_intern); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 7772, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (!__pyx_t_3);
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L5_bool_binop_done;
  }

  /* "cPyparsing.pyx":7773
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])
 *                                               for superclass in cls.__mro__[1:]):             # <<<<<<<<<<<<<<
 *             cls._intern = {}
 *         attrname = self.fn.__name__
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_cls, __pyx_n_s_mro); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_t_2, 1, 0, NULL, NULL, &__pyx_slice_, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7772
 *         if cls is None:
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])             # <<<<<<<<<<<<<<
 *                                               for superclass in cls.__mro__[1:]):
 *             cls._intern = {}
 */
  __pyx_t_2 = __pyx_pf_10cPyparsing_18_lazyclassproperty_7__get___genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_Generator_Next(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 7772, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = __pyx_t_4;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":7774
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])
 *                                               for superclass in cls.__mro__[1:]):
 *             cls._intern = {}             # <<<<<<<<<<<<<<
 *         attrname = self.fn.__name__
 *         if attrname not in cls._intern:
 */
    __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7774, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_cls, __pyx_n_s_intern, __pyx_t_5) < 0) __PYX_ERR(0, 7774, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":7772
 *         if cls is None:
 *             cls = type(obj)
 *         if not hasattr(cls, '_intern') or any(cls._intern is getattr(superclass, '_intern', [])             # <<<<<<<<<<<<<<
 *                                               for superclass in cls.__mro__[1:]):
 *             cls._intern = {}
 */
  }

  /* "cPyparsing.pyx":7775
 *                                               for superclass in cls.__mro__[1:]):
 *             cls._intern = {}
 *         attrname = self.fn.__name__             # <<<<<<<<<<<<<<
 *         if attrname not in cls._intern:
 *             cls._intern[attrname] = self.fn(cls)
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_attrname = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7776
 *             cls._intern = {}
 *         attrname = self.fn.__name__
 *         if attrname not in cls._intern:             # <<<<<<<<<<<<<<
 *             cls._intern[attrname] = self.fn(cls)
 *         return cls._intern[attrname]
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_cls, __pyx_n_s_intern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_attrname, __pyx_t_2, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 7776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":7777
 *         attrname = self.fn.__name__
 *         if attrname not in cls._intern:
 *             cls._intern[attrname] = self.fn(cls)             # <<<<<<<<<<<<<<
 *         return cls._intern[attrname]
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_cls};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7777, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_cls, __pyx_n_s_intern); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (unlikely((PyObject_SetItem(__pyx_t_5, __pyx_v_attrname, __pyx_t_2) < 0))) __PYX_ERR(0, 7777, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":7776
 *             cls._intern = {}
 *         attrname = self.fn.__name__
 *         if attrname not in cls._intern:             # <<<<<<<<<<<<<<
 *             cls._intern[attrname] = self.fn(cls)
 *         return cls._intern[attrname]
 */
  }

  /* "cPyparsing.pyx":7778
 *         if attrname not in cls._intern:
 *             cls._intern[attrname] = self.fn(cls)
 *         return cls._intern[attrname]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_cls, __pyx_n_s_intern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_attrname); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7769
 *         self.__name__ = fn.__name__
 * 
 *     def __get__(self, obj, cls):             # <<<<<<<<<<<<<<
 *         if cls is None:
 *             cls = type(obj)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing._lazyclassproperty.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_attrname);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_18_lazyclassproperty_7__get___2generator46);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7797
 *     _ranges = []
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _get_chars_for_ranges(cls):
 *         ret = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_1_get_chars_for_ranges(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_11unicode_set__get_chars_for_ranges, "unicode_set._get_chars_for_ranges(cls)");
static PyMethodDef __pyx_mdef_10cPyparsing_11unicode_set_1_get_chars_for_ranges = {"_get_chars_for_ranges", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11unicode_set_1_get_chars_for_ranges, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_11unicode_set__get_chars_for_ranges};
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_1_get_chars_for_ranges(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_chars_for_ranges (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7797, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_chars_for_ranges") < 0)) __PYX_ERR(0, 7797, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_cls = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_chars_for_ranges", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7797, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.unicode_set._get_chars_for_ranges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11unicode_set__get_chars_for_ranges(__pyx_self, __pyx_v_cls);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11unicode_set__get_chars_for_ranges(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_cc = NULL;
  PyObject *__pyx_v_rr = NULL;
  PyObject *__pyx_9genexpr62__pyx_v_c = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_chars_for_ranges", 1);

  /* "cPyparsing.pyx":7799
 *     @classmethod
 *     def _get_chars_for_ranges(cls):
 *         ret = []             # <<<<<<<<<<<<<<
 *         for cc in cls.__mro__:
 *             if cc is unicode_set:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ret = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7800
 *     def _get_chars_for_ranges(cls):
 *         ret = []
 *         for cc in cls.__mro__:             # <<<<<<<<<<<<<<
 *             if cc is unicode_set:
 *                 break
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_mro); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7800, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7800, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7800, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 7800, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7800, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7800, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 7800, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7800, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 7800, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_cc, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":7801
 *         ret = []
 *         for cc in cls.__mro__:
 *             if cc is unicode_set:             # <<<<<<<<<<<<<<
 *                 break
 *             for rr in cc._ranges:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__pyx_v_cc == __pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":7802
 *         for cc in cls.__mro__:
 *             if cc is unicode_set:
 *                 break             # <<<<<<<<<<<<<<
 *             for rr in cc._ranges:
 *                 ret.extend(range(rr[0], rr[-1] + 1))
 */
      goto __pyx_L4_break;

      /* "cPyparsing.pyx":7801
 *         ret = []
 *         for cc in cls.__mro__:
 *             if cc is unicode_set:             # <<<<<<<<<<<<<<
 *                 break
 *             for rr in cc._ranges:
 */
    }

    /* "cPyparsing.pyx":7803
 *             if cc is unicode_set:
 *                 break
 *             for rr in cc._ranges:             # <<<<<<<<<<<<<<
 *                 ret.extend(range(rr[0], rr[-1] + 1))
 *         return [unichr(c) for c in sorted(set(ret))]
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cc, __pyx_n_s_ranges); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_6 = __pyx_t_1; __Pyx_INCREF(__pyx_t_6);
      __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7803, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_6))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7803, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 7803, __pyx_L1_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7803, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7803, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 7803, __pyx_L1_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7803, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_8(__pyx_t_6);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 7803, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_v_rr, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":7804
 *                 break
 *             for rr in cc._ranges:
 *                 ret.extend(range(rr[0], rr[-1] + 1))             # <<<<<<<<<<<<<<
 *         return [unichr(c) for c in sorted(set(ret))]
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_range); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_rr, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_GetItemInt(__pyx_v_rr, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 7804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyInt_AddObjC(__pyx_t_11, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 7804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = NULL;
      __pyx_t_13 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_13 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_10, __pyx_t_12};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_13, 2+__pyx_t_13);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7804, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __pyx_t_14 = __Pyx_PyList_Extend(__pyx_v_ret, __pyx_t_1); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 7804, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":7803
 *             if cc is unicode_set:
 *                 break
 *             for rr in cc._ranges:             # <<<<<<<<<<<<<<
 *                 ret.extend(range(rr[0], rr[-1] + 1))
 *         return [unichr(c) for c in sorted(set(ret))]
 */
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":7800
 *     def _get_chars_for_ranges(cls):
 *         ret = []
 *         for cc in cls.__mro__:             # <<<<<<<<<<<<<<
 *             if cc is unicode_set:
 *                 break
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L9_for_end;
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L9_for_end;
  __pyx_L9_for_end:;

  /* "cPyparsing.pyx":7805
 *             for rr in cc._ranges:
 *                 ret.extend(range(rr[0], rr[-1] + 1))
 *         return [unichr(c) for c in sorted(set(ret))]             # <<<<<<<<<<<<<<
 * 
 *     @_lazyclassproperty
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7805, __pyx_L12_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PySet_New(__pyx_v_ret); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7805, __pyx_L12_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7805, __pyx_L12_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = ((PyObject*)__pyx_t_9);
    __pyx_t_9 = 0;
    __pyx_t_14 = PyList_Sort(__pyx_t_6); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 7805, __pyx_L12_error)
    __pyx_t_9 = __pyx_t_6; __Pyx_INCREF(__pyx_t_9);
    __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_9);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7805, __pyx_L12_error)
        #endif
        if (__pyx_t_3 >= __pyx_temp) break;
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_9, __pyx_t_3); __Pyx_INCREF(__pyx_t_6); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 7805, __pyx_L12_error)
      #else
      __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_9, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7805, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_XDECREF_SET(__pyx_9genexpr62__pyx_v_c, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_unichr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7805, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_12 = NULL;
      __pyx_t_13 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_13 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_9genexpr62__pyx_v_c};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7805, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 7805, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_9genexpr62__pyx_v_c); __pyx_9genexpr62__pyx_v_c = 0;
    goto __pyx_L16_exit_scope;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_9genexpr62__pyx_v_c); __pyx_9genexpr62__pyx_v_c = 0;
    goto __pyx_L1_error;
    __pyx_L16_exit_scope:;
  } /* exit inner scope */
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7797
 *     _ranges = []
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _get_chars_for_ranges(cls):
 *         ret = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.unicode_set._get_chars_for_ranges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_cc);
  __Pyx_XDECREF(__pyx_v_rr);
  __Pyx_XDECREF(__pyx_9genexpr62__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7807
 *         return [unichr(c) for c in sorted(set(ret))]
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def printables(cls):
 *         "all non-whitespace characters in this range"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_3printables(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_11unicode_set_2printables, "unicode_set.printables(cls)\nall non-whitespace characters in this range");
static PyMethodDef __pyx_mdef_10cPyparsing_11unicode_set_3printables = {"printables", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11unicode_set_3printables, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_11unicode_set_2printables};
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_3printables(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("printables (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7807, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "printables") < 0)) __PYX_ERR(0, 7807, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_cls = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("printables", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7807, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.unicode_set.printables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11unicode_set_2printables(__pyx_self, __pyx_v_cls);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11unicode_set_2printables(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("printables", 1);

  /* "cPyparsing.pyx":7810
 *     def printables(cls):
 *         "all non-whitespace characters in this range"
 *         return u''.join(filterfalse(unicode.isspace, cls._get_chars_for_ranges()))             # <<<<<<<<<<<<<<
 * 
 *     @_lazyclassproperty
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_filterfalse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_isspace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_get_chars_for_ranges); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7810, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7810, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7807
 *         return [unichr(c) for c in sorted(set(ret))]
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def printables(cls):
 *         "all non-whitespace characters in this range"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.unicode_set.printables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7812
 *         return u''.join(filterfalse(unicode.isspace, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def alphas(cls):
 *         "all alphabetic characters in this range"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_5alphas(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_11unicode_set_4alphas, "unicode_set.alphas(cls)\nall alphabetic characters in this range");
static PyMethodDef __pyx_mdef_10cPyparsing_11unicode_set_5alphas = {"alphas", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11unicode_set_5alphas, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_11unicode_set_4alphas};
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_5alphas(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("alphas (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7812, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "alphas") < 0)) __PYX_ERR(0, 7812, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_cls = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("alphas", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7812, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.unicode_set.alphas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11unicode_set_4alphas(__pyx_self, __pyx_v_cls);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11unicode_set_4alphas(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("alphas", 1);

  /* "cPyparsing.pyx":7815
 *     def alphas(cls):
 *         "all alphabetic characters in this range"
 *         return u''.join(filter(unicode.isalpha, cls._get_chars_for_ranges()))             # <<<<<<<<<<<<<<
 * 
 *     @_lazyclassproperty
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_isalpha); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_get_chars_for_ranges); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7815, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 7815, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(0, 7815, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_filter, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7812
 *         return u''.join(filterfalse(unicode.isspace, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def alphas(cls):
 *         "all alphabetic characters in this range"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.unicode_set.alphas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7817
 *         return u''.join(filter(unicode.isalpha, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def nums(cls):
 *         "all numeric digit characters in this range"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_7nums(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_11unicode_set_6nums, "unicode_set.nums(cls)\nall numeric digit characters in this range");
static PyMethodDef __pyx_mdef_10cPyparsing_11unicode_set_7nums = {"nums", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11unicode_set_7nums, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_11unicode_set_6nums};
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_7nums(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nums (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7817, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nums") < 0)) __PYX_ERR(0, 7817, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_cls = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nums", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7817, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.unicode_set.nums", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11unicode_set_6nums(__pyx_self, __pyx_v_cls);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11unicode_set_6nums(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nums", 1);

  /* "cPyparsing.pyx":7820
 *     def nums(cls):
 *         "all numeric digit characters in this range"
 *         return u''.join(filter(unicode.isdigit, cls._get_chars_for_ranges()))             # <<<<<<<<<<<<<<
 * 
 *     @_lazyclassproperty
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_isdigit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_get_chars_for_ranges); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 7820, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(0, 7820, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_filter, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7817
 *         return u''.join(filter(unicode.isalpha, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def nums(cls):
 *         "all numeric digit characters in this range"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.unicode_set.nums", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7822
 *         return u''.join(filter(unicode.isdigit, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def alphanums(cls):
 *         "all alphanumeric characters in this range"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_9alphanums(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_11unicode_set_8alphanums, "unicode_set.alphanums(cls)\nall alphanumeric characters in this range");
static PyMethodDef __pyx_mdef_10cPyparsing_11unicode_set_9alphanums = {"alphanums", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_11unicode_set_9alphanums, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_11unicode_set_8alphanums};
static PyObject *__pyx_pw_10cPyparsing_11unicode_set_9alphanums(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("alphanums (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7822, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "alphanums") < 0)) __PYX_ERR(0, 7822, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_cls = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("alphanums", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7822, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.unicode_set.alphanums", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11unicode_set_8alphanums(__pyx_self, __pyx_v_cls);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11unicode_set_8alphanums(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("alphanums", 1);

  /* "cPyparsing.pyx":7825
 *     def alphanums(cls):
 *         "all alphanumeric characters in this range"
 *         return cls.alphas + cls.nums             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_alphas); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_nums); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7822
 *         return u''.join(filter(unicode.isdigit, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def alphanums(cls):
 *         "all alphanumeric characters in this range"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.unicode_set.alphanums", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7950
 *         """
 * 
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             self._save_context = {}
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23reset_pyparsing_context___init__, "reset_pyparsing_context.__init__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_23reset_pyparsing_context_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23reset_pyparsing_context_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23reset_pyparsing_context___init__};
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7950, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 7950, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7950, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23reset_pyparsing_context___init__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "cPyparsing.pyx":7951
 * 
 *         def __init__(self):
 *             self._save_context = {}             # <<<<<<<<<<<<<<
 * 
 *         def save(self):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_save_context, __pyx_t_1) < 0) __PYX_ERR(0, 7951, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7950
 *         """
 * 
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             self._save_context = {}
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7953
 *             self._save_context = {}
 * 
 *         def save(self):             # <<<<<<<<<<<<<<
 *             self._save_context["default_whitespace"] = ParserElement.DEFAULT_WHITE_CHARS
 *             self._save_context["default_keyword_chars"] = Keyword.DEFAULT_KEYWORD_CHARS
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_3save(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23reset_pyparsing_context_2save, "reset_pyparsing_context.save(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_23reset_pyparsing_context_3save = {"save", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23reset_pyparsing_context_3save, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23reset_pyparsing_context_2save};
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_3save(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("save (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7953, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "save") < 0)) __PYX_ERR(0, 7953, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("save", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7953, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.save", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23reset_pyparsing_context_2save(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context_2save(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_9genexpr63__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("save", 1);

  /* "cPyparsing.pyx":7954
 * 
 *         def save(self):
 *             self._save_context["default_whitespace"] = ParserElement.DEFAULT_WHITE_CHARS             # <<<<<<<<<<<<<<
 *             self._save_context["default_keyword_chars"] = Keyword.DEFAULT_KEYWORD_CHARS
 *             self._save_context[
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_n_u_default_whitespace, __pyx_t_2) < 0))) __PYX_ERR(0, 7954, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7955
 *         def save(self):
 *             self._save_context["default_whitespace"] = ParserElement.DEFAULT_WHITE_CHARS
 *             self._save_context["default_keyword_chars"] = Keyword.DEFAULT_KEYWORD_CHARS             # <<<<<<<<<<<<<<
 *             self._save_context[
 *                 "literal_string_class"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DEFAULT_KEYWORD_CHARS); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_n_u_default_keyword_chars, __pyx_t_1) < 0))) __PYX_ERR(0, 7955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7958
 *             self._save_context[
 *                 "literal_string_class"
 *             ] = ParserElement._literalStringClass             # <<<<<<<<<<<<<<
 *             self._save_context["packrat_enabled"] = ParserElement._packratEnabled
 *             self._save_context["packrat_parse"] = ParserElement._parse
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7956
 *             self._save_context["default_whitespace"] = ParserElement.DEFAULT_WHITE_CHARS
 *             self._save_context["default_keyword_chars"] = Keyword.DEFAULT_KEYWORD_CHARS
 *             self._save_context[             # <<<<<<<<<<<<<<
 *                 "literal_string_class"
 *             ] = ParserElement._literalStringClass
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_n_u_literal_string_class, __pyx_t_2) < 0))) __PYX_ERR(0, 7956, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7959
 *                 "literal_string_class"
 *             ] = ParserElement._literalStringClass
 *             self._save_context["packrat_enabled"] = ParserElement._packratEnabled             # <<<<<<<<<<<<<<
 *             self._save_context["packrat_parse"] = ParserElement._parse
 *             self._save_context["__diag__"] = {
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_packratEnabled); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_n_u_packrat_enabled, __pyx_t_1) < 0))) __PYX_ERR(0, 7959, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7960
 *             ] = ParserElement._literalStringClass
 *             self._save_context["packrat_enabled"] = ParserElement._packratEnabled
 *             self._save_context["packrat_parse"] = ParserElement._parse             # <<<<<<<<<<<<<<
 *             self._save_context["__diag__"] = {
 *                 name: getattr(__diag__, name) for name in __diag__._all_names
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_n_u_packrat_parse, __pyx_t_2) < 0))) __PYX_ERR(0, 7960, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7961
 *             self._save_context["packrat_enabled"] = ParserElement._packratEnabled
 *             self._save_context["packrat_parse"] = ParserElement._parse
 *             self._save_context["__diag__"] = {             # <<<<<<<<<<<<<<
 *                 name: getattr(__diag__, name) for name in __diag__._all_names
 *             }
 */
  { /* enter inner scope */
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7961, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "cPyparsing.pyx":7962
 *             self._save_context["packrat_parse"] = ParserElement._parse
 *             self._save_context["__diag__"] = {
 *                 name: getattr(__diag__, name) for name in __diag__._all_names             # <<<<<<<<<<<<<<
 *             }
 *             self._save_context["__compat__"] = {
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7962, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_all_names); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7962, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_1 = __pyx_t_3; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7962, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7962, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7962, __pyx_L5_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 7962, __pyx_L5_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7962, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 7962, __pyx_L5_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 7962, __pyx_L5_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7962, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_5(__pyx_t_1);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 7962, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr63__pyx_v_name, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_diag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7962, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_GetAttr(__pyx_t_3, __pyx_9genexpr63__pyx_v_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7962, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(PyDict_SetItem(__pyx_t_2, (PyObject*)__pyx_9genexpr63__pyx_v_name, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 7962, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_9genexpr63__pyx_v_name); __pyx_9genexpr63__pyx_v_name = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_9genexpr63__pyx_v_name); __pyx_9genexpr63__pyx_v_name = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */

  /* "cPyparsing.pyx":7961
 *             self._save_context["packrat_enabled"] = ParserElement._packratEnabled
 *             self._save_context["packrat_parse"] = ParserElement._parse
 *             self._save_context["__diag__"] = {             # <<<<<<<<<<<<<<
 *                 name: getattr(__diag__, name) for name in __diag__._all_names
 *             }
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_n_u_diag, __pyx_t_2) < 0))) __PYX_ERR(0, 7961, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7965
 *             }
 *             self._save_context["__compat__"] = {
 *                 "collect_all_And_tokens": __compat__.collect_all_And_tokens             # <<<<<<<<<<<<<<
 *             }
 *             return self
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_compat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_collect_all_And_tokens); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_collect_all_And_tokens, __pyx_t_6) < 0) __PYX_ERR(0, 7965, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cPyparsing.pyx":7964
 *                 name: getattr(__diag__, name) for name in __diag__._all_names
 *             }
 *             self._save_context["__compat__"] = {             # <<<<<<<<<<<<<<
 *                 "collect_all_And_tokens": __compat__.collect_all_And_tokens
 *             }
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (unlikely((PyObject_SetItem(__pyx_t_6, __pyx_n_u_compat, __pyx_t_2) < 0))) __PYX_ERR(0, 7964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7967
 *                 "collect_all_And_tokens": __compat__.collect_all_And_tokens
 *             }
 *             return self             # <<<<<<<<<<<<<<
 * 
 *         def restore(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7953
 *             self._save_context = {}
 * 
 *         def save(self):             # <<<<<<<<<<<<<<
 *             self._save_context["default_whitespace"] = ParserElement.DEFAULT_WHITE_CHARS
 *             self._save_context["default_keyword_chars"] = Keyword.DEFAULT_KEYWORD_CHARS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.save", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_9genexpr63__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7969
 *             return self
 * 
 *         def restore(self):             # <<<<<<<<<<<<<<
 *             # reset pyparsing global state
 *             if (
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_5restore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23reset_pyparsing_context_4restore, "reset_pyparsing_context.restore(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_23reset_pyparsing_context_5restore = {"restore", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23reset_pyparsing_context_5restore, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23reset_pyparsing_context_4restore};
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_5restore(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("restore (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7969, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "restore") < 0)) __PYX_ERR(0, 7969, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("restore", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7969, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.restore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23reset_pyparsing_context_4restore(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context_4restore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("restore", 1);

  /* "cPyparsing.pyx":7972
 *             # reset pyparsing global state
 *             if (
 *                 ParserElement.DEFAULT_WHITE_CHARS             # <<<<<<<<<<<<<<
 *                 != self._save_context["default_whitespace"]
 *             ):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7973
 *             if (
 *                 ParserElement.DEFAULT_WHITE_CHARS
 *                 != self._save_context["default_whitespace"]             # <<<<<<<<<<<<<<
 *             ):
 *                 ParserElement.setDefaultWhitespaceChars(
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_u_default_whitespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7973, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 7973, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7971
 *         def restore(self):
 *             # reset pyparsing global state
 *             if (             # <<<<<<<<<<<<<<
 *                 ParserElement.DEFAULT_WHITE_CHARS
 *                 != self._save_context["default_whitespace"]
 */
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":7975
 *                 != self._save_context["default_whitespace"]
 *             ):
 *                 ParserElement.setDefaultWhitespaceChars(             # <<<<<<<<<<<<<<
 *                     self._save_context["default_whitespace"]
 *                 )
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setDefaultWhitespaceChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":7976
 *             ):
 *                 ParserElement.setDefaultWhitespaceChars(
 *                     self._save_context["default_whitespace"]             # <<<<<<<<<<<<<<
 *                 )
 *             Keyword.DEFAULT_KEYWORD_CHARS = self._save_context["default_keyword_chars"]
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_u_default_whitespace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7975, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":7971
 *         def restore(self):
 *             # reset pyparsing global state
 *             if (             # <<<<<<<<<<<<<<
 *                 ParserElement.DEFAULT_WHITE_CHARS
 *                 != self._save_context["default_whitespace"]
 */
  }

  /* "cPyparsing.pyx":7978
 *                     self._save_context["default_whitespace"]
 *                 )
 *             Keyword.DEFAULT_KEYWORD_CHARS = self._save_context["default_keyword_chars"]             # <<<<<<<<<<<<<<
 *             ParserElement.inlineLiteralsUsing(
 *                 self._save_context["literal_string_class"]
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_u_default_keyword_chars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_KEYWORD_CHARS, __pyx_t_2) < 0) __PYX_ERR(0, 7978, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7979
 *                 )
 *             Keyword.DEFAULT_KEYWORD_CHARS = self._save_context["default_keyword_chars"]
 *             ParserElement.inlineLiteralsUsing(             # <<<<<<<<<<<<<<
 *                 self._save_context["literal_string_class"]
 *             )
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_inlineLiteralsUsing); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7980
 *             Keyword.DEFAULT_KEYWORD_CHARS = self._save_context["default_keyword_chars"]
 *             ParserElement.inlineLiteralsUsing(
 *                 self._save_context["literal_string_class"]             # <<<<<<<<<<<<<<
 *             )
 *             for name, value in self._save_context["__diag__"].items():
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_u_literal_string_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7982
 *                 self._save_context["literal_string_class"]
 *             )
 *             for name, value in self._save_context["__diag__"].items():             # <<<<<<<<<<<<<<
 *                 setattr(__diag__, name, value)
 *             ParserElement._packratEnabled = self._save_context["packrat_enabled"]
 */
  __pyx_t_7 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_5, __pyx_n_u_diag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 7982, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_t_3, 0, __pyx_n_s_items, (&__pyx_t_8), (&__pyx_t_6)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 7982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_8, &__pyx_t_7, &__pyx_t_5, &__pyx_t_3, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 7982, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":7983
 *             )
 *             for name, value in self._save_context["__diag__"].items():
 *                 setattr(__diag__, name, value)             # <<<<<<<<<<<<<<
 *             ParserElement._packratEnabled = self._save_context["packrat_enabled"]
 *             ParserElement._parse = self._save_context["packrat_parse"]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_diag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7983, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = PyObject_SetAttr(__pyx_t_3, __pyx_v_name, __pyx_v_value); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 7983, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7984
 *             for name, value in self._save_context["__diag__"].items():
 *                 setattr(__diag__, name, value)
 *             ParserElement._packratEnabled = self._save_context["packrat_enabled"]             # <<<<<<<<<<<<<<
 *             ParserElement._parse = self._save_context["packrat_parse"]
 *             __compat__.collect_all_And_tokens = self._save_context["__compat__"]
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_u_packrat_enabled); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_packratEnabled, __pyx_t_3) < 0) __PYX_ERR(0, 7984, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7985
 *                 setattr(__diag__, name, value)
 *             ParserElement._packratEnabled = self._save_context["packrat_enabled"]
 *             ParserElement._parse = self._save_context["packrat_parse"]             # <<<<<<<<<<<<<<
 *             __compat__.collect_all_And_tokens = self._save_context["__compat__"]
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_u_packrat_parse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_parse, __pyx_t_3) < 0) __PYX_ERR(0, 7985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7986
 *             ParserElement._packratEnabled = self._save_context["packrat_enabled"]
 *             ParserElement._parse = self._save_context["packrat_parse"]
 *             __compat__.collect_all_And_tokens = self._save_context["__compat__"]             # <<<<<<<<<<<<<<
 * 
 *         def __enter__(self):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_u_compat); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_compat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_collect_all_And_tokens, __pyx_t_3) < 0) __PYX_ERR(0, 7986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":7969
 *             return self
 * 
 *         def restore(self):             # <<<<<<<<<<<<<<
 *             # reset pyparsing global state
 *             if (
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.restore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7988
 *             __compat__.collect_all_And_tokens = self._save_context["__compat__"]
 * 
 *         def __enter__(self):             # <<<<<<<<<<<<<<
 *             return self.save()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_7__enter__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23reset_pyparsing_context_6__enter__, "reset_pyparsing_context.__enter__(self)");
static PyMethodDef __pyx_mdef_10cPyparsing_23reset_pyparsing_context_7__enter__ = {"__enter__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23reset_pyparsing_context_7__enter__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23reset_pyparsing_context_6__enter__};
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_7__enter__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__enter__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7988, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__enter__") < 0)) __PYX_ERR(0, 7988, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__enter__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7988, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.__enter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23reset_pyparsing_context_6__enter__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context_6__enter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__enter__", 1);

  /* "cPyparsing.pyx":7989
 * 
 *         def __enter__(self):
 *             return self.save()             # <<<<<<<<<<<<<<
 * 
 *         def __exit__(self, *args):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_save); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7988
 *             __compat__.collect_all_And_tokens = self._save_context["__compat__"]
 * 
 *         def __enter__(self):             # <<<<<<<<<<<<<<
 *             return self.save()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.__enter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7991
 *             return self.save()
 * 
 *         def __exit__(self, *args):             # <<<<<<<<<<<<<<
 *             return self.restore()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_9__exit__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23reset_pyparsing_context_8__exit__, "reset_pyparsing_context.__exit__(self, *args)");
static PyMethodDef __pyx_mdef_10cPyparsing_23reset_pyparsing_context_9__exit__ = {"__exit__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23reset_pyparsing_context_9__exit__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23reset_pyparsing_context_8__exit__};
static PyObject *__pyx_pw_10cPyparsing_23reset_pyparsing_context_9__exit__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__exit__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7991, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "__exit__") < 0)) __PYX_ERR(0, 7991, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__exit__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 7991, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23reset_pyparsing_context_8__exit__(__pyx_self, __pyx_v_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23reset_pyparsing_context_8__exit__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__exit__", 1);

  /* "cPyparsing.pyx":7992
 * 
 *         def __exit__(self, *args):
 *             return self.restore()             # <<<<<<<<<<<<<<
 * 
 *     class TestParseResultsAsserts:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_restore); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":7991
 *             return self.save()
 * 
 *         def __exit__(self, *args):             # <<<<<<<<<<<<<<
 *             return self.restore()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.reset_pyparsing_context.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":7998
 *         A mixin class to add parse results assertion methods to normal unittest.TestCase classes.
 *         """
 *         def assertParseResultsEquals(             # <<<<<<<<<<<<<<
 *             self, result, expected_list=None, expected_dict=None, msg=None
 *         ):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_1assertParseResultsEquals(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23TestParseResultsAsserts_assertParseResultsEquals, "TestParseResultsAsserts.assertParseResultsEquals(self, result, expected_list=None, expected_dict=None, msg=None)\n\n            Unit test assertion to compare a ParseResults object with an optional expected_list,\n            and compare any defined results names with an optional expected_dict.\n            ");
static PyMethodDef __pyx_mdef_10cPyparsing_23TestParseResultsAsserts_1assertParseResultsEquals = {"assertParseResultsEquals", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23TestParseResultsAsserts_1assertParseResultsEquals, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23TestParseResultsAsserts_assertParseResultsEquals};
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_1assertParseResultsEquals(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_expected_list = 0;
  PyObject *__pyx_v_expected_dict = 0;
  PyObject *__pyx_v_msg = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("assertParseResultsEquals (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_result,&__pyx_n_s_expected_list,&__pyx_n_s_expected_dict,&__pyx_n_s_msg,0};

    /* "cPyparsing.pyx":7999
 *         """
 *         def assertParseResultsEquals(
 *             self, result, expected_list=None, expected_dict=None, msg=None             # <<<<<<<<<<<<<<
 *         ):
 *             """
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7998, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_result)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7998, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("assertParseResultsEquals", 0, 2, 5, 1); __PYX_ERR(0, 7998, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expected_list);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7998, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expected_dict);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7998, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_msg);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7998, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "assertParseResultsEquals") < 0)) __PYX_ERR(0, 7998, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_result = values[1];
    __pyx_v_expected_list = values[2];
    __pyx_v_expected_dict = values[3];
    __pyx_v_msg = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("assertParseResultsEquals", 0, 2, 5, __pyx_nargs); __PYX_ERR(0, 7998, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertParseResultsEquals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23TestParseResultsAsserts_assertParseResultsEquals(__pyx_self, __pyx_v_self, __pyx_v_result, __pyx_v_expected_list, __pyx_v_expected_dict, __pyx_v_msg);

  /* "cPyparsing.pyx":7998
 *         A mixin class to add parse results assertion methods to normal unittest.TestCase classes.
 *         """
 *         def assertParseResultsEquals(             # <<<<<<<<<<<<<<
 *             self, result, expected_list=None, expected_dict=None, msg=None
 *         ):
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_assertParseResultsEquals(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_result, PyObject *__pyx_v_expected_list, PyObject *__pyx_v_expected_dict, PyObject *__pyx_v_msg) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assertParseResultsEquals", 1);

  /* "cPyparsing.pyx":8005
 *             and compare any defined results names with an optional expected_dict.
 *             """
 *             if expected_list is not None:             # <<<<<<<<<<<<<<
 *                 self.assertEqual(expected_list, result.asList(), msg=msg)
 *             if expected_dict is not None:
 */
  __pyx_t_1 = (__pyx_v_expected_list != Py_None);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":8006
 *             """
 *             if expected_list is not None:
 *                 self.assertEqual(expected_list, result.asList(), msg=msg)             # <<<<<<<<<<<<<<
 *             if expected_dict is not None:
 *                 self.assertEqual(expected_dict, result.asDict(), msg=msg)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_assertEqual); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_asList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8006, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_expected_list);
    __Pyx_GIVEREF(__pyx_v_expected_list);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_expected_list)) __PYX_ERR(0, 8006, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3)) __PYX_ERR(0, 8006, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 8006, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 8006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":8005
 *             and compare any defined results names with an optional expected_dict.
 *             """
 *             if expected_list is not None:             # <<<<<<<<<<<<<<
 *                 self.assertEqual(expected_list, result.asList(), msg=msg)
 *             if expected_dict is not None:
 */
  }

  /* "cPyparsing.pyx":8007
 *             if expected_list is not None:
 *                 self.assertEqual(expected_list, result.asList(), msg=msg)
 *             if expected_dict is not None:             # <<<<<<<<<<<<<<
 *                 self.assertEqual(expected_dict, result.asDict(), msg=msg)
 * 
 */
  __pyx_t_1 = (__pyx_v_expected_dict != Py_None);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":8008
 *                 self.assertEqual(expected_list, result.asList(), msg=msg)
 *             if expected_dict is not None:
 *                 self.assertEqual(expected_dict, result.asDict(), msg=msg)             # <<<<<<<<<<<<<<
 * 
 *         def assertParseAndCheckList(
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_assertEqual); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 8008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_asDict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8008, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_expected_dict);
    __Pyx_GIVEREF(__pyx_v_expected_dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_expected_dict)) __PYX_ERR(0, 8008, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3)) __PYX_ERR(0, 8008, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 8008, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":8007
 *             if expected_list is not None:
 *                 self.assertEqual(expected_list, result.asList(), msg=msg)
 *             if expected_dict is not None:             # <<<<<<<<<<<<<<
 *                 self.assertEqual(expected_dict, result.asDict(), msg=msg)
 * 
 */
  }

  /* "cPyparsing.pyx":7998
 *         A mixin class to add parse results assertion methods to normal unittest.TestCase classes.
 *         """
 *         def assertParseResultsEquals(             # <<<<<<<<<<<<<<
 *             self, result, expected_list=None, expected_dict=None, msg=None
 *         ):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertParseResultsEquals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":8010
 *                 self.assertEqual(expected_dict, result.asDict(), msg=msg)
 * 
 *         def assertParseAndCheckList(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_list, msg=None, verbose=True
 *         ):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_3assertParseAndCheckList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23TestParseResultsAsserts_2assertParseAndCheckList, "TestParseResultsAsserts.assertParseAndCheckList(self, expr, test_string, expected_list, msg=None, verbose=True)\n\n            Convenience wrapper assert to test a parser element and input string, and assert that\n            the resulting ParseResults.asList() is equal to the expected_list.\n            ");
static PyMethodDef __pyx_mdef_10cPyparsing_23TestParseResultsAsserts_3assertParseAndCheckList = {"assertParseAndCheckList", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23TestParseResultsAsserts_3assertParseAndCheckList, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23TestParseResultsAsserts_2assertParseAndCheckList};
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_3assertParseAndCheckList(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_test_string = 0;
  PyObject *__pyx_v_expected_list = 0;
  PyObject *__pyx_v_msg = 0;
  PyObject *__pyx_v_verbose = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("assertParseAndCheckList (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_test_string,&__pyx_n_s_expected_list,&__pyx_n_s_msg,&__pyx_n_s_verbose,0};

    /* "cPyparsing.pyx":8011
 * 
 *         def assertParseAndCheckList(
 *             self, expr, test_string, expected_list, msg=None, verbose=True             # <<<<<<<<<<<<<<
 *         ):
 *             """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8010, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8010, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("assertParseAndCheckList", 0, 4, 6, 1); __PYX_ERR(0, 8010, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_test_string)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8010, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("assertParseAndCheckList", 0, 4, 6, 2); __PYX_ERR(0, 8010, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expected_list)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8010, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("assertParseAndCheckList", 0, 4, 6, 3); __PYX_ERR(0, 8010, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_msg);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8010, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_verbose);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8010, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "assertParseAndCheckList") < 0)) __PYX_ERR(0, 8010, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_test_string = values[2];
    __pyx_v_expected_list = values[3];
    __pyx_v_msg = values[4];
    __pyx_v_verbose = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("assertParseAndCheckList", 0, 4, 6, __pyx_nargs); __PYX_ERR(0, 8010, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertParseAndCheckList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23TestParseResultsAsserts_2assertParseAndCheckList(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_test_string, __pyx_v_expected_list, __pyx_v_msg, __pyx_v_verbose);

  /* "cPyparsing.pyx":8010
 *                 self.assertEqual(expected_dict, result.asDict(), msg=msg)
 * 
 *         def assertParseAndCheckList(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_list, msg=None, verbose=True
 *         ):
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_2assertParseAndCheckList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_test_string, PyObject *__pyx_v_expected_list, PyObject *__pyx_v_msg, PyObject *__pyx_v_verbose) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assertParseAndCheckList", 1);

  /* "cPyparsing.pyx":8017
 *             the resulting ParseResults.asList() is equal to the expected_list.
 *             """
 *             result = expr.parseString(test_string, parseAll=True)             # <<<<<<<<<<<<<<
 *             if verbose:
 *                 print(result.dump())
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_parseString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_test_string);
  __Pyx_GIVEREF(__pyx_v_test_string);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_test_string)) __PYX_ERR(0, 8017, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_parseAll, Py_True) < 0) __PYX_ERR(0, 8017, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":8018
 *             """
 *             result = expr.parseString(test_string, parseAll=True)
 *             if verbose:             # <<<<<<<<<<<<<<
 *                 print(result.dump())
 *             self.assertParseResultsEquals(result, expected_list=expected_list, msg=msg)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_verbose); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 8018, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":8019
 *             result = expr.parseString(test_string, parseAll=True)
 *             if verbose:
 *                 print(result.dump())             # <<<<<<<<<<<<<<
 *             self.assertParseResultsEquals(result, expected_list=expected_list, msg=msg)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_dump); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8019, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":8018
 *             """
 *             result = expr.parseString(test_string, parseAll=True)
 *             if verbose:             # <<<<<<<<<<<<<<
 *                 print(result.dump())
 *             self.assertParseResultsEquals(result, expected_list=expected_list, msg=msg)
 */
  }

  /* "cPyparsing.pyx":8020
 *             if verbose:
 *                 print(result.dump())
 *             self.assertParseResultsEquals(result, expected_list=expected_list, msg=msg)             # <<<<<<<<<<<<<<
 * 
 *         def assertParseAndCheckDict(
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_assertParseResultsEquals); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_result);
  __Pyx_GIVEREF(__pyx_v_result);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_result)) __PYX_ERR(0, 8020, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_expected_list, __pyx_v_expected_list) < 0) __PYX_ERR(0, 8020, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 8020, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":8010
 *                 self.assertEqual(expected_dict, result.asDict(), msg=msg)
 * 
 *         def assertParseAndCheckList(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_list, msg=None, verbose=True
 *         ):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertParseAndCheckList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":8022
 *             self.assertParseResultsEquals(result, expected_list=expected_list, msg=msg)
 * 
 *         def assertParseAndCheckDict(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_dict, msg=None, verbose=True
 *         ):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_5assertParseAndCheckDict(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23TestParseResultsAsserts_4assertParseAndCheckDict, "TestParseResultsAsserts.assertParseAndCheckDict(self, expr, test_string, expected_dict, msg=None, verbose=True)\n\n            Convenience wrapper assert to test a parser element and input string, and assert that\n            the resulting ParseResults.asDict() is equal to the expected_dict.\n            ");
static PyMethodDef __pyx_mdef_10cPyparsing_23TestParseResultsAsserts_5assertParseAndCheckDict = {"assertParseAndCheckDict", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23TestParseResultsAsserts_5assertParseAndCheckDict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23TestParseResultsAsserts_4assertParseAndCheckDict};
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_5assertParseAndCheckDict(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_test_string = 0;
  PyObject *__pyx_v_expected_dict = 0;
  PyObject *__pyx_v_msg = 0;
  PyObject *__pyx_v_verbose = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("assertParseAndCheckDict (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_test_string,&__pyx_n_s_expected_dict,&__pyx_n_s_msg,&__pyx_n_s_verbose,0};

    /* "cPyparsing.pyx":8023
 * 
 *         def assertParseAndCheckDict(
 *             self, expr, test_string, expected_dict, msg=None, verbose=True             # <<<<<<<<<<<<<<
 *         ):
 *             """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8022, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8022, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("assertParseAndCheckDict", 0, 4, 6, 1); __PYX_ERR(0, 8022, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_test_string)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8022, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("assertParseAndCheckDict", 0, 4, 6, 2); __PYX_ERR(0, 8022, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expected_dict)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8022, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("assertParseAndCheckDict", 0, 4, 6, 3); __PYX_ERR(0, 8022, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_msg);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8022, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_verbose);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8022, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "assertParseAndCheckDict") < 0)) __PYX_ERR(0, 8022, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_test_string = values[2];
    __pyx_v_expected_dict = values[3];
    __pyx_v_msg = values[4];
    __pyx_v_verbose = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("assertParseAndCheckDict", 0, 4, 6, __pyx_nargs); __PYX_ERR(0, 8022, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertParseAndCheckDict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23TestParseResultsAsserts_4assertParseAndCheckDict(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_test_string, __pyx_v_expected_dict, __pyx_v_msg, __pyx_v_verbose);

  /* "cPyparsing.pyx":8022
 *             self.assertParseResultsEquals(result, expected_list=expected_list, msg=msg)
 * 
 *         def assertParseAndCheckDict(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_dict, msg=None, verbose=True
 *         ):
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_4assertParseAndCheckDict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_test_string, PyObject *__pyx_v_expected_dict, PyObject *__pyx_v_msg, PyObject *__pyx_v_verbose) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assertParseAndCheckDict", 1);

  /* "cPyparsing.pyx":8029
 *             the resulting ParseResults.asDict() is equal to the expected_dict.
 *             """
 *             result = expr.parseString(test_string, parseAll=True)             # <<<<<<<<<<<<<<
 *             if verbose:
 *                 print(result.dump())
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_parseString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_test_string);
  __Pyx_GIVEREF(__pyx_v_test_string);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_test_string)) __PYX_ERR(0, 8029, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_parseAll, Py_True) < 0) __PYX_ERR(0, 8029, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":8030
 *             """
 *             result = expr.parseString(test_string, parseAll=True)
 *             if verbose:             # <<<<<<<<<<<<<<
 *                 print(result.dump())
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_verbose); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 8030, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":8031
 *             result = expr.parseString(test_string, parseAll=True)
 *             if verbose:
 *                 print(result.dump())             # <<<<<<<<<<<<<<
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_dump); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8031, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":8030
 *             """
 *             result = expr.parseString(test_string, parseAll=True)
 *             if verbose:             # <<<<<<<<<<<<<<
 *                 print(result.dump())
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)
 */
  }

  /* "cPyparsing.pyx":8032
 *             if verbose:
 *                 print(result.dump())
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)             # <<<<<<<<<<<<<<
 * 
 *         def assertRunTestResults(
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_assertParseResultsEquals); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_result);
  __Pyx_GIVEREF(__pyx_v_result);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_result)) __PYX_ERR(0, 8032, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_expected_dict, __pyx_v_expected_dict) < 0) __PYX_ERR(0, 8032, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 8032, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":8022
 *             self.assertParseResultsEquals(result, expected_list=expected_list, msg=msg)
 * 
 *         def assertParseAndCheckDict(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_dict, msg=None, verbose=True
 *         ):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertParseAndCheckDict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":8034
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)
 * 
 *         def assertRunTestResults(             # <<<<<<<<<<<<<<
 *             self, run_tests_report, expected_parse_results=None, msg=None
 *         ):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_7assertRunTestResults(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23TestParseResultsAsserts_6assertRunTestResults, "TestParseResultsAsserts.assertRunTestResults(self, run_tests_report, expected_parse_results=None, msg=None)\n\n            Unit test assertion to evaluate output of ParserElement.runTests(). If a list of\n            list-dict tuples is given as the expected_parse_results argument, then these are zipped\n            with the report tuples returned by runTests and evaluated using assertParseResultsEquals.\n            Finally, asserts that the overall runTests() success value is True.\n\n            :param run_tests_report: tuple(bool, [tuple(str, ParseResults or Exception)]) returned from runTests\n            :param expected_parse_results (optional): [tuple(str, list, dict, Exception)]\n            ");
static PyMethodDef __pyx_mdef_10cPyparsing_23TestParseResultsAsserts_7assertRunTestResults = {"assertRunTestResults", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23TestParseResultsAsserts_7assertRunTestResults, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23TestParseResultsAsserts_6assertRunTestResults};
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_7assertRunTestResults(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_run_tests_report = 0;
  PyObject *__pyx_v_expected_parse_results = 0;
  PyObject *__pyx_v_msg = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("assertRunTestResults (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_run_tests_report,&__pyx_n_s_expected_parse_results,&__pyx_n_s_msg,0};

    /* "cPyparsing.pyx":8035
 * 
 *         def assertRunTestResults(
 *             self, run_tests_report, expected_parse_results=None, msg=None             # <<<<<<<<<<<<<<
 *         ):
 *             """
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8034, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_run_tests_report)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8034, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("assertRunTestResults", 0, 2, 4, 1); __PYX_ERR(0, 8034, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_expected_parse_results);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8034, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_msg);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8034, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "assertRunTestResults") < 0)) __PYX_ERR(0, 8034, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_run_tests_report = values[1];
    __pyx_v_expected_parse_results = values[2];
    __pyx_v_msg = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("assertRunTestResults", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 8034, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRunTestResults", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23TestParseResultsAsserts_6assertRunTestResults(__pyx_self, __pyx_v_self, __pyx_v_run_tests_report, __pyx_v_expected_parse_results, __pyx_v_msg);

  /* "cPyparsing.pyx":8034
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)
 * 
 *         def assertRunTestResults(             # <<<<<<<<<<<<<<
 *             self, run_tests_report, expected_parse_results=None, msg=None
 *         ):
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_2generator47(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":8058
 *                     # an empty tuple will skip any result validation
 *                     fail_msg = next(
 *                         (exp for exp in expected if isinstance(exp, str)), None             # <<<<<<<<<<<<<<
 *                     )
 *                     expected_exception = next(
 */

static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_76_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 8058, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_2generator47, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_pyparsing_test_TestParseResultsA, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 8058, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRunTestResults.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_2generator47(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8058, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 8058, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8058, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8058, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 8058, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8058, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8058, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 8058, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8058, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 8058, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_exp);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_exp, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_exp, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 8058, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exp);
      __pyx_r = __pyx_cur_scope->__pyx_v_exp;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8058, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_5generator48(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":8062
 *                     expected_exception = next(
 *                         (
 *                             exp             # <<<<<<<<<<<<<<
 *                             for exp in expected
 *                             if isinstance(exp, type) and issubclass(exp, Exception)
 */

static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_3genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_77_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 8062, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_5generator48, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_pyparsing_test_TestParseResultsA, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 8062, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRunTestResults.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_5generator48(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L9_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8062, __pyx_L1_error)

  /* "cPyparsing.pyx":8063
 *                         (
 *                             exp
 *                             for exp in expected             # <<<<<<<<<<<<<<
 *                             if isinstance(exp, type) and issubclass(exp, Exception)
 *                         ),
 */
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 8063, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8063, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8063, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8063, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 8063, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8063, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8063, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 8063, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8063, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 8063, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_exp);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_exp, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":8064
 *                             exp
 *                             for exp in expected
 *                             if isinstance(exp, type) and issubclass(exp, Exception)             # <<<<<<<<<<<<<<
 *                         ),
 *                         None,
 */
    __pyx_t_6 = PyType_Check(__pyx_cur_scope->__pyx_v_exp); 
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_6 = PyObject_IsSubclass(__pyx_cur_scope->__pyx_v_exp, ((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0]))); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 8064, __pyx_L1_error)
    __pyx_t_5 = __pyx_t_6;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":8062
 *                     expected_exception = next(
 *                         (
 *                             exp             # <<<<<<<<<<<<<<
 *                             for exp in expected
 *                             if isinstance(exp, type) and issubclass(exp, Exception)
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exp);
      __pyx_r = __pyx_cur_scope->__pyx_v_exp;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L9_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8062, __pyx_L1_error)

      /* "cPyparsing.pyx":8064
 *                             exp
 *                             for exp in expected
 *                             if isinstance(exp, type) and issubclass(exp, Exception)             # <<<<<<<<<<<<<<
 *                         ),
 *                         None,
 */
    }

    /* "cPyparsing.pyx":8063
 *                         (
 *                             exp
 *                             for exp in expected             # <<<<<<<<<<<<<<
 *                             if isinstance(exp, type) and issubclass(exp, Exception)
 *                         ),
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":8062
 *                     expected_exception = next(
 *                         (
 *                             exp             # <<<<<<<<<<<<<<
 *                             for exp in expected
 *                             if isinstance(exp, type) and issubclass(exp, Exception)
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_8generator49(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":8076
 *                     else:
 *                         expected_list = next(
 *                             (exp for exp in expected if isinstance(exp, list)), None             # <<<<<<<<<<<<<<
 *                         )
 *                         expected_dict = next(
 */

static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_6genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_78_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 8076, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_8generator49, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_pyparsing_test_TestParseResultsA, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 8076, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRunTestResults.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_8generator49(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8076, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 8076, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8076, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8076, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8076, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 8076, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8076, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8076, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 8076, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8076, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 8076, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_exp);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_exp, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_5 = PyList_Check(__pyx_cur_scope->__pyx_v_exp); 
    if (__pyx_t_5) {
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exp);
      __pyx_r = __pyx_cur_scope->__pyx_v_exp;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8076, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_11generator50(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":8079
 *                         )
 *                         expected_dict = next(
 *                             (exp for exp in expected if isinstance(exp, dict)), None             # <<<<<<<<<<<<<<
 *                         )
 *                         if (expected_list, expected_dict) != (None, None):
 */

static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_9genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_79_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 8079, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_11generator50, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_pyparsing_test_TestParseResultsA, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 8079, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRunTestResults.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_11generator50(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8079, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 8079, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8079, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8079, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8079, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 8079, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8079, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8079, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 8079, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8079, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 8079, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_exp);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_exp, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_5 = PyDict_Check(__pyx_cur_scope->__pyx_v_exp); 
    if (__pyx_t_5) {
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exp);
      __pyx_r = __pyx_cur_scope->__pyx_v_exp;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8079, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":8034
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)
 * 
 *         def assertRunTestResults(             # <<<<<<<<<<<<<<
 *             self, run_tests_report, expected_parse_results=None, msg=None
 *         ):
 */

static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_6assertRunTestResults(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_run_tests_report, PyObject *__pyx_v_expected_parse_results, PyObject *__pyx_v_msg) {
  PyObject *__pyx_v_run_test_success = NULL;
  PyObject *__pyx_v_run_test_results = NULL;
  PyObject *__pyx_v_merged = NULL;
  PyObject *__pyx_v_test_string = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_expected = NULL;
  PyObject *__pyx_v_fail_msg = NULL;
  PyObject *__pyx_v_expected_exception = NULL;
  PyObject *__pyx_v_expected_list = NULL;
  PyObject *__pyx_v_expected_dict = NULL;
  PyObject *__pyx_9genexpr64__pyx_v_rpt = NULL;
  PyObject *__pyx_9genexpr64__pyx_v_expected = NULL;
  PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_2generator47 = 0;
  PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_5generator48 = 0;
  PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_8generator49 = 0;
  PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_11generator50 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assertRunTestResults", 1);

  /* "cPyparsing.pyx":8046
 *             :param expected_parse_results (optional): [tuple(str, list, dict, Exception)]
 *             """
 *             run_test_success, run_test_results = run_tests_report             # <<<<<<<<<<<<<<
 * 
 *             if expected_parse_results is not None:
 */
  if ((likely(PyTuple_CheckExact(__pyx_v_run_tests_report))) || (PyList_CheckExact(__pyx_v_run_tests_report))) {
    PyObject* sequence = __pyx_v_run_tests_report;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 8046, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
  } else {
    Py_ssize_t index = -1;
    __pyx_t_3 = PyObject_GetIter(__pyx_v_run_tests_report); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3);
    index = 0; __pyx_t_1 = __pyx_t_4(__pyx_t_3); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_2 = __pyx_t_4(__pyx_t_3); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_4(__pyx_t_3), 2) < 0) __PYX_ERR(0, 8046, __pyx_L1_error)
    __pyx_t_4 = NULL;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 8046, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_run_test_success = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_run_test_results = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":8048
 *             run_test_success, run_test_results = run_tests_report
 * 
 *             if expected_parse_results is not None:             # <<<<<<<<<<<<<<
 *                 merged = [
 *                     (rpt[0], rpt[1], expected)
 */
  __pyx_t_5 = (__pyx_v_expected_parse_results != Py_None);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":8049
 * 
 *             if expected_parse_results is not None:
 *                 merged = [             # <<<<<<<<<<<<<<
 *                     (rpt[0], rpt[1], expected)
 *                     for rpt, expected in zip(run_test_results, expected_parse_results)
 */
    { /* enter inner scope */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8049, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "cPyparsing.pyx":8051
 *                 merged = [
 *                     (rpt[0], rpt[1], expected)
 *                     for rpt, expected in zip(run_test_results, expected_parse_results)             # <<<<<<<<<<<<<<
 *                 ]
 *                 for test_string, result, expected in merged:
 */
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8051, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_run_test_results);
      __Pyx_GIVEREF(__pyx_v_run_test_results);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_run_test_results)) __PYX_ERR(0, 8051, __pyx_L8_error);
      __Pyx_INCREF(__pyx_v_expected_parse_results);
      __Pyx_GIVEREF(__pyx_v_expected_parse_results);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_expected_parse_results)) __PYX_ERR(0, 8051, __pyx_L8_error);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8051, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_1 = __pyx_t_3; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8051, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 8051, __pyx_L8_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8051, __pyx_L8_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 8051, __pyx_L8_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8051, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8051, __pyx_L8_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 8051, __pyx_L8_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8051, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          }
        } else {
          __pyx_t_3 = __pyx_t_7(__pyx_t_1);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 8051, __pyx_L8_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_3);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
          PyObject* sequence = __pyx_t_3;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 8051, __pyx_L8_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          #else
          __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 8051, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 8051, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_9);
          #endif
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_10 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8051, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10);
          index = 0; __pyx_t_8 = __pyx_t_4(__pyx_t_10); if (unlikely(!__pyx_t_8)) goto __pyx_L11_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_8);
          index = 1; __pyx_t_9 = __pyx_t_4(__pyx_t_10); if (unlikely(!__pyx_t_9)) goto __pyx_L11_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_4(__pyx_t_10), 2) < 0) __PYX_ERR(0, 8051, __pyx_L8_error)
          __pyx_t_4 = NULL;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          goto __pyx_L12_unpacking_done;
          __pyx_L11_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_4 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 8051, __pyx_L8_error)
          __pyx_L12_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr64__pyx_v_rpt, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_9genexpr64__pyx_v_expected, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "cPyparsing.pyx":8050
 *             if expected_parse_results is not None:
 *                 merged = [
 *                     (rpt[0], rpt[1], expected)             # <<<<<<<<<<<<<<
 *                     for rpt, expected in zip(run_test_results, expected_parse_results)
 *                 ]
 */
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_9genexpr64__pyx_v_rpt, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8050, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_9 = __Pyx_GetItemInt(__pyx_9genexpr64__pyx_v_rpt, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 8050, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 8050, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_3)) __PYX_ERR(0, 8050, __pyx_L8_error);
        __Pyx_GIVEREF(__pyx_t_9);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_9)) __PYX_ERR(0, 8050, __pyx_L8_error);
        __Pyx_INCREF(__pyx_9genexpr64__pyx_v_expected);
        __Pyx_GIVEREF(__pyx_9genexpr64__pyx_v_expected);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_9genexpr64__pyx_v_expected)) __PYX_ERR(0, 8050, __pyx_L8_error);
        __pyx_t_3 = 0;
        __pyx_t_9 = 0;
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 8049, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "cPyparsing.pyx":8051
 *                 merged = [
 *                     (rpt[0], rpt[1], expected)
 *                     for rpt, expected in zip(run_test_results, expected_parse_results)             # <<<<<<<<<<<<<<
 *                 ]
 *                 for test_string, result, expected in merged:
 */
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_9genexpr64__pyx_v_expected); __pyx_9genexpr64__pyx_v_expected = 0;
      __Pyx_XDECREF(__pyx_9genexpr64__pyx_v_rpt); __pyx_9genexpr64__pyx_v_rpt = 0;
      goto __pyx_L14_exit_scope;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_9genexpr64__pyx_v_expected); __pyx_9genexpr64__pyx_v_expected = 0;
      __Pyx_XDECREF(__pyx_9genexpr64__pyx_v_rpt); __pyx_9genexpr64__pyx_v_rpt = 0;
      goto __pyx_L1_error;
      __pyx_L14_exit_scope:;
    } /* exit inner scope */
    __pyx_v_merged = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":8053
 *                     for rpt, expected in zip(run_test_results, expected_parse_results)
 *                 ]
 *                 for test_string, result, expected in merged:             # <<<<<<<<<<<<<<
 *                     # expected should be a tuple containing a list and/or a dict or an exception,
 *                     # and optional failure message string
 */
    __pyx_t_2 = __pyx_v_merged; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 8053, __pyx_L1_error)
        #endif
        if (__pyx_t_6 >= __pyx_temp) break;
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 8053, __pyx_L1_error)
      #else
      __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #endif
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 8053, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2); 
        } else {
          __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_3 = PyList_GET_ITEM(sequence, 2); 
        }
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_3);
        #else
        __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 8053, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 8053, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_3 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8053, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_10 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8053, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10);
        index = 0; __pyx_t_8 = __pyx_t_4(__pyx_t_10); if (unlikely(!__pyx_t_8)) goto __pyx_L17_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        index = 1; __pyx_t_9 = __pyx_t_4(__pyx_t_10); if (unlikely(!__pyx_t_9)) goto __pyx_L17_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_9);
        index = 2; __pyx_t_3 = __pyx_t_4(__pyx_t_10); if (unlikely(!__pyx_t_3)) goto __pyx_L17_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_4(__pyx_t_10), 3) < 0) __PYX_ERR(0, 8053, __pyx_L1_error)
        __pyx_t_4 = NULL;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L18_unpacking_done;
        __pyx_L17_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_4 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 8053, __pyx_L1_error)
        __pyx_L18_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_test_string, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_9);
      __pyx_t_9 = 0;
      __Pyx_XDECREF_SET(__pyx_v_expected, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":8058
 *                     # an empty tuple will skip any result validation
 *                     fail_msg = next(
 *                         (exp for exp in expected if isinstance(exp, str)), None             # <<<<<<<<<<<<<<
 *                     )
 *                     expected_exception = next(
 */
      __pyx_t_1 = __pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_genexpr(NULL, __pyx_v_expected); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8058, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "cPyparsing.pyx":8057
 *                     # and optional failure message string
 *                     # an empty tuple will skip any result validation
 *                     fail_msg = next(             # <<<<<<<<<<<<<<
 *                         (exp for exp in expected if isinstance(exp, str)), None
 *                     )
 */
      __pyx_t_3 = __Pyx_PyIter_Next2(__pyx_t_1, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8057, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_fail_msg, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":8062
 *                     expected_exception = next(
 *                         (
 *                             exp             # <<<<<<<<<<<<<<
 *                             for exp in expected
 *                             if isinstance(exp, type) and issubclass(exp, Exception)
 */
      __pyx_t_3 = __pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_3genexpr(NULL, __pyx_v_expected); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "cPyparsing.pyx":8060
 *                         (exp for exp in expected if isinstance(exp, str)), None
 *                     )
 *                     expected_exception = next(             # <<<<<<<<<<<<<<
 *                         (
 *                             exp
 */
      __pyx_t_1 = __Pyx_PyIter_Next2(__pyx_t_3, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8060, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_v_expected_exception, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":8068
 *                         None,
 *                     )
 *                     if expected_exception is not None:             # <<<<<<<<<<<<<<
 *                         with self.assertRaises(
 *                             expected_exception=expected_exception, msg=fail_msg or msg
 */
      __pyx_t_5 = (__pyx_v_expected_exception != Py_None);
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":8069
 *                     )
 *                     if expected_exception is not None:
 *                         with self.assertRaises(             # <<<<<<<<<<<<<<
 *                             expected_exception=expected_exception, msg=fail_msg or msg
 *                         ):
 */
        /*with:*/ {
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_assertRaises); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);

          /* "cPyparsing.pyx":8070
 *                     if expected_exception is not None:
 *                         with self.assertRaises(
 *                             expected_exception=expected_exception, msg=fail_msg or msg             # <<<<<<<<<<<<<<
 *                         ):
 *                             if isinstance(result, Exception):
 */
          __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8070, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_expected_exception, __pyx_v_expected_exception) < 0) __PYX_ERR(0, 8070, __pyx_L1_error)
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_fail_msg); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 8070, __pyx_L1_error)
          if (!__pyx_t_5) {
          } else {
            __Pyx_INCREF(__pyx_v_fail_msg);
            __pyx_t_9 = __pyx_v_fail_msg;
            goto __pyx_L20_bool_binop_done;
          }
          __Pyx_INCREF(__pyx_v_msg);
          __pyx_t_9 = __pyx_v_msg;
          __pyx_L20_bool_binop_done:;
          if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_msg, __pyx_t_9) < 0) __PYX_ERR(0, 8070, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":8069
 *                     )
 *                     if expected_exception is not None:
 *                         with self.assertRaises(             # <<<<<<<<<<<<<<
 *                             expected_exception=expected_exception, msg=fail_msg or msg
 *                         ):
 */
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 8069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_11 = __Pyx_PyObject_LookupSpecial(__pyx_t_9, __pyx_n_s_exit); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 8069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_1 = __Pyx_PyObject_LookupSpecial(__pyx_t_9, __pyx_n_s_enter); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8069, __pyx_L22_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_8 = NULL;
          __pyx_t_12 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_12 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_12, 0+__pyx_t_12);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8069, __pyx_L22_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          /*try:*/ {
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
              __Pyx_XGOTREF(__pyx_t_13);
              __Pyx_XGOTREF(__pyx_t_14);
              __Pyx_XGOTREF(__pyx_t_15);
              /*try:*/ {

                /* "cPyparsing.pyx":8072
 *                             expected_exception=expected_exception, msg=fail_msg or msg
 *                         ):
 *                             if isinstance(result, Exception):             # <<<<<<<<<<<<<<
 *                                 raise result
 *                     else:
 */
                __pyx_t_5 = __Pyx_PyException_Check(__pyx_v_result); 
                if (unlikely(__pyx_t_5)) {

                  /* "cPyparsing.pyx":8073
 *                         ):
 *                             if isinstance(result, Exception):
 *                                 raise result             # <<<<<<<<<<<<<<
 *                     else:
 *                         expected_list = next(
 */
                  __Pyx_Raise(__pyx_v_result, 0, 0, 0);
                  __PYX_ERR(0, 8073, __pyx_L28_error)

                  /* "cPyparsing.pyx":8072
 *                             expected_exception=expected_exception, msg=fail_msg or msg
 *                         ):
 *                             if isinstance(result, Exception):             # <<<<<<<<<<<<<<
 *                                 raise result
 *                     else:
 */
                }

                /* "cPyparsing.pyx":8069
 *                     )
 *                     if expected_exception is not None:
 *                         with self.assertRaises(             # <<<<<<<<<<<<<<
 *                             expected_exception=expected_exception, msg=fail_msg or msg
 *                         ):
 */
              }
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              goto __pyx_L35_try_end;
              __pyx_L28_error:;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              /*except:*/ {
                __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRunTestResults", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_3, &__pyx_t_1) < 0) __PYX_ERR(0, 8069, __pyx_L30_except_error)
                __Pyx_XGOTREF(__pyx_t_9);
                __Pyx_XGOTREF(__pyx_t_3);
                __Pyx_XGOTREF(__pyx_t_1);
                __pyx_t_8 = PyTuple_Pack(3, __pyx_t_9, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 8069, __pyx_L30_except_error)
                __Pyx_GOTREF(__pyx_t_8);
                __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_8, NULL);
                __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
                __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 8069, __pyx_L30_except_error)
                __Pyx_GOTREF(__pyx_t_16);
                __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_16);
                __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
                if (__pyx_t_5 < 0) __PYX_ERR(0, 8069, __pyx_L30_except_error)
                __pyx_t_17 = (!__pyx_t_5);
                if (unlikely(__pyx_t_17)) {
                  __Pyx_GIVEREF(__pyx_t_9);
                  __Pyx_GIVEREF(__pyx_t_3);
                  __Pyx_XGIVEREF(__pyx_t_1);
                  __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_3, __pyx_t_1);
                  __pyx_t_9 = 0; __pyx_t_3 = 0; __pyx_t_1 = 0; 
                  __PYX_ERR(0, 8069, __pyx_L30_except_error)
                }
                __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                goto __pyx_L29_exception_handled;
              }
              __pyx_L30_except_error:;
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_XGIVEREF(__pyx_t_14);
              __Pyx_XGIVEREF(__pyx_t_15);
              __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
              goto __pyx_L1_error;
              __pyx_L29_exception_handled:;
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_XGIVEREF(__pyx_t_14);
              __Pyx_XGIVEREF(__pyx_t_15);
              __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
              __pyx_L35_try_end:;
            }
          }
          /*finally:*/ {
            /*normal exit:*/{
              if (__pyx_t_11) {
                __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__46, NULL);
                __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
                if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 8069, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_15);
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              }
              goto __pyx_L27;
            }
            __pyx_L27:;
          }
          goto __pyx_L40;
          __pyx_L22_error:;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L1_error;
          __pyx_L40:;
        }

        /* "cPyparsing.pyx":8068
 *                         None,
 *                     )
 *                     if expected_exception is not None:             # <<<<<<<<<<<<<<
 *                         with self.assertRaises(
 *                             expected_exception=expected_exception, msg=fail_msg or msg
 */
        goto __pyx_L19;
      }

      /* "cPyparsing.pyx":8075
 *                                 raise result
 *                     else:
 *                         expected_list = next(             # <<<<<<<<<<<<<<
 *                             (exp for exp in expected if isinstance(exp, list)), None
 *                         )
 */
      /*else*/ {

        /* "cPyparsing.pyx":8076
 *                     else:
 *                         expected_list = next(
 *                             (exp for exp in expected if isinstance(exp, list)), None             # <<<<<<<<<<<<<<
 *                         )
 *                         expected_dict = next(
 */
        __pyx_t_1 = __pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_6genexpr(NULL, __pyx_v_expected); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8076, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);

        /* "cPyparsing.pyx":8075
 *                                 raise result
 *                     else:
 *                         expected_list = next(             # <<<<<<<<<<<<<<
 *                             (exp for exp in expected if isinstance(exp, list)), None
 *                         )
 */
        __pyx_t_3 = __Pyx_PyIter_Next2(__pyx_t_1, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8075, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_expected_list, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "cPyparsing.pyx":8079
 *                         )
 *                         expected_dict = next(
 *                             (exp for exp in expected if isinstance(exp, dict)), None             # <<<<<<<<<<<<<<
 *                         )
 *                         if (expected_list, expected_dict) != (None, None):
 */
        __pyx_t_3 = __pyx_pf_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_9genexpr(NULL, __pyx_v_expected); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8079, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);

        /* "cPyparsing.pyx":8078
 *                             (exp for exp in expected if isinstance(exp, list)), None
 *                         )
 *                         expected_dict = next(             # <<<<<<<<<<<<<<
 *                             (exp for exp in expected if isinstance(exp, dict)), None
 *                         )
 */
        __pyx_t_1 = __Pyx_PyIter_Next2(__pyx_t_3, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8078, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF_SET(__pyx_v_expected_dict, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":8081
 *                             (exp for exp in expected if isinstance(exp, dict)), None
 *                         )
 *                         if (expected_list, expected_dict) != (None, None):             # <<<<<<<<<<<<<<
 *                             self.assertParseResultsEquals(
 *                                 result,
 */
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8081, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_expected_list);
        __Pyx_GIVEREF(__pyx_v_expected_list);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_expected_list)) __PYX_ERR(0, 8081, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_expected_dict);
        __Pyx_GIVEREF(__pyx_v_expected_dict);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_expected_dict)) __PYX_ERR(0, 8081, __pyx_L1_error);
        __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_tuple__58, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8081, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_17 < 0))) __PYX_ERR(0, 8081, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_17) {

          /* "cPyparsing.pyx":8082
 *                         )
 *                         if (expected_list, expected_dict) != (None, None):
 *                             self.assertParseResultsEquals(             # <<<<<<<<<<<<<<
 *                                 result,
 *                                 expected_list=expected_list,
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_assertParseResultsEquals); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8082, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);

          /* "cPyparsing.pyx":8083
 *                         if (expected_list, expected_dict) != (None, None):
 *                             self.assertParseResultsEquals(
 *                                 result,             # <<<<<<<<<<<<<<
 *                                 expected_list=expected_list,
 *                                 expected_dict=expected_dict,
 */
          __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8082, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_v_result);
          __Pyx_GIVEREF(__pyx_v_result);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_result)) __PYX_ERR(0, 8082, __pyx_L1_error);

          /* "cPyparsing.pyx":8084
 *                             self.assertParseResultsEquals(
 *                                 result,
 *                                 expected_list=expected_list,             # <<<<<<<<<<<<<<
 *                                 expected_dict=expected_dict,
 *                                 msg=fail_msg or msg,
 */
          __pyx_t_9 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 8084, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_expected_list, __pyx_v_expected_list) < 0) __PYX_ERR(0, 8084, __pyx_L1_error)

          /* "cPyparsing.pyx":8085
 *                                 result,
 *                                 expected_list=expected_list,
 *                                 expected_dict=expected_dict,             # <<<<<<<<<<<<<<
 *                                 msg=fail_msg or msg,
 *                             )
 */
          if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_expected_dict, __pyx_v_expected_dict) < 0) __PYX_ERR(0, 8084, __pyx_L1_error)

          /* "cPyparsing.pyx":8086
 *                                 expected_list=expected_list,
 *                                 expected_dict=expected_dict,
 *                                 msg=fail_msg or msg,             # <<<<<<<<<<<<<<
 *                             )
 *                         else:
 */
          __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_v_fail_msg); if (unlikely((__pyx_t_17 < 0))) __PYX_ERR(0, 8086, __pyx_L1_error)
          if (!__pyx_t_17) {
          } else {
            __Pyx_INCREF(__pyx_v_fail_msg);
            __pyx_t_8 = __pyx_v_fail_msg;
            goto __pyx_L42_bool_binop_done;
          }
          __Pyx_INCREF(__pyx_v_msg);
          __pyx_t_8 = __pyx_v_msg;
          __pyx_L42_bool_binop_done:;
          if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_msg, __pyx_t_8) < 0) __PYX_ERR(0, 8084, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "cPyparsing.pyx":8082
 *                         )
 *                         if (expected_list, expected_dict) != (None, None):
 *                             self.assertParseResultsEquals(             # <<<<<<<<<<<<<<
 *                                 result,
 *                                 expected_list=expected_list,
 */
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 8082, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "cPyparsing.pyx":8081
 *                             (exp for exp in expected if isinstance(exp, dict)), None
 *                         )
 *                         if (expected_list, expected_dict) != (None, None):             # <<<<<<<<<<<<<<
 *                             self.assertParseResultsEquals(
 *                                 result,
 */
          goto __pyx_L41;
        }

        /* "cPyparsing.pyx":8090
 *                         else:
 *                             # warning here maybe?
 *                             print("no validation for {!r}".format(test_string))             # <<<<<<<<<<<<<<
 * 
 *             # do this last, in case some specific test results can be reported instead
 */
        /*else*/ {
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_no_validation_for_r, __pyx_n_s_format); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 8090, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_1 = NULL;
          __pyx_t_12 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
              __pyx_t_12 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_test_string};
            __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 8090, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
          __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 8090, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_L41:;
      }
      __pyx_L19:;

      /* "cPyparsing.pyx":8053
 *                     for rpt, expected in zip(run_test_results, expected_parse_results)
 *                 ]
 *                 for test_string, result, expected in merged:             # <<<<<<<<<<<<<<
 *                     # expected should be a tuple containing a list and/or a dict or an exception,
 *                     # and optional failure message string
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":8048
 *             run_test_success, run_test_results = run_tests_report
 * 
 *             if expected_parse_results is not None:             # <<<<<<<<<<<<<<
 *                 merged = [
 *                     (rpt[0], rpt[1], expected)
 */
  }

  /* "cPyparsing.pyx":8093
 * 
 *             # do this last, in case some specific test results can be reported instead
 *             self.assertTrue(             # <<<<<<<<<<<<<<
 *                 run_test_success, msg=msg if msg is not None else "failed runTests"
 *             )
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_assertTrue); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "cPyparsing.pyx":8094
 *             # do this last, in case some specific test results can be reported instead
 *             self.assertTrue(
 *                 run_test_success, msg=msg if msg is not None else "failed runTests"             # <<<<<<<<<<<<<<
 *             )
 * 
 */
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 8093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_v_run_test_success);
  __Pyx_GIVEREF(__pyx_v_run_test_success);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_run_test_success)) __PYX_ERR(0, 8093, __pyx_L1_error);
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 8094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_17 = (__pyx_v_msg != Py_None);
  if (__pyx_t_17) {
    __Pyx_INCREF(__pyx_v_msg);
    __pyx_t_1 = __pyx_v_msg;
  } else {
    __Pyx_INCREF(__pyx_kp_u_failed_runTests);
    __pyx_t_1 = __pyx_kp_u_failed_runTests;
  }
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_msg, __pyx_t_1) < 0) __PYX_ERR(0, 8094, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":8093
 * 
 *             # do this last, in case some specific test results can be reported instead
 *             self.assertTrue(             # <<<<<<<<<<<<<<
 *                 run_test_success, msg=msg if msg is not None else "failed runTests"
 *             )
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":8034
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)
 * 
 *         def assertRunTestResults(             # <<<<<<<<<<<<<<
 *             self, run_tests_report, expected_parse_results=None, msg=None
 *         ):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRunTestResults", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_run_test_success);
  __Pyx_XDECREF(__pyx_v_run_test_results);
  __Pyx_XDECREF(__pyx_v_merged);
  __Pyx_XDECREF(__pyx_v_test_string);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_expected);
  __Pyx_XDECREF(__pyx_v_fail_msg);
  __Pyx_XDECREF(__pyx_v_expected_exception);
  __Pyx_XDECREF(__pyx_v_expected_list);
  __Pyx_XDECREF(__pyx_v_expected_dict);
  __Pyx_XDECREF(__pyx_9genexpr64__pyx_v_rpt);
  __Pyx_XDECREF(__pyx_9genexpr64__pyx_v_expected);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_2generator47);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_5generator48);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_8generator49);
  __Pyx_XDECREF(__pyx_gb_10cPyparsing_23TestParseResultsAsserts_20assertRunTestResults_11generator50);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_10generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":8097
 *             )
 * 
 *         @contextmanager             # <<<<<<<<<<<<<<
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):
 */

static PyObject *__pyx_pf_10cPyparsing_111__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);

  /* "cPyparsing.pyx":8098
 * 
 *         @contextmanager
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):             # <<<<<<<<<<<<<<
 *             with self.assertRaises(exc_type, msg=msg):
 *                 yield
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self)->__pyx_arg_exc_type);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self)->__pyx_arg_exc_type);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self)->__pyx_arg_exc_type)) __PYX_ERR(0, 8097, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(0, 8097, __pyx_L1_error);

  /* "cPyparsing.pyx":8097
 *             )
 * 
 *         @contextmanager             # <<<<<<<<<<<<<<
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 8097, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 8097, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_9assertRaisesParseException(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_10cPyparsing_23TestParseResultsAsserts_8assertRaisesParseException, "TestParseResultsAsserts.assertRaisesParseException(self, exc_type=ParseException, msg=None)");
static PyMethodDef __pyx_mdef_10cPyparsing_23TestParseResultsAsserts_9assertRaisesParseException = {"assertRaisesParseException", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_10cPyparsing_23TestParseResultsAsserts_9assertRaisesParseException, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_10cPyparsing_23TestParseResultsAsserts_8assertRaisesParseException};
static PyObject *__pyx_pw_10cPyparsing_23TestParseResultsAsserts_9assertRaisesParseException(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exc_type = 0;
  PyObject *__pyx_v_msg = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("assertRaisesParseException (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exc_type,&__pyx_n_s_msg,0};
    __pyx_defaults11 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self);
    values[1] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_exc_type);

    /* "cPyparsing.pyx":8098
 * 
 *         @contextmanager
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):             # <<<<<<<<<<<<<<
 *             with self.assertRaises(exc_type, msg=msg):
 *                 yield
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8097, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exc_type);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8097, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_msg);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 8097, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "assertRaisesParseException") < 0)) __PYX_ERR(0, 8097, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exc_type = values[1];
    __pyx_v_msg = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("assertRaisesParseException", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 8097, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRaisesParseException", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23TestParseResultsAsserts_8assertRaisesParseException(__pyx_self, __pyx_v_self, __pyx_v_exc_type, __pyx_v_msg);

  /* "cPyparsing.pyx":8097
 *             )
 * 
 *         @contextmanager             # <<<<<<<<<<<<<<
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23TestParseResultsAsserts_8assertRaisesParseException(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc_type, PyObject *__pyx_v_msg) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assertRaisesParseException", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException(__pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 8097, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_exc_type = __pyx_v_exc_type;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exc_type);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_exc_type);
  __pyx_cur_scope->__pyx_v_msg = __pyx_v_msg;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_msg);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_msg);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_23TestParseResultsAsserts_10generator2, __pyx_codeobj__170, (PyObject *) __pyx_cur_scope, __pyx_n_s_assertRaisesParseException, __pyx_n_s_pyparsing_test_TestParseResultsA_2, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 8097, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRaisesParseException", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_23TestParseResultsAsserts_10generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("assertRaisesParseException", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L14_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8097, __pyx_L1_error)

  /* "cPyparsing.pyx":8099
 *         @contextmanager
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):             # <<<<<<<<<<<<<<
 *                 yield
 * 
 */
  /*with:*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_assertRaises); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exc_type);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_exc_type);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_cur_scope->__pyx_v_exc_type)) __PYX_ERR(0, 8099, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_msg, __pyx_cur_scope->__pyx_v_msg) < 0) __PYX_ERR(0, 8099, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_4, __pyx_n_s_exit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 8099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_4, __pyx_n_s_enter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8099, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8099, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    /*try:*/ {
      {
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        /*try:*/ {

          /* "cPyparsing.pyx":8100
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):
 *                 yield             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __pyx_r = Py_None; __Pyx_INCREF(Py_None);
          __Pyx_XGIVEREF(__pyx_t_5);
          __pyx_cur_scope->__pyx_t_0 = __pyx_t_5;
          __Pyx_XGIVEREF(__pyx_t_7);
          __pyx_cur_scope->__pyx_t_1 = __pyx_t_7;
          __Pyx_XGIVEREF(__pyx_t_8);
          __pyx_cur_scope->__pyx_t_2 = __pyx_t_8;
          __Pyx_XGIVEREF(__pyx_t_9);
          __pyx_cur_scope->__pyx_t_3 = __pyx_t_9;
          __Pyx_XGIVEREF(__pyx_r);
          __Pyx_RefNannyFinishContext();
          __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
          /* return from generator, yielding value */
          __pyx_generator->resume_label = 1;
          return __pyx_r;
          __pyx_L14_resume_from_yield:;
          __pyx_t_5 = __pyx_cur_scope->__pyx_t_0;
          __pyx_cur_scope->__pyx_t_0 = 0;
          __Pyx_XGOTREF(__pyx_t_5);
          __pyx_t_7 = __pyx_cur_scope->__pyx_t_1;
          __pyx_cur_scope->__pyx_t_1 = 0;
          __Pyx_XGOTREF(__pyx_t_7);
          __pyx_t_8 = __pyx_cur_scope->__pyx_t_2;
          __pyx_cur_scope->__pyx_t_2 = 0;
          __Pyx_XGOTREF(__pyx_t_8);
          __pyx_t_9 = __pyx_cur_scope->__pyx_t_3;
          __pyx_cur_scope->__pyx_t_3 = 0;
          __Pyx_XGOTREF(__pyx_t_9);
          if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 8100, __pyx_L8_error)

          /* "cPyparsing.pyx":8099
 *         @contextmanager
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):             # <<<<<<<<<<<<<<
 *                 yield
 * 
 */
        }
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L13_try_end;
        __pyx_L8_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("cPyparsing.TestParseResultsAsserts.assertRaisesParseException", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 8099, __pyx_L10_except_error)
          __Pyx_XGOTREF(__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_3);
          __Pyx_XGOTREF(__pyx_t_2);
          __pyx_t_1 = PyTuple_Pack(3, __pyx_t_4, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8099, __pyx_L10_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, NULL);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8099, __pyx_L10_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (__pyx_t_11 < 0) __PYX_ERR(0, 8099, __pyx_L10_except_error)
          __pyx_t_12 = (!__pyx_t_11);
          if (unlikely(__pyx_t_12)) {
            __Pyx_GIVEREF(__pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_XGIVEREF(__pyx_t_2);
            __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_3, __pyx_t_2);
            __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_2 = 0; 
            __PYX_ERR(0, 8099, __pyx_L10_except_error)
          }
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L9_exception_handled;
        }
        __pyx_L10_except_error:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
        goto __pyx_L1_error;
        __pyx_L9_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
        __pyx_L13_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_5) {
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__46, NULL);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 8099, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        goto __pyx_L7;
      }
      __pyx_L7:;
    }
    goto __pyx_L18;
    __pyx_L4_error:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L1_error;
    __pyx_L18:;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":8097
 *             )
 * 
 *         @contextmanager             # <<<<<<<<<<<<<<
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("assertRaisesParseException", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct__genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct__genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct__genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct__genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct__genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_x);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct__genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct__genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_x) {
    e = (*v)(p->__pyx_v_x, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct__genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct__genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct__genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct__genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct__genexpr_spec = {
  "cPyparsing.__pyx_scope_struct__genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct__genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct__genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct__genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct__genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct__genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct__genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_1_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_1_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_1_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_1_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_1_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_y);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_1_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_1_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_y) {
    e = (*v)(p->__pyx_v_y, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_1_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_1_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_1_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_1_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_1_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_1_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_1_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_1_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_2_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_2_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_2_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_2_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_2_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_s);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_2_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_2_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)o;
  if (p->__pyx_v_s) {
    e = (*v)(p->__pyx_v_s, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_2_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_2_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_2_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_2_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_2_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_2_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_2_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_2_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_3_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_3_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_3_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_3_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_3_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_3_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_3_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_3_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_c);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_3_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_3_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_3_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_3_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_3_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_3_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_3_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_3_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_3_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_3_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_3_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_3_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_3_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *__pyx_freelist_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction[--__pyx_freecount_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_exc_type);
  Py_CLEAR(p->__pyx_v_fn);
  Py_CLEAR(p->__pyx_v_msg);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction[__pyx_freecount_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *)o;
  if (p->__pyx_v_exc_type) {
    e = (*v)(p->__pyx_v_exc_type, a); if (e) return e;
  }
  if (p->__pyx_v_fn) {
    e = (*v)(p->__pyx_v_fn, a); if (e) return e;
  }
  if (p->__pyx_v_msg) {
    e = (*v)(p->__pyx_v_msg, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction *)o;
  tmp = ((PyObject*)p->__pyx_v_exc_type);
  p->__pyx_v_exc_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_fn);
  p->__pyx_v_fn = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_msg);
  p->__pyx_v_msg = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction_spec = {
  "cPyparsing.__pyx_scope_struct_4_conditionAsParseAction",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_4_conditionAsParseAction", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *__pyx_freelist_10cPyparsing___pyx_scope_struct_5__itervalues[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_5__itervalues = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_5__itervalues(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_5__itervalues > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_5__itervalues[--__pyx_freecount_10cPyparsing___pyx_scope_struct_5__itervalues];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_5__itervalues(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_5__itervalues) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_5__itervalues < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_5__itervalues[__pyx_freecount_10cPyparsing___pyx_scope_struct_5__itervalues++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_5__itervalues(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_5__itervalues(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_5__itervalues},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_5__itervalues},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_5__itervalues},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_5__itervalues},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues_spec = {
  "cPyparsing.__pyx_scope_struct_5__itervalues",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_5__itervalues", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__itervalues), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_5__itervalues, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_5__itervalues, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_5__itervalues, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_5__itervalues, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_6_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_6_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_6_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_6_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_6_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_6_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_6_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_6_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_6_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_6_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_6_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_6_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_6_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_6_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_6_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *__pyx_freelist_10cPyparsing___pyx_scope_struct_7__iteritems[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_7__iteritems = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_7__iteritems(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_7__iteritems > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_7__iteritems[--__pyx_freecount_10cPyparsing___pyx_scope_struct_7__iteritems];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_7__iteritems(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_7__iteritems) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_7__iteritems < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_7__iteritems[__pyx_freecount_10cPyparsing___pyx_scope_struct_7__iteritems++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_7__iteritems(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_7__iteritems(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_7__iteritems},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_7__iteritems},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_7__iteritems},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_7__iteritems},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems_spec = {
  "cPyparsing.__pyx_scope_struct_7__iteritems",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_7__iteritems", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_7__iteritems), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_7__iteritems, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_7__iteritems, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_7__iteritems, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_7__iteritems, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_8_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_8_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_8_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_8_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_8_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_8_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_8_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_8_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_8_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_8_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_8_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_8_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_8_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_8_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_8_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_8_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_8_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_8_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_8_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_8_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_8_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_9___iadd__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_9___iadd__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_9___iadd__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_9___iadd__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_9___iadd__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_9___iadd__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__));
    (void) PyObject_INIT(o, t);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_9___iadd__(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_9___iadd__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_9___iadd__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_9___iadd__[__pyx_freecount_10cPyparsing___pyx_scope_struct_9___iadd__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_9___iadd___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_9___iadd__},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_9___iadd__},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_9___iadd___spec = {
  "cPyparsing.__pyx_scope_struct_9___iadd__",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_9___iadd___slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_9___iadd__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_9___iadd__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_9___iadd__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_9___iadd__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_9___iadd__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_10_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_10_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_10_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_10_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_10_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_10_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_10_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_10_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_i);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_10_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_10_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_10_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_10_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_i) {
    e = (*v)(p->__pyx_v_i, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_10_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_10_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_10_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_10_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_10_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_10_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_10_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_10_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *__pyx_freelist_10cPyparsing___pyx_scope_struct_11_asDict[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_11_asDict = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_11_asDict(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_11_asDict > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_11_asDict[--__pyx_freecount_10cPyparsing___pyx_scope_struct_11_asDict];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_11_asDict(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_11_asDict) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_toItem);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_11_asDict < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_11_asDict[__pyx_freecount_10cPyparsing___pyx_scope_struct_11_asDict++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_11_asDict(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *)o;
  if (p->__pyx_v_toItem) {
    e = (*v)(p->__pyx_v_toItem, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_11_asDict(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict *)o;
  tmp = ((PyObject*)p->__pyx_v_toItem);
  p->__pyx_v_toItem = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_11_asDict_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_11_asDict},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_11_asDict},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_11_asDict},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_11_asDict},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_11_asDict_spec = {
  "cPyparsing.__pyx_scope_struct_11_asDict",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_11_asDict_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_11_asDict = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_11_asDict", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_asDict), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_11_asDict, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_11_asDict, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_11_asDict, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_11_asDict, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_12_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_12_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_12_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_12_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_12_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_12_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_12_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_12_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_v_v);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_12_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_12_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_12_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_12_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_v_v) {
    e = (*v)(p->__pyx_v_v, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_12_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_12_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_12_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_12_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_12_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_12_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_12_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_12_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_13_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_13_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_13_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_13_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_13_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_v_v);
  Py_CLEAR(p->__pyx_v_vlist);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_13_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_13_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_v_v) {
    e = (*v)(p->__pyx_v_v, a); if (e) return e;
  }
  if (p->__pyx_v_vlist) {
    e = (*v)(p->__pyx_v_vlist, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_13_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_13_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_13_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_13_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_13_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_13_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_13_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_13_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_14_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_14_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_14_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_14_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_14_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_14_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_14_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_14_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_v_v);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_14_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_14_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_14_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_14_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_v_v) {
    e = (*v)(p->__pyx_v_v, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_14_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_14_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_14_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_14_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_14_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_14_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_14_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_14_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_15_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_15_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_15_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_15_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_15_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_vv);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_15_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_15_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_vv) {
    e = (*v)(p->__pyx_v_vv, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_15_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_15_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_15_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_15_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_15_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_15_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_15_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_15_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *__pyx_freelist_10cPyparsing___pyx_scope_struct_16__trim_arity[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_16__trim_arity = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_16__trim_arity(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_16__trim_arity > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_16__trim_arity[--__pyx_freecount_10cPyparsing___pyx_scope_struct_16__trim_arity];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_16__trim_arity(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_16__trim_arity) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_extract_tb);
  Py_CLEAR(p->__pyx_v_foundArity);
  Py_CLEAR(p->__pyx_v_func);
  Py_CLEAR(p->__pyx_v_limit);
  Py_CLEAR(p->__pyx_v_maxargs);
  Py_CLEAR(p->__pyx_v_pa_call_line_synth);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_16__trim_arity < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_16__trim_arity[__pyx_freecount_10cPyparsing___pyx_scope_struct_16__trim_arity++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_16__trim_arity(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *)o;
  if (p->__pyx_v_extract_tb) {
    e = (*v)(p->__pyx_v_extract_tb, a); if (e) return e;
  }
  if (p->__pyx_v_foundArity) {
    e = (*v)(p->__pyx_v_foundArity, a); if (e) return e;
  }
  if (p->__pyx_v_func) {
    e = (*v)(p->__pyx_v_func, a); if (e) return e;
  }
  if (p->__pyx_v_limit) {
    e = (*v)(p->__pyx_v_limit, a); if (e) return e;
  }
  if (p->__pyx_v_maxargs) {
    e = (*v)(p->__pyx_v_maxargs, a); if (e) return e;
  }
  if (p->__pyx_v_pa_call_line_synth) {
    e = (*v)(p->__pyx_v_pa_call_line_synth, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_16__trim_arity(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity *)o;
  tmp = ((PyObject*)p->__pyx_v_extract_tb);
  p->__pyx_v_extract_tb = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_foundArity);
  p->__pyx_v_foundArity = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_func);
  p->__pyx_v_func = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_limit);
  p->__pyx_v_limit = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_maxargs);
  p->__pyx_v_maxargs = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_pa_call_line_synth);
  p->__pyx_v_pa_call_line_synth = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_16__trim_arity},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_16__trim_arity},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_16__trim_arity},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_16__trim_arity},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity_spec = {
  "cPyparsing.__pyx_scope_struct_16__trim_arity",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_16__trim_arity", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_16__trim_arity), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_16__trim_arity, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_16__trim_arity, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_16__trim_arity, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_16__trim_arity, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *__pyx_freelist_10cPyparsing___pyx_scope_struct_17_setBreak[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_17_setBreak = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_17_setBreak(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_17_setBreak > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_17_setBreak[--__pyx_freecount_10cPyparsing___pyx_scope_struct_17_setBreak];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_17_setBreak(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_17_setBreak) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v__parseMethod);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_17_setBreak < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_17_setBreak[__pyx_freecount_10cPyparsing___pyx_scope_struct_17_setBreak++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_17_setBreak(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *)o;
  if (p->__pyx_v__parseMethod) {
    e = (*v)(p->__pyx_v__parseMethod, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_17_setBreak(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak *)o;
  tmp = ((PyObject*)p->__pyx_v__parseMethod);
  p->__pyx_v__parseMethod = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_17_setBreak},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_17_setBreak},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_17_setBreak},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_17_setBreak},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak_spec = {
  "cPyparsing.__pyx_scope_struct_17_setBreak",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_17_setBreak", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_17_setBreak), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_17_setBreak, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_17_setBreak, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_17_setBreak, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_17_setBreak, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_18_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_18_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_18_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_18_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_18_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_18_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_18_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_18_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_fn);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_18_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_18_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_18_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_18_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_fn) {
    e = (*v)(p->__pyx_v_fn, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_18_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_18_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_18_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_18_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_18_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_18_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_18_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_18_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *__pyx_freelist_10cPyparsing___pyx_scope_struct_19_scanString[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_19_scanString = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_19_scanString(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_19_scanString > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_19_scanString[--__pyx_freecount_10cPyparsing___pyx_scope_struct_19_scanString];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_19_scanString(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_19_scanString) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_e);
  Py_CLEAR(p->__pyx_v_exc);
  Py_CLEAR(p->__pyx_v_instring);
  Py_CLEAR(p->__pyx_v_loc);
  Py_CLEAR(p->__pyx_v_maxMatches);
  Py_CLEAR(p->__pyx_v_nextLoc);
  Py_CLEAR(p->__pyx_v_nextloc);
  Py_CLEAR(p->__pyx_v_overlap);
  Py_CLEAR(p->__pyx_v_parseFn);
  Py_CLEAR(p->__pyx_v_preloc);
  Py_CLEAR(p->__pyx_v_preparseFn);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_tokens);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  Py_CLEAR(p->__pyx_t_3);
  Py_CLEAR(p->__pyx_t_4);
  Py_CLEAR(p->__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_19_scanString < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_19_scanString[__pyx_freecount_10cPyparsing___pyx_scope_struct_19_scanString++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_19_scanString(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString *)o;
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  if (p->__pyx_v_exc) {
    e = (*v)(p->__pyx_v_exc, a); if (e) return e;
  }
  if (p->__pyx_v_instring) {
    e = (*v)(p->__pyx_v_instring, a); if (e) return e;
  }
  if (p->__pyx_v_loc) {
    e = (*v)(p->__pyx_v_loc, a); if (e) return e;
  }
  if (p->__pyx_v_maxMatches) {
    e = (*v)(p->__pyx_v_maxMatches, a); if (e) return e;
  }
  if (p->__pyx_v_nextLoc) {
    e = (*v)(p->__pyx_v_nextLoc, a); if (e) return e;
  }
  if (p->__pyx_v_nextloc) {
    e = (*v)(p->__pyx_v_nextloc, a); if (e) return e;
  }
  if (p->__pyx_v_overlap) {
    e = (*v)(p->__pyx_v_overlap, a); if (e) return e;
  }
  if (p->__pyx_v_parseFn) {
    e = (*v)(p->__pyx_v_parseFn, a); if (e) return e;
  }
  if (p->__pyx_v_preloc) {
    e = (*v)(p->__pyx_v_preloc, a); if (e) return e;
  }
  if (p->__pyx_v_preparseFn) {
    e = (*v)(p->__pyx_v_preparseFn, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  if (p->__pyx_v_tokens) {
    e = (*v)(p->__pyx_v_tokens, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  if (p->__pyx_t_3) {
    e = (*v)(p->__pyx_t_3, a); if (e) return e;
  }
  if (p->__pyx_t_4) {
    e = (*v)(p->__pyx_t_4, a); if (e) return e;
  }
  if (p->__pyx_t_5) {
    e = (*v)(p->__pyx_t_5, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_19_scanString_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_19_scanString},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_19_scanString},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_19_scanString},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_19_scanString_spec = {
  "cPyparsing.__pyx_scope_struct_19_scanString",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_19_scanString_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_19_scanString = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_19_scanString", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_scanString), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_19_scanString, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_19_scanString, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_19_scanString, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *__pyx_freelist_10cPyparsing___pyx_scope_struct_20_split[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_20_split = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_20_split(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_20_split > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_20_split[--__pyx_freecount_10cPyparsing___pyx_scope_struct_20_split];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_20_split(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_20_split) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_e);
  Py_CLEAR(p->__pyx_v_includeSeparators);
  Py_CLEAR(p->__pyx_v_instring);
  Py_CLEAR(p->__pyx_v_last);
  Py_CLEAR(p->__pyx_v_maxsplit);
  Py_CLEAR(p->__pyx_v_s);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_t);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_20_split < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_20_split[__pyx_freecount_10cPyparsing___pyx_scope_struct_20_split++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_20_split(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split *)o;
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  if (p->__pyx_v_includeSeparators) {
    e = (*v)(p->__pyx_v_includeSeparators, a); if (e) return e;
  }
  if (p->__pyx_v_instring) {
    e = (*v)(p->__pyx_v_instring, a); if (e) return e;
  }
  if (p->__pyx_v_last) {
    e = (*v)(p->__pyx_v_last, a); if (e) return e;
  }
  if (p->__pyx_v_maxsplit) {
    e = (*v)(p->__pyx_v_maxsplit, a); if (e) return e;
  }
  if (p->__pyx_v_s) {
    e = (*v)(p->__pyx_v_s, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_20_split_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_20_split},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_20_split},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_20_split},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_20_split_spec = {
  "cPyparsing.__pyx_scope_struct_20_split",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_20_split_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_20_split = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_20_split", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_20_split), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_20_split, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_20_split, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_20_split, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_21___mul__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_21___mul__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_21___mul__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_21___mul__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_21___mul__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_21___mul__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_21___mul__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_21___mul__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_makeOptionalList);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_21___mul__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_21___mul__[__pyx_freecount_10cPyparsing___pyx_scope_struct_21___mul__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_21___mul__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *)o;
  if (p->__pyx_v_makeOptionalList) {
    e = (*v)(p->__pyx_v_makeOptionalList, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_21___mul__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__ *)o;
  tmp = ((PyObject*)p->__pyx_v_makeOptionalList);
  p->__pyx_v_makeOptionalList = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_21___mul___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_21___mul__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_21___mul__},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_21___mul__},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_21___mul__},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_21___mul___spec = {
  "cPyparsing.__pyx_scope_struct_21___mul__",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_21___mul___slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_21___mul__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_21___mul__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___mul__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_21___mul__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_21___mul__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_21___mul__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_21___mul__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_22_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_22_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_22_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_22_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_22_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_22_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_22_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_22_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_o);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_22_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_22_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_22_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_22_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_o) {
    e = (*v)(p->__pyx_v_o, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_22_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_22_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_22_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_22_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_22_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_22_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_22_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_22_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_22_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_23___add__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_23___add__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_23___add__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_23___add__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_23___add__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_23___add__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_23___add__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_23___add__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_23___add__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_23___add__[__pyx_freecount_10cPyparsing___pyx_scope_struct_23___add__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_23___add__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_23___add__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_23___add___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_23___add__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_23___add__},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_23___add__},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_23___add__},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_23___add___spec = {
  "cPyparsing.__pyx_scope_struct_23___add__",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_23___add___slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_23___add__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_23___add__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_23___add__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_23___add__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_23___add__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_23___add__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_23___add__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_24___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_24___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_24___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_24___init__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_24___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_24___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_24___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_24___init__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_excludeChars);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_24___init__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_24___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_24___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_24___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *)o;
  if (p->__pyx_v_excludeChars) {
    e = (*v)(p->__pyx_v_excludeChars, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_24___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_excludeChars);
  p->__pyx_v_excludeChars = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_24___init___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_24___init__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_24___init__},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_24___init__},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_24___init__},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_24___init___spec = {
  "cPyparsing.__pyx_scope_struct_24___init__",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_24___init___slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_24___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_24___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_24___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_24___init__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_24___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_24___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_24___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_25_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_25_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_25_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_25_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_25_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_25_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_25_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_25_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_c);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_25_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_25_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_25_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_25_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_25_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_25_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_25_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_25_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_25_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_25_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_25_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_25_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_25_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_26_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_26_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_26_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_26_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_26_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_26_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_26_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_26_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_c);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_26_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_26_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_26_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_26_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_26_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_26_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_26_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_26_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_26_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_26_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_26_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_26_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_26_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *__pyx_freelist_10cPyparsing___pyx_scope_struct_27_sub[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_27_sub = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_27_sub(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_27_sub > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_27_sub[--__pyx_freecount_10cPyparsing___pyx_scope_struct_27_sub];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_27_sub(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_27_sub) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_repl);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_27_sub < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_27_sub[__pyx_freecount_10cPyparsing___pyx_scope_struct_27_sub++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_27_sub(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *)o;
  if (p->__pyx_v_repl) {
    e = (*v)(p->__pyx_v_repl, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_27_sub(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub *)o;
  tmp = ((PyObject*)p->__pyx_v_repl);
  p->__pyx_v_repl = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_27_sub_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_27_sub},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_27_sub},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_27_sub},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_27_sub},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_27_sub_spec = {
  "cPyparsing.__pyx_scope_struct_27_sub",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_27_sub_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_27_sub = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_27_sub", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_sub), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_27_sub, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_27_sub, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_27_sub, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_27_sub, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_28___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_28___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_28___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_28___init__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_28___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_28___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_28___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_28___init__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_28___init__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_28___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_28___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_28___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_28___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_28___init___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_28___init__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_28___init__},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_28___init__},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_28___init__},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_28___init___spec = {
  "cPyparsing.__pyx_scope_struct_28___init__",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_28___init___slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_28___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_28___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_28___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_28___init__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_28___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_28___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_28___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_29_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_29_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_29_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_29_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_29_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_29_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_29_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_29_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_i);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_29_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_29_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_29_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_29_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_i) {
    e = (*v)(p->__pyx_v_i, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_29_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_29_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_29_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_29_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_29_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_29_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_29_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_29_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_29_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_30___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_30___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_30___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_30___init__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_30___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_30___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_30___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_30___init__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_30___init__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_30___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_30___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_30___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_30___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_30___init___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_30___init__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_30___init__},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_30___init__},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_30___init__},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_30___init___spec = {
  "cPyparsing.__pyx_scope_struct_30___init__",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_30___init___slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_30___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_30___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_30___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_30___init__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_30___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_30___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_30___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_31_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_31_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_31_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_31_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_31_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_31_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_31_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_31_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_c);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_31_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_31_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_31_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_31_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_31_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_31_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_31_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_31_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_31_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_31_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_31_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_31_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_31_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_32_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_32_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_32_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_32_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_32_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_c);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_32_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_32_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_32_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_32_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_32_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_32_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_32_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_32_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_32_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_32_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_33___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_33___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_33___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_33___init__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_33___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_33___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_33___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_33___init__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_33___init__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_33___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_33___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_33___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_33___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_33___init___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_33___init__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_33___init__},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_33___init__},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_33___init__},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_33___init___spec = {
  "cPyparsing.__pyx_scope_struct_33___init__",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_33___init___slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_33___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_33___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_33___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_33___init__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_33___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_33___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_33___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_34_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_34_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_34_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_34_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_34_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_34_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_34_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_34_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_expr);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_34_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_34_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_34_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_34_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_expr) {
    e = (*v)(p->__pyx_v_expr, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_34_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_34_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_34_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_34_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_34_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_34_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_34_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_34_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_34_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_35_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_35_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_35_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_35_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_35_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_35_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_35_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_35_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_35_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_35_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_35_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_35_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_35_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_35_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_35_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_36_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_36_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_36_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_36_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_36_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_36_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_36_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_36_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_36_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_36_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_36_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_36_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_36_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_36_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_36_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_36_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_36_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_36_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_36_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_36_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_36_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_37_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_37_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_37_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_37_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_37_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_37_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_37_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_37_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_37_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_37_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_37_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_37_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_37_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_37_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_37_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_38_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_38_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_38_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_38_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_38_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_38_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_38_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_38_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_38_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_38_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_38_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_38_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_38_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_38_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_38_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_38_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_38_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_38_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_38_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_38_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_38_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_39_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_39_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_39_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_39_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_39_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_39_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_39_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_39_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_39_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_39_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_39_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_39_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_39_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_39_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_39_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_40_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_40_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_40_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_40_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_40_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_40_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_40_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_40_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_40_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_40_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_40_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_40_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_40_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_40_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_40_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_40_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_40_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_40_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_40_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_40_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_40_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_41_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_41_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_41_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_41_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_41_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_41_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_41_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_41_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_41_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_41_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_41_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_41_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_41_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_41_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_41_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_42_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_42_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_42_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_42_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_42_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_42_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_42_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_42_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_42_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_42_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_42_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_42_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_42_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_42_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_42_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_42_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_42_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_42_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_42_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_42_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_42_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_43_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_43_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_43_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_43_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_43_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_43_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_43_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_43_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_43_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_43_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_43_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_43_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_43_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_43_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_43_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_44_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_44_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_44_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_44_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_44_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_44_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_44_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_44_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_44_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_44_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_44_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_44_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_44_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_44_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_44_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_44_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_44_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_44_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_44_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_44_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_44_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_45_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_45_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_45_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_45_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_45_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_45_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_45_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_45_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_45_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_45_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_45_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_45_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_45_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_45_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_45_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_46_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_46_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_46_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_46_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_46_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_46_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_46_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_46_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_46_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_46_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_46_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_46_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_46_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_46_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_46_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_46_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_46_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_46_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_46_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_46_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_46_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_47_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_47_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_47_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_47_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_47_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_47_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_47_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_47_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_47_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_47_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_47_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_47_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_47_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_47_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_47_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_48_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_48_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_48_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_48_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_48_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_48_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_48_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_48_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_48_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_48_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_48_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_48_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_48_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_48_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_48_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_48_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_48_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_48_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_48_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_48_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_48_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_49_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_49_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_49_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_49_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_49_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_49_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_49_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_49_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_49_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_49_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_49_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_49_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_49_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_49_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_49_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_50_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_50_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_50_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_50_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_50_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_50_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_50_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_50_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_50_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_50_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_50_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_50_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_50_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_50_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_50_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_50_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_50_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_50_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_50_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_50_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_51_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_51_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_51_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_51_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_51_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_e);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_51_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_51_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_51_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_51_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_51_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_51_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_51_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_51_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_51_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_51_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *__pyx_freelist_10cPyparsing___pyx_scope_struct_52_traceParseAction[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_52_traceParseAction = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_52_traceParseAction(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_52_traceParseAction > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_52_traceParseAction[--__pyx_freecount_10cPyparsing___pyx_scope_struct_52_traceParseAction];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_52_traceParseAction(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_52_traceParseAction) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_f);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_52_traceParseAction < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_52_traceParseAction[__pyx_freecount_10cPyparsing___pyx_scope_struct_52_traceParseAction++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_52_traceParseAction(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *)o;
  if (p->__pyx_v_f) {
    e = (*v)(p->__pyx_v_f, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_52_traceParseAction(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction *)o;
  tmp = ((PyObject*)p->__pyx_v_f);
  p->__pyx_v_f = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_52_traceParseAction},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_52_traceParseAction},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_52_traceParseAction},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_52_traceParseAction},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction_spec = {
  "cPyparsing.__pyx_scope_struct_52_traceParseAction",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_52_traceParseAction", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_traceParseAction), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_52_traceParseAction, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_52_traceParseAction, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_52_traceParseAction, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_52_traceParseAction, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *__pyx_freelist_10cPyparsing___pyx_scope_struct_53_countedArray[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_53_countedArray = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_53_countedArray(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_53_countedArray > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_53_countedArray[--__pyx_freecount_10cPyparsing___pyx_scope_struct_53_countedArray];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_53_countedArray(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_53_countedArray) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_arrayExpr);
  Py_CLEAR(p->__pyx_v_expr);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_53_countedArray < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_53_countedArray[__pyx_freecount_10cPyparsing___pyx_scope_struct_53_countedArray++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_53_countedArray(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *)o;
  if (p->__pyx_v_arrayExpr) {
    e = (*v)(p->__pyx_v_arrayExpr, a); if (e) return e;
  }
  if (p->__pyx_v_expr) {
    e = (*v)(p->__pyx_v_expr, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_53_countedArray(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray *)o;
  tmp = ((PyObject*)p->__pyx_v_arrayExpr);
  p->__pyx_v_arrayExpr = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_expr);
  p->__pyx_v_expr = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_53_countedArray},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_53_countedArray},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_53_countedArray},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_53_countedArray},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray_spec = {
  "cPyparsing.__pyx_scope_struct_53_countedArray",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_53_countedArray", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_53_countedArray), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_53_countedArray, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_53_countedArray, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_53_countedArray, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_53_countedArray, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *__pyx_freelist_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral[--__pyx_freecount_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_rep);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral[__pyx_freecount_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *)o;
  if (p->__pyx_v_rep) {
    e = (*v)(p->__pyx_v_rep, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral *)o;
  tmp = ((PyObject*)p->__pyx_v_rep);
  p->__pyx_v_rep = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral_spec = {
  "cPyparsing.__pyx_scope_struct_54_matchPreviousLiteral",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_54_matchPreviousLiteral", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_55_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_55_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_55_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_55_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_55_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_55_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_55_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_55_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_tt);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_55_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_55_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_55_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_55_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_tt) {
    e = (*v)(p->__pyx_v_tt, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_55_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_55_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_55_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_55_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_55_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_55_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_55_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_55_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_rep);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *)o;
  if (p->__pyx_v_rep) {
    e = (*v)(p->__pyx_v_rep, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *)o;
  tmp = ((PyObject*)p->__pyx_v_rep);
  p->__pyx_v_rep = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr_spec = {
  "cPyparsing.__pyx_scope_struct_56_matchPreviousExpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_56_matchPreviousExpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *__pyx_freelist_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater[--__pyx_freecount_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_matchTokens);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater[__pyx_freecount_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_matchTokens) {
    e = (*v)(p->__pyx_v_matchTokens, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_matchTokens);
  p->__pyx_v_matchTokens = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater_spec = {
  "cPyparsing.__pyx_scope_struct_57_copyTokenToRepeater",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_57_copyTokenToRepeater", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *__pyx_freelist_10cPyparsing___pyx_scope_struct_58_oneOf[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_58_oneOf = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_58_oneOf(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_58_oneOf > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_58_oneOf[--__pyx_freecount_10cPyparsing___pyx_scope_struct_58_oneOf];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_58_oneOf(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_58_oneOf) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_parseElementClass);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_58_oneOf < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_58_oneOf[__pyx_freecount_10cPyparsing___pyx_scope_struct_58_oneOf++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_58_oneOf(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *)o;
  if (p->__pyx_v_parseElementClass) {
    e = (*v)(p->__pyx_v_parseElementClass, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_58_oneOf(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf *)o;
  tmp = ((PyObject*)p->__pyx_v_parseElementClass);
  p->__pyx_v_parseElementClass = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_58_oneOf},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_58_oneOf},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_58_oneOf},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_58_oneOf},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf_spec = {
  "cPyparsing.__pyx_scope_struct_58_oneOf",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_58_oneOf", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_oneOf), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_58_oneOf, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_58_oneOf, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_58_oneOf, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_58_oneOf, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_59_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_59_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_59_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_59_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_59_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_sym);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_59_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_59_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_sym) {
    e = (*v)(p->__pyx_v_sym, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_59_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_59_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_59_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_59_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_59_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_59_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_59_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_59_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_60_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_60_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_60_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_60_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_60_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_60_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_60_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_60_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_sym);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_60_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_60_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_60_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_60_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_sym) {
    e = (*v)(p->__pyx_v_sym, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_60_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_60_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_60_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_60_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_60_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_60_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_60_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_60_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_61_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_61_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_61_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_61_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_61_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_61_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_61_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_61_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_sym);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_61_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_61_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_61_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_61_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_sym) {
    e = (*v)(p->__pyx_v_sym, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_61_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_61_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_61_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_61_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_61_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_61_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_61_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_61_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *__pyx_freelist_10cPyparsing___pyx_scope_struct_62_srange[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_62_srange = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_62_srange(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_62_srange > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_62_srange[--__pyx_freecount_10cPyparsing___pyx_scope_struct_62_srange];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_62_srange(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_62_srange) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v__expanded);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_62_srange < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_62_srange[__pyx_freecount_10cPyparsing___pyx_scope_struct_62_srange++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_62_srange(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *)o;
  if (p->__pyx_v__expanded) {
    e = (*v)(p->__pyx_v__expanded, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_62_srange(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange *)o;
  tmp = ((PyObject*)p->__pyx_v__expanded);
  p->__pyx_v__expanded = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_62_srange_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_62_srange},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_62_srange},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_62_srange},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_62_srange},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_62_srange_spec = {
  "cPyparsing.__pyx_scope_struct_62_srange",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_62_srange_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_62_srange = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_62_srange", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_srange), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_62_srange, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_62_srange, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_62_srange, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_62_srange, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_63_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_63_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_63_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_63_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_63_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_c);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_63_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_63_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_63_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_63_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_63_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_63_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_63_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_63_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_63_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_63_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_64_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_64_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_64_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_64_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_64_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_part);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_64_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_64_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_part) {
    e = (*v)(p->__pyx_v_part, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_64_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_64_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_64_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_64_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_64_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_64_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_64_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_64_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *__pyx_freelist_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol[--__pyx_freecount_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_n);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol[__pyx_freecount_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *)o;
  if (p->__pyx_v_n) {
    e = (*v)(p->__pyx_v_n, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol *)o;
  tmp = ((PyObject*)p->__pyx_v_n);
  p->__pyx_v_n = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol_spec = {
  "cPyparsing.__pyx_scope_struct_65_matchOnlyAtCol",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_65_matchOnlyAtCol", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *__pyx_freelist_10cPyparsing___pyx_scope_struct_66_replaceWith[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_66_replaceWith = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_66_replaceWith(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_66_replaceWith > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_66_replaceWith[--__pyx_freecount_10cPyparsing___pyx_scope_struct_66_replaceWith];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_66_replaceWith(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_66_replaceWith) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_replStr);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_66_replaceWith < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_66_replaceWith[__pyx_freecount_10cPyparsing___pyx_scope_struct_66_replaceWith++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_66_replaceWith(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *)o;
  if (p->__pyx_v_replStr) {
    e = (*v)(p->__pyx_v_replStr, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_66_replaceWith(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith *)o;
  tmp = ((PyObject*)p->__pyx_v_replStr);
  p->__pyx_v_replStr = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_66_replaceWith},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_66_replaceWith},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_66_replaceWith},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_66_replaceWith},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith_spec = {
  "cPyparsing.__pyx_scope_struct_66_replaceWith",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_66_replaceWith", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_replaceWith), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_66_replaceWith, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_66_replaceWith, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_66_replaceWith, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_66_replaceWith, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *__pyx_freelist_10cPyparsing___pyx_scope_struct_67_tokenMap[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_67_tokenMap = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_67_tokenMap(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_67_tokenMap > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_67_tokenMap[--__pyx_freecount_10cPyparsing___pyx_scope_struct_67_tokenMap];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_67_tokenMap(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_67_tokenMap) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_args);
  Py_CLEAR(p->__pyx_v_func);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_67_tokenMap < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_67_tokenMap[__pyx_freecount_10cPyparsing___pyx_scope_struct_67_tokenMap++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_67_tokenMap(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *)o;
  if (p->__pyx_v_args) {
    e = (*v)(p->__pyx_v_args, a); if (e) return e;
  }
  if (p->__pyx_v_func) {
    e = (*v)(p->__pyx_v_func, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_67_tokenMap(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap *)o;
  tmp = ((PyObject*)p->__pyx_v_args);
  p->__pyx_v_args = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_func);
  p->__pyx_v_func = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_67_tokenMap},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_67_tokenMap},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_67_tokenMap},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_67_tokenMap},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap_spec = {
  "cPyparsing.__pyx_scope_struct_67_tokenMap",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_67_tokenMap", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_67_tokenMap), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_67_tokenMap, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_67_tokenMap, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_67_tokenMap, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_67_tokenMap, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *__pyx_freelist_10cPyparsing___pyx_scope_struct_68__makeTags[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_68__makeTags = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_68__makeTags(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_68__makeTags > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_68__makeTags[--__pyx_freecount_10cPyparsing___pyx_scope_struct_68__makeTags];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_68__makeTags(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_68__makeTags) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_resname);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_68__makeTags < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_68__makeTags[__pyx_freecount_10cPyparsing___pyx_scope_struct_68__makeTags++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_68__makeTags(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *)o;
  if (p->__pyx_v_resname) {
    e = (*v)(p->__pyx_v_resname, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_68__makeTags(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags *)o;
  tmp = ((PyObject*)p->__pyx_v_resname);
  p->__pyx_v_resname = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_68__makeTags},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_68__makeTags},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_68__makeTags},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_68__makeTags},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags_spec = {
  "cPyparsing.__pyx_scope_struct_68__makeTags",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_68__makeTags", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_68__makeTags), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_68__makeTags, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_68__makeTags, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_68__makeTags, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_68__makeTags, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_69___call__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_69___call__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_69___call__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_69___call__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_69___call__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_69___call__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_69___call__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_69___call__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_attrs);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_69___call__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_69___call__[__pyx_freecount_10cPyparsing___pyx_scope_struct_69___call__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_69___call__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *)o;
  if (p->__pyx_v_attrs) {
    e = (*v)(p->__pyx_v_attrs, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_69___call__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__ *)o;
  tmp = ((PyObject*)p->__pyx_v_attrs);
  p->__pyx_v_attrs = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_69___call___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_69___call__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_69___call__},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_69___call__},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_69___call__},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_69___call___spec = {
  "cPyparsing.__pyx_scope_struct_69___call__",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_69___call___slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_69___call__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_69___call__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_69___call__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_69___call__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_69___call__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_69___call__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_69___call__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *__pyx_freelist_10cPyparsing___pyx_scope_struct_70_indentedBlock[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_70_indentedBlock = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_70_indentedBlock(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_70_indentedBlock > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_70_indentedBlock[--__pyx_freecount_10cPyparsing___pyx_scope_struct_70_indentedBlock];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_70_indentedBlock(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_70_indentedBlock) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_backup_stack);
  Py_CLEAR(p->__pyx_v_indentStack);
  Py_CLEAR(p->__pyx_v_reset_stack);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_70_indentedBlock < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_70_indentedBlock[__pyx_freecount_10cPyparsing___pyx_scope_struct_70_indentedBlock++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_70_indentedBlock(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *)o;
  if (p->__pyx_v_backup_stack) {
    e = (*v)(p->__pyx_v_backup_stack, a); if (e) return e;
  }
  if (p->__pyx_v_indentStack) {
    e = (*v)(p->__pyx_v_indentStack, a); if (e) return e;
  }
  if (p->__pyx_v_reset_stack) {
    e = (*v)(p->__pyx_v_reset_stack, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_70_indentedBlock(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock *)o;
  tmp = ((PyObject*)p->__pyx_v_backup_stack);
  p->__pyx_v_backup_stack = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_indentStack);
  p->__pyx_v_indentStack = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_reset_stack);
  p->__pyx_v_reset_stack = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_70_indentedBlock},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_70_indentedBlock},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_70_indentedBlock},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_70_indentedBlock},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock_spec = {
  "cPyparsing.__pyx_scope_struct_70_indentedBlock",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_70_indentedBlock", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_indentedBlock), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_70_indentedBlock, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_70_indentedBlock, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_70_indentedBlock, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_70_indentedBlock, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_71_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_71_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_71_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_71_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_71_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_71_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_71_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_71_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_tt);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_71_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_71_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_71_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_71_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_tt) {
    e = (*v)(p->__pyx_v_tt, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_71_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_71_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_71_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_71_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_71_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_71_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_71_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_71_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *__pyx_freelist_10cPyparsing___pyx_scope_struct_72_convertToDate[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_72_convertToDate = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_72_convertToDate(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_72_convertToDate > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_72_convertToDate[--__pyx_freecount_10cPyparsing___pyx_scope_struct_72_convertToDate];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_72_convertToDate(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_72_convertToDate) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_fmt);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_72_convertToDate < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_72_convertToDate[__pyx_freecount_10cPyparsing___pyx_scope_struct_72_convertToDate++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_72_convertToDate(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *)o;
  if (p->__pyx_v_fmt) {
    e = (*v)(p->__pyx_v_fmt, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_72_convertToDate(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate *)o;
  tmp = ((PyObject*)p->__pyx_v_fmt);
  p->__pyx_v_fmt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_72_convertToDate},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_72_convertToDate},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_72_convertToDate},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_72_convertToDate},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate_spec = {
  "cPyparsing.__pyx_scope_struct_72_convertToDate",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_72_convertToDate", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_convertToDate), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_72_convertToDate, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_72_convertToDate, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_72_convertToDate, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_72_convertToDate, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *__pyx_freelist_10cPyparsing___pyx_scope_struct_73_convertToDatetime[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_73_convertToDatetime = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_73_convertToDatetime(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_73_convertToDatetime > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_73_convertToDatetime[--__pyx_freecount_10cPyparsing___pyx_scope_struct_73_convertToDatetime];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_73_convertToDatetime(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_73_convertToDatetime) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_fmt);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_73_convertToDatetime < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_73_convertToDatetime[__pyx_freecount_10cPyparsing___pyx_scope_struct_73_convertToDatetime++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_73_convertToDatetime(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *)o;
  if (p->__pyx_v_fmt) {
    e = (*v)(p->__pyx_v_fmt, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_73_convertToDatetime(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime *)o;
  tmp = ((PyObject*)p->__pyx_v_fmt);
  p->__pyx_v_fmt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_73_convertToDatetime},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_73_convertToDatetime},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_73_convertToDatetime},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_73_convertToDatetime},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime_spec = {
  "cPyparsing.__pyx_scope_struct_73_convertToDatetime",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_73_convertToDatetime", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_convertToDatetime), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_73_convertToDatetime, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_73_convertToDatetime, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_73_convertToDatetime, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_73_convertToDatetime, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_74___get__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_74___get__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_74___get__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_74___get__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_74___get__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_74___get__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_74___get__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_74___get__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_cls);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_74___get__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_74___get__[__pyx_freecount_10cPyparsing___pyx_scope_struct_74___get__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_74___get__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *)o;
  if (p->__pyx_v_cls) {
    e = (*v)(p->__pyx_v_cls, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_74___get__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__ *)o;
  tmp = ((PyObject*)p->__pyx_v_cls);
  p->__pyx_v_cls = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_74___get___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_74___get__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_74___get__},
  {Py_tp_clear, (void *)__pyx_tp_clear_10cPyparsing___pyx_scope_struct_74___get__},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_74___get__},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_74___get___spec = {
  "cPyparsing.__pyx_scope_struct_74___get__",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_74___get___slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_74___get__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_74___get__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___get__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_74___get__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_74___get__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_74___get__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_74___get__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_75_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_75_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_75_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_75_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_75_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_75_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_75_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_75_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_superclass);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_75_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_75_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_75_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_75_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_superclass) {
    e = (*v)(p->__pyx_v_superclass, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_75_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_75_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_75_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_75_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_75_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_75_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_75_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_75_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_76_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_76_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_76_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_76_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_76_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_76_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_76_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_76_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_exp);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_76_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_76_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_76_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_76_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_exp) {
    e = (*v)(p->__pyx_v_exp, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_76_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_76_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_76_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_76_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_76_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_76_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_76_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_76_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_76_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_77_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_77_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_77_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_77_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_77_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_exp);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_77_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_77_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_exp) {
    e = (*v)(p->__pyx_v_exp, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_77_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_77_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_77_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_77_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_77_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_77_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_77_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_77_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_78_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_78_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_78_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_78_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_78_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_78_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_78_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_78_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_exp);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_78_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_78_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_78_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_78_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_exp) {
    e = (*v)(p->__pyx_v_exp, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_78_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_78_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_78_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_78_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_78_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_78_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_78_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_78_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_79_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_79_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_79_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_79_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_79_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_79_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_79_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_79_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_exp);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_79_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_79_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_79_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_79_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_exp) {
    e = (*v)(p->__pyx_v_exp, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_79_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_79_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_79_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr_spec = {
  "cPyparsing.__pyx_scope_struct_79_genexpr",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_79_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_79_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_79_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_79_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *__pyx_freelist_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException[--__pyx_freecount_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_exc_type);
  Py_CLEAR(p->__pyx_v_msg);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  Py_CLEAR(p->__pyx_t_3);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException[__pyx_freecount_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException *)o;
  if (p->__pyx_v_exc_type) {
    e = (*v)(p->__pyx_v_exc_type, a); if (e) return e;
  }
  if (p->__pyx_v_msg) {
    e = (*v)(p->__pyx_v_msg, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  if (p->__pyx_t_3) {
    e = (*v)(p->__pyx_t_3, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException},
  {Py_tp_new, (void *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException},
  {0, 0},
};
static PyType_Spec __pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException_spec = {
  "cPyparsing.__pyx_scope_struct_80_assertRaisesParseException",
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException_slots,
};
#else

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.""__pyx_scope_struct_80_assertRaisesParseException", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_u_0, __pyx_k_0, sizeof(__pyx_k_0), 0, 1, 0, 0},
    {&__pyx_kp_u_0123456789, __pyx_k_0123456789, sizeof(__pyx_k_0123456789), 0, 1, 0, 0},
    {&__pyx_kp_u_0_0_7, __pyx_k_0_0_7, sizeof(__pyx_k_0_0_7), 0, 1, 0, 0},
    {&__pyx_kp_u_0_1, __pyx_k_0_1, sizeof(__pyx_k_0_1), 0, 1, 0, 0},
    {&__pyx_kp_u_0_1_2, __pyx_k_0_1_2, sizeof(__pyx_k_0_1_2), 0, 1, 0, 0},
    {&__pyx_kp_u_0_1_3, __pyx_k_0_1_3, sizeof(__pyx_k_0_1_3), 0, 1, 0, 0},
    {&__pyx_kp_u_0_2, __pyx_k_0_2, sizeof(__pyx_k_0_2), 0, 1, 0, 0},
    {&__pyx_kp_u_0_9a_fA_F_1_4, __pyx_k_0_9a_fA_F_1_4, sizeof(__pyx_k_0_9a_fA_F_1_4), 0, 1, 0, 0},
    {&__pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a, __pyx_k_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a, sizeof(__pyx_k_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a), 0, 1, 0, 0},
    {&__pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a, __pyx_k_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a, sizeof(__pyx_k_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a), 0, 1, 0, 0},
    {&__pyx_kp_u_0_failed_1_2, __pyx_k_0_failed_1_2, sizeof(__pyx_k_0_failed_1_2), 0, 1, 0, 0},
    {&__pyx_kp_u_0_setting_results_name_0_r_on_1, __pyx_k_0_setting_results_name_0_r_on_1, sizeof(__pyx_k_0_setting_results_name_0_r_on_1), 0, 1, 0, 0},
    {&__pyx_kp_u_0_setting_results_name_1_r_on_2, __pyx_k_0_setting_results_name_1_r_on_2, sizeof(__pyx_k_0_setting_results_name_1_r_on_2), 0, 1, 0, 0},
    {&__pyx_kp_u_0_setting_results_name_1_r_on_2_2, __pyx_k_0_setting_results_name_1_r_on_2_2, sizeof(__pyx_k_0_setting_results_name_1_r_on_2_2), 0, 1, 0, 0},
    {&__pyx_kp_u_0_xX_0_9a_fA_F, __pyx_k_0_xX_0_9a_fA_F, sizeof(__pyx_k_0_xX_0_9a_fA_F), 0, 1, 0, 0},
    {&__pyx_kp_u_0x, __pyx_k_0x, sizeof(__pyx_k_0x), 0, 1, 0, 0},
    {&__pyx_kp_u_0xa1_0xbf_0xd7_0xf7, __pyx_k_0xa1_0xbf_0xd7_0xf7, sizeof(__pyx_k_0xa1_0xbf_0xd7_0xf7), 0, 1, 0, 0},
    {&__pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff, __pyx_k_0xc0_0xd6_0xd8_0xf6_0xf8_0xff, sizeof(__pyx_k_0xc0_0xd6_0xd8_0xf6_0xf8_0xff), 0, 1, 0, 0},
    {&__pyx_kp_u_100_100_100_3_14159_6_02e23_1e, __pyx_k_100_100_100_3_14159_6_02e23_1e, sizeof(__pyx_k_100_100_100_3_14159_6_02e23_1e), 0, 1, 0, 0},
    {&__pyx_kp_u_100_FF, __pyx_k_100_FF, sizeof(__pyx_k_100_FF), 0, 1, 0, 0},
    {&__pyx_kp_u_12345678_1234_5678_1234_5678123, __pyx_k_12345678_1234_5678_1234_5678123, sizeof(__pyx_k_12345678_1234_5678_1234_5678123), 0, 1, 0, 0},
    {&__pyx_kp_u_24_Nov_2023_01_45_UTC, __pyx_k_24_Nov_2023_01_45_UTC, sizeof(__pyx_k_24_Nov_2023_01_45_UTC), 0, 1, 0, 0},
    {&__pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0, __pyx_k_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0, sizeof(__pyx_k_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0), 0, 1, 0, 0},
    {&__pyx_kp_u_2_4_7_2_3_0, __pyx_k_2_4_7_2_3_0, sizeof(__pyx_k_2_4_7_2_3_0), 0, 1, 0, 0},
    {&__pyx_n_u_ABCDEFabcdef, __pyx_k_ABCDEFabcdef, sizeof(__pyx_k_ABCDEFabcdef), 0, 1, 0, 1},
    {&__pyx_n_s_ANY_VALUE, __pyx_k_ANY_VALUE, sizeof(__pyx_k_ANY_VALUE), 0, 0, 1, 1},
    {&__pyx_kp_u_A_cross_version_compatibility_c, __pyx_k_A_cross_version_compatibility_c, sizeof(__pyx_k_A_cross_version_compatibility_c), 0, 1, 0, 0},
    {&__pyx_kp_s_A_mixin_class_to_add_parse_resu, __pyx_k_A_mixin_class_to_add_parse_resu, sizeof(__pyx_k_A_mixin_class_to_add_parse_resu), 0, 0, 1, 0},
    {&__pyx_kp_s_A_namespace_class_for_defining, __pyx_k_A_namespace_class_for_defining, sizeof(__pyx_k_A_namespace_class_for_defining), 0, 0, 1, 0},
    {&__pyx_kp_s_A_set_of_Unicode_characters_for, __pyx_k_A_set_of_Unicode_characters_for, sizeof(__pyx_k_A_set_of_Unicode_characters_for), 0, 0, 1, 0},
    {&__pyx_kp_s_A_short_cut_class_for_defining_W, __pyx_k_A_short_cut_class_for_defining_W, sizeof(__pyx_k_A_short_cut_class_for_defining_W), 0, 0, 1, 0},
    {&__pyx_kp_s_A_token_that_will_never_match, __pyx_k_A_token_that_will_never_match, sizeof(__pyx_k_A_token_that_will_never_match), 0, 0, 1, 0},
    {&__pyx_kp_s_A_variation_on_class_Literal_whi, __pyx_k_A_variation_on_class_Literal_whi, sizeof(__pyx_k_A_variation_on_class_Literal_whi), 0, 0, 1, 0},
    {&__pyx_kp_s_Abstract_base_level_parser_eleme, __pyx_k_Abstract_base_level_parser_eleme, sizeof(__pyx_k_Abstract_base_level_parser_eleme), 0, 0, 1, 0},
    {&__pyx_kp_s_Abstract_class_ParserElement_sub, __pyx_k_Abstract_class_ParserElement_sub, sizeof(__pyx_k_Abstract_class_ParserElement_sub), 0, 0, 1, 0},
    {&__pyx_kp_s_Abstract_subclass_of_ParserEleme, __pyx_k_Abstract_subclass_of_ParserEleme, sizeof(__pyx_k_Abstract_subclass_of_ParserEleme), 0, 0, 1, 0},
    {&__pyx_kp_s_Abstract_subclass_of_class_Pars, __pyx_k_Abstract_subclass_of_class_Pars, sizeof(__pyx_k_Abstract_subclass_of_class_Pars), 0, 0, 1, 0},
    {&__pyx_kp_s_Abstract_subclass_of_class_Parse, __pyx_k_Abstract_subclass_of_class_Parse, sizeof(__pyx_k_Abstract_subclass_of_class_Parse), 0, 0, 1, 0},
    {&__pyx_kp_s_An_empty_token_will_always_match, __pyx_k_An_empty_token_will_always_match, sizeof(__pyx_k_An_empty_token_will_always_match), 0, 0, 1, 0},
    {&__pyx_n_s_And, __pyx_k_And, sizeof(__pyx_k_And), 0, 0, 1, 1},
    {&__pyx_n_u_And, __pyx_k_And, sizeof(__pyx_k_And), 0, 1, 0, 1},
    {&__pyx_n_s_And__ErrorStop, __pyx_k_And__ErrorStop, sizeof(__pyx_k_And__ErrorStop), 0, 0, 1, 1},
    {&__pyx_n_s_And__ErrorStop___init, __pyx_k_And__ErrorStop___init, sizeof(__pyx_k_And__ErrorStop___init), 0, 0, 1, 1},
    {&__pyx_n_s_And___iadd, __pyx_k_And___iadd, sizeof(__pyx_k_And___iadd), 0, 0, 1, 1},
    {&__pyx_n_s_And___init, __pyx_k_And___init, sizeof(__pyx_k_And___init), 0, 0, 1, 1},
    {&__pyx_n_s_And___init___locals_genexpr, __pyx_k_And___init___locals_genexpr, sizeof(__pyx_k_And___init___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_And___str, __pyx_k_And___str, sizeof(__pyx_k_And___str), 0, 0, 1, 1},
    {&__pyx_n_s_And___str___locals_genexpr, __pyx_k_And___str___locals_genexpr, sizeof(__pyx_k_And___str___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_And_checkRecursion, __pyx_k_And_checkRecursion, sizeof(__pyx_k_And_checkRecursion), 0, 0, 1, 1},
    {&__pyx_n_s_And_parseImpl, __pyx_k_And_parseImpl, sizeof(__pyx_k_And_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_And_streamline, __pyx_k_And_streamline, sizeof(__pyx_k_And_streamline), 0, 0, 1, 1},
    {&__pyx_n_s_And_streamline_locals_genexpr, __pyx_k_And_streamline_locals_genexpr, sizeof(__pyx_k_And_streamline_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_Arabic, __pyx_k_Arabic, sizeof(__pyx_k_Arabic), 0, 0, 1, 1},
    {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
    {&__pyx_n_s_BOM, __pyx_k_BOM, sizeof(__pyx_k_BOM), 0, 0, 1, 1},
    {&__pyx_n_s_BaseWithAttribute, __pyx_k_BaseWithAttribute, sizeof(__pyx_k_BaseWithAttribute), 0, 0, 1, 1},
    {&__pyx_n_s_BaseWithAttribute___call, __pyx_k_BaseWithAttribute___call, sizeof(__pyx_k_BaseWithAttribute___call), 0, 0, 1, 1},
    {&__pyx_n_s_BaseWithAttribute___call___local, __pyx_k_BaseWithAttribute___call___local, sizeof(__pyx_k_BaseWithAttribute___call___local), 0, 0, 1, 1},
    {&__pyx_n_s_CJK, __pyx_k_CJK, sizeof(__pyx_k_CJK), 0, 0, 1, 1},
    {&__pyx_kp_u_CR, __pyx_k_CR, sizeof(__pyx_k_CR), 0, 1, 0, 0},
    {&__pyx_kp_u_C_style_comment, __pyx_k_C_style_comment, sizeof(__pyx_k_C_style_comment), 0, 1, 0, 0},
    {&__pyx_kp_u_C_style_comment_2, __pyx_k_C_style_comment_2, sizeof(__pyx_k_C_style_comment_2), 0, 1, 0, 0},
    {&__pyx_kp_u_Cannot_combine_element_of_type_s, __pyx_k_Cannot_combine_element_of_type_s, sizeof(__pyx_k_Cannot_combine_element_of_type_s), 0, 1, 0, 0},
    {&__pyx_n_s_CaselessKeyword, __pyx_k_CaselessKeyword, sizeof(__pyx_k_CaselessKeyword), 0, 0, 1, 1},
    {&__pyx_n_u_CaselessKeyword, __pyx_k_CaselessKeyword, sizeof(__pyx_k_CaselessKeyword), 0, 1, 0, 1},
    {&__pyx_n_s_CaselessKeyword___init, __pyx_k_CaselessKeyword___init, sizeof(__pyx_k_CaselessKeyword___init), 0, 0, 1, 1},
    {&__pyx_n_s_CaselessLiteral, __pyx_k_CaselessLiteral, sizeof(__pyx_k_CaselessLiteral), 0, 0, 1, 1},
    {&__pyx_n_u_CaselessLiteral, __pyx_k_CaselessLiteral, sizeof(__pyx_k_CaselessLiteral), 0, 1, 0, 1},
    {&__pyx_n_s_CaselessLiteral___init, __pyx_k_CaselessLiteral___init, sizeof(__pyx_k_CaselessLiteral___init), 0, 0, 1, 1},
    {&__pyx_n_s_CaselessLiteral_parseImpl, __pyx_k_CaselessLiteral_parseImpl, sizeof(__pyx_k_CaselessLiteral_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_s_Caseless_version_of_class_Keywo, __pyx_k_Caseless_version_of_class_Keywo, sizeof(__pyx_k_Caseless_version_of_class_Keywo), 0, 0, 1, 0},
    {&__pyx_n_s_Char, __pyx_k_Char, sizeof(__pyx_k_Char), 0, 0, 1, 1},
    {&__pyx_n_u_Char, __pyx_k_Char, sizeof(__pyx_k_Char), 0, 1, 0, 1},
    {&__pyx_n_s_Char___init, __pyx_k_Char___init, sizeof(__pyx_k_Char___init), 0, 0, 1, 1},
    {&__pyx_n_s_CharsNotIn, __pyx_k_CharsNotIn, sizeof(__pyx_k_CharsNotIn), 0, 0, 1, 1},
    {&__pyx_n_u_CharsNotIn, __pyx_k_CharsNotIn, sizeof(__pyx_k_CharsNotIn), 0, 1, 0, 1},
    {&__pyx_n_s_CharsNotIn___init, __pyx_k_CharsNotIn___init, sizeof(__pyx_k_CharsNotIn___init), 0, 0, 1, 1},
    {&__pyx_n_s_CharsNotIn___str, __pyx_k_CharsNotIn___str, sizeof(__pyx_k_CharsNotIn___str), 0, 0, 1, 1},
    {&__pyx_n_s_CharsNotIn_parseImpl, __pyx_k_CharsNotIn_parseImpl, sizeof(__pyx_k_CharsNotIn_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Chinese, __pyx_k_Chinese, sizeof(__pyx_k_Chinese), 0, 0, 1, 1},
    {&__pyx_n_s_CloseMatch, __pyx_k_CloseMatch, sizeof(__pyx_k_CloseMatch), 0, 0, 1, 1},
    {&__pyx_n_u_CloseMatch, __pyx_k_CloseMatch, sizeof(__pyx_k_CloseMatch), 0, 1, 0, 1},
    {&__pyx_n_s_CloseMatch___init, __pyx_k_CloseMatch___init, sizeof(__pyx_k_CloseMatch___init), 0, 0, 1, 1},
    {&__pyx_n_s_CloseMatch_parseImpl, __pyx_k_CloseMatch_parseImpl, sizeof(__pyx_k_CloseMatch_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Combine, __pyx_k_Combine, sizeof(__pyx_k_Combine), 0, 0, 1, 1},
    {&__pyx_n_u_Combine, __pyx_k_Combine, sizeof(__pyx_k_Combine), 0, 1, 0, 1},
    {&__pyx_n_s_Combine___init, __pyx_k_Combine___init, sizeof(__pyx_k_Combine___init), 0, 0, 1, 1},
    {&__pyx_n_s_Combine_ignore, __pyx_k_Combine_ignore, sizeof(__pyx_k_Combine_ignore), 0, 0, 1, 1},
    {&__pyx_n_s_Combine_postParse, __pyx_k_Combine_postParse, sizeof(__pyx_k_Combine_postParse), 0, 0, 1, 1},
    {&__pyx_kp_s_Context_manager_to_be_used_when, __pyx_k_Context_manager_to_be_used_when, sizeof(__pyx_k_Context_manager_to_be_used_when), 0, 0, 1, 0},
    {&__pyx_kp_s_Converter_for_ignoring_the_resul, __pyx_k_Converter_for_ignoring_the_resul, sizeof(__pyx_k_Converter_for_ignoring_the_resul), 0, 0, 1, 0},
    {&__pyx_kp_s_Converter_to_concatenate_all_mat, __pyx_k_Converter_to_concatenate_all_mat, sizeof(__pyx_k_Converter_to_concatenate_all_mat), 0, 0, 1, 0},
    {&__pyx_kp_s_Converter_to_return_a_repetitive, __pyx_k_Converter_to_return_a_repetitive, sizeof(__pyx_k_Converter_to_return_a_repetitive), 0, 0, 1, 0},
    {&__pyx_kp_s_Converter_to_return_the_matched, __pyx_k_Converter_to_return_the_matched, sizeof(__pyx_k_Converter_to_return_the_matched), 0, 0, 1, 0},
    {&__pyx_n_s_Cyrillic, __pyx_k_Cyrillic, sizeof(__pyx_k_Cyrillic), 0, 0, 1, 1},
    {&__pyx_n_s_DEFAULT_KEYWORD_CHARS, __pyx_k_DEFAULT_KEYWORD_CHARS, sizeof(__pyx_k_DEFAULT_KEYWORD_CHARS), 0, 0, 1, 1},
    {&__pyx_n_s_DEFAULT_WHITE_CHARS, __pyx_k_DEFAULT_WHITE_CHARS, sizeof(__pyx_k_DEFAULT_WHITE_CHARS), 0, 0, 1, 1},
    {&__pyx_n_s_DOTALL, __pyx_k_DOTALL, sizeof(__pyx_k_DOTALL), 0, 0, 1, 1},
    {&__pyx_n_s_Devanagari, __pyx_k_Devanagari, sizeof(__pyx_k_Devanagari), 0, 0, 1, 1},
    {&__pyx_kp_u_Diagnostic_configuration_all_de, __pyx_k_Diagnostic_configuration_all_de, sizeof(__pyx_k_Diagnostic_configuration_all_de), 0, 1, 0, 0},
    {&__pyx_n_s_Dict, __pyx_k_Dict, sizeof(__pyx_k_Dict), 0, 0, 1, 1},
    {&__pyx_n_u_Dict, __pyx_k_Dict, sizeof(__pyx_k_Dict), 0, 1, 0, 1},
    {&__pyx_n_s_Dict___init, __pyx_k_Dict___init, sizeof(__pyx_k_Dict___init), 0, 0, 1, 1},
    {&__pyx_n_s_Dict_postParse, __pyx_k_Dict_postParse, sizeof(__pyx_k_Dict_postParse), 0, 0, 1, 1},
    {&__pyx_kp_u_EM_QUAD, __pyx_k_EM_QUAD, sizeof(__pyx_k_EM_QUAD), 0, 1, 0, 0},
    {&__pyx_kp_u_EM_SPACE, __pyx_k_EM_SPACE, sizeof(__pyx_k_EM_SPACE), 0, 1, 0, 0},
    {&__pyx_kp_u_EN_QUAD, __pyx_k_EN_QUAD, sizeof(__pyx_k_EN_QUAD), 0, 1, 0, 0},
    {&__pyx_kp_u_EN_SPACE, __pyx_k_EN_SPACE, sizeof(__pyx_k_EN_SPACE), 0, 1, 0, 0},
    {&__pyx_n_s_Each, __pyx_k_Each, sizeof(__pyx_k_Each), 0, 0, 1, 1},
    {&__pyx_n_u_Each, __pyx_k_Each, sizeof(__pyx_k_Each), 0, 1, 0, 1},
    {&__pyx_n_s_Each___init, __pyx_k_Each___init, sizeof(__pyx_k_Each___init), 0, 0, 1, 1},
    {&__pyx_n_s_Each___init___locals_genexpr, __pyx_k_Each___init___locals_genexpr, sizeof(__pyx_k_Each___init___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_Each___str, __pyx_k_Each___str, sizeof(__pyx_k_Each___str), 0, 0, 1, 1},
    {&__pyx_n_s_Each___str___locals_genexpr, __pyx_k_Each___str___locals_genexpr, sizeof(__pyx_k_Each___str___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_Each_checkRecursion, __pyx_k_Each_checkRecursion, sizeof(__pyx_k_Each_checkRecursion), 0, 0, 1, 1},
    {&__pyx_n_s_Each_parseImpl, __pyx_k_Each_parseImpl, sizeof(__pyx_k_Each_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Each_parseImpl_locals_genexpr, __pyx_k_Each_parseImpl_locals_genexpr, sizeof(__pyx_k_Each_parseImpl_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_Each_streamline, __pyx_k_Each_streamline, sizeof(__pyx_k_Each_streamline), 0, 0, 1, 1},
    {&__pyx_n_s_Each_streamline_locals_genexpr, __pyx_k_Each_streamline_locals_genexpr, sizeof(__pyx_k_Each_streamline_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_Ellipsis, __pyx_k_Ellipsis, sizeof(__pyx_k_Ellipsis), 0, 0, 1, 1},
    {&__pyx_n_s_Empty, __pyx_k_Empty, sizeof(__pyx_k_Empty), 0, 0, 1, 1},
    {&__pyx_n_u_Empty, __pyx_k_Empty, sizeof(__pyx_k_Empty), 0, 1, 0, 1},
    {&__pyx_n_s_Empty___init, __pyx_k_Empty___init, sizeof(__pyx_k_Empty___init), 0, 0, 1, 1},
    {&__pyx_n_s_ErrorStop, __pyx_k_ErrorStop, sizeof(__pyx_k_ErrorStop), 0, 0, 1, 1},
    {&__pyx_kp_u_Evan_Hubinger_evanjhub_gmail_com, __pyx_k_Evan_Hubinger_evanjhub_gmail_com, sizeof(__pyx_k_Evan_Hubinger_evanjhub_gmail_com), 0, 1, 0, 0},
    {&__pyx_kp_u_Exception_creating_Regex_for_one, __pyx_k_Exception_creating_Regex_for_one, sizeof(__pyx_k_Exception_creating_Regex_for_one), 0, 1, 0, 0},
    {&__pyx_kp_u_Exception_raised, __pyx_k_Exception_raised, sizeof(__pyx_k_Exception_raised), 0, 1, 0, 0},
    {&__pyx_kp_s_Exception_thrown_when_parse_exp, __pyx_k_Exception_thrown_when_parse_exp, sizeof(__pyx_k_Exception_thrown_when_parse_exp), 0, 0, 1, 0},
    {&__pyx_kp_u_Expected, __pyx_k_Expected, sizeof(__pyx_k_Expected), 0, 1, 0, 0},
    {&__pyx_kp_u_Expected_end_of_line, __pyx_k_Expected_end_of_line, sizeof(__pyx_k_Expected_end_of_line), 0, 1, 0, 0},
    {&__pyx_kp_u_Expected_end_of_text, __pyx_k_Expected_end_of_text, sizeof(__pyx_k_Expected_end_of_text), 0, 1, 0, 0},
    {&__pyx_kp_u_Expected_start_of_line, __pyx_k_Expected_start_of_line, sizeof(__pyx_k_Expected_start_of_line), 0, 1, 0, 0},
    {&__pyx_kp_u_Expected_start_of_text, __pyx_k_Expected_start_of_text, sizeof(__pyx_k_Expected_start_of_text), 0, 1, 0, 0},
    {&__pyx_n_s_FAIL, __pyx_k_FAIL, sizeof(__pyx_k_FAIL), 0, 0, 1, 1},
    {&__pyx_kp_u_FAIL_2, __pyx_k_FAIL_2, sizeof(__pyx_k_FAIL_2), 0, 1, 0, 0},
    {&__pyx_kp_u_FAIL_EXCEPTION, __pyx_k_FAIL_EXCEPTION, sizeof(__pyx_k_FAIL_EXCEPTION), 0, 1, 0, 0},
    {&__pyx_kp_u_FATAL, __pyx_k_FATAL, sizeof(__pyx_k_FATAL), 0, 1, 0, 0},
    {&__pyx_n_s_FB, __pyx_k_FB, sizeof(__pyx_k_FB), 0, 0, 1, 1},
    {&__pyx_kp_u_FF, __pyx_k_FF, sizeof(__pyx_k_FF), 0, 1, 0, 0},
    {&__pyx_kp_u_FIGURE_SPACE, __pyx_k_FIGURE_SPACE, sizeof(__pyx_k_FIGURE_SPACE), 0, 1, 0, 0},
    {&__pyx_n_s_FILE_NAME, __pyx_k_FILE_NAME, sizeof(__pyx_k_FILE_NAME), 0, 0, 1, 1},
    {&__pyx_kp_u_FOUR_PER_EM_SPACE, __pyx_k_FOUR_PER_EM_SPACE, sizeof(__pyx_k_FOUR_PER_EM_SPACE), 0, 1, 0, 0},
    {&__pyx_n_s_FifoCache, __pyx_k_FifoCache, sizeof(__pyx_k_FifoCache), 0, 0, 1, 1},
    {&__pyx_n_s_FifoCache___init, __pyx_k_FifoCache___init, sizeof(__pyx_k_FifoCache___init), 0, 0, 1, 1},
    {&__pyx_n_s_FifoCache___len, __pyx_k_FifoCache___len, sizeof(__pyx_k_FifoCache___len), 0, 0, 1, 1},
    {&__pyx_n_s_FifoCache___reduce, __pyx_k_FifoCache___reduce, sizeof(__pyx_k_FifoCache___reduce), 0, 0, 1, 1},
    {&__pyx_n_s_FifoCache_clear, __pyx_k_FifoCache_clear, sizeof(__pyx_k_FifoCache_clear), 0, 0, 1, 1},
    {&__pyx_n_s_FifoCache_get, __pyx_k_FifoCache_get, sizeof(__pyx_k_FifoCache_get), 0, 0, 1, 1},
    {&__pyx_n_s_FifoCache_set, __pyx_k_FifoCache_set, sizeof(__pyx_k_FifoCache_set), 0, 0, 1, 1},
    {&__pyx_n_s_FifoCache_update, __pyx_k_FifoCache_update, sizeof(__pyx_k_FifoCache_update), 0, 0, 1, 1},
    {&__pyx_n_s_FollowedBy, __pyx_k_FollowedBy, sizeof(__pyx_k_FollowedBy), 0, 0, 1, 1},
    {&__pyx_n_u_FollowedBy, __pyx_k_FollowedBy, sizeof(__pyx_k_FollowedBy), 0, 1, 0, 1},
    {&__pyx_n_s_FollowedBy___init, __pyx_k_FollowedBy___init, sizeof(__pyx_k_FollowedBy___init), 0, 0, 1, 1},
    {&__pyx_n_s_FollowedBy_parseImpl, __pyx_k_FollowedBy_parseImpl, sizeof(__pyx_k_FollowedBy_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Forward, __pyx_k_Forward, sizeof(__pyx_k_Forward), 0, 0, 1, 1},
    {&__pyx_n_u_Forward, __pyx_k_Forward, sizeof(__pyx_k_Forward), 0, 1, 0, 1},
    {&__pyx_n_s_Forward___ilshift, __pyx_k_Forward___ilshift, sizeof(__pyx_k_Forward___ilshift), 0, 0, 1, 1},
    {&__pyx_n_s_Forward___init, __pyx_k_Forward___init, sizeof(__pyx_k_Forward___init), 0, 0, 1, 1},
    {&__pyx_n_s_Forward___lshift, __pyx_k_Forward___lshift, sizeof(__pyx_k_Forward___lshift), 0, 0, 1, 1},
    {&__pyx_n_s_Forward___str, __pyx_k_Forward___str, sizeof(__pyx_k_Forward___str), 0, 0, 1, 1},
    {&__pyx_n_s_Forward__setResultsName, __pyx_k_Forward__setResultsName, sizeof(__pyx_k_Forward__setResultsName), 0, 0, 1, 1},
    {&__pyx_n_s_Forward_copy, __pyx_k_Forward_copy, sizeof(__pyx_k_Forward_copy), 0, 0, 1, 1},
    {&__pyx_kp_s_Forward_declaration_of_an_expres, __pyx_k_Forward_declaration_of_an_expres, sizeof(__pyx_k_Forward_declaration_of_an_expres), 0, 0, 1, 0},
    {&__pyx_n_s_Forward_leaveWhitespace, __pyx_k_Forward_leaveWhitespace, sizeof(__pyx_k_Forward_leaveWhitespace), 0, 0, 1, 1},
    {&__pyx_n_s_Forward_streamline, __pyx_k_Forward_streamline, sizeof(__pyx_k_Forward_streamline), 0, 0, 1, 1},
    {&__pyx_n_s_Forward_validate, __pyx_k_Forward_validate, sizeof(__pyx_k_Forward_validate), 0, 0, 1, 1},
    {&__pyx_kp_u_Found_unwanted_token, __pyx_k_Found_unwanted_token, sizeof(__pyx_k_Found_unwanted_token), 0, 1, 0, 0},
    {&__pyx_n_s_GoToColumn, __pyx_k_GoToColumn, sizeof(__pyx_k_GoToColumn), 0, 0, 1, 1},
    {&__pyx_n_u_GoToColumn, __pyx_k_GoToColumn, sizeof(__pyx_k_GoToColumn), 0, 1, 0, 1},
    {&__pyx_n_s_GoToColumn___init, __pyx_k_GoToColumn___init, sizeof(__pyx_k_GoToColumn___init), 0, 0, 1, 1},
    {&__pyx_n_s_GoToColumn_parseImpl, __pyx_k_GoToColumn_parseImpl, sizeof(__pyx_k_GoToColumn_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_GoToColumn_preParse, __pyx_k_GoToColumn_preParse, sizeof(__pyx_k_GoToColumn_preParse), 0, 0, 1, 1},
    {&__pyx_n_s_Greek, __pyx_k_Greek, sizeof(__pyx_k_Greek), 0, 0, 1, 1},
    {&__pyx_n_s_Group, __pyx_k_Group, sizeof(__pyx_k_Group), 0, 0, 1, 1},
    {&__pyx_n_u_Group, __pyx_k_Group, sizeof(__pyx_k_Group), 0, 1, 0, 1},
    {&__pyx_n_s_Group___init, __pyx_k_Group___init, sizeof(__pyx_k_Group___init), 0, 0, 1, 1},
    {&__pyx_n_s_Group_postParse, __pyx_k_Group_postParse, sizeof(__pyx_k_Group_postParse), 0, 0, 1, 1},
    {&__pyx_kp_u_HAIR_SPACE, __pyx_k_HAIR_SPACE, sizeof(__pyx_k_HAIR_SPACE), 0, 1, 0, 0},
    {&__pyx_n_s_HIT, __pyx_k_HIT, sizeof(__pyx_k_HIT), 0, 0, 1, 1},
    {&__pyx_kp_u_HTML_comment, __pyx_k_HTML_comment, sizeof(__pyx_k_HTML_comment), 0, 1, 0, 0},
    {&__pyx_n_s_Hebrew, __pyx_k_Hebrew, sizeof(__pyx_k_Hebrew), 0, 0, 1, 1},
    {&__pyx_kp_s_Here_are_some_common_low_level_e, __pyx_k_Here_are_some_common_low_level_e, sizeof(__pyx_k_Here_are_some_common_low_level_e), 0, 0, 1, 0},
    {&__pyx_n_s_Hiragana, __pyx_k_Hiragana, sizeof(__pyx_k_Hiragana), 0, 0, 1, 1},
    {&__pyx_kp_u_IDEOGRAPHIC_SPACE, __pyx_k_IDEOGRAPHIC_SPACE, sizeof(__pyx_k_IDEOGRAPHIC_SPACE), 0, 1, 0, 0},
    {&__pyx_n_s_INDENT, __pyx_k_INDENT, sizeof(__pyx_k_INDENT), 0, 0, 1, 1},
    {&__pyx_n_u_INDENT, __pyx_k_INDENT, sizeof(__pyx_k_INDENT), 0, 1, 0, 1},
    {&__pyx_kp_u_IPv4_address, __pyx_k_IPv4_address, sizeof(__pyx_k_IPv4_address), 0, 1, 0, 0},
    {&__pyx_kp_u_IPv6_address, __pyx_k_IPv6_address, sizeof(__pyx_k_IPv6_address), 0, 1, 0, 0},
    {&__pyx_kp_u_ISO8601_date, __pyx_k_ISO8601_date, sizeof(__pyx_k_ISO8601_date), 0, 1, 0, 0},
    {&__pyx_kp_u_ISO8601_datetime, __pyx_k_ISO8601_datetime, sizeof(__pyx_k_ISO8601_datetime), 0, 1, 0, 0},
    {&__pyx_n_u_ITEM, __pyx_k_ITEM, sizeof(__pyx_k_ITEM), 0, 1, 0, 1},
    {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
    {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
    {&__pyx_kp_u_Invalid_argument_to_oneOf_expect, __pyx_k_Invalid_argument_to_oneOf_expect, sizeof(__pyx_k_Invalid_argument_to_oneOf_expect), 0, 1, 0, 0},
    {&__pyx_n_s_Iterable, __pyx_k_Iterable, sizeof(__pyx_k_Iterable), 0, 0, 1, 1},
    {&__pyx_n_s_Japanese, __pyx_k_Japanese, sizeof(__pyx_k_Japanese), 0, 0, 1, 1},
    {&__pyx_n_s_Kanji, __pyx_k_Kanji, sizeof(__pyx_k_Kanji), 0, 0, 1, 1},
    {&__pyx_n_s_Katakana, __pyx_k_Katakana, sizeof(__pyx_k_Katakana), 0, 0, 1, 1},
    {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
    {&__pyx_n_s_Keyword, __pyx_k_Keyword, sizeof(__pyx_k_Keyword), 0, 0, 1, 1},
    {&__pyx_n_u_Keyword, __pyx_k_Keyword, sizeof(__pyx_k_Keyword), 0, 1, 0, 1},
    {&__pyx_n_s_Keyword___init, __pyx_k_Keyword___init, sizeof(__pyx_k_Keyword___init), 0, 0, 1, 1},
    {&__pyx_n_s_Keyword_copy, __pyx_k_Keyword_copy, sizeof(__pyx_k_Keyword_copy), 0, 0, 1, 1},
    {&__pyx_n_s_Keyword_parseImpl, __pyx_k_Keyword_parseImpl, sizeof(__pyx_k_Keyword_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Keyword_setDefaultKeywordChars, __pyx_k_Keyword_setDefaultKeywordChars, sizeof(__pyx_k_Keyword_setDefaultKeywordChars), 0, 0, 1, 1},
    {&__pyx_n_s_Korean, __pyx_k_Korean, sizeof(__pyx_k_Korean), 0, 0, 1, 1},
    {&__pyx_n_s_L, __pyx_k_L, sizeof(__pyx_k_L), 0, 0, 1, 1},
    {&__pyx_n_s_LEFT, __pyx_k_LEFT, sizeof(__pyx_k_LEFT), 0, 0, 1, 1},
    {&__pyx_kp_u_LF, __pyx_k_LF, sizeof(__pyx_k_LF), 0, 1, 0, 0},
    {&__pyx_n_s_L_2, __pyx_k_L_2, sizeof(__pyx_k_L_2), 0, 0, 1, 1},
    {&__pyx_n_s_Latin1, __pyx_k_Latin1, sizeof(__pyx_k_Latin1), 0, 0, 1, 1},
    {&__pyx_n_s_LatinA, __pyx_k_LatinA, sizeof(__pyx_k_LatinA), 0, 0, 1, 1},
    {&__pyx_n_s_LatinB, __pyx_k_LatinB, sizeof(__pyx_k_LatinB), 0, 0, 1, 1},
    {&__pyx_n_s_LineEnd, __pyx_k_LineEnd, sizeof(__pyx_k_LineEnd), 0, 0, 1, 1},
    {&__pyx_n_u_LineEnd, __pyx_k_LineEnd, sizeof(__pyx_k_LineEnd), 0, 1, 0, 1},
    {&__pyx_n_s_LineEnd___init, __pyx_k_LineEnd___init, sizeof(__pyx_k_LineEnd___init), 0, 0, 1, 1},
    {&__pyx_n_s_LineEnd_parseImpl, __pyx_k_LineEnd_parseImpl, sizeof(__pyx_k_LineEnd_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_LineStart, __pyx_k_LineStart, sizeof(__pyx_k_LineStart), 0, 0, 1, 1},
    {&__pyx_n_u_LineStart, __pyx_k_LineStart, sizeof(__pyx_k_LineStart), 0, 1, 0, 1},
    {&__pyx_n_s_LineStart___init, __pyx_k_LineStart___init, sizeof(__pyx_k_LineStart___init), 0, 0, 1, 1},
    {&__pyx_n_s_LineStart_parseImpl, __pyx_k_LineStart_parseImpl, sizeof(__pyx_k_LineStart_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Literal, __pyx_k_Literal, sizeof(__pyx_k_Literal), 0, 0, 1, 1},
    {&__pyx_n_u_Literal, __pyx_k_Literal, sizeof(__pyx_k_Literal), 0, 1, 0, 1},
    {&__pyx_n_s_Literal___init, __pyx_k_Literal___init, sizeof(__pyx_k_Literal___init), 0, 0, 1, 1},
    {&__pyx_n_s_Literal_parseImpl, __pyx_k_Literal_parseImpl, sizeof(__pyx_k_Literal_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_s_Lookahead_matching_of_the_given, __pyx_k_Lookahead_matching_of_the_given, sizeof(__pyx_k_Lookahead_matching_of_the_given), 0, 0, 1, 0},
    {&__pyx_kp_s_Lookahead_to_disallow_matching_w, __pyx_k_Lookahead_to_disallow_matching_w, sizeof(__pyx_k_Lookahead_to_disallow_matching_w), 0, 0, 1, 0},
    {&__pyx_kp_s_Lookbehind_matching_of_the_given, __pyx_k_Lookbehind_matching_of_the_given, sizeof(__pyx_k_Lookbehind_matching_of_the_given), 0, 0, 1, 0},
    {&__pyx_kp_u_MAC_address, __pyx_k_MAC_address, sizeof(__pyx_k_MAC_address), 0, 1, 0, 0},
    {&__pyx_n_s_MATCH, __pyx_k_MATCH, sizeof(__pyx_k_MATCH), 0, 0, 1, 1},
    {&__pyx_n_s_MAX_INT, __pyx_k_MAX_INT, sizeof(__pyx_k_MAX_INT), 0, 0, 1, 1},
    {&__pyx_n_s_MISS, __pyx_k_MISS, sizeof(__pyx_k_MISS), 0, 0, 1, 1},
    {&__pyx_kp_u_MMSP, __pyx_k_MMSP, sizeof(__pyx_k_MMSP), 0, 1, 0, 0},
    {&__pyx_kp_u_MONGOLIAN_VOWEL_SEPARATOR, __pyx_k_MONGOLIAN_VOWEL_SEPARATOR, sizeof(__pyx_k_MONGOLIAN_VOWEL_SEPARATOR), 0, 1, 0, 0},
    {&__pyx_n_s_MULTILINE, __pyx_k_MULTILINE, sizeof(__pyx_k_MULTILINE), 0, 0, 1, 1},
    {&__pyx_n_s_Mapping, __pyx_k_Mapping, sizeof(__pyx_k_Mapping), 0, 0, 1, 1},
    {&__pyx_kp_u_Match, __pyx_k_Match, sizeof(__pyx_k_Match), 0, 1, 0, 0},
    {&__pyx_n_s_MatchFirst, __pyx_k_MatchFirst, sizeof(__pyx_k_MatchFirst), 0, 0, 1, 1},
    {&__pyx_n_u_MatchFirst, __pyx_k_MatchFirst, sizeof(__pyx_k_MatchFirst), 0, 1, 0, 1},
    {&__pyx_n_s_MatchFirst___init, __pyx_k_MatchFirst___init, sizeof(__pyx_k_MatchFirst___init), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst___init___locals_genex, __pyx_k_MatchFirst___init___locals_genex, sizeof(__pyx_k_MatchFirst___init___locals_genex), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst___ior, __pyx_k_MatchFirst___ior, sizeof(__pyx_k_MatchFirst___ior), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst___str, __pyx_k_MatchFirst___str, sizeof(__pyx_k_MatchFirst___str), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst___str___locals_genexp, __pyx_k_MatchFirst___str___locals_genexp, sizeof(__pyx_k_MatchFirst___str___locals_genexp), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst__setResultsName, __pyx_k_MatchFirst__setResultsName, sizeof(__pyx_k_MatchFirst__setResultsName), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst__setResultsName_local, __pyx_k_MatchFirst__setResultsName_local, sizeof(__pyx_k_MatchFirst__setResultsName_local), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst_checkRecursion, __pyx_k_MatchFirst_checkRecursion, sizeof(__pyx_k_MatchFirst_checkRecursion), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst_parseImpl, __pyx_k_MatchFirst_parseImpl, sizeof(__pyx_k_MatchFirst_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst_setAdaptiveMode, __pyx_k_MatchFirst_setAdaptiveMode, sizeof(__pyx_k_MatchFirst_setAdaptiveMode), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst_streamline, __pyx_k_MatchFirst_streamline, sizeof(__pyx_k_MatchFirst_streamline), 0, 0, 1, 1},
    {&__pyx_n_s_MatchFirst_streamline_locals_gen, __pyx_k_MatchFirst_streamline_locals_gen, sizeof(__pyx_k_MatchFirst_streamline_locals_gen), 0, 0, 1, 1},
    {&__pyx_kp_u_Matched, __pyx_k_Matched, sizeof(__pyx_k_Matched), 0, 1, 0, 0},
    {&__pyx_kp_s_Matches_if_current_position_is_a, __pyx_k_Matches_if_current_position_is_a, sizeof(__pyx_k_Matches_if_current_position_is_a), 0, 0, 1, 0},
    {&__pyx_kp_s_Matches_if_current_position_is_a_2, __pyx_k_Matches_if_current_position_is_a_2, sizeof(__pyx_k_Matches_if_current_position_is_a_2), 0, 0, 1, 0},
    {&__pyx_kp_s_Matches_if_current_position_is_a_3, __pyx_k_Matches_if_current_position_is_a_3, sizeof(__pyx_k_Matches_if_current_position_is_a_3), 0, 0, 1, 0},
    {&__pyx_kp_s_Matches_if_current_position_is_a_4, __pyx_k_Matches_if_current_position_is_a_4, sizeof(__pyx_k_Matches_if_current_position_is_a_4), 0, 0, 1, 0},
    {&__pyx_kp_s_Matches_if_the_current_position, __pyx_k_Matches_if_the_current_position, sizeof(__pyx_k_Matches_if_the_current_position), 0, 0, 1, 0},
    {&__pyx_kp_s_Matches_if_the_current_position_2, __pyx_k_Matches_if_the_current_position_2, sizeof(__pyx_k_Matches_if_the_current_position_2), 0, 0, 1, 0},
    {&__pyx_kp_u_Missing_one_or_more_required_ele, __pyx_k_Missing_one_or_more_required_ele, sizeof(__pyx_k_Missing_one_or_more_required_ele), 0, 1, 0, 0},
    {&__pyx_kp_u_More_than_one_string_argument_pa, __pyx_k_More_than_one_string_argument_pa, sizeof(__pyx_k_More_than_one_string_argument_pa), 0, 1, 0, 0},
    {&__pyx_n_s_MultipleMatch, __pyx_k_MultipleMatch, sizeof(__pyx_k_MultipleMatch), 0, 0, 1, 1},
    {&__pyx_n_s_MultipleMatch___init, __pyx_k_MultipleMatch___init, sizeof(__pyx_k_MultipleMatch___init), 0, 0, 1, 1},
    {&__pyx_n_s_MultipleMatch__setResultsName, __pyx_k_MultipleMatch__setResultsName, sizeof(__pyx_k_MultipleMatch__setResultsName), 0, 0, 1, 1},
    {&__pyx_n_s_MultipleMatch_parseImpl, __pyx_k_MultipleMatch_parseImpl, sizeof(__pyx_k_MultipleMatch_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_MultipleMatch_stopOn, __pyx_k_MultipleMatch_stopOn, sizeof(__pyx_k_MultipleMatch_stopOn), 0, 0, 1, 1},
    {&__pyx_n_s_MutableMapping, __pyx_k_MutableMapping, sizeof(__pyx_k_MutableMapping), 0, 0, 1, 1},
    {&__pyx_kp_u_NBSP, __pyx_k_NBSP, sizeof(__pyx_k_NBSP), 0, 1, 0, 0},
    {&__pyx_n_s_NL, __pyx_k_NL, sizeof(__pyx_k_NL), 0, 0, 1, 1},
    {&__pyx_kp_u_NNBSP, __pyx_k_NNBSP, sizeof(__pyx_k_NNBSP), 0, 1, 0, 0},
    {&__pyx_n_s_NameError, __pyx_k_NameError, sizeof(__pyx_k_NameError), 0, 0, 1, 1},
    {&__pyx_n_s_NoMatch, __pyx_k_NoMatch, sizeof(__pyx_k_NoMatch), 0, 0, 1, 1},
    {&__pyx_n_u_NoMatch, __pyx_k_NoMatch, sizeof(__pyx_k_NoMatch), 0, 1, 0, 1},
    {&__pyx_n_s_NoMatch___init, __pyx_k_NoMatch___init, sizeof(__pyx_k_NoMatch___init), 0, 0, 1, 1},
    {&__pyx_n_s_NoMatch_parseImpl, __pyx_k_NoMatch_parseImpl, sizeof(__pyx_k_NoMatch_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_u_No_match_found_for, __pyx_k_No_match_found_for, sizeof(__pyx_k_No_match_found_for), 0, 1, 0, 0},
    {&__pyx_n_s_NotAny, __pyx_k_NotAny, sizeof(__pyx_k_NotAny), 0, 0, 1, 1},
    {&__pyx_n_u_NotAny, __pyx_k_NotAny, sizeof(__pyx_k_NotAny), 0, 1, 0, 1},
    {&__pyx_n_s_NotAny___init, __pyx_k_NotAny___init, sizeof(__pyx_k_NotAny___init), 0, 0, 1, 1},
    {&__pyx_n_s_NotAny___str, __pyx_k_NotAny___str, sizeof(__pyx_k_NotAny___str), 0, 0, 1, 1},
    {&__pyx_n_s_NotAny_parseImpl, __pyx_k_NotAny_parseImpl, sizeof(__pyx_k_NotAny_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_u_Not_at_the_end_of_a_word, __pyx_k_Not_at_the_end_of_a_word, sizeof(__pyx_k_Not_at_the_end_of_a_word), 0, 1, 0, 0},
    {&__pyx_kp_u_Not_at_the_start_of_a_word, __pyx_k_Not_at_the_start_of_a_word, sizeof(__pyx_k_Not_at_the_start_of_a_word), 0, 1, 0, 0},
    {&__pyx_n_s_NullToken, __pyx_k_NullToken, sizeof(__pyx_k_NullToken), 0, 0, 1, 1},
    {&__pyx_n_s_NullToken___bool, __pyx_k_NullToken___bool, sizeof(__pyx_k_NullToken___bool), 0, 0, 1, 1},
    {&__pyx_n_s_NullToken___str, __pyx_k_NullToken___str, sizeof(__pyx_k_NullToken___str), 0, 0, 1, 1},
    {&__pyx_kp_u_OGHAM_SPACE_MARK, __pyx_k_OGHAM_SPACE_MARK, sizeof(__pyx_k_OGHAM_SPACE_MARK), 0, 1, 0, 0},
    {&__pyx_n_s_OneOrMore, __pyx_k_OneOrMore, sizeof(__pyx_k_OneOrMore), 0, 0, 1, 1},
    {&__pyx_n_u_OneOrMore, __pyx_k_OneOrMore, sizeof(__pyx_k_OneOrMore), 0, 1, 0, 1},
    {&__pyx_n_s_OneOrMore___str, __pyx_k_OneOrMore___str, sizeof(__pyx_k_OneOrMore___str), 0, 0, 1, 1},
    {&__pyx_n_s_OnlyOnce, __pyx_k_OnlyOnce, sizeof(__pyx_k_OnlyOnce), 0, 0, 1, 1},
    {&__pyx_n_u_OnlyOnce, __pyx_k_OnlyOnce, sizeof(__pyx_k_OnlyOnce), 0, 1, 0, 1},
    {&__pyx_n_s_OnlyOnce___call, __pyx_k_OnlyOnce___call, sizeof(__pyx_k_OnlyOnce___call), 0, 0, 1, 1},
    {&__pyx_n_s_OnlyOnce___init, __pyx_k_OnlyOnce___init, sizeof(__pyx_k_OnlyOnce___init), 0, 0, 1, 1},
    {&__pyx_n_s_OnlyOnce_reset, __pyx_k_OnlyOnce_reset, sizeof(__pyx_k_OnlyOnce_reset), 0, 0, 1, 1},
    {&__pyx_n_s_Optional, __pyx_k_Optional, sizeof(__pyx_k_Optional), 0, 0, 1, 1},
    {&__pyx_n_u_Optional, __pyx_k_Optional, sizeof(__pyx_k_Optional), 0, 1, 0, 1},
    {&__pyx_n_s_Optional___init, __pyx_k_Optional___init, sizeof(__pyx_k_Optional___init), 0, 0, 1, 1},
    {&__pyx_n_s_Optional___str, __pyx_k_Optional___str, sizeof(__pyx_k_Optional___str), 0, 0, 1, 1},
    {&__pyx_n_s_Optional__optionalNotMatched, __pyx_k_Optional__optionalNotMatched, sizeof(__pyx_k_Optional__optionalNotMatched), 0, 0, 1, 1},
    {&__pyx_kp_s_Optional_matching_of_the_given_e, __pyx_k_Optional_matching_of_the_given_e, sizeof(__pyx_k_Optional_matching_of_the_given_e), 0, 0, 1, 0},
    {&__pyx_n_s_Optional_parseImpl, __pyx_k_Optional_parseImpl, sizeof(__pyx_k_Optional_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_s_Optional_repetition_of_zero_or_m, __pyx_k_Optional_repetition_of_zero_or_m, sizeof(__pyx_k_Optional_repetition_of_zero_or_m), 0, 0, 1, 0},
    {&__pyx_n_s_Or, __pyx_k_Or, sizeof(__pyx_k_Or), 0, 0, 1, 1},
    {&__pyx_n_u_Or, __pyx_k_Or, sizeof(__pyx_k_Or), 0, 1, 0, 1},
    {&__pyx_n_s_Or___init, __pyx_k_Or___init, sizeof(__pyx_k_Or___init), 0, 0, 1, 1},
    {&__pyx_n_s_Or___init___locals_genexpr, __pyx_k_Or___init___locals_genexpr, sizeof(__pyx_k_Or___init___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_Or___ixor, __pyx_k_Or___ixor, sizeof(__pyx_k_Or___ixor), 0, 0, 1, 1},
    {&__pyx_n_s_Or___str, __pyx_k_Or___str, sizeof(__pyx_k_Or___str), 0, 0, 1, 1},
    {&__pyx_n_s_Or___str___locals_genexpr, __pyx_k_Or___str___locals_genexpr, sizeof(__pyx_k_Or___str___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_Or__setResultsName, __pyx_k_Or__setResultsName, sizeof(__pyx_k_Or__setResultsName), 0, 0, 1, 1},
    {&__pyx_n_s_Or__setResultsName_locals_genexp, __pyx_k_Or__setResultsName_locals_genexp, sizeof(__pyx_k_Or__setResultsName_locals_genexp), 0, 0, 1, 1},
    {&__pyx_n_s_Or_checkRecursion, __pyx_k_Or_checkRecursion, sizeof(__pyx_k_Or_checkRecursion), 0, 0, 1, 1},
    {&__pyx_n_s_Or_parseImpl, __pyx_k_Or_parseImpl, sizeof(__pyx_k_Or_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Or_streamline, __pyx_k_Or_streamline, sizeof(__pyx_k_Or_streamline), 0, 0, 1, 1},
    {&__pyx_n_s_Or_streamline_locals_genexpr, __pyx_k_Or_streamline_locals_genexpr, sizeof(__pyx_k_Or_streamline_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_OrderedDict, __pyx_k_OrderedDict, sizeof(__pyx_k_OrderedDict), 0, 0, 1, 1},
    {&__pyx_n_s_OrderedDict_2, __pyx_k_OrderedDict_2, sizeof(__pyx_k_OrderedDict_2), 0, 0, 1, 1},
    {&__pyx_n_s_PEER, __pyx_k_PEER, sizeof(__pyx_k_PEER), 0, 0, 1, 1},
    {&__pyx_kp_u_PUNCTUATION_SPACE, __pyx_k_PUNCTUATION_SPACE, sizeof(__pyx_k_PUNCTUATION_SPACE), 0, 1, 0, 0},
    {&__pyx_n_s_PY_3, __pyx_k_PY_3, sizeof(__pyx_k_PY_3), 0, 0, 1, 1},
    {&__pyx_kp_u_P_entity, __pyx_k_P_entity, sizeof(__pyx_k_P_entity), 0, 1, 0, 0},
    {&__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d, __pyx_k_P_year_d_4_P_month_d_d_P_day_d, sizeof(__pyx_k_P_year_d_4_P_month_d_d_P_day_d), 0, 1, 0, 0},
    {&__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2, __pyx_k_P_year_d_4_P_month_d_d_P_day_d_2, sizeof(__pyx_k_P_year_d_4_P_month_d_d_P_day_d_2), 0, 1, 0, 0},
    {&__pyx_n_s_ParseBaseException, __pyx_k_ParseBaseException, sizeof(__pyx_k_ParseBaseException), 0, 0, 1, 1},
    {&__pyx_n_u_ParseBaseException, __pyx_k_ParseBaseException, sizeof(__pyx_k_ParseBaseException), 0, 1, 0, 1},
    {&__pyx_n_s_ParseBaseException___dir, __pyx_k_ParseBaseException___dir, sizeof(__pyx_k_ParseBaseException___dir), 0, 0, 1, 1},
    {&__pyx_n_s_ParseBaseException___getattr, __pyx_k_ParseBaseException___getattr, sizeof(__pyx_k_ParseBaseException___getattr), 0, 0, 1, 1},
    {&__pyx_n_s_ParseBaseException___init, __pyx_k_ParseBaseException___init, sizeof(__pyx_k_ParseBaseException___init), 0, 0, 1, 1},
    {&__pyx_n_s_ParseBaseException___repr, __pyx_k_ParseBaseException___repr, sizeof(__pyx_k_ParseBaseException___repr), 0, 0, 1, 1},
    {&__pyx_n_s_ParseBaseException___str, __pyx_k_ParseBaseException___str, sizeof(__pyx_k_ParseBaseException___str), 0, 0, 1, 1},
    {&__pyx_n_s_ParseBaseException__from_excepti, __pyx_k_ParseBaseException__from_excepti, sizeof(__pyx_k_ParseBaseException__from_excepti), 0, 0, 1, 1},
    {&__pyx_n_s_ParseBaseException_markInputline, __pyx_k_ParseBaseException_markInputline, sizeof(__pyx_k_ParseBaseException_markInputline), 0, 0, 1, 1},
    {&__pyx_n_s_ParseElementEnhance, __pyx_k_ParseElementEnhance, sizeof(__pyx_k_ParseElementEnhance), 0, 0, 1, 1},
    {&__pyx_n_u_ParseElementEnhance, __pyx_k_ParseElementEnhance, sizeof(__pyx_k_ParseElementEnhance), 0, 1, 0, 1},
    {&__pyx_n_s_ParseElementEnhance___init, __pyx_k_ParseElementEnhance___init, sizeof(__pyx_k_ParseElementEnhance___init), 0, 0, 1, 1},
    {&__pyx_n_s_ParseElementEnhance___str, __pyx_k_ParseElementEnhance___str, sizeof(__pyx_k_ParseElementEnhance___str), 0, 0, 1, 1},
    {&__pyx_n_s_ParseElementEnhance_checkRecursi, __pyx_k_ParseElementEnhance_checkRecursi, sizeof(__pyx_k_ParseElementEnhance_checkRecursi), 0, 0, 1, 1},
    {&__pyx_n_s_ParseElementEnhance_ignore, __pyx_k_ParseElementEnhance_ignore, sizeof(__pyx_k_ParseElementEnhance_ignore), 0, 0, 1, 1},
    {&__pyx_n_s_ParseElementEnhance_leaveWhitesp, __pyx_k_ParseElementEnhance_leaveWhitesp, sizeof(__pyx_k_ParseElementEnhance_leaveWhitesp), 0, 0, 1, 1},
    {&__pyx_n_s_ParseElementEnhance_parseImpl, __pyx_k_ParseElementEnhance_parseImpl, sizeof(__pyx_k_ParseElementEnhance_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_ParseElementEnhance_streamline, __pyx_k_ParseElementEnhance_streamline, sizeof(__pyx_k_ParseElementEnhance_streamline), 0, 0, 1, 1},
    {&__pyx_n_s_ParseElementEnhance_validate, __pyx_k_ParseElementEnhance_validate, sizeof(__pyx_k_ParseElementEnhance_validate), 0, 0, 1, 1},
    {&__pyx_n_s_ParseException, __pyx_k_ParseException, sizeof(__pyx_k_ParseException), 0, 0, 1, 1},
    {&__pyx_n_u_ParseException, __pyx_k_ParseException, sizeof(__pyx_k_ParseException), 0, 1, 0, 1},
    {&__pyx_n_s_ParseException_explain, __pyx_k_ParseException_explain, sizeof(__pyx_k_ParseException_explain), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression, __pyx_k_ParseExpression, sizeof(__pyx_k_ParseExpression), 0, 0, 1, 1},
    {&__pyx_n_u_ParseExpression, __pyx_k_ParseExpression, sizeof(__pyx_k_ParseExpression), 0, 1, 0, 1},
    {&__pyx_n_s_ParseExpression___init, __pyx_k_ParseExpression___init, sizeof(__pyx_k_ParseExpression___init), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression___init___locals, __pyx_k_ParseExpression___init___locals, sizeof(__pyx_k_ParseExpression___init___locals), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression___init___locals_2, __pyx_k_ParseExpression___init___locals_2, sizeof(__pyx_k_ParseExpression___init___locals_2), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression___str, __pyx_k_ParseExpression___str, sizeof(__pyx_k_ParseExpression___str), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression__setResultsName, __pyx_k_ParseExpression__setResultsName, sizeof(__pyx_k_ParseExpression__setResultsName), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression_append, __pyx_k_ParseExpression_append, sizeof(__pyx_k_ParseExpression_append), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression_copy, __pyx_k_ParseExpression_copy, sizeof(__pyx_k_ParseExpression_copy), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression_ignore, __pyx_k_ParseExpression_ignore, sizeof(__pyx_k_ParseExpression_ignore), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression_leaveWhitespace, __pyx_k_ParseExpression_leaveWhitespace, sizeof(__pyx_k_ParseExpression_leaveWhitespace), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression_streamline, __pyx_k_ParseExpression_streamline, sizeof(__pyx_k_ParseExpression_streamline), 0, 0, 1, 1},
    {&__pyx_n_s_ParseExpression_validate, __pyx_k_ParseExpression_validate, sizeof(__pyx_k_ParseExpression_validate), 0, 0, 1, 1},
    {&__pyx_n_s_ParseFatalException, __pyx_k_ParseFatalException, sizeof(__pyx_k_ParseFatalException), 0, 0, 1, 1},
    {&__pyx_n_u_ParseFatalException, __pyx_k_ParseFatalException, sizeof(__pyx_k_ParseFatalException), 0, 1, 0, 1},
    {&__pyx_n_s_ParseResults, __pyx_k_ParseResults, sizeof(__pyx_k_ParseResults), 0, 0, 1, 1},
    {&__pyx_n_u_ParseResults, __pyx_k_ParseResults, sizeof(__pyx_k_ParseResults), 0, 1, 0, 1},
    {&__pyx_n_s_ParseResultsWithOffset, __pyx_k_ParseResultsWithOffset, sizeof(__pyx_k_ParseResultsWithOffset), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResultsWithOffset___getite, __pyx_k_ParseResultsWithOffset___getite, sizeof(__pyx_k_ParseResultsWithOffset___getite), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResultsWithOffset___init, __pyx_k_ParseResultsWithOffset___init, sizeof(__pyx_k_ParseResultsWithOffset___init), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResultsWithOffset___repr, __pyx_k_ParseResultsWithOffset___repr, sizeof(__pyx_k_ParseResultsWithOffset___repr), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResultsWithOffset_setOffse, __pyx_k_ParseResultsWithOffset_setOffse, sizeof(__pyx_k_ParseResultsWithOffset_setOffse), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___add, __pyx_k_ParseResults___add, sizeof(__pyx_k_ParseResults___add), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___bool, __pyx_k_ParseResults___bool, sizeof(__pyx_k_ParseResults___bool), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___contains, __pyx_k_ParseResults___contains, sizeof(__pyx_k_ParseResults___contains), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___delitem, __pyx_k_ParseResults___delitem, sizeof(__pyx_k_ParseResults___delitem), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___dir, __pyx_k_ParseResults___dir, sizeof(__pyx_k_ParseResults___dir), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___getattr, __pyx_k_ParseResults___getattr, sizeof(__pyx_k_ParseResults___getattr), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___getitem, __pyx_k_ParseResults___getitem, sizeof(__pyx_k_ParseResults___getitem), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___getnewargs, __pyx_k_ParseResults___getnewargs, sizeof(__pyx_k_ParseResults___getnewargs), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___getstate, __pyx_k_ParseResults___getstate, sizeof(__pyx_k_ParseResults___getstate), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___iadd, __pyx_k_ParseResults___iadd, sizeof(__pyx_k_ParseResults___iadd), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___iadd___locals_lam, __pyx_k_ParseResults___iadd___locals_lam, sizeof(__pyx_k_ParseResults___iadd___locals_lam), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___init, __pyx_k_ParseResults___init, sizeof(__pyx_k_ParseResults___init), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___iter, __pyx_k_ParseResults___iter, sizeof(__pyx_k_ParseResults___iter), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___len, __pyx_k_ParseResults___len, sizeof(__pyx_k_ParseResults___len), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___lookup, __pyx_k_ParseResults___lookup, sizeof(__pyx_k_ParseResults___lookup), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___new, __pyx_k_ParseResults___new, sizeof(__pyx_k_ParseResults___new), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___radd, __pyx_k_ParseResults___radd, sizeof(__pyx_k_ParseResults___radd), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___repr, __pyx_k_ParseResults___repr, sizeof(__pyx_k_ParseResults___repr), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___reversed, __pyx_k_ParseResults___reversed, sizeof(__pyx_k_ParseResults___reversed), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___setitem, __pyx_k_ParseResults___setitem, sizeof(__pyx_k_ParseResults___setitem), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___setstate, __pyx_k_ParseResults___setstate, sizeof(__pyx_k_ParseResults___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___str, __pyx_k_ParseResults___str, sizeof(__pyx_k_ParseResults___str), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults___str___locals_gene, __pyx_k_ParseResults___str___locals_gene, sizeof(__pyx_k_ParseResults___str___locals_gene), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__accumNames, __pyx_k_ParseResults__accumNames, sizeof(__pyx_k_ParseResults__accumNames), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__asList, __pyx_k_ParseResults__asList, sizeof(__pyx_k_ParseResults__asList), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__asStringList, __pyx_k_ParseResults__asStringList, sizeof(__pyx_k_ParseResults__asStringList), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__doinit, __pyx_k_ParseResults__doinit, sizeof(__pyx_k_ParseResults__doinit), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__iteritems, __pyx_k_ParseResults__iteritems, sizeof(__pyx_k_ParseResults__iteritems), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__iteritems_locals_g, __pyx_k_ParseResults__iteritems_locals_g, sizeof(__pyx_k_ParseResults__iteritems_locals_g), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__iterkeys, __pyx_k_ParseResults__iterkeys, sizeof(__pyx_k_ParseResults__iterkeys), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__itervalues, __pyx_k_ParseResults__itervalues, sizeof(__pyx_k_ParseResults__itervalues), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__itervalues_locals, __pyx_k_ParseResults__itervalues_locals, sizeof(__pyx_k_ParseResults__itervalues_locals), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__lookup, __pyx_k_ParseResults__lookup, sizeof(__pyx_k_ParseResults__lookup), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__modal, __pyx_k_ParseResults__modal, sizeof(__pyx_k_ParseResults__modal), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__name, __pyx_k_ParseResults__name, sizeof(__pyx_k_ParseResults__name), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__parent, __pyx_k_ParseResults__parent, sizeof(__pyx_k_ParseResults__parent), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__tokdict, __pyx_k_ParseResults__tokdict, sizeof(__pyx_k_ParseResults__tokdict), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults__toklist, __pyx_k_ParseResults__toklist, sizeof(__pyx_k_ParseResults__toklist), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_append, __pyx_k_ParseResults_append, sizeof(__pyx_k_ParseResults_append), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_asDict, __pyx_k_ParseResults_asDict, sizeof(__pyx_k_ParseResults_asDict), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_asDict_locals_genex, __pyx_k_ParseResults_asDict_locals_genex, sizeof(__pyx_k_ParseResults_asDict_locals_genex), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_asDict_locals_toIte, __pyx_k_ParseResults_asDict_locals_toIte, sizeof(__pyx_k_ParseResults_asDict_locals_toIte), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_asList, __pyx_k_ParseResults_asList, sizeof(__pyx_k_ParseResults_asList), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_asXML, __pyx_k_ParseResults_asXML, sizeof(__pyx_k_ParseResults_asXML), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_asXML_locals_genexp, __pyx_k_ParseResults_asXML_locals_genexp, sizeof(__pyx_k_ParseResults_asXML_locals_genexp), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_clear, __pyx_k_ParseResults_clear, sizeof(__pyx_k_ParseResults_clear), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_copy, __pyx_k_ParseResults_copy, sizeof(__pyx_k_ParseResults_copy), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_dump, __pyx_k_ParseResults_dump, sizeof(__pyx_k_ParseResults_dump), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_dump_locals_genexpr, __pyx_k_ParseResults_dump_locals_genexpr, sizeof(__pyx_k_ParseResults_dump_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_extend, __pyx_k_ParseResults_extend, sizeof(__pyx_k_ParseResults_extend), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_from_dict, __pyx_k_ParseResults_from_dict, sizeof(__pyx_k_ParseResults_from_dict), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_from_dict_locals_is, __pyx_k_ParseResults_from_dict_locals_is, sizeof(__pyx_k_ParseResults_from_dict_locals_is), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_get, __pyx_k_ParseResults_get, sizeof(__pyx_k_ParseResults_get), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_getName, __pyx_k_ParseResults_getName, sizeof(__pyx_k_ParseResults_getName), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_haskeys, __pyx_k_ParseResults_haskeys, sizeof(__pyx_k_ParseResults_haskeys), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_insert, __pyx_k_ParseResults_insert, sizeof(__pyx_k_ParseResults_insert), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_items, __pyx_k_ParseResults_items, sizeof(__pyx_k_ParseResults_items), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_keys, __pyx_k_ParseResults_keys, sizeof(__pyx_k_ParseResults_keys), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_pop, __pyx_k_ParseResults_pop, sizeof(__pyx_k_ParseResults_pop), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_pprint, __pyx_k_ParseResults_pprint, sizeof(__pyx_k_ParseResults_pprint), 0, 0, 1, 1},
    {&__pyx_n_s_ParseResults_values, __pyx_k_ParseResults_values, sizeof(__pyx_k_ParseResults_values), 0, 0, 1, 1},
    {&__pyx_n_s_ParseSyntaxException, __pyx_k_ParseSyntaxException, sizeof(__pyx_k_ParseSyntaxException), 0, 0, 1, 1},
    {&__pyx_n_u_ParseSyntaxException, __pyx_k_ParseSyntaxException, sizeof(__pyx_k_ParseSyntaxException), 0, 1, 0, 1},
    {&__pyx_n_s_ParserElement, __pyx_k_ParserElement, sizeof(__pyx_k_ParserElement), 0, 0, 1, 1},
    {&__pyx_n_u_ParserElement, __pyx_k_ParserElement, sizeof(__pyx_k_ParserElement), 0, 1, 0, 1},
    {&__pyx_n_s_ParserElement___add, __pyx_k_ParserElement___add, sizeof(__pyx_k_ParserElement___add), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___and, __pyx_k_ParserElement___and, sizeof(__pyx_k_ParserElement___and), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___call, __pyx_k_ParserElement___call, sizeof(__pyx_k_ParserElement___call), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___eq, __pyx_k_ParserElement___eq, sizeof(__pyx_k_ParserElement___eq), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___getitem, __pyx_k_ParserElement___getitem, sizeof(__pyx_k_ParserElement___getitem), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___hash, __pyx_k_ParserElement___hash, sizeof(__pyx_k_ParserElement___hash), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___init, __pyx_k_ParserElement___init, sizeof(__pyx_k_ParserElement___init), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___invert, __pyx_k_ParserElement___invert, sizeof(__pyx_k_ParserElement___invert), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___iter, __pyx_k_ParserElement___iter, sizeof(__pyx_k_ParserElement___iter), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___mul, __pyx_k_ParserElement___mul, sizeof(__pyx_k_ParserElement___mul), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___mul___locals_gen, __pyx_k_ParserElement___mul___locals_gen, sizeof(__pyx_k_ParserElement___mul___locals_gen), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___mul___locals_mak, __pyx_k_ParserElement___mul___locals_mak, sizeof(__pyx_k_ParserElement___mul___locals_mak), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___ne, __pyx_k_ParserElement___ne, sizeof(__pyx_k_ParserElement___ne), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___or, __pyx_k_ParserElement___or, sizeof(__pyx_k_ParserElement___or), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___radd, __pyx_k_ParserElement___radd, sizeof(__pyx_k_ParserElement___radd), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___rand, __pyx_k_ParserElement___rand, sizeof(__pyx_k_ParserElement___rand), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___repr, __pyx_k_ParserElement___repr, sizeof(__pyx_k_ParserElement___repr), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___req, __pyx_k_ParserElement___req, sizeof(__pyx_k_ParserElement___req), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___rmul, __pyx_k_ParserElement___rmul, sizeof(__pyx_k_ParserElement___rmul), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___rne, __pyx_k_ParserElement___rne, sizeof(__pyx_k_ParserElement___rne), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___ror, __pyx_k_ParserElement___ror, sizeof(__pyx_k_ParserElement___ror), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___rsub, __pyx_k_ParserElement___rsub, sizeof(__pyx_k_ParserElement___rsub), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___rxor, __pyx_k_ParserElement___rxor, sizeof(__pyx_k_ParserElement___rxor), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___str, __pyx_k_ParserElement___str, sizeof(__pyx_k_ParserElement___str), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___sub, __pyx_k_ParserElement___sub, sizeof(__pyx_k_ParserElement___sub), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement___xor, __pyx_k_ParserElement___xor, sizeof(__pyx_k_ParserElement___xor), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement__parseCache, __pyx_k_ParserElement__parseCache, sizeof(__pyx_k_ParserElement__parseCache), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement__parseIncremental, __pyx_k_ParserElement__parseIncremental, sizeof(__pyx_k_ParserElement__parseIncremental), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement__parseIncremental_2, __pyx_k_ParserElement__parseIncremental_2, sizeof(__pyx_k_ParserElement__parseIncremental_2), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement__parseNoCache, __pyx_k_ParserElement__parseNoCache, sizeof(__pyx_k_ParserElement__parseNoCache), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement__setResultsName, __pyx_k_ParserElement__setResultsName, sizeof(__pyx_k_ParserElement__setResultsName), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement__skipIgnorables, __pyx_k_ParserElement__skipIgnorables, sizeof(__pyx_k_ParserElement__skipIgnorables), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement__trim_traceback, __pyx_k_ParserElement__trim_traceback, sizeof(__pyx_k_ParserElement__trim_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement__update_furthest_l, __pyx_k_ParserElement__update_furthest_l, sizeof(__pyx_k_ParserElement__update_furthest_l), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_addCondition, __pyx_k_ParserElement_addCondition, sizeof(__pyx_k_ParserElement_addCondition), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_addParseAction, __pyx_k_ParserElement_addParseAction, sizeof(__pyx_k_ParserElement_addParseAction), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_canParseNext, __pyx_k_ParserElement_canParseNext, sizeof(__pyx_k_ParserElement_canParseNext), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_checkRecursion, __pyx_k_ParserElement_checkRecursion, sizeof(__pyx_k_ParserElement_checkRecursion), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_collectParseElemen, __pyx_k_ParserElement_collectParseElemen, sizeof(__pyx_k_ParserElement_collectParseElemen), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_copy, __pyx_k_ParserElement_copy, sizeof(__pyx_k_ParserElement_copy), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_enableIncremental, __pyx_k_ParserElement_enableIncremental, sizeof(__pyx_k_ParserElement_enableIncremental), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_enablePackrat, __pyx_k_ParserElement_enablePackrat, sizeof(__pyx_k_ParserElement_enablePackrat), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_ignore, __pyx_k_ParserElement_ignore, sizeof(__pyx_k_ParserElement_ignore), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_inlineLiteralsUsin, __pyx_k_ParserElement_inlineLiteralsUsin, sizeof(__pyx_k_ParserElement_inlineLiteralsUsin), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_leaveWhitespace, __pyx_k_ParserElement_leaveWhitespace, sizeof(__pyx_k_ParserElement_leaveWhitespace), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_matches, __pyx_k_ParserElement_matches, sizeof(__pyx_k_ParserElement_matches), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_parseFile, __pyx_k_ParserElement_parseFile, sizeof(__pyx_k_ParserElement_parseFile), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_parseImpl, __pyx_k_ParserElement_parseImpl, sizeof(__pyx_k_ParserElement_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_parseString, __pyx_k_ParserElement_parseString, sizeof(__pyx_k_ParserElement_parseString), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_parseWithTabs, __pyx_k_ParserElement_parseWithTabs, sizeof(__pyx_k_ParserElement_parseWithTabs), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_postParse, __pyx_k_ParserElement_postParse, sizeof(__pyx_k_ParserElement_postParse), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_preParse, __pyx_k_ParserElement_preParse, sizeof(__pyx_k_ParserElement_preParse), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_resetCache, __pyx_k_ParserElement_resetCache, sizeof(__pyx_k_ParserElement_resetCache), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_runTests, __pyx_k_ParserElement_runTests, sizeof(__pyx_k_ParserElement_runTests), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_scanString, __pyx_k_ParserElement_scanString, sizeof(__pyx_k_ParserElement_scanString), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_searchString, __pyx_k_ParserElement_searchString, sizeof(__pyx_k_ParserElement_searchString), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setBreak, __pyx_k_ParserElement_setBreak, sizeof(__pyx_k_ParserElement_setBreak), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setBreak_locals_br, __pyx_k_ParserElement_setBreak_locals_br, sizeof(__pyx_k_ParserElement_setBreak_locals_br), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setDebug, __pyx_k_ParserElement_setDebug, sizeof(__pyx_k_ParserElement_setDebug), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setDebugActions, __pyx_k_ParserElement_setDebugActions, sizeof(__pyx_k_ParserElement_setDebugActions), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setDefaultWhitespa, __pyx_k_ParserElement_setDefaultWhitespa, sizeof(__pyx_k_ParserElement_setDefaultWhitespa), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setFailAction, __pyx_k_ParserElement_setFailAction, sizeof(__pyx_k_ParserElement_setFailAction), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setName, __pyx_k_ParserElement_setName, sizeof(__pyx_k_ParserElement_setName), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setParseAction, __pyx_k_ParserElement_setParseAction, sizeof(__pyx_k_ParserElement_setParseAction), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setParseAction_loc, __pyx_k_ParserElement_setParseAction_loc, sizeof(__pyx_k_ParserElement_setParseAction_loc), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setResultsName, __pyx_k_ParserElement_setResultsName, sizeof(__pyx_k_ParserElement_setResultsName), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_setWhitespaceChars, __pyx_k_ParserElement_setWhitespaceChars, sizeof(__pyx_k_ParserElement_setWhitespaceChars), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_split, __pyx_k_ParserElement_split, sizeof(__pyx_k_ParserElement_split), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_streamline, __pyx_k_ParserElement_streamline, sizeof(__pyx_k_ParserElement_streamline), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_suppress, __pyx_k_ParserElement_suppress, sizeof(__pyx_k_ParserElement_suppress), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_transformString, __pyx_k_ParserElement_transformString, sizeof(__pyx_k_ParserElement_transformString), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_tryParse, __pyx_k_ParserElement_tryParse, sizeof(__pyx_k_ParserElement_tryParse), 0, 0, 1, 1},
    {&__pyx_n_s_ParserElement_validate, __pyx_k_ParserElement_validate, sizeof(__pyx_k_ParserElement_validate), 0, 0, 1, 1},
    {&__pyx_n_s_PendingSkip, __pyx_k_PendingSkip, sizeof(__pyx_k_PendingSkip), 0, 0, 1, 1},
    {&__pyx_n_s_PendingSkip___add, __pyx_k_PendingSkip___add, sizeof(__pyx_k_PendingSkip___add), 0, 0, 1, 1},
    {&__pyx_n_s_PendingSkip___add___locals_must, __pyx_k_PendingSkip___add___locals_must, sizeof(__pyx_k_PendingSkip___add___locals_must), 0, 0, 1, 1},
    {&__pyx_n_s_PendingSkip___add___locals_show, __pyx_k_PendingSkip___add___locals_show, sizeof(__pyx_k_PendingSkip___add___locals_show), 0, 0, 1, 1},
    {&__pyx_n_s_PendingSkip___init, __pyx_k_PendingSkip___init, sizeof(__pyx_k_PendingSkip___init), 0, 0, 1, 1},
    {&__pyx_n_s_PendingSkip___repr, __pyx_k_PendingSkip___repr, sizeof(__pyx_k_PendingSkip___repr), 0, 0, 1, 1},
    {&__pyx_n_s_PendingSkip_parseImpl, __pyx_k_PendingSkip_parseImpl, sizeof(__pyx_k_PendingSkip_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_PositionToken, __pyx_k_PositionToken, sizeof(__pyx_k_PositionToken), 0, 0, 1, 1},
    {&__pyx_n_s_PositionToken___init, __pyx_k_PositionToken___init, sizeof(__pyx_k_PositionToken___init), 0, 0, 1, 1},
    {&__pyx_n_s_PrecededBy, __pyx_k_PrecededBy, sizeof(__pyx_k_PrecededBy), 0, 0, 1, 1},
    {&__pyx_n_u_PrecededBy, __pyx_k_PrecededBy, sizeof(__pyx_k_PrecededBy), 0, 1, 0, 1},
    {&__pyx_n_s_PrecededBy___init, __pyx_k_PrecededBy___init, sizeof(__pyx_k_PrecededBy___init), 0, 0, 1, 1},
    {&__pyx_n_s_PrecededBy___init___locals_lambd, __pyx_k_PrecededBy___init___locals_lambd, sizeof(__pyx_k_PrecededBy___init___locals_lambd), 0, 0, 1, 1},
    {&__pyx_n_s_PrecededBy_parseImpl, __pyx_k_PrecededBy_parseImpl, sizeof(__pyx_k_PrecededBy_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_u_Python_style_comment, __pyx_k_Python_style_comment, sizeof(__pyx_k_Python_style_comment), 0, 1, 0, 0},
    {&__pyx_n_s_QuotedString, __pyx_k_QuotedString, sizeof(__pyx_k_QuotedString), 0, 0, 1, 1},
    {&__pyx_n_u_QuotedString, __pyx_k_QuotedString, sizeof(__pyx_k_QuotedString), 0, 1, 0, 1},
    {&__pyx_n_s_QuotedString___init, __pyx_k_QuotedString___init, sizeof(__pyx_k_QuotedString___init), 0, 0, 1, 1},
    {&__pyx_n_s_QuotedString___init___locals_gen, __pyx_k_QuotedString___init___locals_gen, sizeof(__pyx_k_QuotedString___init___locals_gen), 0, 0, 1, 1},
    {&__pyx_n_s_QuotedString___str, __pyx_k_QuotedString___str, sizeof(__pyx_k_QuotedString___str), 0, 0, 1, 1},
    {&__pyx_n_s_QuotedString_parseImpl, __pyx_k_QuotedString_parseImpl, sizeof(__pyx_k_QuotedString_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_RIGHT, __pyx_k_RIGHT, sizeof(__pyx_k_RIGHT), 0, 0, 1, 1},
    {&__pyx_n_s_RLock, __pyx_k_RLock, sizeof(__pyx_k_RLock), 0, 0, 1, 1},
    {&__pyx_kp_u_Re_s, __pyx_k_Re_s, sizeof(__pyx_k_Re_s), 0, 1, 0, 0},
    {&__pyx_n_s_RecursiveGrammarException, __pyx_k_RecursiveGrammarException, sizeof(__pyx_k_RecursiveGrammarException), 0, 0, 1, 1},
    {&__pyx_n_u_RecursiveGrammarException, __pyx_k_RecursiveGrammarException, sizeof(__pyx_k_RecursiveGrammarException), 0, 1, 0, 1},
    {&__pyx_n_s_RecursiveGrammarException___init, __pyx_k_RecursiveGrammarException___init, sizeof(__pyx_k_RecursiveGrammarException___init), 0, 0, 1, 1},
    {&__pyx_n_s_RecursiveGrammarException___str, __pyx_k_RecursiveGrammarException___str, sizeof(__pyx_k_RecursiveGrammarException___str), 0, 0, 1, 1},
    {&__pyx_kp_u_RecursiveGrammarException_s, __pyx_k_RecursiveGrammarException_s, sizeof(__pyx_k_RecursiveGrammarException_s), 0, 1, 0, 0},
    {&__pyx_n_s_Regex, __pyx_k_Regex, sizeof(__pyx_k_Regex), 0, 0, 1, 1},
    {&__pyx_n_u_Regex, __pyx_k_Regex, sizeof(__pyx_k_Regex), 0, 1, 0, 1},
    {&__pyx_n_s_Regex___init, __pyx_k_Regex___init, sizeof(__pyx_k_Regex___init), 0, 0, 1, 1},
    {&__pyx_n_s_Regex___str, __pyx_k_Regex___str, sizeof(__pyx_k_Regex___str), 0, 0, 1, 1},
    {&__pyx_kp_u_Regex_may_only_be_constructed_wi, __pyx_k_Regex_may_only_be_constructed_wi, sizeof(__pyx_k_Regex_may_only_be_constructed_wi), 0, 1, 0, 0},
    {&__pyx_n_s_Regex_parseImpl, __pyx_k_Regex_parseImpl, sizeof(__pyx_k_Regex_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Regex_parseImplAsGroupList, __pyx_k_Regex_parseImplAsGroupList, sizeof(__pyx_k_Regex_parseImplAsGroupList), 0, 0, 1, 1},
    {&__pyx_n_s_Regex_parseImplAsMatch, __pyx_k_Regex_parseImplAsMatch, sizeof(__pyx_k_Regex_parseImplAsMatch), 0, 0, 1, 1},
    {&__pyx_n_s_Regex_sub, __pyx_k_Regex_sub, sizeof(__pyx_k_Regex_sub), 0, 0, 1, 1},
    {&__pyx_n_s_Regex_sub_locals_pa, __pyx_k_Regex_sub_locals_pa, sizeof(__pyx_k_Regex_sub_locals_pa), 0, 0, 1, 1},
    {&__pyx_kp_s_Repetition_of_one_or_more_of_the, __pyx_k_Repetition_of_one_or_more_of_the, sizeof(__pyx_k_Repetition_of_one_or_more_of_the), 0, 0, 1, 0},
    {&__pyx_kp_s_Requires_all_given_class_ParseE, __pyx_k_Requires_all_given_class_ParseE, sizeof(__pyx_k_Requires_all_given_class_ParseE), 0, 0, 1, 0},
    {&__pyx_kp_s_Requires_all_given_class_ParseEx, __pyx_k_Requires_all_given_class_ParseEx, sizeof(__pyx_k_Requires_all_given_class_ParseEx), 0, 0, 1, 0},
    {&__pyx_kp_s_Requires_that_at_least_one_class, __pyx_k_Requires_that_at_least_one_class, sizeof(__pyx_k_Requires_that_at_least_one_class), 0, 0, 1, 0},
    {&__pyx_kp_s_Requires_that_at_least_one_class_2, __pyx_k_Requires_that_at_least_one_class_2, sizeof(__pyx_k_Requires_that_at_least_one_class_2), 0, 0, 1, 0},
    {&__pyx_kp_u_SIX_PER_EM_SPACE, __pyx_k_SIX_PER_EM_SPACE, sizeof(__pyx_k_SIX_PER_EM_SPACE), 0, 1, 0, 0},
    {&__pyx_kp_u_SP, __pyx_k_SP, sizeof(__pyx_k_SP), 0, 1, 0, 0},
    {&__pyx_n_s_SimpleNamespace, __pyx_k_SimpleNamespace, sizeof(__pyx_k_SimpleNamespace), 0, 0, 1, 1},
    {&__pyx_n_s_SingleCharLiteral, __pyx_k_SingleCharLiteral, sizeof(__pyx_k_SingleCharLiteral), 0, 0, 1, 1},
    {&__pyx_n_s_SingleCharLiteral_parseImpl, __pyx_k_SingleCharLiteral_parseImpl, sizeof(__pyx_k_SingleCharLiteral_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_SkipTo, __pyx_k_SkipTo, sizeof(__pyx_k_SkipTo), 0, 0, 1, 1},
    {&__pyx_n_u_SkipTo, __pyx_k_SkipTo, sizeof(__pyx_k_SkipTo), 0, 1, 0, 1},
    {&__pyx_n_s_SkipTo___init, __pyx_k_SkipTo___init, sizeof(__pyx_k_SkipTo___init), 0, 0, 1, 1},
    {&__pyx_n_s_SkipTo_parseImpl, __pyx_k_SkipTo_parseImpl, sizeof(__pyx_k_SkipTo_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_s_Special_matching_class_for_match, __pyx_k_Special_matching_class_for_match, sizeof(__pyx_k_Special_matching_class_for_match), 0, 0, 1, 0},
    {&__pyx_n_s_StringEnd, __pyx_k_StringEnd, sizeof(__pyx_k_StringEnd), 0, 0, 1, 1},
    {&__pyx_n_u_StringEnd, __pyx_k_StringEnd, sizeof(__pyx_k_StringEnd), 0, 1, 0, 1},
    {&__pyx_n_s_StringEnd___init, __pyx_k_StringEnd___init, sizeof(__pyx_k_StringEnd___init), 0, 0, 1, 1},
    {&__pyx_n_s_StringEnd_parseImpl, __pyx_k_StringEnd_parseImpl, sizeof(__pyx_k_StringEnd_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_StringStart, __pyx_k_StringStart, sizeof(__pyx_k_StringStart), 0, 0, 1, 1},
    {&__pyx_n_u_StringStart, __pyx_k_StringStart, sizeof(__pyx_k_StringStart), 0, 1, 0, 1},
    {&__pyx_n_s_StringStart___init, __pyx_k_StringStart___init, sizeof(__pyx_k_StringStart___init), 0, 0, 1, 1},
    {&__pyx_n_s_StringStart_parseImpl, __pyx_k_StringStart_parseImpl, sizeof(__pyx_k_StringStart_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_s_Structured_parse_results_to_prov, __pyx_k_Structured_parse_results_to_prov, sizeof(__pyx_k_Structured_parse_results_to_prov), 0, 0, 1, 0},
    {&__pyx_n_s_Suppress, __pyx_k_Suppress, sizeof(__pyx_k_Suppress), 0, 0, 1, 1},
    {&__pyx_n_u_Suppress, __pyx_k_Suppress, sizeof(__pyx_k_Suppress), 0, 1, 0, 1},
    {&__pyx_n_s_Suppress_postParse, __pyx_k_Suppress_postParse, sizeof(__pyx_k_Suppress_postParse), 0, 0, 1, 1},
    {&__pyx_n_s_Suppress_suppress, __pyx_k_Suppress_suppress, sizeof(__pyx_k_Suppress_suppress), 0, 0, 1, 1},
    {&__pyx_n_s_SyntaxError, __pyx_k_SyntaxError, sizeof(__pyx_k_SyntaxError), 0, 0, 1, 1},
    {&__pyx_n_s_SyntaxWarning, __pyx_k_SyntaxWarning, sizeof(__pyx_k_SyntaxWarning), 0, 0, 1, 1},
    {&__pyx_kp_u_TAB, __pyx_k_TAB, sizeof(__pyx_k_TAB), 0, 1, 0, 0},
    {&__pyx_kp_u_THIN_SPACE, __pyx_k_THIN_SPACE, sizeof(__pyx_k_THIN_SPACE), 0, 1, 0, 0},
    {&__pyx_kp_u_THREE_PER_EM_SPACE, __pyx_k_THREE_PER_EM_SPACE, sizeof(__pyx_k_THREE_PER_EM_SPACE), 0, 1, 0, 0},
    {&__pyx_n_s_TRY, __pyx_k_TRY, sizeof(__pyx_k_TRY), 0, 0, 1, 1},
    {&__pyx_n_s_TestParseResultsAsserts, __pyx_k_TestParseResultsAsserts, sizeof(__pyx_k_TestParseResultsAsserts), 0, 0, 1, 1},
    {&__pyx_kp_u_Text_not_in_expected_column, __pyx_k_Text_not_in_expected_column, sizeof(__pyx_k_Text_not_in_expected_column), 0, 1, 0, 0},
    {&__pyx_n_s_Thai, __pyx_k_Thai, sizeof(__pyx_k_Thai), 0, 0, 1, 1},
    {&__pyx_n_s_Token, __pyx_k_Token, sizeof(__pyx_k_Token), 0, 0, 1, 1},
    {&__pyx_n_u_Token, __pyx_k_Token, sizeof(__pyx_k_Token), 0, 1, 0, 1},
    {&__pyx_n_s_TokenConverter, __pyx_k_TokenConverter, sizeof(__pyx_k_TokenConverter), 0, 0, 1, 1},
    {&__pyx_n_u_TokenConverter, __pyx_k_TokenConverter, sizeof(__pyx_k_TokenConverter), 0, 1, 0, 1},
    {&__pyx_n_s_TokenConverter___init, __pyx_k_TokenConverter___init, sizeof(__pyx_k_TokenConverter___init), 0, 0, 1, 1},
    {&__pyx_n_s_Token___init, __pyx_k_Token___init, sizeof(__pyx_k_Token___init), 0, 0, 1, 1},
    {&__pyx_kp_s_Token_for_matching_strings_that, __pyx_k_Token_for_matching_strings_that, sizeof(__pyx_k_Token_for_matching_strings_that), 0, 0, 1, 0},
    {&__pyx_kp_s_Token_for_matching_strings_that_2, __pyx_k_Token_for_matching_strings_that_2, sizeof(__pyx_k_Token_for_matching_strings_that_2), 0, 0, 1, 0},
    {&__pyx_kp_s_Token_for_matching_words_compose, __pyx_k_Token_for_matching_words_compose, sizeof(__pyx_k_Token_for_matching_words_compose), 0, 0, 1, 0},
    {&__pyx_kp_s_Token_for_matching_words_compose_2, __pyx_k_Token_for_matching_words_compose_2, sizeof(__pyx_k_Token_for_matching_words_compose_2), 0, 0, 1, 0},
    {&__pyx_kp_s_Token_for_skipping_over_all_unde, __pyx_k_Token_for_skipping_over_all_unde, sizeof(__pyx_k_Token_for_skipping_over_all_unde), 0, 0, 1, 0},
    {&__pyx_kp_s_Token_to_advance_to_a_specific_c, __pyx_k_Token_to_advance_to_a_specific_c, sizeof(__pyx_k_Token_to_advance_to_a_specific_c), 0, 0, 1, 0},
    {&__pyx_kp_s_Token_to_exactly_match_a_specifi, __pyx_k_Token_to_exactly_match_a_specifi, sizeof(__pyx_k_Token_to_exactly_match_a_specifi), 0, 0, 1, 0},
    {&__pyx_kp_s_Token_to_exactly_match_a_specifi_2, __pyx_k_Token_to_exactly_match_a_specifi_2, sizeof(__pyx_k_Token_to_exactly_match_a_specifi_2), 0, 0, 1, 0},
    {&__pyx_kp_s_Token_to_match_a_specified_strin, __pyx_k_Token_to_match_a_specified_strin, sizeof(__pyx_k_Token_to_match_a_specified_strin), 0, 0, 1, 0},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_n_s_UNDENT, __pyx_k_UNDENT, sizeof(__pyx_k_UNDENT), 0, 0, 1, 1},
    {&__pyx_n_u_UNINDENT, __pyx_k_UNINDENT, sizeof(__pyx_k_UNINDENT), 0, 1, 0, 1},
    {&__pyx_n_s_UUID, __pyx_k_UUID, sizeof(__pyx_k_UUID), 0, 0, 1, 1},
    {&__pyx_n_u_UUID, __pyx_k_UUID, sizeof(__pyx_k_UUID), 0, 1, 0, 1},
    {&__pyx_n_s_UnboundedCache, __pyx_k_UnboundedCache, sizeof(__pyx_k_UnboundedCache), 0, 0, 1, 1},
    {&__pyx_n_s_UnboundedCache___init, __pyx_k_UnboundedCache___init, sizeof(__pyx_k_UnboundedCache___init), 0, 0, 1, 1},
    {&__pyx_n_s_UnboundedCache___len, __pyx_k_UnboundedCache___len, sizeof(__pyx_k_UnboundedCache___len), 0, 0, 1, 1},
    {&__pyx_n_s_UnboundedCache___reduce, __pyx_k_UnboundedCache___reduce, sizeof(__pyx_k_UnboundedCache___reduce), 0, 0, 1, 1},
    {&__pyx_n_s_UnboundedCache_clear, __pyx_k_UnboundedCache_clear, sizeof(__pyx_k_UnboundedCache_clear), 0, 0, 1, 1},
    {&__pyx_n_s_UnboundedCache_get, __pyx_k_UnboundedCache_get, sizeof(__pyx_k_UnboundedCache_get), 0, 0, 1, 1},
    {&__pyx_n_s_UnboundedCache_set, __pyx_k_UnboundedCache_set, sizeof(__pyx_k_UnboundedCache_set), 0, 0, 1, 1},
    {&__pyx_n_s_UnboundedCache_update, __pyx_k_UnboundedCache_update, sizeof(__pyx_k_UnboundedCache_update), 0, 0, 1, 1},
    {&__pyx_kp_s_Unicode_set_for_Arabic_Unicode_C, __pyx_k_Unicode_set_for_Arabic_Unicode_C, sizeof(__pyx_k_Unicode_set_for_Arabic_Unicode_C), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Chinese_Unicode, __pyx_k_Unicode_set_for_Chinese_Unicode, sizeof(__pyx_k_Unicode_set_for_Chinese_Unicode), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Cyrillic_Unicode, __pyx_k_Unicode_set_for_Cyrillic_Unicode, sizeof(__pyx_k_Unicode_set_for_Cyrillic_Unicode), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Devanagari_Unico, __pyx_k_Unicode_set_for_Devanagari_Unico, sizeof(__pyx_k_Unicode_set_for_Devanagari_Unico), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Greek_Unicode_Ch, __pyx_k_Unicode_set_for_Greek_Unicode_Ch, sizeof(__pyx_k_Unicode_set_for_Greek_Unicode_Ch), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Hebrew_Unicode_C, __pyx_k_Unicode_set_for_Hebrew_Unicode_C, sizeof(__pyx_k_Unicode_set_for_Hebrew_Unicode_C), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Hiragana_Unicode, __pyx_k_Unicode_set_for_Hiragana_Unicode, sizeof(__pyx_k_Unicode_set_for_Hiragana_Unicode), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Japanese_Unicode, __pyx_k_Unicode_set_for_Japanese_Unicode, sizeof(__pyx_k_Unicode_set_for_Japanese_Unicode), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Kanji_Unicode_Ch, __pyx_k_Unicode_set_for_Kanji_Unicode_Ch, sizeof(__pyx_k_Unicode_set_for_Kanji_Unicode_Ch), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Katakana_Unicode, __pyx_k_Unicode_set_for_Katakana_Unicode, sizeof(__pyx_k_Unicode_set_for_Katakana_Unicode), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Korean_Unicode_C, __pyx_k_Unicode_set_for_Korean_Unicode_C, sizeof(__pyx_k_Unicode_set_for_Korean_Unicode_C), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Latin_1_Unicode, __pyx_k_Unicode_set_for_Latin_1_Unicode, sizeof(__pyx_k_Unicode_set_for_Latin_1_Unicode), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Latin_A_Unicode, __pyx_k_Unicode_set_for_Latin_A_Unicode, sizeof(__pyx_k_Unicode_set_for_Latin_A_Unicode), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Latin_B_Unicode, __pyx_k_Unicode_set_for_Latin_B_Unicode, sizeof(__pyx_k_Unicode_set_for_Latin_B_Unicode), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_Thai_Unicode_Cha, __pyx_k_Unicode_set_for_Thai_Unicode_Cha, sizeof(__pyx_k_Unicode_set_for_Thai_Unicode_Cha), 0, 0, 1, 0},
    {&__pyx_kp_s_Unicode_set_for_combined_Chinese, __pyx_k_Unicode_set_for_combined_Chinese, sizeof(__pyx_k_Unicode_set_for_combined_Chinese), 0, 0, 1, 0},
    {&__pyx_kp_u_Unmatchable_token, __pyx_k_Unmatchable_token, sizeof(__pyx_k_Unmatchable_token), 0, 1, 0, 0},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_kp_u_W, __pyx_k_W, sizeof(__pyx_k_W), 0, 1, 0, 0},
    {&__pyx_n_s_WRAP_CALL_LINE_NUM, __pyx_k_WRAP_CALL_LINE_NUM, sizeof(__pyx_k_WRAP_CALL_LINE_NUM), 0, 0, 1, 1},
    {&__pyx_kp_u_W_s, __pyx_k_W_s, sizeof(__pyx_k_W_s), 0, 1, 0, 0},
    {&__pyx_kp_u_W_s_2, __pyx_k_W_s_2, sizeof(__pyx_k_W_s_2), 0, 1, 0, 0},
    {&__pyx_kp_u_W_s_3, __pyx_k_W_s_3, sizeof(__pyx_k_W_s_3), 0, 1, 0, 0},
    {&__pyx_n_s_White, __pyx_k_White, sizeof(__pyx_k_White), 0, 0, 1, 1},
    {&__pyx_n_u_White, __pyx_k_White, sizeof(__pyx_k_White), 0, 1, 0, 1},
    {&__pyx_n_s_White___init, __pyx_k_White___init, sizeof(__pyx_k_White___init), 0, 0, 1, 1},
    {&__pyx_n_s_White___init___locals_genexpr, __pyx_k_White___init___locals_genexpr, sizeof(__pyx_k_White___init___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_White_parseImpl, __pyx_k_White_parseImpl, sizeof(__pyx_k_White_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Word, __pyx_k_Word, sizeof(__pyx_k_Word), 0, 0, 1, 1},
    {&__pyx_n_u_Word, __pyx_k_Word, sizeof(__pyx_k_Word), 0, 1, 0, 1},
    {&__pyx_n_s_WordEnd, __pyx_k_WordEnd, sizeof(__pyx_k_WordEnd), 0, 0, 1, 1},
    {&__pyx_n_u_WordEnd, __pyx_k_WordEnd, sizeof(__pyx_k_WordEnd), 0, 1, 0, 1},
    {&__pyx_n_s_WordEnd___init, __pyx_k_WordEnd___init, sizeof(__pyx_k_WordEnd___init), 0, 0, 1, 1},
    {&__pyx_n_s_WordEnd_parseImpl, __pyx_k_WordEnd_parseImpl, sizeof(__pyx_k_WordEnd_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_WordRegex, __pyx_k_WordRegex, sizeof(__pyx_k_WordRegex), 0, 0, 1, 1},
    {&__pyx_n_s_WordRegex_parseImpl, __pyx_k_WordRegex_parseImpl, sizeof(__pyx_k_WordRegex_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_WordStart, __pyx_k_WordStart, sizeof(__pyx_k_WordStart), 0, 0, 1, 1},
    {&__pyx_n_u_WordStart, __pyx_k_WordStart, sizeof(__pyx_k_WordStart), 0, 1, 0, 1},
    {&__pyx_n_s_WordStart___init, __pyx_k_WordStart___init, sizeof(__pyx_k_WordStart___init), 0, 0, 1, 1},
    {&__pyx_n_s_WordStart_parseImpl, __pyx_k_WordStart_parseImpl, sizeof(__pyx_k_WordStart_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_s_Word___init, __pyx_k_Word___init, sizeof(__pyx_k_Word___init), 0, 0, 1, 1},
    {&__pyx_n_s_Word___init___locals_genexpr, __pyx_k_Word___init___locals_genexpr, sizeof(__pyx_k_Word___init___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_Word___str, __pyx_k_Word___str, sizeof(__pyx_k_Word___str), 0, 0, 1, 1},
    {&__pyx_n_s_Word___str___locals_charsAsStr, __pyx_k_Word___str___locals_charsAsStr, sizeof(__pyx_k_Word___str___locals_charsAsStr), 0, 0, 1, 1},
    {&__pyx_n_s_Word_parseImpl, __pyx_k_Word_parseImpl, sizeof(__pyx_k_Word_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_s_Wrapper_for_parse_actions_to_ens, __pyx_k_Wrapper_for_parse_actions_to_ens, sizeof(__pyx_k_Wrapper_for_parse_actions_to_ens), 0, 0, 1, 0},
    {&__pyx_kp_u_Y_m_d, __pyx_k_Y_m_d, sizeof(__pyx_k_Y_m_d), 0, 1, 0, 0},
    {&__pyx_kp_u_Y_m_dT_H_M_S_f, __pyx_k_Y_m_dT_H_M_S_f, sizeof(__pyx_k_Y_m_dT_H_M_S_f), 0, 1, 0, 0},
    {&__pyx_kp_u_ZERO_WIDTH_SPACE, __pyx_k_ZERO_WIDTH_SPACE, sizeof(__pyx_k_ZERO_WIDTH_SPACE), 0, 1, 0, 0},
    {&__pyx_n_s_ZeroOrMore, __pyx_k_ZeroOrMore, sizeof(__pyx_k_ZeroOrMore), 0, 0, 1, 1},
    {&__pyx_n_u_ZeroOrMore, __pyx_k_ZeroOrMore, sizeof(__pyx_k_ZeroOrMore), 0, 1, 0, 1},
    {&__pyx_n_s_ZeroOrMore___init, __pyx_k_ZeroOrMore___init, sizeof(__pyx_k_ZeroOrMore___init), 0, 0, 1, 1},
    {&__pyx_n_s_ZeroOrMore___str, __pyx_k_ZeroOrMore___str, sizeof(__pyx_k_ZeroOrMore___str), 0, 0, 1, 1},
    {&__pyx_n_s_ZeroOrMore_parseImpl, __pyx_k_ZeroOrMore_parseImpl, sizeof(__pyx_k_ZeroOrMore_parseImpl), 0, 0, 1, 1},
    {&__pyx_kp_u__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 1, 0, 0},
    {&__pyx_kp_u__100, __pyx_k__100, sizeof(__pyx_k__100), 0, 1, 0, 0},
    {&__pyx_kp_u__102, __pyx_k__102, sizeof(__pyx_k__102), 0, 1, 0, 0},
    {&__pyx_kp_u__104, __pyx_k__104, sizeof(__pyx_k__104), 0, 1, 0, 0},
    {&__pyx_kp_u__105, __pyx_k__105, sizeof(__pyx_k__105), 0, 1, 0, 0},
    {&__pyx_kp_u__107, __pyx_k__107, sizeof(__pyx_k__107), 0, 1, 0, 0},
    {&__pyx_kp_u__108, __pyx_k__108, sizeof(__pyx_k__108), 0, 1, 0, 0},
    {&__pyx_kp_u__11, __pyx_k__11, sizeof(__pyx_k__11), 0, 1, 0, 0},
    {&__pyx_kp_u__110, __pyx_k__110, sizeof(__pyx_k__110), 0, 1, 0, 0},
    {&__pyx_kp_u__111, __pyx_k__111, sizeof(__pyx_k__111), 0, 1, 0, 0},
    {&__pyx_kp_u__112, __pyx_k__112, sizeof(__pyx_k__112), 0, 1, 0, 0},
    {&__pyx_kp_u__113, __pyx_k__113, sizeof(__pyx_k__113), 0, 1, 0, 0},
    {&__pyx_kp_u__114, __pyx_k__114, sizeof(__pyx_k__114), 0, 1, 0, 0},
    {&__pyx_kp_u__115, __pyx_k__115, sizeof(__pyx_k__115), 0, 1, 0, 0},
    {&__pyx_kp_u__116, __pyx_k__116, sizeof(__pyx_k__116), 0, 1, 0, 0},
    {&__pyx_kp_u__117, __pyx_k__117, sizeof(__pyx_k__117), 0, 1, 0, 0},
    {&__pyx_kp_u__118, __pyx_k__118, sizeof(__pyx_k__118), 0, 1, 0, 0},
    {&__pyx_kp_u__119, __pyx_k__119, sizeof(__pyx_k__119), 0, 1, 0, 0},
    {&__pyx_kp_u__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 1, 0, 0},
    {&__pyx_kp_u__122, __pyx_k__122, sizeof(__pyx_k__122), 0, 1, 0, 0},
    {&__pyx_kp_u__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 1, 0, 0},
    {&__pyx_kp_u__136, __pyx_k__136, sizeof(__pyx_k__136), 0, 1, 0, 0},
    {&__pyx_kp_u__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 1, 0, 0},
    {&__pyx_kp_u__144, __pyx_k__144, sizeof(__pyx_k__144), 0, 1, 0, 0},
    {&__pyx_kp_u__145, __pyx_k__145, sizeof(__pyx_k__145), 0, 1, 0, 0},
    {&__pyx_kp_u__147, __pyx_k__147, sizeof(__pyx_k__147), 0, 1, 0, 0},
    {&__pyx_kp_u__148, __pyx_k__148, sizeof(__pyx_k__148), 0, 1, 0, 0},
    {&__pyx_n_s__15, __pyx_k__15, sizeof(__pyx_k__15), 0, 0, 1, 1},
    {&__pyx_kp_u__15, __pyx_k__15, sizeof(__pyx_k__15), 0, 1, 0, 0},
    {&__pyx_kp_u__150, __pyx_k__150, sizeof(__pyx_k__150), 0, 1, 0, 0},
    {&__pyx_kp_u__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 1, 0, 0},
    {&__pyx_kp_u__166, __pyx_k__166, sizeof(__pyx_k__166), 0, 1, 0, 0},
    {&__pyx_kp_u__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 1, 0, 0},
    {&__pyx_kp_u__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 1, 0, 0},
    {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
    {&__pyx_kp_u__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 1, 0, 0},
    {&__pyx_kp_u__25, __pyx_k__25, sizeof(__pyx_k__25), 0, 1, 0, 0},
    {&__pyx_kp_u__26, __pyx_k__26, sizeof(__pyx_k__26), 0, 1, 0, 0},
    {&__pyx_kp_u__27, __pyx_k__27, sizeof(__pyx_k__27), 0, 1, 0, 0},
    {&__pyx_kp_u__28, __pyx_k__28, sizeof(__pyx_k__28), 0, 1, 0, 0},
    {&__pyx_kp_u__29, __pyx_k__29, sizeof(__pyx_k__29), 0, 1, 0, 0},
    {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
    {&__pyx_kp_u__30, __pyx_k__30, sizeof(__pyx_k__30), 0, 1, 0, 0},
    {&__pyx_kp_u__31, __pyx_k__31, sizeof(__pyx_k__31), 0, 1, 0, 0},
    {&__pyx_kp_u__339, __pyx_k__339, sizeof(__pyx_k__339), 0, 1, 0, 0},
    {&__pyx_kp_u__34, __pyx_k__34, sizeof(__pyx_k__34), 0, 1, 0, 0},
    {&__pyx_kp_u__35, __pyx_k__35, sizeof(__pyx_k__35), 0, 1, 0, 0},
    {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
    {&__pyx_kp_u__461, __pyx_k__461, sizeof(__pyx_k__461), 0, 1, 0, 0},
    {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
    {&__pyx_kp_u__511, __pyx_k__511, sizeof(__pyx_k__511), 0, 1, 0, 0},
    {&__pyx_kp_u__512, __pyx_k__512, sizeof(__pyx_k__512), 0, 1, 0, 0},
    {&__pyx_kp_u__513, __pyx_k__513, sizeof(__pyx_k__513), 0, 1, 0, 0},
    {&__pyx_kp_u__514, __pyx_k__514, sizeof(__pyx_k__514), 0, 1, 0, 0},
    {&__pyx_kp_u__515, __pyx_k__515, sizeof(__pyx_k__515), 0, 1, 0, 0},
    {&__pyx_kp_u__516, __pyx_k__516, sizeof(__pyx_k__516), 0, 1, 0, 0},
    {&__pyx_kp_u__517, __pyx_k__517, sizeof(__pyx_k__517), 0, 1, 0, 0},
    {&__pyx_kp_u__518, __pyx_k__518, sizeof(__pyx_k__518), 0, 1, 0, 0},
    {&__pyx_kp_u__519, __pyx_k__519, sizeof(__pyx_k__519), 0, 1, 0, 0},
    {&__pyx_kp_u__520, __pyx_k__520, sizeof(__pyx_k__520), 0, 1, 0, 0},
    {&__pyx_kp_u__521, __pyx_k__521, sizeof(__pyx_k__521), 0, 1, 0, 0},
    {&__pyx_kp_u__522, __pyx_k__522, sizeof(__pyx_k__522), 0, 1, 0, 0},
    {&__pyx_kp_u__523, __pyx_k__523, sizeof(__pyx_k__523), 0, 1, 0, 0},
    {&__pyx_kp_u__524, __pyx_k__524, sizeof(__pyx_k__524), 0, 1, 0, 0},
    {&__pyx_kp_u__525, __pyx_k__525, sizeof(__pyx_k__525), 0, 1, 0, 0},
    {&__pyx_kp_u__526, __pyx_k__526, sizeof(__pyx_k__526), 0, 1, 0, 0},
    {&__pyx_kp_u__527, __pyx_k__527, sizeof(__pyx_k__527), 0, 1, 0, 0},
    {&__pyx_kp_u__528, __pyx_k__528, sizeof(__pyx_k__528), 0, 1, 0, 0},
    {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
    {&__pyx_n_s__621, __pyx_k__621, sizeof(__pyx_k__621), 0, 0, 1, 1},
    {&__pyx_n_u__621, __pyx_k__621, sizeof(__pyx_k__621), 0, 1, 0, 1},
    {&__pyx_kp_u__65, __pyx_k__65, sizeof(__pyx_k__65), 0, 1, 0, 0},
    {&__pyx_kp_u__66, __pyx_k__66, sizeof(__pyx_k__66), 0, 1, 0, 0},
    {&__pyx_kp_u__67, __pyx_k__67, sizeof(__pyx_k__67), 0, 1, 0, 0},
    {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
    {&__pyx_kp_u__718, __pyx_k__718, sizeof(__pyx_k__718), 0, 1, 0, 0},
    {&__pyx_kp_u__721, __pyx_k__721, sizeof(__pyx_k__721), 0, 1, 0, 0},
    {&__pyx_kp_u__755, __pyx_k__755, sizeof(__pyx_k__755), 0, 1, 0, 0},
    {&__pyx_kp_u__768, __pyx_k__768, sizeof(__pyx_k__768), 0, 1, 0, 0},
    {&__pyx_kp_u__770, __pyx_k__770, sizeof(__pyx_k__770), 0, 1, 0, 0},
    {&__pyx_kp_u__771, __pyx_k__771, sizeof(__pyx_k__771), 0, 1, 0, 0},
    {&__pyx_kp_u__774, __pyx_k__774, sizeof(__pyx_k__774), 0, 1, 0, 0},
    {&__pyx_kp_u__776, __pyx_k__776, sizeof(__pyx_k__776), 0, 1, 0, 0},
    {&__pyx_kp_u__780, __pyx_k__780, sizeof(__pyx_k__780), 0, 1, 0, 0},
    {&__pyx_kp_u__786, __pyx_k__786, sizeof(__pyx_k__786), 0, 1, 0, 0},
    {&__pyx_kp_u__789, __pyx_k__789, sizeof(__pyx_k__789), 0, 1, 0, 0},
    {&__pyx_kp_u__79, __pyx_k__79, sizeof(__pyx_k__79), 0, 1, 0, 0},
    {&__pyx_kp_u__795, __pyx_k__795, sizeof(__pyx_k__795), 0, 1, 0, 0},
    {&__pyx_kp_u__80, __pyx_k__80, sizeof(__pyx_k__80), 0, 1, 0, 0},
    {&__pyx_n_u__856, __pyx_k__856, sizeof(__pyx_k__856), 0, 1, 0, 1},
    {&__pyx_n_u__857, __pyx_k__857, sizeof(__pyx_k__857), 0, 1, 0, 1},
    {&__pyx_n_u__858, __pyx_k__858, sizeof(__pyx_k__858), 0, 1, 0, 1},
    {&__pyx_n_u__859, __pyx_k__859, sizeof(__pyx_k__859), 0, 1, 0, 1},
    {&__pyx_kp_u__860, __pyx_k__860, sizeof(__pyx_k__860), 0, 1, 0, 0},
    {&__pyx_n_u__861, __pyx_k__861, sizeof(__pyx_k__861), 0, 1, 0, 1},
    {&__pyx_n_u__862, __pyx_k__862, sizeof(__pyx_k__862), 0, 1, 0, 1},
    {&__pyx_n_u__863, __pyx_k__863, sizeof(__pyx_k__863), 0, 1, 0, 1},
    {&__pyx_n_u__864, __pyx_k__864, sizeof(__pyx_k__864), 0, 1, 0, 1},
    {&__pyx_n_u__865, __pyx_k__865, sizeof(__pyx_k__865), 0, 1, 0, 1},
    {&__pyx_n_u__866, __pyx_k__866, sizeof(__pyx_k__866), 0, 1, 0, 1},
    {&__pyx_kp_u__867, __pyx_k__867, sizeof(__pyx_k__867), 0, 1, 0, 0},
    {&__pyx_n_s__893, __pyx_k__893, sizeof(__pyx_k__893), 0, 0, 1, 1},
    {&__pyx_kp_u__91, __pyx_k__91, sizeof(__pyx_k__91), 0, 1, 0, 0},
    {&__pyx_kp_u__94, __pyx_k__94, sizeof(__pyx_k__94), 0, 1, 0, 0},
    {&__pyx_kp_u__95, __pyx_k__95, sizeof(__pyx_k__95), 0, 1, 0, 0},
    {&__pyx_kp_u__96, __pyx_k__96, sizeof(__pyx_k__96), 0, 1, 0, 0},
    {&__pyx_kp_u__97, __pyx_k__97, sizeof(__pyx_k__97), 0, 1, 0, 0},
    {&__pyx_kp_u__98, __pyx_k__98, sizeof(__pyx_k__98), 0, 1, 0, 0},
    {&__pyx_kp_u__99, __pyx_k__99, sizeof(__pyx_k__99), 0, 1, 0, 0},
    {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
    {&__pyx_n_s_adaptive_mode, __pyx_k_adaptive_mode, sizeof(__pyx_k_adaptive_mode), 0, 0, 1, 1},
    {&__pyx_n_s_adaptive_usage, __pyx_k_adaptive_usage, sizeof(__pyx_k_adaptive_usage), 0, 0, 1, 1},
    {&__pyx_n_s_adaptive_usage_check_rate, __pyx_k_adaptive_usage_check_rate, sizeof(__pyx_k_adaptive_usage_check_rate), 0, 0, 1, 1},
    {&__pyx_n_s_add, __pyx_k_add, sizeof(__pyx_k_add), 0, 0, 1, 1},
    {&__pyx_n_s_addCondition, __pyx_k_addCondition, sizeof(__pyx_k_addCondition), 0, 0, 1, 1},
    {&__pyx_n_s_addParseAction, __pyx_k_addParseAction, sizeof(__pyx_k_addParseAction), 0, 0, 1, 1},
    {&__pyx_n_s_addoffset, __pyx_k_addoffset, sizeof(__pyx_k_addoffset), 0, 0, 1, 1},
    {&__pyx_n_s_adjacent, __pyx_k_adjacent, sizeof(__pyx_k_adjacent), 0, 0, 1, 1},
    {&__pyx_n_s_all, __pyx_k_all, sizeof(__pyx_k_all), 0, 0, 1, 1},
    {&__pyx_n_s_allResults, __pyx_k_allResults, sizeof(__pyx_k_allResults), 0, 0, 1, 1},
    {&__pyx_n_s_all_2, __pyx_k_all_2, sizeof(__pyx_k_all_2), 0, 0, 1, 1},
    {&__pyx_n_s_all_names, __pyx_k_all_names, sizeof(__pyx_k_all_names), 0, 0, 1, 1},
    {&__pyx_n_s_all_parse_elements, __pyx_k_all_parse_elements, sizeof(__pyx_k_all_parse_elements), 0, 0, 1, 1},
    {&__pyx_n_s_allow_unused_expr_order, __pyx_k_allow_unused_expr_order, sizeof(__pyx_k_allow_unused_expr_order), 0, 0, 1, 1},
    {&__pyx_n_s_alphanums, __pyx_k_alphanums, sizeof(__pyx_k_alphanums), 0, 0, 1, 1},
    {&__pyx_n_u_alphanums, __pyx_k_alphanums, sizeof(__pyx_k_alphanums), 0, 1, 0, 1},
    {&__pyx_n_s_alphas, __pyx_k_alphas, sizeof(__pyx_k_alphas), 0, 0, 1, 1},
    {&__pyx_n_u_alphas, __pyx_k_alphas, sizeof(__pyx_k_alphas), 0, 1, 0, 1},
    {&__pyx_n_s_alphas8bit, __pyx_k_alphas8bit, sizeof(__pyx_k_alphas8bit), 0, 0, 1, 1},
    {&__pyx_n_u_alphas8bit, __pyx_k_alphas8bit, sizeof(__pyx_k_alphas8bit), 0, 1, 0, 1},
    {&__pyx_kp_u_amp_gt_lt_quot_apos, __pyx_k_amp_gt_lt_quot_apos, sizeof(__pyx_k_amp_gt_lt_quot_apos), 0, 1, 0, 0},
    {&__pyx_n_s_aname, __pyx_k_aname, sizeof(__pyx_k_aname), 0, 0, 1, 1},
    {&__pyx_n_s_anchor, __pyx_k_anchor, sizeof(__pyx_k_anchor), 0, 0, 1, 1},
    {&__pyx_n_s_and, __pyx_k_and, sizeof(__pyx_k_and), 0, 0, 1, 1},
    {&__pyx_n_s_any, __pyx_k_any, sizeof(__pyx_k_any), 0, 0, 1, 1},
    {&__pyx_n_s_anyCloseTag, __pyx_k_anyCloseTag, sizeof(__pyx_k_anyCloseTag), 0, 0, 1, 1},
    {&__pyx_n_u_anyCloseTag, __pyx_k_anyCloseTag, sizeof(__pyx_k_anyCloseTag), 0, 1, 0, 1},
    {&__pyx_n_s_anyOpenTag, __pyx_k_anyOpenTag, sizeof(__pyx_k_anyOpenTag), 0, 0, 1, 1},
    {&__pyx_n_u_anyOpenTag, __pyx_k_anyOpenTag, sizeof(__pyx_k_anyOpenTag), 0, 1, 0, 1},
    {&__pyx_kp_u_any_tag, __pyx_k_any_tag, sizeof(__pyx_k_any_tag), 0, 1, 0, 0},
    {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
    {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
    {&__pyx_n_u_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 1, 0, 1},
    {&__pyx_n_s_arity, __pyx_k_arity, sizeof(__pyx_k_arity), 0, 0, 1, 1},
    {&__pyx_n_s_arrayExpr, __pyx_k_arrayExpr, sizeof(__pyx_k_arrayExpr), 0, 0, 1, 1},
    {&__pyx_n_u_arrayLen, __pyx_k_arrayLen, sizeof(__pyx_k_arrayLen), 0, 1, 0, 1},
    {&__pyx_n_s_asDict, __pyx_k_asDict, sizeof(__pyx_k_asDict), 0, 0, 1, 1},
    {&__pyx_n_s_asGroupList, __pyx_k_asGroupList, sizeof(__pyx_k_asGroupList), 0, 0, 1, 1},
    {&__pyx_n_s_asKeyword, __pyx_k_asKeyword, sizeof(__pyx_k_asKeyword), 0, 0, 1, 1},
    {&__pyx_n_s_asList, __pyx_k_asList, sizeof(__pyx_k_asList), 0, 0, 1, 1},
    {&__pyx_n_s_asMatch, __pyx_k_asMatch, sizeof(__pyx_k_asMatch), 0, 0, 1, 1},
    {&__pyx_n_s_asString, __pyx_k_asString, sizeof(__pyx_k_asString), 0, 0, 1, 1},
    {&__pyx_n_s_asStringList, __pyx_k_asStringList, sizeof(__pyx_k_asStringList), 0, 0, 1, 1},
    {&__pyx_n_s_asXML, __pyx_k_asXML, sizeof(__pyx_k_asXML), 0, 0, 1, 1},
    {&__pyx_kp_u_as_column_list_and_dotted_table, __pyx_k_as_column_list_and_dotted_table, sizeof(__pyx_k_as_column_list_and_dotted_table), 0, 1, 0, 0},
    {&__pyx_n_s_ascii_lowercase, __pyx_k_ascii_lowercase, sizeof(__pyx_k_ascii_lowercase), 0, 0, 1, 1},
    {&__pyx_n_s_ascii_uppercase, __pyx_k_ascii_uppercase, sizeof(__pyx_k_ascii_uppercase), 0, 0, 1, 1},
    {&__pyx_n_s_assertEqual, __pyx_k_assertEqual, sizeof(__pyx_k_assertEqual), 0, 0, 1, 1},
    {&__pyx_n_s_assertParseAndCheckDict, __pyx_k_assertParseAndCheckDict, sizeof(__pyx_k_assertParseAndCheckDict), 0, 0, 1, 1},
    {&__pyx_n_s_assertParseAndCheckList, __pyx_k_assertParseAndCheckList, sizeof(__pyx_k_assertParseAndCheckList), 0, 0, 1, 1},
    {&__pyx_n_s_assertParseResultsEquals, __pyx_k_assertParseResultsEquals, sizeof(__pyx_k_assertParseResultsEquals), 0, 0, 1, 1},
    {&__pyx_n_s_assertRaises, __pyx_k_assertRaises, sizeof(__pyx_k_assertRaises), 0, 0, 1, 1},
    {&__pyx_n_s_assertRaisesParseException, __pyx_k_assertRaisesParseException, sizeof(__pyx_k_assertRaisesParseException), 0, 0, 1, 1},
    {&__pyx_n_s_assertRunTestResults, __pyx_k_assertRunTestResults, sizeof(__pyx_k_assertRunTestResults), 0, 0, 1, 1},
    {&__pyx_n_s_assertTrue, __pyx_k_assertTrue, sizeof(__pyx_k_assertTrue), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_kp_u_at_char, __pyx_k_at_char, sizeof(__pyx_k_at_char), 0, 1, 0, 0},
    {&__pyx_kp_u_at_loc, __pyx_k_at_loc, sizeof(__pyx_k_at_loc), 0, 1, 0, 0},
    {&__pyx_n_s_attrDict, __pyx_k_attrDict, sizeof(__pyx_k_attrDict), 0, 0, 1, 1},
    {&__pyx_n_s_attrName, __pyx_k_attrName, sizeof(__pyx_k_attrName), 0, 0, 1, 1},
    {&__pyx_n_s_attrValue, __pyx_k_attrValue, sizeof(__pyx_k_attrValue), 0, 0, 1, 1},
    {&__pyx_kp_u_attribute, __pyx_k_attribute, sizeof(__pyx_k_attribute), 0, 1, 0, 0},
    {&__pyx_n_s_attrname, __pyx_k_attrname, sizeof(__pyx_k_attrname), 0, 0, 1, 1},
    {&__pyx_n_s_attrs, __pyx_k_attrs, sizeof(__pyx_k_attrs), 0, 0, 1, 1},
    {&__pyx_n_s_author, __pyx_k_author, sizeof(__pyx_k_author), 0, 0, 1, 1},
    {&__pyx_n_u_author, __pyx_k_author, sizeof(__pyx_k_author), 0, 1, 0, 1},
    {&__pyx_kp_u_b, __pyx_k_b, sizeof(__pyx_k_b), 0, 1, 0, 0},
    {&__pyx_n_s_b_2, __pyx_k_b_2, sizeof(__pyx_k_b_2), 0, 0, 1, 1},
    {&__pyx_kp_u_b_s_b, __pyx_k_b_s_b, sizeof(__pyx_k_b_s_b), 0, 1, 0, 0},
    {&__pyx_n_s_backup_stack, __pyx_k_backup_stack, sizeof(__pyx_k_backup_stack), 0, 0, 1, 1},
    {&__pyx_n_s_baseExpr, __pyx_k_baseExpr, sizeof(__pyx_k_baseExpr), 0, 0, 1, 1},
    {&__pyx_kp_s_base_exception_class_for_all_par, __pyx_k_base_exception_class_for_all_par, sizeof(__pyx_k_base_exception_class_for_all_par), 0, 0, 1, 0},
    {&__pyx_n_s_basestring, __pyx_k_basestring, sizeof(__pyx_k_basestring), 0, 0, 1, 1},
    {&__pyx_n_s_best_expr, __pyx_k_best_expr, sizeof(__pyx_k_best_expr), 0, 0, 1, 1},
    {&__pyx_n_s_blockStatementExpr, __pyx_k_blockStatementExpr, sizeof(__pyx_k_blockStatementExpr), 0, 0, 1, 1},
    {&__pyx_n_s_body, __pyx_k_body, sizeof(__pyx_k_body), 0, 0, 1, 1},
    {&__pyx_n_u_body, __pyx_k_body, sizeof(__pyx_k_body), 0, 1, 0, 1},
    {&__pyx_n_s_bodyChars, __pyx_k_bodyChars, sizeof(__pyx_k_bodyChars), 0, 0, 1, 1},
    {&__pyx_n_s_bodyCharsOrig, __pyx_k_bodyCharsOrig, sizeof(__pyx_k_bodyCharsOrig), 0, 0, 1, 1},
    {&__pyx_n_s_bodychars, __pyx_k_bodychars, sizeof(__pyx_k_bodychars), 0, 0, 1, 1},
    {&__pyx_n_s_bool, __pyx_k_bool, sizeof(__pyx_k_bool), 0, 0, 1, 1},
    {&__pyx_n_s_breakFlag, __pyx_k_breakFlag, sizeof(__pyx_k_breakFlag), 0, 0, 1, 1},
    {&__pyx_n_s_breaker, __pyx_k_breaker, sizeof(__pyx_k_breaker), 0, 0, 1, 1},
    {&__pyx_n_s_bslash, __pyx_k_bslash, sizeof(__pyx_k_bslash), 0, 0, 1, 1},
    {&__pyx_n_s_builtin, __pyx_k_builtin, sizeof(__pyx_k_builtin), 0, 0, 1, 1},
    {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
    {&__pyx_n_s_cPyparsing, __pyx_k_cPyparsing, sizeof(__pyx_k_cPyparsing), 0, 0, 1, 1},
    {&__pyx_kp_s_cPyparsing_pyx, __pyx_k_cPyparsing_pyx, sizeof(__pyx_k_cPyparsing_pyx), 0, 0, 1, 0},
    {&__pyx_kp_u_cPyparsing_pyx, __pyx_k_cPyparsing_pyx, sizeof(__pyx_k_cPyparsing_pyx), 0, 1, 0, 0},
    {&__pyx_n_s_cStyleComment, __pyx_k_cStyleComment, sizeof(__pyx_k_cStyleComment), 0, 0, 1, 1},
    {&__pyx_n_u_cStyleComment, __pyx_k_cStyleComment, sizeof(__pyx_k_cStyleComment), 0, 1, 0, 1},
    {&__pyx_n_s_cache, __pyx_k_cache, sizeof(__pyx_k_cache), 0, 0, 1, 1},
    {&__pyx_n_u_cache, __pyx_k_cache, sizeof(__pyx_k_cache), 0, 1, 0, 1},
    {&__pyx_n_s_cache_furthest_loc, __pyx_k_cache_furthest_loc, sizeof(__pyx_k_cache_furthest_loc), 0, 0, 1, 1},
    {&__pyx_n_s_cache_item, __pyx_k_cache_item, sizeof(__pyx_k_cache_item), 0, 0, 1, 1},
    {&__pyx_n_s_cache_result, __pyx_k_cache_result, sizeof(__pyx_k_cache_result), 0, 0, 1, 1},
    {&__pyx_n_s_cache_size_limit, __pyx_k_cache_size_limit, sizeof(__pyx_k_cache_size_limit), 0, 0, 1, 1},
    {&__pyx_n_s_cache_successes, __pyx_k_cache_successes, sizeof(__pyx_k_cache_successes), 0, 0, 1, 1},
    {&__pyx_n_s_cache_usefullness_obj, __pyx_k_cache_usefullness_obj, sizeof(__pyx_k_cache_usefullness_obj), 0, 0, 1, 1},
    {&__pyx_n_s_call, __pyx_k_call, sizeof(__pyx_k_call), 0, 0, 1, 1},
    {&__pyx_n_s_callDuringTry, __pyx_k_callDuringTry, sizeof(__pyx_k_callDuringTry), 0, 0, 1, 1},
    {&__pyx_n_u_callDuringTry, __pyx_k_callDuringTry, sizeof(__pyx_k_callDuringTry), 0, 1, 0, 1},
    {&__pyx_n_s_callPreParse, __pyx_k_callPreParse, sizeof(__pyx_k_callPreParse), 0, 0, 1, 1},
    {&__pyx_n_s_callPreparse, __pyx_k_callPreparse, sizeof(__pyx_k_callPreparse), 0, 0, 1, 1},
    {&__pyx_n_s_callable, __pyx_k_callable, sizeof(__pyx_k_callable), 0, 0, 1, 1},
    {&__pyx_n_s_called, __pyx_k_called, sizeof(__pyx_k_called), 0, 0, 1, 1},
    {&__pyx_n_s_callers, __pyx_k_callers, sizeof(__pyx_k_callers), 0, 0, 1, 1},
    {&__pyx_n_s_canParseNext, __pyx_k_canParseNext, sizeof(__pyx_k_canParseNext), 0, 0, 1, 1},
    {&__pyx_kp_u_cannot_construct_And_with_sequen, __pyx_k_cannot_construct_And_with_sequen, sizeof(__pyx_k_cannot_construct_And_with_sequen), 0, 1, 0, 0},
    {&__pyx_kp_u_cannot_multiply_ParserElement_an, __pyx_k_cannot_multiply_ParserElement_an, sizeof(__pyx_k_cannot_multiply_ParserElement_an), 0, 1, 0, 0},
    {&__pyx_kp_u_cannot_multiply_ParserElement_an_2, __pyx_k_cannot_multiply_ParserElement_an_2, sizeof(__pyx_k_cannot_multiply_ParserElement_an_2), 0, 1, 0, 0},
    {&__pyx_kp_u_cannot_multiply_ParserElement_by, __pyx_k_cannot_multiply_ParserElement_by, sizeof(__pyx_k_cannot_multiply_ParserElement_by), 0, 1, 0, 0},
    {&__pyx_kp_u_cannot_multiply_ParserElement_by_2, __pyx_k_cannot_multiply_ParserElement_by_2, sizeof(__pyx_k_cannot_multiply_ParserElement_by_2), 0, 1, 0, 0},
    {&__pyx_kp_u_cannot_specify_a_minimum_length, __pyx_k_cannot_specify_a_minimum_length, sizeof(__pyx_k_cannot_specify_a_minimum_length), 0, 1, 0, 0},
    {&__pyx_kp_u_cannot_specify_a_minimum_length_2, __pyx_k_cannot_specify_a_minimum_length_2, sizeof(__pyx_k_cannot_specify_a_minimum_length_2), 0, 1, 0, 0},
    {&__pyx_kp_u_cannot_use_sub_with_Regex_asGrou, __pyx_k_cannot_use_sub_with_Regex_asGrou, sizeof(__pyx_k_cannot_use_sub_with_Regex_asGrou), 0, 1, 0, 0},
    {&__pyx_kp_u_cannot_use_sub_with_a_callable_w, __pyx_k_cannot_use_sub_with_a_callable_w, sizeof(__pyx_k_cannot_use_sub_with_a_callable_w), 0, 1, 0, 0},
    {&__pyx_n_s_caseless, __pyx_k_caseless, sizeof(__pyx_k_caseless), 0, 0, 1, 1},
    {&__pyx_n_s_caselessmatch, __pyx_k_caselessmatch, sizeof(__pyx_k_caselessmatch), 0, 0, 1, 1},
    {&__pyx_n_s_cause, __pyx_k_cause, sizeof(__pyx_k_cause), 0, 0, 1, 1},
    {&__pyx_n_s_cc, __pyx_k_cc, sizeof(__pyx_k_cc), 0, 0, 1, 1},
    {&__pyx_n_s_charRange, __pyx_k_charRange, sizeof(__pyx_k_charRange), 0, 0, 1, 1},
    {&__pyx_n_s_chars, __pyx_k_chars, sizeof(__pyx_k_chars), 0, 0, 1, 1},
    {&__pyx_n_s_charsAsStr, __pyx_k_charsAsStr, sizeof(__pyx_k_charsAsStr), 0, 0, 1, 1},
    {&__pyx_n_s_charset, __pyx_k_charset, sizeof(__pyx_k_charset), 0, 0, 1, 1},
    {&__pyx_n_s_checkPeerIndent, __pyx_k_checkPeerIndent, sizeof(__pyx_k_checkPeerIndent), 0, 0, 1, 1},
    {&__pyx_n_s_checkRecursion, __pyx_k_checkRecursion, sizeof(__pyx_k_checkRecursion), 0, 0, 1, 1},
    {&__pyx_n_s_checkSubIndent, __pyx_k_checkSubIndent, sizeof(__pyx_k_checkSubIndent), 0, 0, 1, 1},
    {&__pyx_n_s_checkUnindent, __pyx_k_checkUnindent, sizeof(__pyx_k_checkUnindent), 0, 0, 1, 1},
    {&__pyx_n_s_check_ender, __pyx_k_check_ender, sizeof(__pyx_k_check_ender), 0, 0, 1, 1},
    {&__pyx_n_s_chr, __pyx_k_chr, sizeof(__pyx_k_chr), 0, 0, 1, 1},
    {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
    {&__pyx_n_u_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 1, 0, 1},
    {&__pyx_n_u_class_2, __pyx_k_class_2, sizeof(__pyx_k_class_2), 0, 1, 0, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_classattr, __pyx_k_classattr, sizeof(__pyx_k_classattr), 0, 0, 1, 1},
    {&__pyx_n_s_classname, __pyx_k_classname, sizeof(__pyx_k_classname), 0, 0, 1, 1},
    {&__pyx_n_s_clear, __pyx_k_clear, sizeof(__pyx_k_clear), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
    {&__pyx_n_s_closeTag, __pyx_k_closeTag, sizeof(__pyx_k_closeTag), 0, 0, 1, 1},
    {&__pyx_n_s_closer, __pyx_k_closer, sizeof(__pyx_k_closer), 0, 0, 1, 1},
    {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
    {&__pyx_n_s_co_name, __pyx_k_co_name, sizeof(__pyx_k_co_name), 0, 0, 1, 1},
    {&__pyx_n_s_code, __pyx_k_code, sizeof(__pyx_k_code), 0, 0, 1, 1},
    {&__pyx_n_s_col, __pyx_k_col, sizeof(__pyx_k_col), 0, 0, 1, 1},
    {&__pyx_n_u_col, __pyx_k_col, sizeof(__pyx_k_col), 0, 1, 0, 1},
    {&__pyx_kp_u_col_2, __pyx_k_col_2, sizeof(__pyx_k_col_2), 0, 1, 0, 0},
    {&__pyx_n_s_collectParseElements, __pyx_k_collectParseElements, sizeof(__pyx_k_collectParseElements), 0, 0, 1, 1},
    {&__pyx_n_s_collect_all_And_tokens, __pyx_k_collect_all_And_tokens, sizeof(__pyx_k_collect_all_And_tokens), 0, 0, 1, 1},
    {&__pyx_n_u_collect_all_And_tokens, __pyx_k_collect_all_And_tokens, sizeof(__pyx_k_collect_all_And_tokens), 0, 1, 0, 1},
    {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
    {&__pyx_n_s_collections_abc, __pyx_k_collections_abc, sizeof(__pyx_k_collections_abc), 0, 0, 1, 1},
    {&__pyx_n_s_colno, __pyx_k_colno, sizeof(__pyx_k_colno), 0, 0, 1, 1},
    {&__pyx_n_s_column, __pyx_k_column, sizeof(__pyx_k_column), 0, 0, 1, 1},
    {&__pyx_n_u_column, __pyx_k_column, sizeof(__pyx_k_column), 0, 1, 0, 1},
    {&__pyx_n_s_columnName, __pyx_k_columnName, sizeof(__pyx_k_columnName), 0, 0, 1, 1},
    {&__pyx_n_s_columnNameList, __pyx_k_columnNameList, sizeof(__pyx_k_columnNameList), 0, 0, 1, 1},
    {&__pyx_n_s_columnSpec, __pyx_k_columnSpec, sizeof(__pyx_k_columnSpec), 0, 0, 1, 1},
    {&__pyx_n_u_columns, __pyx_k_columns, sizeof(__pyx_k_columns), 0, 1, 0, 1},
    {&__pyx_n_s_combine, __pyx_k_combine, sizeof(__pyx_k_combine), 0, 0, 1, 1},
    {&__pyx_n_u_commaItem, __pyx_k_commaItem, sizeof(__pyx_k_commaItem), 0, 1, 0, 1},
    {&__pyx_n_s_commaSeparatedList, __pyx_k_commaSeparatedList, sizeof(__pyx_k_commaSeparatedList), 0, 0, 1, 1},
    {&__pyx_n_u_commaSeparatedList, __pyx_k_commaSeparatedList, sizeof(__pyx_k_commaSeparatedList), 0, 1, 0, 1},
    {&__pyx_kp_u_comma_separated_list, __pyx_k_comma_separated_list, sizeof(__pyx_k_comma_separated_list), 0, 1, 0, 0},
    {&__pyx_n_s_comma_separated_list_2, __pyx_k_comma_separated_list_2, sizeof(__pyx_k_comma_separated_list_2), 0, 0, 1, 1},
    {&__pyx_n_u_command, __pyx_k_command, sizeof(__pyx_k_command), 0, 1, 0, 1},
    {&__pyx_n_s_commasepitem, __pyx_k_commasepitem, sizeof(__pyx_k_commasepitem), 0, 0, 1, 1},
    {&__pyx_n_s_comment, __pyx_k_comment, sizeof(__pyx_k_comment), 0, 0, 1, 1},
    {&__pyx_kp_u_comment_2, __pyx_k_comment_2, sizeof(__pyx_k_comment_2), 0, 1, 0, 0},
    {&__pyx_n_s_comments, __pyx_k_comments, sizeof(__pyx_k_comments), 0, 0, 1, 1},
    {&__pyx_n_s_commonHTMLEntity, __pyx_k_commonHTMLEntity, sizeof(__pyx_k_commonHTMLEntity), 0, 0, 1, 1},
    {&__pyx_n_u_commonHTMLEntity, __pyx_k_commonHTMLEntity, sizeof(__pyx_k_commonHTMLEntity), 0, 1, 0, 1},
    {&__pyx_kp_u_common_HTML_entity, __pyx_k_common_HTML_entity, sizeof(__pyx_k_common_HTML_entity), 0, 1, 0, 0},
    {&__pyx_n_s_common_prefix_len, __pyx_k_common_prefix_len, sizeof(__pyx_k_common_prefix_len), 0, 0, 1, 1},
    {&__pyx_n_s_common_suffix_len, __pyx_k_common_suffix_len, sizeof(__pyx_k_common_suffix_len), 0, 0, 1, 1},
    {&__pyx_n_s_commonprefix, __pyx_k_commonprefix, sizeof(__pyx_k_commonprefix), 0, 0, 1, 1},
    {&__pyx_n_s_compat, __pyx_k_compat, sizeof(__pyx_k_compat), 0, 0, 1, 1},
    {&__pyx_n_u_compat, __pyx_k_compat, sizeof(__pyx_k_compat), 0, 1, 0, 1},
    {&__pyx_n_s_compile, __pyx_k_compile, sizeof(__pyx_k_compile), 0, 0, 1, 1},
    {&__pyx_n_s_conditionAsParseAction, __pyx_k_conditionAsParseAction, sizeof(__pyx_k_conditionAsParseAction), 0, 0, 1, 1},
    {&__pyx_n_u_conditionAsParseAction, __pyx_k_conditionAsParseAction, sizeof(__pyx_k_conditionAsParseAction), 0, 1, 0, 1},
    {&__pyx_n_s_conditionAsParseAction_locals_pa, __pyx_k_conditionAsParseAction_locals_pa, sizeof(__pyx_k_conditionAsParseAction_locals_pa), 0, 0, 1, 1},
    {&__pyx_n_s_contains, __pyx_k_contains, sizeof(__pyx_k_contains), 0, 0, 1, 1},
    {&__pyx_n_s_content, __pyx_k_content, sizeof(__pyx_k_content), 0, 0, 1, 1},
    {&__pyx_n_s_context, __pyx_k_context, sizeof(__pyx_k_context), 0, 0, 1, 1},
    {&__pyx_n_s_contextlib, __pyx_k_contextlib, sizeof(__pyx_k_contextlib), 0, 0, 1, 1},
    {&__pyx_n_s_contextmanager, __pyx_k_contextmanager, sizeof(__pyx_k_contextmanager), 0, 0, 1, 1},
    {&__pyx_n_s_convertToDate, __pyx_k_convertToDate, sizeof(__pyx_k_convertToDate), 0, 0, 1, 1},
    {&__pyx_n_s_convertToDatetime, __pyx_k_convertToDatetime, sizeof(__pyx_k_convertToDatetime), 0, 0, 1, 1},
    {&__pyx_n_s_convertToFloat, __pyx_k_convertToFloat, sizeof(__pyx_k_convertToFloat), 0, 0, 1, 1},
    {&__pyx_n_s_convertToInteger, __pyx_k_convertToInteger, sizeof(__pyx_k_convertToInteger), 0, 0, 1, 1},
    {&__pyx_n_s_convertWhitespaceEscapes, __pyx_k_convertWhitespaceEscapes, sizeof(__pyx_k_convertWhitespaceEscapes), 0, 0, 1, 1},
    {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
    {&__pyx_n_s_copyDefaultWhiteChars, __pyx_k_copyDefaultWhiteChars, sizeof(__pyx_k_copyDefaultWhiteChars), 0, 0, 1, 1},
    {&__pyx_n_s_copyTokenToRepeater, __pyx_k_copyTokenToRepeater, sizeof(__pyx_k_copyTokenToRepeater), 0, 0, 1, 1},
    {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
    {&__pyx_n_s_countFieldParseAction, __pyx_k_countFieldParseAction, sizeof(__pyx_k_countFieldParseAction), 0, 0, 1, 1},
    {&__pyx_n_s_countedArray, __pyx_k_countedArray, sizeof(__pyx_k_countedArray), 0, 0, 1, 1},
    {&__pyx_n_u_countedArray, __pyx_k_countedArray, sizeof(__pyx_k_countedArray), 0, 1, 0, 1},
    {&__pyx_n_s_countedArray_locals_countFieldPa, __pyx_k_countedArray_locals_countFieldPa, sizeof(__pyx_k_countedArray_locals_countFieldPa), 0, 0, 1, 1},
    {&__pyx_n_s_countedArray_locals_lambda, __pyx_k_countedArray_locals_lambda, sizeof(__pyx_k_countedArray_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_cppStyleComment, __pyx_k_cppStyleComment, sizeof(__pyx_k_cppStyleComment), 0, 0, 1, 1},
    {&__pyx_n_u_cppStyleComment, __pyx_k_cppStyleComment, sizeof(__pyx_k_cppStyleComment), 0, 1, 0, 1},
    {&__pyx_n_s_cpy, __pyx_k_cpy, sizeof(__pyx_k_cpy), 0, 0, 1, 1},
    {&__pyx_n_s_cur, __pyx_k_cur, sizeof(__pyx_k_cur), 0, 0, 1, 1},
    {&__pyx_n_s_curCol, __pyx_k_curCol, sizeof(__pyx_k_curCol), 0, 0, 1, 1},
    {&__pyx_n_s_cvt_fn, __pyx_k_cvt_fn, sizeof(__pyx_k_cvt_fn), 0, 0, 1, 1},
    {&__pyx_n_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 1},
    {&__pyx_n_u_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 1, 0, 1},
    {&__pyx_kp_u_d_2, __pyx_k_d_2, sizeof(__pyx_k_d_2), 0, 1, 0, 0},
    {&__pyx_kp_u_d_d_d, __pyx_k_d_d_d, sizeof(__pyx_k_d_d_d), 0, 1, 0, 0},
    {&__pyx_kp_u_d_d_eE_d, __pyx_k_d_d_eE_d, sizeof(__pyx_k_d_d_eE_d), 0, 1, 0, 0},
    {&__pyx_kp_u_d_eE_d_d_d_d_eE_d, __pyx_k_d_eE_d_d_d_d_eE_d, sizeof(__pyx_k_d_eE_d_d_d_d_eE_d), 0, 1, 0, 0},
    {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
    {&__pyx_n_s_date, __pyx_k_date, sizeof(__pyx_k_date), 0, 0, 1, 1},
    {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
    {&__pyx_n_s_dblQuotedString, __pyx_k_dblQuotedString, sizeof(__pyx_k_dblQuotedString), 0, 0, 1, 1},
    {&__pyx_n_u_dblQuotedString, __pyx_k_dblQuotedString, sizeof(__pyx_k_dblQuotedString), 0, 1, 0, 1},
    {&__pyx_n_s_dblSlashComment, __pyx_k_dblSlashComment, sizeof(__pyx_k_dblSlashComment), 0, 0, 1, 1},
    {&__pyx_n_u_dblSlashComment, __pyx_k_dblSlashComment, sizeof(__pyx_k_dblSlashComment), 0, 1, 0, 1},
    {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
    {&__pyx_n_s_debugActions, __pyx_k_debugActions, sizeof(__pyx_k_debugActions), 0, 0, 1, 1},
    {&__pyx_n_s_debugging, __pyx_k_debugging, sizeof(__pyx_k_debugging), 0, 0, 1, 1},
    {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
    {&__pyx_n_s_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 0, 1, 1},
    {&__pyx_n_u_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 1, 0, 1},
    {&__pyx_n_s_defaultExceptionDebugAction, __pyx_k_defaultExceptionDebugAction, sizeof(__pyx_k_defaultExceptionDebugAction), 0, 0, 1, 1},
    {&__pyx_n_s_defaultStartDebugAction, __pyx_k_defaultStartDebugAction, sizeof(__pyx_k_defaultStartDebugAction), 0, 0, 1, 1},
    {&__pyx_n_s_defaultSuccessDebugAction, __pyx_k_defaultSuccessDebugAction, sizeof(__pyx_k_defaultSuccessDebugAction), 0, 0, 1, 1},
    {&__pyx_n_s_defaultValue, __pyx_k_defaultValue, sizeof(__pyx_k_defaultValue), 0, 0, 1, 1},
    {&__pyx_n_u_default_keyword_chars, __pyx_k_default_keyword_chars, sizeof(__pyx_k_default_keyword_chars), 0, 1, 0, 1},
    {&__pyx_n_u_default_whitespace, __pyx_k_default_whitespace, sizeof(__pyx_k_default_whitespace), 0, 1, 0, 1},
    {&__pyx_n_s_defaultdict, __pyx_k_defaultdict, sizeof(__pyx_k_defaultdict), 0, 0, 1, 1},
    {&__pyx_n_s_defaultvalue, __pyx_k_defaultvalue, sizeof(__pyx_k_defaultvalue), 0, 0, 1, 1},
    {&__pyx_n_s_delim, __pyx_k_delim, sizeof(__pyx_k_delim), 0, 0, 1, 1},
    {&__pyx_n_s_delimitedList, __pyx_k_delimitedList, sizeof(__pyx_k_delimitedList), 0, 0, 1, 1},
    {&__pyx_n_u_delimitedList, __pyx_k_delimitedList, sizeof(__pyx_k_delimitedList), 0, 1, 0, 1},
    {&__pyx_n_s_delitem, __pyx_k_delitem, sizeof(__pyx_k_delitem), 0, 0, 1, 1},
    {&__pyx_n_s_depth, __pyx_k_depth, sizeof(__pyx_k_depth), 0, 0, 1, 1},
    {&__pyx_n_s_depth_2, __pyx_k_depth_2, sizeof(__pyx_k_depth_2), 0, 0, 1, 1},
    {&__pyx_n_s_deque, __pyx_k_deque, sizeof(__pyx_k_deque), 0, 0, 1, 1},
    {&__pyx_n_s_diag, __pyx_k_diag, sizeof(__pyx_k_diag), 0, 0, 1, 1},
    {&__pyx_n_u_diag, __pyx_k_diag, sizeof(__pyx_k_diag), 0, 1, 0, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_n_s_dictOf, __pyx_k_dictOf, sizeof(__pyx_k_dictOf), 0, 0, 1, 1},
    {&__pyx_n_u_dictOf, __pyx_k_dictOf, sizeof(__pyx_k_dictOf), 0, 1, 0, 1},
    {&__pyx_n_s_dictvalue, __pyx_k_dictvalue, sizeof(__pyx_k_dictvalue), 0, 0, 1, 1},
    {&__pyx_n_s_dir, __pyx_k_dir, sizeof(__pyx_k_dir), 0, 0, 1, 1},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_n_s_dlName, __pyx_k_dlName, sizeof(__pyx_k_dlName), 0, 0, 1, 1},
    {&__pyx_n_s_doActions, __pyx_k_doActions, sizeof(__pyx_k_doActions), 0, 0, 1, 1},
    {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
    {&__pyx_n_s_doctag, __pyx_k_doctag, sizeof(__pyx_k_doctag), 0, 0, 1, 1},
    {&__pyx_n_s_downcaseTokens, __pyx_k_downcaseTokens, sizeof(__pyx_k_downcaseTokens), 0, 0, 1, 1},
    {&__pyx_n_u_downcaseTokens, __pyx_k_downcaseTokens, sizeof(__pyx_k_downcaseTokens), 0, 1, 0, 1},
    {&__pyx_n_s_dummy, __pyx_k_dummy, sizeof(__pyx_k_dummy), 0, 0, 1, 1},
    {&__pyx_n_s_dump, __pyx_k_dump, sizeof(__pyx_k_dump), 0, 0, 1, 1},
    {&__pyx_n_s_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
    {&__pyx_n_s_e2, __pyx_k_e2, sizeof(__pyx_k_e2), 0, 0, 1, 1},
    {&__pyx_n_s_elem, __pyx_k_elem, sizeof(__pyx_k_elem), 0, 0, 1, 1},
    {&__pyx_n_s_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 0, 1, 1},
    {&__pyx_n_u_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 1, 0, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_enableIncremental, __pyx_k_enableIncremental, sizeof(__pyx_k_enableIncremental), 0, 0, 1, 1},
    {&__pyx_n_s_enablePackrat, __pyx_k_enablePackrat, sizeof(__pyx_k_enablePackrat), 0, 0, 1, 1},
    {&__pyx_n_u_enable_2, __pyx_k_enable_2, sizeof(__pyx_k_enable_2), 0, 1, 0, 1},
    {&__pyx_n_s_enable_all_warnings, __pyx_k_enable_all_warnings, sizeof(__pyx_k_enable_all_warnings), 0, 0, 1, 1},
    {&__pyx_n_s_enable_all_warnings_2, __pyx_k_enable_all_warnings_2, sizeof(__pyx_k_enable_all_warnings_2), 0, 0, 1, 1},
    {&__pyx_n_s_enable_debug_on_named_expression, __pyx_k_enable_debug_on_named_expression, sizeof(__pyx_k_enable_debug_on_named_expression), 0, 0, 1, 1},
    {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
    {&__pyx_n_u_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 1, 0, 1},
    {&__pyx_n_s_endQuoteChar, __pyx_k_endQuoteChar, sizeof(__pyx_k_endQuoteChar), 0, 0, 1, 1},
    {&__pyx_n_s_endQuoteCharLen, __pyx_k_endQuoteCharLen, sizeof(__pyx_k_endQuoteCharLen), 0, 0, 1, 1},
    {&__pyx_kp_u_endQuoteChar_cannot_be_the_empty, __pyx_k_endQuoteChar_cannot_be_the_empty, sizeof(__pyx_k_endQuoteChar_cannot_be_the_empty), 0, 1, 0, 0},
    {&__pyx_n_s_ender, __pyx_k_ender, sizeof(__pyx_k_ender), 0, 0, 1, 1},
    {&__pyx_kp_u_ending_with, __pyx_k_ending_with, sizeof(__pyx_k_ending_with), 0, 1, 0, 0},
    {&__pyx_n_s_endloc, __pyx_k_endloc, sizeof(__pyx_k_endloc), 0, 0, 1, 1},
    {&__pyx_n_s_endlocMarker, __pyx_k_endlocMarker, sizeof(__pyx_k_endlocMarker), 0, 0, 1, 1},
    {&__pyx_n_s_endswith, __pyx_k_endswith, sizeof(__pyx_k_endswith), 0, 0, 1, 1},
    {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
    {&__pyx_kp_u_entering, __pyx_k_entering, sizeof(__pyx_k_entering), 0, 1, 0, 0},
    {&__pyx_n_s_entity, __pyx_k_entity, sizeof(__pyx_k_entity), 0, 0, 1, 1},
    {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
    {&__pyx_n_s_eq, __pyx_k_eq, sizeof(__pyx_k_eq), 0, 0, 1, 1},
    {&__pyx_n_s_err, __pyx_k_err, sizeof(__pyx_k_err), 0, 0, 1, 1},
    {&__pyx_n_s_errmsg, __pyx_k_errmsg, sizeof(__pyx_k_errmsg), 0, 0, 1, 1},
    {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
    {&__pyx_n_s_errorStop, __pyx_k_errorStop, sizeof(__pyx_k_errorStop), 0, 0, 1, 1},
    {&__pyx_n_s_escChar, __pyx_k_escChar, sizeof(__pyx_k_escChar), 0, 0, 1, 1},
    {&__pyx_n_s_escCharReplacePattern, __pyx_k_escCharReplacePattern, sizeof(__pyx_k_escCharReplacePattern), 0, 0, 1, 1},
    {&__pyx_n_s_escQuote, __pyx_k_escQuote, sizeof(__pyx_k_escQuote), 0, 0, 1, 1},
    {&__pyx_n_s_escape, __pyx_k_escape, sizeof(__pyx_k_escape), 0, 0, 1, 1},
    {&__pyx_n_s_escapeRegexRangeChars, __pyx_k_escapeRegexRangeChars, sizeof(__pyx_k_escapeRegexRangeChars), 0, 0, 1, 1},
    {&__pyx_n_s_escapedHexChar, __pyx_k_escapedHexChar, sizeof(__pyx_k_escapedHexChar), 0, 0, 1, 1},
    {&__pyx_n_s_escapedOctChar, __pyx_k_escapedOctChar, sizeof(__pyx_k_escapedOctChar), 0, 0, 1, 1},
    {&__pyx_n_s_escapedPunc, __pyx_k_escapedPunc, sizeof(__pyx_k_escapedPunc), 0, 0, 1, 1},
    {&__pyx_n_s_exact, __pyx_k_exact, sizeof(__pyx_k_exact), 0, 0, 1, 1},
    {&__pyx_n_s_exc, __pyx_k_exc, sizeof(__pyx_k_exc), 0, 0, 1, 1},
    {&__pyx_n_s_exc_info, __pyx_k_exc_info, sizeof(__pyx_k_exc_info), 0, 0, 1, 1},
    {&__pyx_n_s_exc_type, __pyx_k_exc_type, sizeof(__pyx_k_exc_type), 0, 0, 1, 1},
    {&__pyx_kp_u_exception, __pyx_k_exception, sizeof(__pyx_k_exception), 0, 1, 0, 0},
    {&__pyx_n_s_exceptionAction, __pyx_k_exceptionAction, sizeof(__pyx_k_exceptionAction), 0, 0, 1, 1},
    {&__pyx_kp_u_exception_raised_in_parse_action, __pyx_k_exception_raised_in_parse_action, sizeof(__pyx_k_exception_raised_in_parse_action), 0, 1, 0, 0},
    {&__pyx_kp_s_exception_thrown_by_class_Parser, __pyx_k_exception_thrown_by_class_Parser, sizeof(__pyx_k_exception_thrown_by_class_Parser), 0, 0, 1, 0},
    {&__pyx_n_s_excludeChars, __pyx_k_excludeChars, sizeof(__pyx_k_excludeChars), 0, 0, 1, 1},
    {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
    {&__pyx_n_s_expand, __pyx_k_expand, sizeof(__pyx_k_expand), 0, 0, 1, 1},
    {&__pyx_n_s_expanded, __pyx_k_expanded, sizeof(__pyx_k_expanded), 0, 0, 1, 1},
    {&__pyx_n_s_expandtabs, __pyx_k_expandtabs, sizeof(__pyx_k_expandtabs), 0, 0, 1, 1},
    {&__pyx_n_s_expected, __pyx_k_expected, sizeof(__pyx_k_expected), 0, 0, 1, 1},
    {&__pyx_n_s_expected_dict, __pyx_k_expected_dict, sizeof(__pyx_k_expected_dict), 0, 0, 1, 1},
    {&__pyx_n_s_expected_exception, __pyx_k_expected_exception, sizeof(__pyx_k_expected_exception), 0, 0, 1, 1},
    {&__pyx_n_s_expected_list, __pyx_k_expected_list, sizeof(__pyx_k_expected_list), 0, 0, 1, 1},
    {&__pyx_n_s_expected_parse_results, __pyx_k_expected_parse_results, sizeof(__pyx_k_expected_parse_results), 0, 0, 1, 1},
    {&__pyx_n_s_explain, __pyx_k_explain, sizeof(__pyx_k_explain), 0, 0, 1, 1},
    {&__pyx_n_s_expr, __pyx_k_expr, sizeof(__pyx_k_expr), 0, 0, 1, 1},
    {&__pyx_n_s_expr1, __pyx_k_expr1, sizeof(__pyx_k_expr1), 0, 0, 1, 1},
    {&__pyx_n_s_expr_order, __pyx_k_expr_order, sizeof(__pyx_k_expr_order), 0, 0, 1, 1},
    {&__pyx_n_s_expr_parse, __pyx_k_expr_parse, sizeof(__pyx_k_expr_parse), 0, 0, 1, 1},
    {&__pyx_kp_u_expression, __pyx_k_expression, sizeof(__pyx_k_expression), 0, 1, 0, 0},
    {&__pyx_n_s_exprs, __pyx_k_exprs, sizeof(__pyx_k_exprs), 0, 0, 1, 1},
    {&__pyx_n_u_exprs, __pyx_k_exprs, sizeof(__pyx_k_exprs), 0, 1, 0, 1},
    {&__pyx_n_s_exprsFound, __pyx_k_exprsFound, sizeof(__pyx_k_exprsFound), 0, 0, 1, 1},
    {&__pyx_n_s_exprtokens, __pyx_k_exprtokens, sizeof(__pyx_k_exprtokens), 0, 0, 1, 1},
    {&__pyx_n_s_extend, __pyx_k_extend, sizeof(__pyx_k_extend), 0, 0, 1, 1},
    {&__pyx_n_s_extractText, __pyx_k_extractText, sizeof(__pyx_k_extractText), 0, 0, 1, 1},
    {&__pyx_n_s_extract_stack, __pyx_k_extract_stack, sizeof(__pyx_k_extract_stack), 0, 0, 1, 1},
    {&__pyx_n_s_extract_tb, __pyx_k_extract_tb, sizeof(__pyx_k_extract_tb), 0, 0, 1, 1},
    {&__pyx_kp_u_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 1, 0, 0},
    {&__pyx_n_s_f_2, __pyx_k_f_2, sizeof(__pyx_k_f_2), 0, 0, 1, 1},
    {&__pyx_n_s_f_code, __pyx_k_f_code, sizeof(__pyx_k_f_code), 0, 0, 1, 1},
    {&__pyx_n_s_f_locals, __pyx_k_f_locals, sizeof(__pyx_k_f_locals), 0, 0, 1, 1},
    {&__pyx_n_s_f_self, __pyx_k_f_self, sizeof(__pyx_k_f_self), 0, 0, 1, 1},
    {&__pyx_n_s_failAction, __pyx_k_failAction, sizeof(__pyx_k_failAction), 0, 0, 1, 1},
    {&__pyx_n_s_failOn, __pyx_k_failOn, sizeof(__pyx_k_failOn), 0, 0, 1, 1},
    {&__pyx_n_s_fail_msg, __pyx_k_fail_msg, sizeof(__pyx_k_fail_msg), 0, 0, 1, 1},
    {&__pyx_n_s_failed, __pyx_k_failed, sizeof(__pyx_k_failed), 0, 0, 1, 1},
    {&__pyx_kp_u_failed_runTests, __pyx_k_failed_runTests, sizeof(__pyx_k_failed_runTests), 0, 1, 0, 0},
    {&__pyx_kp_u_failed_user_defined_condition, __pyx_k_failed_user_defined_condition, sizeof(__pyx_k_failed_user_defined_condition), 0, 1, 0, 0},
    {&__pyx_n_s_failureTests, __pyx_k_failureTests, sizeof(__pyx_k_failureTests), 0, 0, 1, 1},
    {&__pyx_n_s_fatal, __pyx_k_fatal, sizeof(__pyx_k_fatal), 0, 0, 1, 1},
    {&__pyx_n_u_fatal, __pyx_k_fatal, sizeof(__pyx_k_fatal), 0, 1, 0, 1},
    {&__pyx_n_s_ff, __pyx_k_ff, sizeof(__pyx_k_ff), 0, 0, 1, 1},
    {&__pyx_kp_u_ffff, __pyx_k_ffff, sizeof(__pyx_k_ffff), 0, 1, 0, 0},
    {&__pyx_n_s_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 0, 1, 1},
    {&__pyx_n_s_file_contents, __pyx_k_file_contents, sizeof(__pyx_k_file_contents), 0, 0, 1, 1},
    {&__pyx_n_s_file_or_filename, __pyx_k_file_or_filename, sizeof(__pyx_k_file_or_filename), 0, 0, 1, 1},
    {&__pyx_n_s_filter, __pyx_k_filter, sizeof(__pyx_k_filter), 0, 0, 1, 1},
    {&__pyx_n_s_filterfalse, __pyx_k_filterfalse, sizeof(__pyx_k_filterfalse), 0, 0, 1, 1},
    {&__pyx_n_s_finalResults, __pyx_k_finalResults, sizeof(__pyx_k_finalResults), 0, 0, 1, 1},
    {&__pyx_n_s_find, __pyx_k_find, sizeof(__pyx_k_find), 0, 0, 1, 1},
    {&__pyx_n_s_firstMatchChar, __pyx_k_firstMatchChar, sizeof(__pyx_k_firstMatchChar), 0, 0, 1, 1},
    {&__pyx_n_s_firstQuoteChar, __pyx_k_firstQuoteChar, sizeof(__pyx_k_firstQuoteChar), 0, 0, 1, 1},
    {&__pyx_n_s_flag, __pyx_k_flag, sizeof(__pyx_k_flag), 0, 0, 1, 1},
    {&__pyx_n_s_flags, __pyx_k_flags, sizeof(__pyx_k_flags), 0, 0, 1, 1},
    {&__pyx_n_s_flatten, __pyx_k_flatten, sizeof(__pyx_k_flatten), 0, 0, 1, 1},
    {&__pyx_n_s_fmt, __pyx_k_fmt, sizeof(__pyx_k_fmt), 0, 0, 1, 1},
    {&__pyx_n_s_fn, __pyx_k_fn, sizeof(__pyx_k_fn), 0, 0, 1, 1},
    {&__pyx_n_s_fname, __pyx_k_fname, sizeof(__pyx_k_fname), 0, 0, 1, 1},
    {&__pyx_n_s_fns, __pyx_k_fns, sizeof(__pyx_k_fns), 0, 0, 1, 1},
    {&__pyx_n_s_fnumber, __pyx_k_fnumber, sizeof(__pyx_k_fnumber), 0, 0, 1, 1},
    {&__pyx_n_u_fnumber, __pyx_k_fnumber, sizeof(__pyx_k_fnumber), 0, 1, 0, 1},
    {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
    {&__pyx_n_s_formatted, __pyx_k_formatted, sizeof(__pyx_k_formatted), 0, 0, 1, 1},
    {&__pyx_n_s_foundArity, __pyx_k_foundArity, sizeof(__pyx_k_foundArity), 0, 0, 1, 1},
    {&__pyx_kp_u_found_end_of_text, __pyx_k_found_end_of_text, sizeof(__pyx_k_found_end_of_text), 0, 1, 0, 0},
    {&__pyx_kp_u_found_multiline_regex_during_inc, __pyx_k_found_multiline_regex_during_inc, sizeof(__pyx_k_found_multiline_regex_during_inc), 0, 1, 0, 0},
    {&__pyx_kp_u_found_r, __pyx_k_found_r, sizeof(__pyx_k_found_r), 0, 1, 0, 0},
    {&__pyx_n_s_foundstr, __pyx_k_foundstr, sizeof(__pyx_k_foundstr), 0, 0, 1, 1},
    {&__pyx_n_s_fraction, __pyx_k_fraction, sizeof(__pyx_k_fraction), 0, 0, 1, 1},
    {&__pyx_n_u_fraction, __pyx_k_fraction, sizeof(__pyx_k_fraction), 0, 1, 0, 1},
    {&__pyx_kp_u_fraction_or_mixed_integer_fracti, __pyx_k_fraction_or_mixed_integer_fracti, sizeof(__pyx_k_fraction_or_mixed_integer_fracti), 0, 1, 0, 0},
    {&__pyx_n_s_frame_summary, __pyx_k_frame_summary, sizeof(__pyx_k_frame_summary), 0, 0, 1, 1},
    {&__pyx_n_s_frames, __pyx_k_frames, sizeof(__pyx_k_frames), 0, 0, 1, 1},
    {&__pyx_n_s_frm, __pyx_k_frm, sizeof(__pyx_k_frm), 0, 0, 1, 1},
    {&__pyx_n_s_from, __pyx_k_from, sizeof(__pyx_k_from), 0, 0, 1, 1},
    {&__pyx_n_s_fromToken, __pyx_k_fromToken, sizeof(__pyx_k_fromToken), 0, 0, 1, 1},
    {&__pyx_n_u_from_2, __pyx_k_from_2, sizeof(__pyx_k_from_2), 0, 1, 0, 1},
    {&__pyx_n_s_from_dict, __pyx_k_from_dict, sizeof(__pyx_k_from_dict), 0, 0, 1, 1},
    {&__pyx_n_s_from_exception, __pyx_k_from_exception, sizeof(__pyx_k_from_exception), 0, 0, 1, 1},
    {&__pyx_n_s_from_symbols, __pyx_k_from_symbols, sizeof(__pyx_k_from_symbols), 0, 0, 1, 1},
    {&__pyx_n_s_full, __pyx_k_full, sizeof(__pyx_k_full), 0, 0, 1, 1},
    {&__pyx_n_s_fullDump, __pyx_k_fullDump, sizeof(__pyx_k_fullDump), 0, 0, 1, 1},
    {&__pyx_kp_u_full_IPv6_address, __pyx_k_full_IPv6_address, sizeof(__pyx_k_full_IPv6_address), 0, 1, 0, 0},
    {&__pyx_n_s_full_ipv6_address, __pyx_k_full_ipv6_address, sizeof(__pyx_k_full_ipv6_address), 0, 0, 1, 1},
    {&__pyx_n_s_func, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
    {&__pyx_n_s_func_name, __pyx_k_func_name, sizeof(__pyx_k_func_name), 0, 0, 1, 1},
    {&__pyx_n_s_functools, __pyx_k_functools, sizeof(__pyx_k_functools), 0, 0, 1, 1},
    {&__pyx_n_s_furthest_locs, __pyx_k_furthest_locs, sizeof(__pyx_k_furthest_locs), 0, 0, 1, 1},
    {&__pyx_kp_u_g_1, __pyx_k_g_1, sizeof(__pyx_k_g_1), 0, 1, 0, 0},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_generatorType, __pyx_k_generatorType, sizeof(__pyx_k_generatorType), 0, 0, 1, 1},
    {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
    {&__pyx_n_s_getName, __pyx_k_getName, sizeof(__pyx_k_getName), 0, 0, 1, 1},
    {&__pyx_n_s_get_2, __pyx_k_get_2, sizeof(__pyx_k_get_2), 0, 0, 1, 1},
    {&__pyx_n_s_get_chars_for_ranges, __pyx_k_get_chars_for_ranges, sizeof(__pyx_k_get_chars_for_ranges), 0, 0, 1, 1},
    {&__pyx_n_s_getattr, __pyx_k_getattr, sizeof(__pyx_k_getattr), 0, 0, 1, 1},
    {&__pyx_n_s_getinnerframes, __pyx_k_getinnerframes, sizeof(__pyx_k_getinnerframes), 0, 0, 1, 1},
    {&__pyx_n_s_getitem, __pyx_k_getitem, sizeof(__pyx_k_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_getnewargs, __pyx_k_getnewargs, sizeof(__pyx_k_getnewargs), 0, 0, 1, 1},
    {&__pyx_n_s_getrecursionlimit, __pyx_k_getrecursionlimit, sizeof(__pyx_k_getrecursionlimit), 0, 0, 1, 1},
    {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
    {&__pyx_n_s_group, __pyx_k_group, sizeof(__pyx_k_group), 0, 0, 1, 1},
    {&__pyx_n_s_groupdict, __pyx_k_groupdict, sizeof(__pyx_k_groupdict), 0, 0, 1, 1},
    {&__pyx_n_s_groups, __pyx_k_groups, sizeof(__pyx_k_groups), 0, 0, 1, 1},
    {&__pyx_kp_u_gt_lt_amp_nbsp_quot_apos, __pyx_k_gt_lt_amp_nbsp_quot_apos, sizeof(__pyx_k_gt_lt_amp_nbsp_quot_apos), 0, 1, 0, 0},
    {&__pyx_n_s_hasIgnoreExprs, __pyx_k_hasIgnoreExprs, sizeof(__pyx_k_hasIgnoreExprs), 0, 0, 1, 1},
    {&__pyx_kp_u_has_value, __pyx_k_has_value, sizeof(__pyx_k_has_value), 0, 1, 0, 0},
    {&__pyx_n_s_hash, __pyx_k_hash, sizeof(__pyx_k_hash), 0, 0, 1, 1},
    {&__pyx_n_s_haskeys, __pyx_k_haskeys, sizeof(__pyx_k_haskeys), 0, 0, 1, 1},
    {&__pyx_kp_u_hex_integer, __pyx_k_hex_integer, sizeof(__pyx_k_hex_integer), 0, 1, 0, 0},
    {&__pyx_n_s_hex_integer_2, __pyx_k_hex_integer_2, sizeof(__pyx_k_hex_integer_2), 0, 0, 1, 1},
    {&__pyx_n_u_hex_integer_2, __pyx_k_hex_integer_2, sizeof(__pyx_k_hex_integer_2), 0, 1, 0, 1},
    {&__pyx_n_s_hexnums, __pyx_k_hexnums, sizeof(__pyx_k_hexnums), 0, 0, 1, 1},
    {&__pyx_n_u_hexnums, __pyx_k_hexnums, sizeof(__pyx_k_hexnums), 0, 1, 0, 1},
    {&__pyx_n_s_hit, __pyx_k_hit, sizeof(__pyx_k_hit), 0, 0, 1, 1},
    {&__pyx_n_s_htmlComment, __pyx_k_htmlComment, sizeof(__pyx_k_htmlComment), 0, 0, 1, 1},
    {&__pyx_n_u_htmlComment, __pyx_k_htmlComment, sizeof(__pyx_k_htmlComment), 0, 1, 0, 1},
    {&__pyx_n_s_htmlEntityMap, __pyx_k_htmlEntityMap, sizeof(__pyx_k_htmlEntityMap), 0, 0, 1, 1},
    {&__pyx_n_s_html_stripper, __pyx_k_html_stripper, sizeof(__pyx_k_html_stripper), 0, 0, 1, 1},
    {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
    {&__pyx_n_s_iadd, __pyx_k_iadd, sizeof(__pyx_k_iadd), 0, 0, 1, 1},
    {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
    {&__pyx_n_s_ident, __pyx_k_ident, sizeof(__pyx_k_ident), 0, 0, 1, 1},
    {&__pyx_n_s_identChars, __pyx_k_identChars, sizeof(__pyx_k_identChars), 0, 0, 1, 1},
    {&__pyx_n_s_identifier, __pyx_k_identifier, sizeof(__pyx_k_identifier), 0, 0, 1, 1},
    {&__pyx_n_u_identifier, __pyx_k_identifier, sizeof(__pyx_k_identifier), 0, 1, 0, 1},
    {&__pyx_kp_u_if_numterms_3_opExpr_must_be_a_t, __pyx_k_if_numterms_3_opExpr_must_be_a_t, sizeof(__pyx_k_if_numterms_3_opExpr_must_be_a_t), 0, 1, 0, 0},
    {&__pyx_n_s_ifilterfalse, __pyx_k_ifilterfalse, sizeof(__pyx_k_ifilterfalse), 0, 0, 1, 1},
    {&__pyx_n_s_ignore, __pyx_k_ignore, sizeof(__pyx_k_ignore), 0, 0, 1, 1},
    {&__pyx_n_s_ignoreExpr, __pyx_k_ignoreExpr, sizeof(__pyx_k_ignoreExpr), 0, 0, 1, 1},
    {&__pyx_n_s_ignoreExprs, __pyx_k_ignoreExprs, sizeof(__pyx_k_ignoreExprs), 0, 0, 1, 1},
    {&__pyx_n_s_ikey, __pyx_k_ikey, sizeof(__pyx_k_ikey), 0, 0, 1, 1},
    {&__pyx_kp_u_illegal_nesting, __pyx_k_illegal_nesting, sizeof(__pyx_k_illegal_nesting), 0, 1, 0, 0},
    {&__pyx_n_s_ilshift, __pyx_k_ilshift, sizeof(__pyx_k_ilshift), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_inAccumNames, __pyx_k_inAccumNames, sizeof(__pyx_k_inAccumNames), 0, 0, 1, 1},
    {&__pyx_n_u_include, __pyx_k_include, sizeof(__pyx_k_include), 0, 1, 0, 1},
    {&__pyx_n_s_includeMatch, __pyx_k_includeMatch, sizeof(__pyx_k_includeMatch), 0, 0, 1, 1},
    {&__pyx_n_s_includeSeparators, __pyx_k_includeSeparators, sizeof(__pyx_k_includeSeparators), 0, 0, 1, 1},
    {&__pyx_n_s_include_2, __pyx_k_include_2, sizeof(__pyx_k_include_2), 0, 0, 1, 1},
    {&__pyx_n_s_include_list, __pyx_k_include_list, sizeof(__pyx_k_include_list), 0, 0, 1, 1},
    {&__pyx_n_s_incrementalEnabled, __pyx_k_incrementalEnabled, sizeof(__pyx_k_incrementalEnabled), 0, 0, 1, 1},
    {&__pyx_n_s_incrementalWithResets, __pyx_k_incrementalWithResets, sizeof(__pyx_k_incrementalWithResets), 0, 0, 1, 1},
    {&__pyx_n_s_incremental_parent_usefullness, __pyx_k_incremental_parent_usefullness, sizeof(__pyx_k_incremental_parent_usefullness), 0, 0, 1, 1},
    {&__pyx_n_s_ind, __pyx_k_ind, sizeof(__pyx_k_ind), 0, 0, 1, 1},
    {&__pyx_n_s_ind_or_e, __pyx_k_ind_or_e, sizeof(__pyx_k_ind_or_e), 0, 0, 1, 1},
    {&__pyx_n_s_indent, __pyx_k_indent, sizeof(__pyx_k_indent), 0, 0, 1, 1},
    {&__pyx_n_s_indentStack, __pyx_k_indentStack, sizeof(__pyx_k_indentStack), 0, 0, 1, 1},
    {&__pyx_n_s_indentedBlock, __pyx_k_indentedBlock, sizeof(__pyx_k_indentedBlock), 0, 0, 1, 1},
    {&__pyx_n_u_indentedBlock, __pyx_k_indentedBlock, sizeof(__pyx_k_indentedBlock), 0, 1, 0, 1},
    {&__pyx_n_s_indentedBlock_locals_checkPeerIn, __pyx_k_indentedBlock_locals_checkPeerIn, sizeof(__pyx_k_indentedBlock_locals_checkPeerIn), 0, 0, 1, 1},
    {&__pyx_n_s_indentedBlock_locals_checkSubInd, __pyx_k_indentedBlock_locals_checkSubInd, sizeof(__pyx_k_indentedBlock_locals_checkSubInd), 0, 0, 1, 1},
    {&__pyx_n_s_indentedBlock_locals_checkUninde, __pyx_k_indentedBlock_locals_checkUninde, sizeof(__pyx_k_indentedBlock_locals_checkUninde), 0, 0, 1, 1},
    {&__pyx_n_s_indentedBlock_locals_lambda, __pyx_k_indentedBlock_locals_lambda, sizeof(__pyx_k_indentedBlock_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_indentedBlock_locals_reset_stack, __pyx_k_indentedBlock_locals_reset_stack, sizeof(__pyx_k_indentedBlock_locals_reset_stack), 0, 0, 1, 1},
    {&__pyx_kp_u_indented_block, __pyx_k_indented_block, sizeof(__pyx_k_indented_block), 0, 1, 0, 0},
    {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
    {&__pyx_n_s_indices, __pyx_k_indices, sizeof(__pyx_k_indices), 0, 0, 1, 1},
    {&__pyx_n_s_infixNotation, __pyx_k_infixNotation, sizeof(__pyx_k_infixNotation), 0, 0, 1, 1},
    {&__pyx_n_u_infixNotation, __pyx_k_infixNotation, sizeof(__pyx_k_infixNotation), 0, 1, 0, 1},
    {&__pyx_n_s_infixNotation_locals__FB, __pyx_k_infixNotation_locals__FB, sizeof(__pyx_k_infixNotation_locals__FB), 0, 0, 1, 1},
    {&__pyx_n_s_infixNotation_locals__FB_parseIm, __pyx_k_infixNotation_locals__FB_parseIm, sizeof(__pyx_k_infixNotation_locals__FB_parseIm), 0, 0, 1, 1},
    {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
    {&__pyx_n_s_initChars, __pyx_k_initChars, sizeof(__pyx_k_initChars), 0, 0, 1, 1},
    {&__pyx_n_s_initCharsOrig, __pyx_k_initCharsOrig, sizeof(__pyx_k_initCharsOrig), 0, 0, 1, 1},
    {&__pyx_n_s_initExprGroups, __pyx_k_initExprGroups, sizeof(__pyx_k_initExprGroups), 0, 0, 1, 1},
    {&__pyx_n_s_init_subclass, __pyx_k_init_subclass, sizeof(__pyx_k_init_subclass), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_inlineLiteralsUsing, __pyx_k_inlineLiteralsUsing, sizeof(__pyx_k_inlineLiteralsUsing), 0, 0, 1, 1},
    {&__pyx_n_s_insStr, __pyx_k_insStr, sizeof(__pyx_k_insStr), 0, 0, 1, 1},
    {&__pyx_n_s_insert, __pyx_k_insert, sizeof(__pyx_k_insert), 0, 0, 1, 1},
    {&__pyx_n_s_inspect, __pyx_k_inspect, sizeof(__pyx_k_inspect), 0, 0, 1, 1},
    {&__pyx_n_s_inspect_tracebacks, __pyx_k_inspect_tracebacks, sizeof(__pyx_k_inspect_tracebacks), 0, 0, 1, 1},
    {&__pyx_n_s_instring, __pyx_k_instring, sizeof(__pyx_k_instring), 0, 0, 1, 1},
    {&__pyx_n_s_instring_prefixes_and_suffixes, __pyx_k_instring_prefixes_and_suffixes, sizeof(__pyx_k_instring_prefixes_and_suffixes), 0, 0, 1, 1},
    {&__pyx_n_s_instring_slice, __pyx_k_instring_slice, sizeof(__pyx_k_instring_slice), 0, 0, 1, 1},
    {&__pyx_n_s_instrlen, __pyx_k_instrlen, sizeof(__pyx_k_instrlen), 0, 0, 1, 1},
    {&__pyx_n_s_intExpr, __pyx_k_intExpr, sizeof(__pyx_k_intExpr), 0, 0, 1, 1},
    {&__pyx_n_s_integer, __pyx_k_integer, sizeof(__pyx_k_integer), 0, 0, 1, 1},
    {&__pyx_n_u_integer, __pyx_k_integer, sizeof(__pyx_k_integer), 0, 1, 0, 1},
    {&__pyx_n_s_intern, __pyx_k_intern, sizeof(__pyx_k_intern), 0, 0, 1, 1},
    {&__pyx_n_u_intern, __pyx_k_intern, sizeof(__pyx_k_intern), 0, 1, 0, 1},
    {&__pyx_kp_u_invalid_pattern_s_passed_to_Rege, __pyx_k_invalid_pattern_s_passed_to_Rege, sizeof(__pyx_k_invalid_pattern_s_passed_to_Rege), 0, 1, 0, 0},
    {&__pyx_n_s_invert, __pyx_k_invert, sizeof(__pyx_k_invert), 0, 0, 1, 1},
    {&__pyx_n_s_ior, __pyx_k_ior, sizeof(__pyx_k_ior), 0, 0, 1, 1},
    {&__pyx_n_s_ipv4_address, __pyx_k_ipv4_address, sizeof(__pyx_k_ipv4_address), 0, 0, 1, 1},
    {&__pyx_n_s_ipv6_address, __pyx_k_ipv6_address, sizeof(__pyx_k_ipv6_address), 0, 0, 1, 1},
    {&__pyx_n_s_ipv6_part, __pyx_k_ipv6_part, sizeof(__pyx_k_ipv6_part), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_n_s_is_instring, __pyx_k_is_instring, sizeof(__pyx_k_is_instring), 0, 0, 1, 1},
    {&__pyx_n_s_is_iterable, __pyx_k_is_iterable, sizeof(__pyx_k_is_iterable), 0, 0, 1, 1},
    {&__pyx_n_s_isalpha, __pyx_k_isalpha, sizeof(__pyx_k_isalpha), 0, 0, 1, 1},
    {&__pyx_n_s_isdigit, __pyx_k_isdigit, sizeof(__pyx_k_isdigit), 0, 0, 1, 1},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_isequal, __pyx_k_isequal, sizeof(__pyx_k_isequal), 0, 0, 1, 1},
    {&__pyx_n_s_isinstance, __pyx_k_isinstance, sizeof(__pyx_k_isinstance), 0, 0, 1, 1},
    {&__pyx_n_s_iso8601_date, __pyx_k_iso8601_date, sizeof(__pyx_k_iso8601_date), 0, 0, 1, 1},
    {&__pyx_n_s_iso8601_datetime, __pyx_k_iso8601_datetime, sizeof(__pyx_k_iso8601_datetime), 0, 0, 1, 1},
    {&__pyx_n_s_isspace, __pyx_k_isspace, sizeof(__pyx_k_isspace), 0, 0, 1, 1},
    {&__pyx_n_s_item, __pyx_k_item, sizeof(__pyx_k_item), 0, 0, 1, 1},
    {&__pyx_n_s_item_fn, __pyx_k_item_fn, sizeof(__pyx_k_item_fn), 0, 0, 1, 1},
    {&__pyx_n_s_itemgetter, __pyx_k_itemgetter, sizeof(__pyx_k_itemgetter), 0, 0, 1, 1},
    {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
    {&__pyx_n_s_itemseq, __pyx_k_itemseq, sizeof(__pyx_k_itemseq), 0, 0, 1, 1},
    {&__pyx_n_s_iter, __pyx_k_iter, sizeof(__pyx_k_iter), 0, 0, 1, 1},
    {&__pyx_n_s_iteritems, __pyx_k_iteritems, sizeof(__pyx_k_iteritems), 0, 0, 1, 1},
    {&__pyx_n_s_iteritems_2, __pyx_k_iteritems_2, sizeof(__pyx_k_iteritems_2), 0, 0, 1, 1},
    {&__pyx_n_s_iterkeys, __pyx_k_iterkeys, sizeof(__pyx_k_iterkeys), 0, 0, 1, 1},
    {&__pyx_n_u_iterkeys, __pyx_k_iterkeys, sizeof(__pyx_k_iterkeys), 0, 1, 0, 1},
    {&__pyx_n_s_iterkeys_2, __pyx_k_iterkeys_2, sizeof(__pyx_k_iterkeys_2), 0, 0, 1, 1},
    {&__pyx_n_s_itertools, __pyx_k_itertools, sizeof(__pyx_k_itertools), 0, 0, 1, 1},
    {&__pyx_n_s_itervalues, __pyx_k_itervalues, sizeof(__pyx_k_itervalues), 0, 0, 1, 1},
    {&__pyx_n_s_itervalues_2, __pyx_k_itervalues_2, sizeof(__pyx_k_itervalues_2), 0, 0, 1, 1},
    {&__pyx_n_s_ixor, __pyx_k_ixor, sizeof(__pyx_k_ixor), 0, 0, 1, 1},
    {&__pyx_n_s_j, __pyx_k_j, sizeof(__pyx_k_j), 0, 0, 1, 1},
    {&__pyx_n_s_javaStyleComment, __pyx_k_javaStyleComment, sizeof(__pyx_k_javaStyleComment), 0, 0, 1, 1},
    {&__pyx_n_u_javaStyleComment, __pyx_k_javaStyleComment, sizeof(__pyx_k_javaStyleComment), 0, 1, 0, 1},
    {&__pyx_n_s_joinString, __pyx_k_joinString, sizeof(__pyx_k_joinString), 0, 0, 1, 1},
    {&__pyx_kp_s_just_like_class_ParseFatalExcept, __pyx_k_just_like_class_ParseFatalExcept, sizeof(__pyx_k_just_like_class_ParseFatalExcept), 0, 0, 1, 0},
    {&__pyx_n_s_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 0, 1, 1},
    {&__pyx_n_s_keepMatching, __pyx_k_keepMatching, sizeof(__pyx_k_keepMatching), 0, 0, 1, 1},
    {&__pyx_n_s_keepTabs, __pyx_k_keepTabs, sizeof(__pyx_k_keepTabs), 0, 0, 1, 1},
    {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
    {&__pyx_n_s_key_fifo, __pyx_k_key_fifo, sizeof(__pyx_k_key_fifo), 0, 0, 1, 1},
    {&__pyx_n_u_key_fifo, __pyx_k_key_fifo, sizeof(__pyx_k_key_fifo), 0, 1, 0, 1},
    {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
    {&__pyx_n_s_kwargs, __pyx_k_kwargs, sizeof(__pyx_k_kwargs), 0, 0, 1, 1},
    {&__pyx_n_s_l, __pyx_k_l, sizeof(__pyx_k_l), 0, 0, 1, 1},
    {&__pyx_n_s_lambda, __pyx_k_lambda, sizeof(__pyx_k_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_last, __pyx_k_last, sizeof(__pyx_k_last), 0, 0, 1, 1},
    {&__pyx_n_s_lastCR, __pyx_k_lastCR, sizeof(__pyx_k_lastCR), 0, 0, 1, 1},
    {&__pyx_n_s_lastE, __pyx_k_lastE, sizeof(__pyx_k_lastE), 0, 0, 1, 1},
    {&__pyx_n_s_lastExpr, __pyx_k_lastExpr, sizeof(__pyx_k_lastExpr), 0, 0, 1, 1},
    {&__pyx_n_s_last_expr, __pyx_k_last_expr, sizeof(__pyx_k_last_expr), 0, 0, 1, 1},
    {&__pyx_n_s_lazyclassproperty, __pyx_k_lazyclassproperty, sizeof(__pyx_k_lazyclassproperty), 0, 0, 1, 1},
    {&__pyx_n_s_lazyclassproperty___get, __pyx_k_lazyclassproperty___get, sizeof(__pyx_k_lazyclassproperty___get), 0, 0, 1, 1},
    {&__pyx_n_s_lazyclassproperty___get___local, __pyx_k_lazyclassproperty___get___local, sizeof(__pyx_k_lazyclassproperty___get___local), 0, 0, 1, 1},
    {&__pyx_n_s_lazyclassproperty___init, __pyx_k_lazyclassproperty___init, sizeof(__pyx_k_lazyclassproperty___init), 0, 0, 1, 1},
    {&__pyx_n_s_leaveWhitespace, __pyx_k_leaveWhitespace, sizeof(__pyx_k_leaveWhitespace), 0, 0, 1, 1},
    {&__pyx_kp_u_leaving, __pyx_k_leaving, sizeof(__pyx_k_leaving), 0, 1, 0, 0},
    {&__pyx_kp_u_len, __pyx_k_len, sizeof(__pyx_k_len), 0, 1, 0, 0},
    {&__pyx_n_s_len_2, __pyx_k_len_2, sizeof(__pyx_k_len_2), 0, 0, 1, 1},
    {&__pyx_n_s_len_3, __pyx_k_len_3, sizeof(__pyx_k_len_3), 0, 0, 1, 1},
    {&__pyx_n_s_limit, __pyx_k_limit, sizeof(__pyx_k_limit), 0, 0, 1, 1},
    {&__pyx_n_s_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 0, 1, 1},
    {&__pyx_n_u_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 1, 0, 1},
    {&__pyx_n_s_lineEnd, __pyx_k_lineEnd, sizeof(__pyx_k_lineEnd), 0, 0, 1, 1},
    {&__pyx_n_u_lineEnd, __pyx_k_lineEnd, sizeof(__pyx_k_lineEnd), 0, 1, 0, 1},
    {&__pyx_n_s_lineStart, __pyx_k_lineStart, sizeof(__pyx_k_lineStart), 0, 0, 1, 1},
    {&__pyx_n_u_lineStart, __pyx_k_lineStart, sizeof(__pyx_k_lineStart), 0, 1, 0, 1},
    {&__pyx_kp_u_line_2, __pyx_k_line_2, sizeof(__pyx_k_line_2), 0, 1, 0, 0},
    {&__pyx_kp_u_line_3, __pyx_k_line_3, sizeof(__pyx_k_line_3), 0, 1, 0, 0},
    {&__pyx_n_s_line_column, __pyx_k_line_column, sizeof(__pyx_k_line_column), 0, 0, 1, 1},
    {&__pyx_n_s_line_str, __pyx_k_line_str, sizeof(__pyx_k_line_str), 0, 0, 1, 1},
    {&__pyx_n_s_lineno, __pyx_k_lineno, sizeof(__pyx_k_lineno), 0, 0, 1, 1},
    {&__pyx_n_u_lineno, __pyx_k_lineno, sizeof(__pyx_k_lineno), 0, 1, 0, 1},
    {&__pyx_kp_u_lineno_col_line, __pyx_k_lineno_col_line, sizeof(__pyx_k_lineno_col_line), 0, 1, 0, 0},
    {&__pyx_n_s_listAllMatches, __pyx_k_listAllMatches, sizeof(__pyx_k_listAllMatches), 0, 0, 1, 1},
    {&__pyx_n_s_list_str, __pyx_k_list_str, sizeof(__pyx_k_list_str), 0, 0, 1, 1},
    {&__pyx_n_s_list_str_locals_genexpr, __pyx_k_list_str_locals_genexpr, sizeof(__pyx_k_list_str_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_literalStringClass, __pyx_k_literalStringClass, sizeof(__pyx_k_literalStringClass), 0, 0, 1, 1},
    {&__pyx_n_u_literal_string_class, __pyx_k_literal_string_class, sizeof(__pyx_k_literal_string_class), 0, 1, 0, 1},
    {&__pyx_n_s_loc, __pyx_k_loc, sizeof(__pyx_k_loc), 0, 0, 1, 1},
    {&__pyx_n_u_loc, __pyx_k_loc, sizeof(__pyx_k_loc), 0, 1, 0, 1},
    {&__pyx_n_s_loc1, __pyx_k_loc1, sizeof(__pyx_k_loc1), 0, 0, 1, 1},
    {&__pyx_n_s_loc2, __pyx_k_loc2, sizeof(__pyx_k_loc2), 0, 0, 1, 1},
    {&__pyx_n_s_locMarker, __pyx_k_locMarker, sizeof(__pyx_k_locMarker), 0, 0, 1, 1},
    {&__pyx_n_s_loc_in_suffix, __pyx_k_loc_in_suffix, sizeof(__pyx_k_loc_in_suffix), 0, 0, 1, 1},
    {&__pyx_n_s_locatedExpr, __pyx_k_locatedExpr, sizeof(__pyx_k_locatedExpr), 0, 0, 1, 1},
    {&__pyx_n_u_locatedExpr, __pyx_k_locatedExpr, sizeof(__pyx_k_locatedExpr), 0, 1, 0, 1},
    {&__pyx_n_s_locatedExpr_locals_lambda, __pyx_k_locatedExpr_locals_lambda, sizeof(__pyx_k_locatedExpr_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_locator, __pyx_k_locator, sizeof(__pyx_k_locator), 0, 0, 1, 1},
    {&__pyx_n_s_locn, __pyx_k_locn, sizeof(__pyx_k_locn), 0, 0, 1, 1},
    {&__pyx_n_u_locn_end, __pyx_k_locn_end, sizeof(__pyx_k_locn_end), 0, 1, 0, 1},
    {&__pyx_n_u_locn_start, __pyx_k_locn_start, sizeof(__pyx_k_locn_start), 0, 1, 0, 1},
    {&__pyx_n_s_longest, __pyx_k_longest, sizeof(__pyx_k_longest), 0, 0, 1, 1},
    {&__pyx_n_s_lookup, __pyx_k_lookup, sizeof(__pyx_k_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_lookup_2, __pyx_k_lookup_2, sizeof(__pyx_k_lookup_2), 0, 0, 1, 1},
    {&__pyx_n_s_lookup_bools, __pyx_k_lookup_bools, sizeof(__pyx_k_lookup_bools), 0, 0, 1, 1},
    {&__pyx_n_s_lower, __pyx_k_lower, sizeof(__pyx_k_lower), 0, 0, 1, 1},
    {&__pyx_n_s_lpar, __pyx_k_lpar, sizeof(__pyx_k_lpar), 0, 0, 1, 1},
    {&__pyx_n_s_lshift, __pyx_k_lshift, sizeof(__pyx_k_lshift), 0, 0, 1, 1},
    {&__pyx_n_s_lstrip, __pyx_k_lstrip, sizeof(__pyx_k_lstrip), 0, 0, 1, 1},
    {&__pyx_n_s_mac_address, __pyx_k_mac_address, sizeof(__pyx_k_mac_address), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_u_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 1, 0, 1},
    {&__pyx_n_s_makeHTMLTags, __pyx_k_makeHTMLTags, sizeof(__pyx_k_makeHTMLTags), 0, 0, 1, 1},
    {&__pyx_n_u_makeHTMLTags, __pyx_k_makeHTMLTags, sizeof(__pyx_k_makeHTMLTags), 0, 1, 0, 1},
    {&__pyx_n_s_makeOptionalList, __pyx_k_makeOptionalList, sizeof(__pyx_k_makeOptionalList), 0, 0, 1, 1},
    {&__pyx_n_s_makeTags, __pyx_k_makeTags, sizeof(__pyx_k_makeTags), 0, 0, 1, 1},
    {&__pyx_n_s_makeTags_locals_lambda, __pyx_k_makeTags_locals_lambda, sizeof(__pyx_k_makeTags_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_makeXMLTags, __pyx_k_makeXMLTags, sizeof(__pyx_k_makeXMLTags), 0, 0, 1, 1},
    {&__pyx_n_u_makeXMLTags, __pyx_k_makeXMLTags, sizeof(__pyx_k_makeXMLTags), 0, 1, 0, 1},
    {&__pyx_n_s_map, __pyx_k_map, sizeof(__pyx_k_map), 0, 0, 1, 1},
    {&__pyx_n_s_markInputline, __pyx_k_markInputline, sizeof(__pyx_k_markInputline), 0, 0, 1, 1},
    {&__pyx_n_s_markerString, __pyx_k_markerString, sizeof(__pyx_k_markerString), 0, 0, 1, 1},
    {&__pyx_n_s_masks, __pyx_k_masks, sizeof(__pyx_k_masks), 0, 0, 1, 1},
    {&__pyx_n_s_mat, __pyx_k_mat, sizeof(__pyx_k_mat), 0, 0, 1, 1},
    {&__pyx_n_s_match, __pyx_k_match, sizeof(__pyx_k_match), 0, 0, 1, 1},
    {&__pyx_n_u_match, __pyx_k_match, sizeof(__pyx_k_match), 0, 1, 0, 1},
    {&__pyx_n_s_matchExpr, __pyx_k_matchExpr, sizeof(__pyx_k_matchExpr), 0, 0, 1, 1},
    {&__pyx_n_s_matchLen, __pyx_k_matchLen, sizeof(__pyx_k_matchLen), 0, 0, 1, 1},
    {&__pyx_n_s_matchOnlyAtCol, __pyx_k_matchOnlyAtCol, sizeof(__pyx_k_matchOnlyAtCol), 0, 0, 1, 1},
    {&__pyx_n_u_matchOnlyAtCol, __pyx_k_matchOnlyAtCol, sizeof(__pyx_k_matchOnlyAtCol), 0, 1, 0, 1},
    {&__pyx_n_s_matchOnlyAtCol_locals_verifyCol, __pyx_k_matchOnlyAtCol_locals_verifyCol, sizeof(__pyx_k_matchOnlyAtCol_locals_verifyCol), 0, 0, 1, 1},
    {&__pyx_n_s_matchOrder, __pyx_k_matchOrder, sizeof(__pyx_k_matchOrder), 0, 0, 1, 1},
    {&__pyx_n_s_matchPreviousExpr, __pyx_k_matchPreviousExpr, sizeof(__pyx_k_matchPreviousExpr), 0, 0, 1, 1},
    {&__pyx_n_u_matchPreviousExpr, __pyx_k_matchPreviousExpr, sizeof(__pyx_k_matchPreviousExpr), 0, 1, 0, 1},
    {&__pyx_n_s_matchPreviousExpr_locals_copyTok, __pyx_k_matchPreviousExpr_locals_copyTok, sizeof(__pyx_k_matchPreviousExpr_locals_copyTok), 0, 0, 1, 1},
    {&__pyx_n_s_matchPreviousExpr_locals_copyTok_2, __pyx_k_matchPreviousExpr_locals_copyTok_2, sizeof(__pyx_k_matchPreviousExpr_locals_copyTok_2), 0, 0, 1, 1},
    {&__pyx_n_s_matchPreviousLiteral, __pyx_k_matchPreviousLiteral, sizeof(__pyx_k_matchPreviousLiteral), 0, 0, 1, 1},
    {&__pyx_n_u_matchPreviousLiteral, __pyx_k_matchPreviousLiteral, sizeof(__pyx_k_matchPreviousLiteral), 0, 1, 0, 1},
    {&__pyx_n_s_matchPreviousLiteral_locals_copy, __pyx_k_matchPreviousLiteral_locals_copy, sizeof(__pyx_k_matchPreviousLiteral_locals_copy), 0, 0, 1, 1},
    {&__pyx_n_s_matchPreviousLiteral_locals_copy_2, __pyx_k_matchPreviousLiteral_locals_copy_2, sizeof(__pyx_k_matchPreviousLiteral_locals_copy_2), 0, 0, 1, 1},
    {&__pyx_n_s_matchString, __pyx_k_matchString, sizeof(__pyx_k_matchString), 0, 0, 1, 1},
    {&__pyx_n_s_matchTokens, __pyx_k_matchTokens, sizeof(__pyx_k_matchTokens), 0, 0, 1, 1},
    {&__pyx_n_s_matchWhite, __pyx_k_matchWhite, sizeof(__pyx_k_matchWhite), 0, 0, 1, 1},
    {&__pyx_n_s_match_string, __pyx_k_match_string, sizeof(__pyx_k_match_string), 0, 0, 1, 1},
    {&__pyx_n_s_match_stringloc, __pyx_k_match_stringloc, sizeof(__pyx_k_match_stringloc), 0, 0, 1, 1},
    {&__pyx_kp_u_matched_token_not_at_column_d, __pyx_k_matched_token_not_at_column_d, sizeof(__pyx_k_matched_token_not_at_column_d), 0, 1, 0, 0},
    {&__pyx_n_s_matches, __pyx_k_matches, sizeof(__pyx_k_matches), 0, 0, 1, 1},
    {&__pyx_n_s_max, __pyx_k_max, sizeof(__pyx_k_max), 0, 0, 1, 1},
    {&__pyx_n_s_maxExcLoc, __pyx_k_maxExcLoc, sizeof(__pyx_k_maxExcLoc), 0, 0, 1, 1},
    {&__pyx_n_s_maxException, __pyx_k_maxException, sizeof(__pyx_k_maxException), 0, 0, 1, 1},
    {&__pyx_n_s_maxLen, __pyx_k_maxLen, sizeof(__pyx_k_maxLen), 0, 0, 1, 1},
    {&__pyx_n_s_maxMatches, __pyx_k_maxMatches, sizeof(__pyx_k_maxMatches), 0, 0, 1, 1},
    {&__pyx_n_s_maxMismatches, __pyx_k_maxMismatches, sizeof(__pyx_k_maxMismatches), 0, 0, 1, 1},
    {&__pyx_n_s_maxSpecified, __pyx_k_maxSpecified, sizeof(__pyx_k_maxSpecified), 0, 0, 1, 1},
    {&__pyx_n_s_maxargs, __pyx_k_maxargs, sizeof(__pyx_k_maxargs), 0, 0, 1, 1},
    {&__pyx_n_s_maxint, __pyx_k_maxint, sizeof(__pyx_k_maxint), 0, 0, 1, 1},
    {&__pyx_n_s_maxlen, __pyx_k_maxlen, sizeof(__pyx_k_maxlen), 0, 0, 1, 1},
    {&__pyx_n_s_maxloc, __pyx_k_maxloc, sizeof(__pyx_k_maxloc), 0, 0, 1, 1},
    {&__pyx_n_s_maxsize, __pyx_k_maxsize, sizeof(__pyx_k_maxsize), 0, 0, 1, 1},
    {&__pyx_n_s_maxsplit, __pyx_k_maxsplit, sizeof(__pyx_k_maxsplit), 0, 0, 1, 1},
    {&__pyx_n_s_maxunicode, __pyx_k_maxunicode, sizeof(__pyx_k_maxunicode), 0, 0, 1, 1},
    {&__pyx_n_s_mayIndexError, __pyx_k_mayIndexError, sizeof(__pyx_k_mayIndexError), 0, 0, 1, 1},
    {&__pyx_n_s_mayReturnEmpty, __pyx_k_mayReturnEmpty, sizeof(__pyx_k_mayReturnEmpty), 0, 0, 1, 1},
    {&__pyx_n_s_merged, __pyx_k_merged, sizeof(__pyx_k_merged), 0, 0, 1, 1},
    {&__pyx_n_s_message, __pyx_k_message, sizeof(__pyx_k_message), 0, 0, 1, 1},
    {&__pyx_n_u_message, __pyx_k_message, sizeof(__pyx_k_message), 0, 1, 0, 1},
    {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
    {&__pyx_n_s_methodCall, __pyx_k_methodCall, sizeof(__pyx_k_methodCall), 0, 0, 1, 1},
    {&__pyx_n_s_min, __pyx_k_min, sizeof(__pyx_k_min), 0, 0, 1, 1},
    {&__pyx_n_s_minElements, __pyx_k_minElements, sizeof(__pyx_k_minElements), 0, 0, 1, 1},
    {&__pyx_n_s_minLen, __pyx_k_minLen, sizeof(__pyx_k_minLen), 0, 0, 1, 1},
    {&__pyx_kp_u_mismatches, __pyx_k_mismatches, sizeof(__pyx_k_mismatches), 0, 1, 0, 0},
    {&__pyx_n_s_mismatches_2, __pyx_k_mismatches_2, sizeof(__pyx_k_mismatches_2), 0, 0, 1, 1},
    {&__pyx_n_u_mismatches_2, __pyx_k_mismatches_2, sizeof(__pyx_k_mismatches_2), 0, 1, 0, 1},
    {&__pyx_kp_u_missing, __pyx_k_missing, sizeof(__pyx_k_missing), 0, 1, 0, 0},
    {&__pyx_n_s_missing_2, __pyx_k_missing_2, sizeof(__pyx_k_missing_2), 0, 0, 1, 1},
    {&__pyx_kp_u_mixed_IPv6_address, __pyx_k_mixed_IPv6_address, sizeof(__pyx_k_mixed_IPv6_address), 0, 1, 0, 0},
    {&__pyx_n_s_mixed_integer, __pyx_k_mixed_integer, sizeof(__pyx_k_mixed_integer), 0, 0, 1, 1},
    {&__pyx_n_s_mixed_ipv6_address, __pyx_k_mixed_ipv6_address, sizeof(__pyx_k_mixed_ipv6_address), 0, 0, 1, 1},
    {&__pyx_n_s_modal, __pyx_k_modal, sizeof(__pyx_k_modal), 0, 0, 1, 1},
    {&__pyx_n_s_modalResults, __pyx_k_modalResults, sizeof(__pyx_k_modalResults), 0, 0, 1, 1},
    {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
    {&__pyx_kp_u_module_2, __pyx_k_module_2, sizeof(__pyx_k_module_2), 0, 1, 0, 0},
    {&__pyx_n_s_mro, __pyx_k_mro, sizeof(__pyx_k_mro), 0, 0, 1, 1},
    {&__pyx_n_s_mro_entries, __pyx_k_mro_entries, sizeof(__pyx_k_mro_entries), 0, 0, 1, 1},
    {&__pyx_n_s_msg, __pyx_k_msg, sizeof(__pyx_k_msg), 0, 0, 1, 1},
    {&__pyx_n_u_msg, __pyx_k_msg, sizeof(__pyx_k_msg), 0, 1, 0, 1},
    {&__pyx_n_s_mul, __pyx_k_mul, sizeof(__pyx_k_mul), 0, 0, 1, 1},
    {&__pyx_n_s_multiline, __pyx_k_multiline, sizeof(__pyx_k_multiline), 0, 0, 1, 1},
    {&__pyx_n_s_multioptionals, __pyx_k_multioptionals, sizeof(__pyx_k_multioptionals), 0, 0, 1, 1},
    {&__pyx_n_s_multirequired, __pyx_k_multirequired, sizeof(__pyx_k_multirequired), 0, 0, 1, 1},
    {&__pyx_n_s_mustMatchTheseTokens, __pyx_k_mustMatchTheseTokens, sizeof(__pyx_k_mustMatchTheseTokens), 0, 0, 1, 1},
    {&__pyx_kp_u_must_be, __pyx_k_must_be, sizeof(__pyx_k_must_be), 0, 1, 0, 0},
    {&__pyx_n_s_must_skip, __pyx_k_must_skip, sizeof(__pyx_k_must_skip), 0, 0, 1, 1},
    {&__pyx_n_s_mylen, __pyx_k_mylen, sizeof(__pyx_k_mylen), 0, 0, 1, 1},
    {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
    {&__pyx_kp_u_n_2, __pyx_k_n_2, sizeof(__pyx_k_n_2), 0, 1, 0, 0},
    {&__pyx_kp_u_n_n, __pyx_k_n_n, sizeof(__pyx_k_n_n), 0, 1, 0, 0},
    {&__pyx_kp_u_n_r, __pyx_k_n_r, sizeof(__pyx_k_n_r), 0, 1, 0, 0},
    {&__pyx_kp_u_n_r_x_x_0_9a_fA_F, __pyx_k_n_r_x_x_0_9a_fA_F, sizeof(__pyx_k_n_r_x_x_0_9a_fA_F), 0, 1, 0, 0},
    {&__pyx_kp_u_n_r_x_x_0_9a_fA_F_2, __pyx_k_n_r_x_x_0_9a_fA_F_2, sizeof(__pyx_k_n_r_x_x_0_9a_fA_F_2), 0, 1, 0, 0},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_u_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 1, 0, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_u_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 1, 0, 1},
    {&__pyx_n_s_namedItems, __pyx_k_namedItems, sizeof(__pyx_k_namedItems), 0, 0, 1, 1},
    {&__pyx_n_s_namedItemsOnly, __pyx_k_namedItemsOnly, sizeof(__pyx_k_namedItemsOnly), 0, 0, 1, 1},
    {&__pyx_n_s_namespace, __pyx_k_namespace, sizeof(__pyx_k_namespace), 0, 0, 1, 1},
    {&__pyx_kp_s_namespace_class_for_classes_use, __pyx_k_namespace_class_for_classes_use, sizeof(__pyx_k_namespace_class_for_classes_use), 0, 0, 1, 0},
    {&__pyx_n_s_ne, __pyx_k_ne, sizeof(__pyx_k_ne), 0, 0, 1, 1},
    {&__pyx_n_u_negate, __pyx_k_negate, sizeof(__pyx_k_negate), 0, 1, 0, 1},
    {&__pyx_kp_u_nested, __pyx_k_nested, sizeof(__pyx_k_nested), 0, 1, 0, 0},
    {&__pyx_n_s_nestedExpr, __pyx_k_nestedExpr, sizeof(__pyx_k_nestedExpr), 0, 0, 1, 1},
    {&__pyx_n_u_nestedExpr, __pyx_k_nestedExpr, sizeof(__pyx_k_nestedExpr), 0, 1, 0, 1},
    {&__pyx_n_s_nestedExpr_locals_lambda, __pyx_k_nestedExpr_locals_lambda, sizeof(__pyx_k_nestedExpr_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_n_s_new_loc, __pyx_k_new_loc, sizeof(__pyx_k_new_loc), 0, 0, 1, 1},
    {&__pyx_n_s_newloc, __pyx_k_newloc, sizeof(__pyx_k_newloc), 0, 0, 1, 1},
    {&__pyx_n_s_newself, __pyx_k_newself, sizeof(__pyx_k_newself), 0, 0, 1, 1},
    {&__pyx_n_s_nextCR, __pyx_k_nextCR, sizeof(__pyx_k_nextCR), 0, 0, 1, 1},
    {&__pyx_n_s_nextLevelIndent, __pyx_k_nextLevelIndent, sizeof(__pyx_k_nextLevelIndent), 0, 0, 1, 1},
    {&__pyx_n_s_nextLoc, __pyx_k_nextLoc, sizeof(__pyx_k_nextLoc), 0, 0, 1, 1},
    {&__pyx_n_s_next_linebreak_loc, __pyx_k_next_linebreak_loc, sizeof(__pyx_k_next_linebreak_loc), 0, 0, 1, 1},
    {&__pyx_n_s_nextloc, __pyx_k_nextloc, sizeof(__pyx_k_nextloc), 0, 0, 1, 1},
    {&__pyx_n_s_nl, __pyx_k_nl, sizeof(__pyx_k_nl), 0, 0, 1, 1},
    {&__pyx_kp_u_no_defined_alternatives_to_match, __pyx_k_no_defined_alternatives_to_match, sizeof(__pyx_k_no_defined_alternatives_to_match), 0, 1, 0, 0},
    {&__pyx_kp_u_no_matching_attribute, __pyx_k_no_matching_attribute, sizeof(__pyx_k_no_matching_attribute), 0, 1, 0, 0},
    {&__pyx_kp_u_no_validation_for_r, __pyx_k_no_validation_for_r, sizeof(__pyx_k_no_validation_for_r), 0, 1, 0, 0},
    {&__pyx_n_s_nonzero, __pyx_k_nonzero, sizeof(__pyx_k_nonzero), 0, 0, 1, 1},
    {&__pyx_n_s_notChars, __pyx_k_notChars, sizeof(__pyx_k_notChars), 0, 0, 1, 1},
    {&__pyx_kp_u_not_a_peer_entry, __pyx_k_not_a_peer_entry, sizeof(__pyx_k_not_a_peer_entry), 0, 1, 0, 0},
    {&__pyx_kp_u_not_a_subentry, __pyx_k_not_a_subentry, sizeof(__pyx_k_not_a_subentry), 0, 1, 0, 0},
    {&__pyx_kp_u_not_an_unindent, __pyx_k_not_an_unindent, sizeof(__pyx_k_not_an_unindent), 0, 1, 0, 0},
    {&__pyx_n_s_not_ender, __pyx_k_not_ender, sizeof(__pyx_k_not_ender), 0, 0, 1, 1},
    {&__pyx_n_s_not_in_cache, __pyx_k_not_in_cache, sizeof(__pyx_k_not_in_cache), 0, 0, 1, 1},
    {&__pyx_kp_u_not_preceded_by, __pyx_k_not_preceded_by, sizeof(__pyx_k_not_preceded_by), 0, 1, 0, 0},
    {&__pyx_n_s_notchars, __pyx_k_notchars, sizeof(__pyx_k_notchars), 0, 0, 1, 1},
    {&__pyx_n_s_nullDebugAction, __pyx_k_nullDebugAction, sizeof(__pyx_k_nullDebugAction), 0, 0, 1, 1},
    {&__pyx_n_u_nullDebugAction, __pyx_k_nullDebugAction, sizeof(__pyx_k_nullDebugAction), 0, 1, 0, 1},
    {&__pyx_kp_u_null_string_passed_to_Keyword_us, __pyx_k_null_string_passed_to_Keyword_us, sizeof(__pyx_k_null_string_passed_to_Keyword_us), 0, 1, 0, 0},
    {&__pyx_kp_u_null_string_passed_to_Literal_us, __pyx_k_null_string_passed_to_Literal_us, sizeof(__pyx_k_null_string_passed_to_Literal_us), 0, 1, 0, 0},
    {&__pyx_kp_u_null_string_passed_to_Regex_use, __pyx_k_null_string_passed_to_Regex_use, sizeof(__pyx_k_null_string_passed_to_Regex_use), 0, 1, 0, 0},
    {&__pyx_n_s_number, __pyx_k_number, sizeof(__pyx_k_number), 0, 0, 1, 1},
    {&__pyx_n_s_nums, __pyx_k_nums, sizeof(__pyx_k_nums), 0, 0, 1, 1},
    {&__pyx_n_u_nums, __pyx_k_nums, sizeof(__pyx_k_nums), 0, 1, 0, 1},
    {&__pyx_n_s_o, __pyx_k_o, sizeof(__pyx_k_o), 0, 0, 1, 1},
    {&__pyx_n_s_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 0, 1, 1},
    {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
    {&__pyx_n_s_occurrences, __pyx_k_occurrences, sizeof(__pyx_k_occurrences), 0, 0, 1, 1},
    {&__pyx_n_s_offset, __pyx_k_offset, sizeof(__pyx_k_offset), 0, 0, 1, 1},
    {&__pyx_n_s_on, __pyx_k_on, sizeof(__pyx_k_on), 0, 0, 1, 1},
    {&__pyx_n_s_oneOf, __pyx_k_oneOf, sizeof(__pyx_k_oneOf), 0, 0, 1, 1},
    {&__pyx_n_u_oneOf, __pyx_k_oneOf, sizeof(__pyx_k_oneOf), 0, 1, 0, 1},
    {&__pyx_n_s_oneOf_locals_genexpr, __pyx_k_oneOf_locals_genexpr, sizeof(__pyx_k_oneOf_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_oneOf_locals_lambda, __pyx_k_oneOf_locals_lambda, sizeof(__pyx_k_oneOf_locals_lambda), 0, 0, 1, 1},
    {&__pyx_kp_u_only_1_or_2_index_arguments_supp, __pyx_k_only_1_or_2_index_arguments_supp, sizeof(__pyx_k_only_1_or_2_index_arguments_supp), 0, 1, 0, 0},
    {&__pyx_n_s_opAssoc, __pyx_k_opAssoc, sizeof(__pyx_k_opAssoc), 0, 0, 1, 1},
    {&__pyx_n_u_opAssoc, __pyx_k_opAssoc, sizeof(__pyx_k_opAssoc), 0, 1, 0, 1},
    {&__pyx_n_s_opExpr, __pyx_k_opExpr, sizeof(__pyx_k_opExpr), 0, 0, 1, 1},
    {&__pyx_n_s_opExpr1, __pyx_k_opExpr1, sizeof(__pyx_k_opExpr1), 0, 0, 1, 1},
    {&__pyx_n_s_opExpr2, __pyx_k_opExpr2, sizeof(__pyx_k_opExpr2), 0, 0, 1, 1},
    {&__pyx_n_s_opList, __pyx_k_opList, sizeof(__pyx_k_opList), 0, 0, 1, 1},
    {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
    {&__pyx_n_s_openTag, __pyx_k_openTag, sizeof(__pyx_k_openTag), 0, 0, 1, 1},
    {&__pyx_n_s_opener, __pyx_k_opener, sizeof(__pyx_k_opener), 0, 0, 1, 1},
    {&__pyx_kp_u_opening_and_closing_arguments_mu, __pyx_k_opening_and_closing_arguments_mu, sizeof(__pyx_k_opening_and_closing_arguments_mu), 0, 1, 0, 0},
    {&__pyx_kp_u_opening_and_closing_strings_cann, __pyx_k_opening_and_closing_strings_cann, sizeof(__pyx_k_opening_and_closing_strings_cann), 0, 1, 0, 0},
    {&__pyx_n_s_operDef, __pyx_k_operDef, sizeof(__pyx_k_operDef), 0, 0, 1, 1},
    {&__pyx_n_s_operator, __pyx_k_operator, sizeof(__pyx_k_operator), 0, 0, 1, 1},
    {&__pyx_n_s_operatorPrecedence, __pyx_k_operatorPrecedence, sizeof(__pyx_k_operatorPrecedence), 0, 0, 1, 1},
    {&__pyx_n_u_operatorPrecedence, __pyx_k_operatorPrecedence, sizeof(__pyx_k_operatorPrecedence), 0, 1, 0, 1},
    {&__pyx_kp_u_operator_must_be_unary_1_binary, __pyx_k_operator_must_be_unary_1_binary, sizeof(__pyx_k_operator_must_be_unary_1_binary), 0, 1, 0, 0},
    {&__pyx_kp_u_operator_must_indicate_right_or, __pyx_k_operator_must_indicate_right_or, sizeof(__pyx_k_operator_must_indicate_right_or), 0, 1, 0, 0},
    {&__pyx_n_s_opt1, __pyx_k_opt1, sizeof(__pyx_k_opt1), 0, 0, 1, 1},
    {&__pyx_n_s_opt1map, __pyx_k_opt1map, sizeof(__pyx_k_opt1map), 0, 0, 1, 1},
    {&__pyx_n_s_opt2, __pyx_k_opt2, sizeof(__pyx_k_opt2), 0, 0, 1, 1},
    {&__pyx_n_s_optElements, __pyx_k_optElements, sizeof(__pyx_k_optElements), 0, 0, 1, 1},
    {&__pyx_n_s_optionals, __pyx_k_optionals, sizeof(__pyx_k_optionals), 0, 0, 1, 1},
    {&__pyx_n_s_or, __pyx_k_or, sizeof(__pyx_k_or), 0, 0, 1, 1},
    {&__pyx_n_s_ordereddict, __pyx_k_ordereddict, sizeof(__pyx_k_ordereddict), 0, 0, 1, 1},
    {&__pyx_n_u_original, __pyx_k_original, sizeof(__pyx_k_original), 0, 1, 0, 1},
    {&__pyx_n_s_originalParseMethod, __pyx_k_originalParseMethod, sizeof(__pyx_k_originalParseMethod), 0, 0, 1, 1},
    {&__pyx_n_u_originalParseMethod, __pyx_k_originalParseMethod, sizeof(__pyx_k_originalParseMethod), 0, 1, 0, 1},
    {&__pyx_n_s_originalTextFor, __pyx_k_originalTextFor, sizeof(__pyx_k_originalTextFor), 0, 0, 1, 1},
    {&__pyx_n_u_originalTextFor, __pyx_k_originalTextFor, sizeof(__pyx_k_originalTextFor), 0, 1, 0, 1},
    {&__pyx_n_s_originalTextFor_locals_extractTe, __pyx_k_originalTextFor_locals_extractTe, sizeof(__pyx_k_originalTextFor_locals_extractTe), 0, 0, 1, 1},
    {&__pyx_n_s_originalTextFor_locals_lambda, __pyx_k_originalTextFor_locals_lambda, sizeof(__pyx_k_originalTextFor_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_original_end, __pyx_k_original_end, sizeof(__pyx_k_original_end), 0, 0, 1, 1},
    {&__pyx_n_u_original_end, __pyx_k_original_end, sizeof(__pyx_k_original_end), 0, 1, 0, 1},
    {&__pyx_n_s_original_start, __pyx_k_original_start, sizeof(__pyx_k_original_start), 0, 0, 1, 1},
    {&__pyx_n_u_original_start, __pyx_k_original_start, sizeof(__pyx_k_original_start), 0, 1, 0, 1},
    {&__pyx_n_s_os_path, __pyx_k_os_path, sizeof(__pyx_k_os_path), 0, 0, 1, 1},
    {&__pyx_n_s_other, __pyx_k_other, sizeof(__pyx_k_other), 0, 0, 1, 1},
    {&__pyx_n_s_other_instring, __pyx_k_other_instring, sizeof(__pyx_k_other_instring), 0, 0, 1, 1},
    {&__pyx_n_s_otherdictitems, __pyx_k_otherdictitems, sizeof(__pyx_k_otherdictitems), 0, 0, 1, 1},
    {&__pyx_n_s_otheritems, __pyx_k_otheritems, sizeof(__pyx_k_otheritems), 0, 0, 1, 1},
    {&__pyx_n_s_out, __pyx_k_out, sizeof(__pyx_k_out), 0, 0, 1, 1},
    {&__pyx_n_s_outer_parent_usefullness_obj, __pyx_k_outer_parent_usefullness_obj, sizeof(__pyx_k_outer_parent_usefullness_obj), 0, 0, 1, 1},
    {&__pyx_n_s_overlap, __pyx_k_overlap, sizeof(__pyx_k_overlap), 0, 0, 1, 1},
    {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
    {&__pyx_n_s_p1, __pyx_k_p1, sizeof(__pyx_k_p1), 0, 0, 1, 1},
    {&__pyx_n_s_p2, __pyx_k_p2, sizeof(__pyx_k_p2), 0, 0, 1, 1},
    {&__pyx_n_s_pa, __pyx_k_pa, sizeof(__pyx_k_pa), 0, 0, 1, 1},
    {&__pyx_n_s_paArgs, __pyx_k_paArgs, sizeof(__pyx_k_paArgs), 0, 0, 1, 1},
    {&__pyx_n_s_pa_call_line_synth, __pyx_k_pa_call_line_synth, sizeof(__pyx_k_pa_call_line_synth), 0, 0, 1, 1},
    {&__pyx_n_s_packratEnabled, __pyx_k_packratEnabled, sizeof(__pyx_k_packratEnabled), 0, 0, 1, 1},
    {&__pyx_n_s_packrat_cache, __pyx_k_packrat_cache, sizeof(__pyx_k_packrat_cache), 0, 0, 1, 1},
    {&__pyx_n_s_packrat_cache_lock, __pyx_k_packrat_cache_lock, sizeof(__pyx_k_packrat_cache_lock), 0, 0, 1, 1},
    {&__pyx_n_s_packrat_cache_stats, __pyx_k_packrat_cache_stats, sizeof(__pyx_k_packrat_cache_stats), 0, 0, 1, 1},
    {&__pyx_n_s_packrat_context, __pyx_k_packrat_context, sizeof(__pyx_k_packrat_context), 0, 0, 1, 1},
    {&__pyx_n_u_packrat_enabled, __pyx_k_packrat_enabled, sizeof(__pyx_k_packrat_enabled), 0, 1, 0, 1},
    {&__pyx_n_u_packrat_parse, __pyx_k_packrat_parse, sizeof(__pyx_k_packrat_parse), 0, 1, 0, 1},
    {&__pyx_n_s_par, __pyx_k_par, sizeof(__pyx_k_par), 0, 0, 1, 1},
    {&__pyx_n_s_parse, __pyx_k_parse, sizeof(__pyx_k_parse), 0, 0, 1, 1},
    {&__pyx_n_s_parseAction, __pyx_k_parseAction, sizeof(__pyx_k_parseAction), 0, 0, 1, 1},
    {&__pyx_n_s_parseAll, __pyx_k_parseAll, sizeof(__pyx_k_parseAll), 0, 0, 1, 1},
    {&__pyx_n_s_parseCache, __pyx_k_parseCache, sizeof(__pyx_k_parseCache), 0, 0, 1, 1},
    {&__pyx_n_s_parseElementClass, __pyx_k_parseElementClass, sizeof(__pyx_k_parseElementClass), 0, 0, 1, 1},
    {&__pyx_n_s_parseElementList, __pyx_k_parseElementList, sizeof(__pyx_k_parseElementList), 0, 0, 1, 1},
    {&__pyx_n_s_parseElementTrace, __pyx_k_parseElementTrace, sizeof(__pyx_k_parseElementTrace), 0, 0, 1, 1},
    {&__pyx_n_s_parseFile, __pyx_k_parseFile, sizeof(__pyx_k_parseFile), 0, 0, 1, 1},
    {&__pyx_n_s_parseFn, __pyx_k_parseFn, sizeof(__pyx_k_parseFn), 0, 0, 1, 1},
    {&__pyx_n_s_parseImpl, __pyx_k_parseImpl, sizeof(__pyx_k_parseImpl), 0, 0, 1, 1},
    {&__pyx_n_u_parseImpl, __pyx_k_parseImpl, sizeof(__pyx_k_parseImpl), 0, 1, 0, 1},
    {&__pyx_n_s_parseImplAsGroupList, __pyx_k_parseImplAsGroupList, sizeof(__pyx_k_parseImplAsGroupList), 0, 0, 1, 1},
    {&__pyx_n_s_parseImplAsMatch, __pyx_k_parseImplAsMatch, sizeof(__pyx_k_parseImplAsMatch), 0, 0, 1, 1},
    {&__pyx_n_s_parseIncremental, __pyx_k_parseIncremental, sizeof(__pyx_k_parseIncremental), 0, 0, 1, 1},
    {&__pyx_n_s_parseMethod, __pyx_k_parseMethod, sizeof(__pyx_k_parseMethod), 0, 0, 1, 1},
    {&__pyx_n_s_parseNoCache, __pyx_k_parseNoCache, sizeof(__pyx_k_parseNoCache), 0, 0, 1, 1},
    {&__pyx_n_u_parseNoCache, __pyx_k_parseNoCache, sizeof(__pyx_k_parseNoCache), 0, 1, 0, 1},
    {&__pyx_n_s_parseString, __pyx_k_parseString, sizeof(__pyx_k_parseString), 0, 0, 1, 1},
    {&__pyx_n_s_parseWithTabs, __pyx_k_parseWithTabs, sizeof(__pyx_k_parseWithTabs), 0, 0, 1, 1},
    {&__pyx_kp_u_parse_action, __pyx_k_parse_action, sizeof(__pyx_k_parse_action), 0, 1, 0, 0},
    {&__pyx_n_s_parse_action_exc, __pyx_k_parse_action_exc, sizeof(__pyx_k_parse_action_exc), 0, 0, 1, 1},
    {&__pyx_kp_u_parse_actions_must_be_callable, __pyx_k_parse_actions_must_be_callable, sizeof(__pyx_k_parse_actions_must_be_callable), 0, 1, 0, 0},
    {&__pyx_n_s_parse_element_index, __pyx_k_parse_element_index, sizeof(__pyx_k_parse_element_index), 0, 0, 1, 1},
    {&__pyx_n_s_parserElement, __pyx_k_parserElement, sizeof(__pyx_k_parserElement), 0, 0, 1, 1},
    {&__pyx_n_u_parserElement, __pyx_k_parserElement, sizeof(__pyx_k_parserElement), 0, 1, 0, 1},
    {&__pyx_n_s_pattern, __pyx_k_pattern, sizeof(__pyx_k_pattern), 0, 0, 1, 1},
    {&__pyx_n_u_pattern, __pyx_k_pattern, sizeof(__pyx_k_pattern), 0, 1, 0, 1},
    {&__pyx_n_s_pbe, __pyx_k_pbe, sizeof(__pyx_k_pbe), 0, 0, 1, 1},
    {&__pyx_n_s_pdb, __pyx_k_pdb, sizeof(__pyx_k_pdb), 0, 0, 1, 1},
    {&__pyx_n_s_pe, __pyx_k_pe, sizeof(__pyx_k_pe), 0, 0, 1, 1},
    {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
    {&__pyx_kp_u_pop_got_an_unexpected_keyword_ar, __pyx_k_pop_got_an_unexpected_keyword_ar, sizeof(__pyx_k_pop_got_an_unexpected_keyword_ar), 0, 1, 0, 0},
    {&__pyx_n_s_popitem, __pyx_k_popitem, sizeof(__pyx_k_popitem), 0, 0, 1, 1},
    {&__pyx_n_s_popleft, __pyx_k_popleft, sizeof(__pyx_k_popleft), 0, 0, 1, 1},
    {&__pyx_n_s_position, __pyx_k_position, sizeof(__pyx_k_position), 0, 0, 1, 1},
    {&__pyx_n_s_postParse, __pyx_k_postParse, sizeof(__pyx_k_postParse), 0, 0, 1, 1},
    {&__pyx_n_s_pp_value, __pyx_k_pp_value, sizeof(__pyx_k_pp_value), 0, 0, 1, 1},
    {&__pyx_n_s_pprint, __pyx_k_pprint, sizeof(__pyx_k_pprint), 0, 0, 1, 1},
    {&__pyx_n_s_preParse, __pyx_k_preParse, sizeof(__pyx_k_preParse), 0, 0, 1, 1},
    {&__pyx_n_s_prefix_len, __pyx_k_prefix_len, sizeof(__pyx_k_prefix_len), 0, 0, 1, 1},
    {&__pyx_n_s_prefix_lookup, __pyx_k_prefix_lookup, sizeof(__pyx_k_prefix_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_prefixes_and_suffixes, __pyx_k_prefixes_and_suffixes, sizeof(__pyx_k_prefixes_and_suffixes), 0, 0, 1, 1},
    {&__pyx_n_s_preloc, __pyx_k_preloc, sizeof(__pyx_k_preloc), 0, 0, 1, 1},
    {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
    {&__pyx_n_s_preparseFn, __pyx_k_preparseFn, sizeof(__pyx_k_preparseFn), 0, 0, 1, 1},
    {&__pyx_kp_u_prev, __pyx_k_prev, sizeof(__pyx_k_prev), 0, 1, 0, 0},
    {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
    {&__pyx_n_s_printResults, __pyx_k_printResults, sizeof(__pyx_k_printResults), 0, 0, 1, 1},
    {&__pyx_n_s_print_2, __pyx_k_print_2, sizeof(__pyx_k_print_2), 0, 0, 1, 1},
    {&__pyx_n_s_printable, __pyx_k_printable, sizeof(__pyx_k_printable), 0, 0, 1, 1},
    {&__pyx_n_s_printables, __pyx_k_printables, sizeof(__pyx_k_printables), 0, 0, 1, 1},
    {&__pyx_n_u_printables, __pyx_k_printables, sizeof(__pyx_k_printables), 0, 1, 0, 1},
    {&__pyx_n_s_pstr, __pyx_k_pstr, sizeof(__pyx_k_pstr), 0, 0, 1, 1},
    {&__pyx_n_u_pstr, __pyx_k_pstr, sizeof(__pyx_k_pstr), 0, 1, 0, 1},
    {&__pyx_n_s_punc8bit, __pyx_k_punc8bit, sizeof(__pyx_k_punc8bit), 0, 0, 1, 1},
    {&__pyx_n_u_punc8bit, __pyx_k_punc8bit, sizeof(__pyx_k_punc8bit), 0, 1, 0, 1},
    {&__pyx_n_s_py_repr, __pyx_k_py_repr, sizeof(__pyx_k_py_repr), 0, 0, 1, 1},
    {&__pyx_n_s_py_str, __pyx_k_py_str, sizeof(__pyx_k_py_str), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_common, __pyx_k_pyparsing_common, sizeof(__pyx_k_pyparsing_common), 0, 0, 1, 1},
    {&__pyx_n_u_pyparsing_common, __pyx_k_pyparsing_common, sizeof(__pyx_k_pyparsing_common), 0, 1, 0, 1},
    {&__pyx_n_s_pyparsing_common_convertToDate, __pyx_k_pyparsing_common_convertToDate, sizeof(__pyx_k_pyparsing_common_convertToDate), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_common_convertToDate_l, __pyx_k_pyparsing_common_convertToDate_l, sizeof(__pyx_k_pyparsing_common_convertToDate_l), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_common_convertToDateti, __pyx_k_pyparsing_common_convertToDateti, sizeof(__pyx_k_pyparsing_common_convertToDateti), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_common_convertToDateti_2, __pyx_k_pyparsing_common_convertToDateti_2, sizeof(__pyx_k_pyparsing_common_convertToDateti_2), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_common_lambda, __pyx_k_pyparsing_common_lambda, sizeof(__pyx_k_pyparsing_common_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_common_lambda_locals_g, __pyx_k_pyparsing_common_lambda_locals_g, sizeof(__pyx_k_pyparsing_common_lambda_locals_g), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_common_stripHTMLTags, __pyx_k_pyparsing_common_stripHTMLTags, sizeof(__pyx_k_pyparsing_common_stripHTMLTags), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test, __pyx_k_pyparsing_test, sizeof(__pyx_k_pyparsing_test), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_TestParseResultsA, __pyx_k_pyparsing_test_TestParseResultsA, sizeof(__pyx_k_pyparsing_test_TestParseResultsA), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_TestParseResultsA_2, __pyx_k_pyparsing_test_TestParseResultsA_2, sizeof(__pyx_k_pyparsing_test_TestParseResultsA_2), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_TestParseResultsA_3, __pyx_k_pyparsing_test_TestParseResultsA_3, sizeof(__pyx_k_pyparsing_test_TestParseResultsA_3), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_TestParseResultsA_4, __pyx_k_pyparsing_test_TestParseResultsA_4, sizeof(__pyx_k_pyparsing_test_TestParseResultsA_4), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_TestParseResultsA_5, __pyx_k_pyparsing_test_TestParseResultsA_5, sizeof(__pyx_k_pyparsing_test_TestParseResultsA_5), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_TestParseResultsA_6, __pyx_k_pyparsing_test_TestParseResultsA_6, sizeof(__pyx_k_pyparsing_test_TestParseResultsA_6), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_TestParseResultsA_7, __pyx_k_pyparsing_test_TestParseResultsA_7, sizeof(__pyx_k_pyparsing_test_TestParseResultsA_7), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_reset_pyparsing_c, __pyx_k_pyparsing_test_reset_pyparsing_c, sizeof(__pyx_k_pyparsing_test_reset_pyparsing_c), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_reset_pyparsing_c_2, __pyx_k_pyparsing_test_reset_pyparsing_c_2, sizeof(__pyx_k_pyparsing_test_reset_pyparsing_c_2), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_reset_pyparsing_c_3, __pyx_k_pyparsing_test_reset_pyparsing_c_3, sizeof(__pyx_k_pyparsing_test_reset_pyparsing_c_3), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_reset_pyparsing_c_4, __pyx_k_pyparsing_test_reset_pyparsing_c_4, sizeof(__pyx_k_pyparsing_test_reset_pyparsing_c_4), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_reset_pyparsing_c_5, __pyx_k_pyparsing_test_reset_pyparsing_c_5, sizeof(__pyx_k_pyparsing_test_reset_pyparsing_c_5), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_test_reset_pyparsing_c_6, __pyx_k_pyparsing_test_reset_pyparsing_c_6, sizeof(__pyx_k_pyparsing_test_reset_pyparsing_c_6), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode, __pyx_k_pyparsing_unicode, sizeof(__pyx_k_pyparsing_unicode), 0, 0, 1, 1},
    {&__pyx_n_u_pyparsing_unicode, __pyx_k_pyparsing_unicode, sizeof(__pyx_k_pyparsing_unicode), 0, 1, 0, 1},
    {&__pyx_n_s_pyparsing_unicode_Arabic, __pyx_k_pyparsing_unicode_Arabic, sizeof(__pyx_k_pyparsing_unicode_Arabic), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_CJK, __pyx_k_pyparsing_unicode_CJK, sizeof(__pyx_k_pyparsing_unicode_CJK), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Chinese, __pyx_k_pyparsing_unicode_Chinese, sizeof(__pyx_k_pyparsing_unicode_Chinese), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Cyrillic, __pyx_k_pyparsing_unicode_Cyrillic, sizeof(__pyx_k_pyparsing_unicode_Cyrillic), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Devanagari, __pyx_k_pyparsing_unicode_Devanagari, sizeof(__pyx_k_pyparsing_unicode_Devanagari), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Greek, __pyx_k_pyparsing_unicode_Greek, sizeof(__pyx_k_pyparsing_unicode_Greek), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Hebrew, __pyx_k_pyparsing_unicode_Hebrew, sizeof(__pyx_k_pyparsing_unicode_Hebrew), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Japanese, __pyx_k_pyparsing_unicode_Japanese, sizeof(__pyx_k_pyparsing_unicode_Japanese), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Japanese_Hirag, __pyx_k_pyparsing_unicode_Japanese_Hirag, sizeof(__pyx_k_pyparsing_unicode_Japanese_Hirag), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Japanese_Kanji, __pyx_k_pyparsing_unicode_Japanese_Kanji, sizeof(__pyx_k_pyparsing_unicode_Japanese_Kanji), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Japanese_Katak, __pyx_k_pyparsing_unicode_Japanese_Katak, sizeof(__pyx_k_pyparsing_unicode_Japanese_Katak), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Korean, __pyx_k_pyparsing_unicode_Korean, sizeof(__pyx_k_pyparsing_unicode_Korean), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Latin1, __pyx_k_pyparsing_unicode_Latin1, sizeof(__pyx_k_pyparsing_unicode_Latin1), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_LatinA, __pyx_k_pyparsing_unicode_LatinA, sizeof(__pyx_k_pyparsing_unicode_LatinA), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_LatinB, __pyx_k_pyparsing_unicode_LatinB, sizeof(__pyx_k_pyparsing_unicode_LatinB), 0, 0, 1, 1},
    {&__pyx_n_s_pyparsing_unicode_Thai, __pyx_k_pyparsing_unicode_Thai, sizeof(__pyx_k_pyparsing_unicode_Thai), 0, 0, 1, 1},
    {&__pyx_n_s_pythonStyleComment, __pyx_k_pythonStyleComment, sizeof(__pyx_k_pythonStyleComment), 0, 0, 1, 1},
    {&__pyx_n_u_pythonStyleComment, __pyx_k_pythonStyleComment, sizeof(__pyx_k_pythonStyleComment), 0, 1, 0, 1},
    {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
    {&__pyx_n_s_quoteChar, __pyx_k_quoteChar, sizeof(__pyx_k_quoteChar), 0, 0, 1, 1},
    {&__pyx_n_s_quoteCharLen, __pyx_k_quoteCharLen, sizeof(__pyx_k_quoteCharLen), 0, 0, 1, 1},
    {&__pyx_kp_u_quoteChar_cannot_be_the_empty_st, __pyx_k_quoteChar_cannot_be_the_empty_st, sizeof(__pyx_k_quoteChar_cannot_be_the_empty_st), 0, 1, 0, 0},
    {&__pyx_n_s_quotedString, __pyx_k_quotedString, sizeof(__pyx_k_quotedString), 0, 0, 1, 1},
    {&__pyx_n_u_quotedString, __pyx_k_quotedString, sizeof(__pyx_k_quotedString), 0, 1, 0, 1},
    {&__pyx_kp_u_quotedString_using_single_or_dou, __pyx_k_quotedString_using_single_or_dou, sizeof(__pyx_k_quotedString_using_single_or_dou), 0, 1, 0, 0},
    {&__pyx_kp_u_quoted_string_starting_with, __pyx_k_quoted_string_starting_with, sizeof(__pyx_k_quoted_string_starting_with), 0, 1, 0, 0},
    {&__pyx_n_u_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 1, 0, 1},
    {&__pyx_kp_u_r_2, __pyx_k_r_2, sizeof(__pyx_k_r_2), 0, 1, 0, 0},
    {&__pyx_kp_u_r_object_is_not_iterable, __pyx_k_r_object_is_not_iterable, sizeof(__pyx_k_r_object_is_not_iterable), 0, 1, 0, 0},
    {&__pyx_n_s_radd, __pyx_k_radd, sizeof(__pyx_k_radd), 0, 0, 1, 1},
    {&__pyx_n_s_rand, __pyx_k_rand, sizeof(__pyx_k_rand), 0, 0, 1, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_ranges, __pyx_k_ranges, sizeof(__pyx_k_ranges), 0, 0, 1, 1},
    {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
    {&__pyx_n_u_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 1, 0, 1},
    {&__pyx_n_s_reBracketExpr, __pyx_k_reBracketExpr, sizeof(__pyx_k_reBracketExpr), 0, 0, 1, 1},
    {&__pyx_n_s_reString, __pyx_k_reString, sizeof(__pyx_k_reString), 0, 0, 1, 1},
    {&__pyx_n_s_re_match, __pyx_k_re_match, sizeof(__pyx_k_re_match), 0, 0, 1, 1},
    {&__pyx_n_s_read, __pyx_k_read, sizeof(__pyx_k_read), 0, 0, 1, 1},
    {&__pyx_n_s_real, __pyx_k_real, sizeof(__pyx_k_real), 0, 0, 1, 1},
    {&__pyx_kp_u_real_number, __pyx_k_real_number, sizeof(__pyx_k_real_number), 0, 1, 0, 0},
    {&__pyx_kp_u_real_number_with_scientific_nota, __pyx_k_real_number_with_scientific_nota, sizeof(__pyx_k_real_number_with_scientific_nota), 0, 1, 0, 0},
    {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_ref, __pyx_k_ref, sizeof(__pyx_k_ref), 0, 0, 1, 1},
    {&__pyx_n_s_register, __pyx_k_register, sizeof(__pyx_k_register), 0, 0, 1, 1},
    {&__pyx_n_s_remove, __pyx_k_remove, sizeof(__pyx_k_remove), 0, 0, 1, 1},
    {&__pyx_n_s_removeQuotes, __pyx_k_removeQuotes, sizeof(__pyx_k_removeQuotes), 0, 0, 1, 1},
    {&__pyx_n_u_removeQuotes, __pyx_k_removeQuotes, sizeof(__pyx_k_removeQuotes), 0, 1, 0, 1},
    {&__pyx_n_s_removed, __pyx_k_removed, sizeof(__pyx_k_removed), 0, 0, 1, 1},
    {&__pyx_n_s_rep, __pyx_k_rep, sizeof(__pyx_k_rep), 0, 0, 1, 1},
    {&__pyx_n_s_repl, __pyx_k_repl, sizeof(__pyx_k_repl), 0, 0, 1, 1},
    {&__pyx_n_s_replStr, __pyx_k_replStr, sizeof(__pyx_k_replStr), 0, 0, 1, 1},
    {&__pyx_n_s_replace, __pyx_k_replace, sizeof(__pyx_k_replace), 0, 0, 1, 1},
    {&__pyx_n_s_replaceHTMLEntity, __pyx_k_replaceHTMLEntity, sizeof(__pyx_k_replaceHTMLEntity), 0, 0, 1, 1},
    {&__pyx_n_u_replaceHTMLEntity, __pyx_k_replaceHTMLEntity, sizeof(__pyx_k_replaceHTMLEntity), 0, 1, 0, 1},
    {&__pyx_n_s_replaceWith, __pyx_k_replaceWith, sizeof(__pyx_k_replaceWith), 0, 0, 1, 1},
    {&__pyx_n_u_replaceWith, __pyx_k_replaceWith, sizeof(__pyx_k_replaceWith), 0, 1, 0, 1},
    {&__pyx_n_s_replaceWith_locals_lambda, __pyx_k_replaceWith_locals_lambda, sizeof(__pyx_k_replaceWith_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_repr, __pyx_k_repr, sizeof(__pyx_k_repr), 0, 0, 1, 1},
    {&__pyx_n_s_repr_2, __pyx_k_repr_2, sizeof(__pyx_k_repr_2), 0, 0, 1, 1},
    {&__pyx_n_s_req, __pyx_k_req, sizeof(__pyx_k_req), 0, 0, 1, 1},
    {&__pyx_n_s_required, __pyx_k_required, sizeof(__pyx_k_required), 0, 0, 1, 1},
    {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
    {&__pyx_n_s_resTag, __pyx_k_resTag, sizeof(__pyx_k_resTag), 0, 0, 1, 1},
    {&__pyx_n_s_reset, __pyx_k_reset, sizeof(__pyx_k_reset), 0, 0, 1, 1},
    {&__pyx_n_s_resetCache, __pyx_k_resetCache, sizeof(__pyx_k_resetCache), 0, 0, 1, 1},
    {&__pyx_n_s_reset_pyparsing_context, __pyx_k_reset_pyparsing_context, sizeof(__pyx_k_reset_pyparsing_context), 0, 0, 1, 1},
    {&__pyx_n_s_reset_stack, __pyx_k_reset_stack, sizeof(__pyx_k_reset_stack), 0, 0, 1, 1},
    {&__pyx_n_s_resname, __pyx_k_resname, sizeof(__pyx_k_resname), 0, 0, 1, 1},
    {&__pyx_n_s_restOfLine, __pyx_k_restOfLine, sizeof(__pyx_k_restOfLine), 0, 0, 1, 1},
    {&__pyx_n_u_restOfLine, __pyx_k_restOfLine, sizeof(__pyx_k_restOfLine), 0, 1, 0, 1},
    {&__pyx_kp_u_rest_of_line, __pyx_k_rest_of_line, sizeof(__pyx_k_rest_of_line), 0, 1, 0, 0},
    {&__pyx_n_s_restore, __pyx_k_restore, sizeof(__pyx_k_restore), 0, 0, 1, 1},
    {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
    {&__pyx_n_s_resultlist, __pyx_k_resultlist, sizeof(__pyx_k_resultlist), 0, 0, 1, 1},
    {&__pyx_n_s_results, __pyx_k_results, sizeof(__pyx_k_results), 0, 0, 1, 1},
    {&__pyx_n_s_resultsName, __pyx_k_resultsName, sizeof(__pyx_k_resultsName), 0, 0, 1, 1},
    {&__pyx_n_s_ret, __pyx_k_ret, sizeof(__pyx_k_ret), 0, 0, 1, 1},
    {&__pyx_n_s_retTokens, __pyx_k_retTokens, sizeof(__pyx_k_retTokens), 0, 0, 1, 1},
    {&__pyx_n_s_retToks, __pyx_k_retToks, sizeof(__pyx_k_retToks), 0, 0, 1, 1},
    {&__pyx_kp_u_ret_2, __pyx_k_ret_2, sizeof(__pyx_k_ret_2), 0, 1, 0, 0},
    {&__pyx_n_s_ret_toks, __pyx_k_ret_toks, sizeof(__pyx_k_ret_toks), 0, 0, 1, 1},
    {&__pyx_n_s_retobj, __pyx_k_retobj, sizeof(__pyx_k_retobj), 0, 0, 1, 1},
    {&__pyx_n_s_retreat, __pyx_k_retreat, sizeof(__pyx_k_retreat), 0, 0, 1, 1},
    {&__pyx_n_s_returnString, __pyx_k_returnString, sizeof(__pyx_k_returnString), 0, 0, 1, 1},
    {&__pyx_n_s_reverse, __pyx_k_reverse, sizeof(__pyx_k_reverse), 0, 0, 1, 1},
    {&__pyx_n_s_reversed, __pyx_k_reversed, sizeof(__pyx_k_reversed), 0, 0, 1, 1},
    {&__pyx_n_s_reversed_2, __pyx_k_reversed_2, sizeof(__pyx_k_reversed_2), 0, 0, 1, 1},
    {&__pyx_n_s_reversed_instring, __pyx_k_reversed_instring, sizeof(__pyx_k_reversed_instring), 0, 0, 1, 1},
    {&__pyx_n_s_rfind, __pyx_k_rfind, sizeof(__pyx_k_rfind), 0, 0, 1, 1},
    {&__pyx_n_s_rightLeftAssoc, __pyx_k_rightLeftAssoc, sizeof(__pyx_k_rightLeftAssoc), 0, 0, 1, 1},
    {&__pyx_n_s_rmul, __pyx_k_rmul, sizeof(__pyx_k_rmul), 0, 0, 1, 1},
    {&__pyx_n_s_rne, __pyx_k_rne, sizeof(__pyx_k_rne), 0, 0, 1, 1},
    {&__pyx_n_s_ror, __pyx_k_ror, sizeof(__pyx_k_ror), 0, 0, 1, 1},
    {&__pyx_n_s_rpar, __pyx_k_rpar, sizeof(__pyx_k_rpar), 0, 0, 1, 1},
    {&__pyx_n_s_rpt, __pyx_k_rpt, sizeof(__pyx_k_rpt), 0, 0, 1, 1},
    {&__pyx_n_s_rr, __pyx_k_rr, sizeof(__pyx_k_rr), 0, 0, 1, 1},
    {&__pyx_n_s_rstrip, __pyx_k_rstrip, sizeof(__pyx_k_rstrip), 0, 0, 1, 1},
    {&__pyx_n_s_rsub, __pyx_k_rsub, sizeof(__pyx_k_rsub), 0, 0, 1, 1},
    {&__pyx_n_s_runTests, __pyx_k_runTests, sizeof(__pyx_k_runTests), 0, 0, 1, 1},
    {&__pyx_n_s_run_test_results, __pyx_k_run_test_results, sizeof(__pyx_k_run_test_results), 0, 0, 1, 1},
    {&__pyx_n_s_run_test_success, __pyx_k_run_test_success, sizeof(__pyx_k_run_test_success), 0, 0, 1, 1},
    {&__pyx_n_s_run_tests_report, __pyx_k_run_tests_report, sizeof(__pyx_k_run_tests_report), 0, 0, 1, 1},
    {&__pyx_n_s_rxor, __pyx_k_rxor, sizeof(__pyx_k_rxor), 0, 0, 1, 1},
    {&__pyx_n_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 1},
    {&__pyx_kp_u_s_10, __pyx_k_s_10, sizeof(__pyx_k_s_10), 0, 1, 0, 0},
    {&__pyx_kp_u_s_2, __pyx_k_s_2, sizeof(__pyx_k_s_2), 0, 1, 0, 0},
    {&__pyx_kp_u_s_3, __pyx_k_s_3, sizeof(__pyx_k_s_3), 0, 1, 0, 0},
    {&__pyx_kp_u_s_4, __pyx_k_s_4, sizeof(__pyx_k_s_4), 0, 1, 0, 0},
    {&__pyx_kp_u_s_5, __pyx_k_s_5, sizeof(__pyx_k_s_5), 0, 1, 0, 0},
    {&__pyx_kp_u_s_6, __pyx_k_s_6, sizeof(__pyx_k_s_6), 0, 1, 0, 0},
    {&__pyx_kp_u_s_7, __pyx_k_s_7, sizeof(__pyx_k_s_7), 0, 1, 0, 0},
    {&__pyx_kp_u_s_8, __pyx_k_s_8, sizeof(__pyx_k_s_8), 0, 1, 0, 0},
    {&__pyx_kp_u_s_9, __pyx_k_s_9, sizeof(__pyx_k_s_9), 0, 1, 0, 0},
    {&__pyx_kp_u_s_S, __pyx_k_s_S, sizeof(__pyx_k_s_S), 0, 1, 0, 0},
    {&__pyx_kp_u_s_class, __pyx_k_s_class, sizeof(__pyx_k_s_class), 0, 1, 0, 0},
    {&__pyx_n_s_s_m, __pyx_k_s_m, sizeof(__pyx_k_s_m), 0, 0, 1, 1},
    {&__pyx_n_s_s_pl_sl, __pyx_k_s_pl_sl, sizeof(__pyx_k_s_pl_sl), 0, 0, 1, 1},
    {&__pyx_kp_u_s_s_term, __pyx_k_s_s_term, sizeof(__pyx_k_s_s_term), 0, 1, 0, 0},
    {&__pyx_kp_u_s_term, __pyx_k_s_term, sizeof(__pyx_k_s_term), 0, 1, 0, 0},
    {&__pyx_n_s_save, __pyx_k_save, sizeof(__pyx_k_save), 0, 0, 1, 1},
    {&__pyx_n_s_saveAsList, __pyx_k_saveAsList, sizeof(__pyx_k_saveAsList), 0, 0, 1, 1},
    {&__pyx_n_s_save_context, __pyx_k_save_context, sizeof(__pyx_k_save_context), 0, 0, 1, 1},
    {&__pyx_n_s_savelist, __pyx_k_savelist, sizeof(__pyx_k_savelist), 0, 0, 1, 1},
    {&__pyx_n_s_scanString, __pyx_k_scanString, sizeof(__pyx_k_scanString), 0, 0, 1, 1},
    {&__pyx_n_s_sci_real, __pyx_k_sci_real, sizeof(__pyx_k_sci_real), 0, 0, 1, 1},
    {&__pyx_n_s_se, __pyx_k_se, sizeof(__pyx_k_se), 0, 0, 1, 1},
    {&__pyx_n_s_searchString, __pyx_k_searchString, sizeof(__pyx_k_searchString), 0, 0, 1, 1},
    {&__pyx_kp_u_second_tuple_value_must_be_great, __pyx_k_second_tuple_value_must_be_great, sizeof(__pyx_k_second_tuple_value_must_be_great), 0, 1, 0, 0},
    {&__pyx_n_s_seen, __pyx_k_seen, sizeof(__pyx_k_seen), 0, 0, 1, 1},
    {&__pyx_n_u_select, __pyx_k_select, sizeof(__pyx_k_select), 0, 1, 0, 1},
    {&__pyx_n_s_selectToken, __pyx_k_selectToken, sizeof(__pyx_k_selectToken), 0, 0, 1, 1},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_n_u_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 1, 0, 1},
    {&__pyx_n_s_selfTag, __pyx_k_selfTag, sizeof(__pyx_k_selfTag), 0, 0, 1, 1},
    {&__pyx_n_s_self_expr_parse, __pyx_k_self_expr_parse, sizeof(__pyx_k_self_expr_parse), 0, 0, 1, 1},
    {&__pyx_n_s_self_failOn_canParseNext, __pyx_k_self_failOn_canParseNext, sizeof(__pyx_k_self_failOn_canParseNext), 0, 0, 1, 1},
    {&__pyx_n_s_self_ignoreExpr_tryParse, __pyx_k_self_ignoreExpr_tryParse, sizeof(__pyx_k_self_ignoreExpr_tryParse), 0, 0, 1, 1},
    {&__pyx_n_s_self_skip_ignorables, __pyx_k_self_skip_ignorables, sizeof(__pyx_k_self_skip_ignorables), 0, 0, 1, 1},
    {&__pyx_n_s_self_type, __pyx_k_self_type, sizeof(__pyx_k_self_type), 0, 0, 1, 1},
    {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
    {&__pyx_n_s_sep, __pyx_k_sep, sizeof(__pyx_k_sep), 0, 0, 1, 1},
    {&__pyx_n_s_set, __pyx_k_set, sizeof(__pyx_k_set), 0, 0, 1, 1},
    {&__pyx_n_s_setAdaptiveMode, __pyx_k_setAdaptiveMode, sizeof(__pyx_k_setAdaptiveMode), 0, 0, 1, 1},
    {&__pyx_n_s_setBreak, __pyx_k_setBreak, sizeof(__pyx_k_setBreak), 0, 0, 1, 1},
    {&__pyx_n_s_setDebug, __pyx_k_setDebug, sizeof(__pyx_k_setDebug), 0, 0, 1, 1},
    {&__pyx_n_s_setDebugActions, __pyx_k_setDebugActions, sizeof(__pyx_k_setDebugActions), 0, 0, 1, 1},
    {&__pyx_n_s_setDefaultKeywordChars, __pyx_k_setDefaultKeywordChars, sizeof(__pyx_k_setDefaultKeywordChars), 0, 0, 1, 1},
    {&__pyx_n_s_setDefaultWhitespaceChars, __pyx_k_setDefaultWhitespaceChars, sizeof(__pyx_k_setDefaultWhitespaceChars), 0, 0, 1, 1},
    {&__pyx_n_s_setFailAction, __pyx_k_setFailAction, sizeof(__pyx_k_setFailAction), 0, 0, 1, 1},
    {&__pyx_n_s_setName, __pyx_k_setName, sizeof(__pyx_k_setName), 0, 0, 1, 1},
    {&__pyx_n_s_setOffset, __pyx_k_setOffset, sizeof(__pyx_k_setOffset), 0, 0, 1, 1},
    {&__pyx_n_s_setParseAction, __pyx_k_setParseAction, sizeof(__pyx_k_setParseAction), 0, 0, 1, 1},
    {&__pyx_n_s_setResultsName, __pyx_k_setResultsName, sizeof(__pyx_k_setResultsName), 0, 0, 1, 1},
    {&__pyx_n_s_setResultsName_2, __pyx_k_setResultsName_2, sizeof(__pyx_k_setResultsName_2), 0, 0, 1, 1},
    {&__pyx_n_s_setWhitespaceChars, __pyx_k_setWhitespaceChars, sizeof(__pyx_k_setWhitespaceChars), 0, 0, 1, 1},
    {&__pyx_n_s_set_name, __pyx_k_set_name, sizeof(__pyx_k_set_name), 0, 0, 1, 1},
    {&__pyx_n_s_set_trace, __pyx_k_set_trace, sizeof(__pyx_k_set_trace), 0, 0, 1, 1},
    {&__pyx_n_s_setitem, __pyx_k_setitem, sizeof(__pyx_k_setitem), 0, 0, 1, 1},
    {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_sglQuotedString, __pyx_k_sglQuotedString, sizeof(__pyx_k_sglQuotedString), 0, 0, 1, 1},
    {&__pyx_n_u_sglQuotedString, __pyx_k_sglQuotedString, sizeof(__pyx_k_sglQuotedString), 0, 1, 0, 1},
    {&__pyx_kp_u_short_IPv6_address, __pyx_k_short_IPv6_address, sizeof(__pyx_k_short_IPv6_address), 0, 1, 0, 0},
    {&__pyx_n_s_short_ipv6_address, __pyx_k_short_ipv6_address, sizeof(__pyx_k_short_ipv6_address), 0, 0, 1, 1},
    {&__pyx_n_s_should_cache_incremental_succes, __pyx_k_should_cache_incremental_succes, sizeof(__pyx_k_should_cache_incremental_succes), 0, 0, 1, 1},
    {&__pyx_n_s_show_skip, __pyx_k_show_skip, sizeof(__pyx_k_show_skip), 0, 0, 1, 1},
    {&__pyx_kp_u_signed_integer, __pyx_k_signed_integer, sizeof(__pyx_k_signed_integer), 0, 1, 0, 0},
    {&__pyx_n_s_signed_integer_2, __pyx_k_signed_integer_2, sizeof(__pyx_k_signed_integer_2), 0, 0, 1, 1},
    {&__pyx_n_s_simpleSQL, __pyx_k_simpleSQL, sizeof(__pyx_k_simpleSQL), 0, 0, 1, 1},
    {&__pyx_n_s_singleArgBuiltins, __pyx_k_singleArgBuiltins, sizeof(__pyx_k_singleArgBuiltins), 0, 0, 1, 1},
    {&__pyx_n_s_singleChar, __pyx_k_singleChar, sizeof(__pyx_k_singleChar), 0, 0, 1, 1},
    {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
    {&__pyx_n_s_skipIgnorables, __pyx_k_skipIgnorables, sizeof(__pyx_k_skipIgnorables), 0, 0, 1, 1},
    {&__pyx_n_s_skipWhitespace, __pyx_k_skipWhitespace, sizeof(__pyx_k_skipWhitespace), 0, 0, 1, 1},
    {&__pyx_kp_u_skipped, __pyx_k_skipped, sizeof(__pyx_k_skipped), 0, 1, 0, 0},
    {&__pyx_n_s_skipped_2, __pyx_k_skipped_2, sizeof(__pyx_k_skipped_2), 0, 0, 1, 1},
    {&__pyx_n_u_skipped_2, __pyx_k_skipped_2, sizeof(__pyx_k_skipped_2), 0, 1, 0, 1},
    {&__pyx_n_s_skipped_3, __pyx_k_skipped_3, sizeof(__pyx_k_skipped_3), 0, 0, 1, 1},
    {&__pyx_n_s_skipper, __pyx_k_skipper, sizeof(__pyx_k_skipper), 0, 0, 1, 1},
    {&__pyx_n_s_skipresult, __pyx_k_skipresult, sizeof(__pyx_k_skipresult), 0, 0, 1, 1},
    {&__pyx_n_s_skiptext, __pyx_k_skiptext, sizeof(__pyx_k_skiptext), 0, 0, 1, 1},
    {&__pyx_n_s_skipto_arg, __pyx_k_skipto_arg, sizeof(__pyx_k_skipto_arg), 0, 0, 1, 1},
    {&__pyx_n_s_slots, __pyx_k_slots, sizeof(__pyx_k_slots), 0, 0, 1, 1},
    {&__pyx_n_s_smExpr, __pyx_k_smExpr, sizeof(__pyx_k_smExpr), 0, 0, 1, 1},
    {&__pyx_n_s_sort, __pyx_k_sort, sizeof(__pyx_k_sort), 0, 0, 1, 1},
    {&__pyx_n_s_sorted, __pyx_k_sorted, sizeof(__pyx_k_sorted), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
    {&__pyx_n_s_splitlines, __pyx_k_splitlines, sizeof(__pyx_k_splitlines), 0, 0, 1, 1},
    {&__pyx_n_s_splits, __pyx_k_splits, sizeof(__pyx_k_splits), 0, 0, 1, 1},
    {&__pyx_n_s_srange, __pyx_k_srange, sizeof(__pyx_k_srange), 0, 0, 1, 1},
    {&__pyx_n_u_srange, __pyx_k_srange, sizeof(__pyx_k_srange), 0, 1, 0, 1},
    {&__pyx_n_s_srange_locals_genexpr, __pyx_k_srange_locals_genexpr, sizeof(__pyx_k_srange_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_srange_locals_lambda, __pyx_k_srange_locals_lambda, sizeof(__pyx_k_srange_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_srange_locals_lambda_locals_gene, __pyx_k_srange_locals_lambda_locals_gene, sizeof(__pyx_k_srange_locals_lambda_locals_gene), 0, 0, 1, 1},
    {&__pyx_n_s_src, __pyx_k_src, sizeof(__pyx_k_src), 0, 0, 1, 1},
    {&__pyx_n_s_sre_constants, __pyx_k_sre_constants, sizeof(__pyx_k_sre_constants), 0, 0, 1, 1},
    {&__pyx_n_s_stacklevel, __pyx_k_stacklevel, sizeof(__pyx_k_stacklevel), 0, 0, 1, 1},
    {&__pyx_n_s_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 0, 1, 1},
    {&__pyx_n_u_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 1, 0, 1},
    {&__pyx_n_s_startAction, __pyx_k_startAction, sizeof(__pyx_k_startAction), 0, 0, 1, 1},
    {&__pyx_n_s_startloc, __pyx_k_startloc, sizeof(__pyx_k_startloc), 0, 0, 1, 1},
    {&__pyx_n_s_startswith, __pyx_k_startswith, sizeof(__pyx_k_startswith), 0, 0, 1, 1},
    {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
    {&__pyx_n_s_staticmethod, __pyx_k_staticmethod, sizeof(__pyx_k_staticmethod), 0, 0, 1, 1},
    {&__pyx_n_s_stderr, __pyx_k_stderr, sizeof(__pyx_k_stderr), 0, 0, 1, 1},
    {&__pyx_n_s_stdout, __pyx_k_stdout, sizeof(__pyx_k_stdout), 0, 0, 1, 1},
    {&__pyx_n_s_still_reset_cache, __pyx_k_still_reset_cache, sizeof(__pyx_k_still_reset_cache), 0, 0, 1, 1},
    {&__pyx_n_s_stopOn, __pyx_k_stopOn, sizeof(__pyx_k_stopOn), 0, 0, 1, 1},
    {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
    {&__pyx_n_s_strRepr, __pyx_k_strRepr, sizeof(__pyx_k_strRepr), 0, 0, 1, 1},
    {&__pyx_n_s_str_2, __pyx_k_str_2, sizeof(__pyx_k_str_2), 0, 0, 1, 1},
    {&__pyx_n_s_streamline, __pyx_k_streamline, sizeof(__pyx_k_streamline), 0, 0, 1, 1},
    {&__pyx_n_s_streamlined, __pyx_k_streamlined, sizeof(__pyx_k_streamlined), 0, 0, 1, 1},
    {&__pyx_n_s_strg, __pyx_k_strg, sizeof(__pyx_k_strg), 0, 0, 1, 1},
    {&__pyx_n_s_string, __pyx_k_string, sizeof(__pyx_k_string), 0, 0, 1, 1},
    {&__pyx_n_s_stringEnd, __pyx_k_stringEnd, sizeof(__pyx_k_stringEnd), 0, 0, 1, 1},
    {&__pyx_n_u_stringEnd, __pyx_k_stringEnd, sizeof(__pyx_k_stringEnd), 0, 1, 0, 1},
    {&__pyx_n_s_stringStart, __pyx_k_stringStart, sizeof(__pyx_k_stringStart), 0, 0, 1, 1},
    {&__pyx_n_u_stringStart, __pyx_k_stringStart, sizeof(__pyx_k_stringStart), 0, 1, 0, 1},
    {&__pyx_kp_u_string_enclosed_in_double_quotes, __pyx_k_string_enclosed_in_double_quotes, sizeof(__pyx_k_string_enclosed_in_double_quotes), 0, 1, 0, 0},
    {&__pyx_kp_u_string_enclosed_in_single_quotes, __pyx_k_string_enclosed_in_single_quotes, sizeof(__pyx_k_string_enclosed_in_single_quotes), 0, 1, 0, 0},
    {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
    {&__pyx_n_s_stripHTMLTags, __pyx_k_stripHTMLTags, sizeof(__pyx_k_stripHTMLTags), 0, 0, 1, 1},
    {&__pyx_n_s_strptime, __pyx_k_strptime, sizeof(__pyx_k_strptime), 0, 0, 1, 1},
    {&__pyx_n_s_strs, __pyx_k_strs, sizeof(__pyx_k_strs), 0, 0, 1, 1},
    {&__pyx_n_s_sub, __pyx_k_sub, sizeof(__pyx_k_sub), 0, 0, 1, 1},
    {&__pyx_n_s_subRecCheckList, __pyx_k_subRecCheckList, sizeof(__pyx_k_subRecCheckList), 0, 0, 1, 1},
    {&__pyx_n_s_sub_2, __pyx_k_sub_2, sizeof(__pyx_k_sub_2), 0, 0, 1, 1},
    {&__pyx_n_s_success, __pyx_k_success, sizeof(__pyx_k_success), 0, 0, 1, 1},
    {&__pyx_n_s_successAction, __pyx_k_successAction, sizeof(__pyx_k_successAction), 0, 0, 1, 1},
    {&__pyx_n_s_suffix_len, __pyx_k_suffix_len, sizeof(__pyx_k_suffix_len), 0, 0, 1, 1},
    {&__pyx_n_s_suffix_lookup, __pyx_k_suffix_lookup, sizeof(__pyx_k_suffix_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_sum, __pyx_k_sum, sizeof(__pyx_k_sum), 0, 0, 1, 1},
    {&__pyx_kp_u_sum_len_sorted_reversed_list_tup, __pyx_k_sum_len_sorted_reversed_list_tup, sizeof(__pyx_k_sum_len_sorted_reversed_list_tup), 0, 1, 0, 0},
    {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
    {&__pyx_n_s_suppress, __pyx_k_suppress, sizeof(__pyx_k_suppress), 0, 0, 1, 1},
    {&__pyx_n_s_suppress_GT, __pyx_k_suppress_GT, sizeof(__pyx_k_suppress_GT), 0, 0, 1, 1},
    {&__pyx_n_s_suppress_LT, __pyx_k_suppress_LT, sizeof(__pyx_k_suppress_LT), 0, 0, 1, 1},
    {&__pyx_n_s_symbols, __pyx_k_symbols, sizeof(__pyx_k_symbols), 0, 0, 1, 1},
    {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
    {&__pyx_n_s_system_version, __pyx_k_system_version, sizeof(__pyx_k_system_version), 0, 0, 1, 1},
    {&__pyx_n_s_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 0, 1, 1},
    {&__pyx_kp_u_t_2, __pyx_k_t_2, sizeof(__pyx_k_t_2), 0, 1, 0, 0},
    {&__pyx_n_s_tableName, __pyx_k_tableName, sizeof(__pyx_k_tableName), 0, 0, 1, 1},
    {&__pyx_n_s_tableNameList, __pyx_k_tableNameList, sizeof(__pyx_k_tableNameList), 0, 0, 1, 1},
    {&__pyx_n_u_tables, __pyx_k_tables, sizeof(__pyx_k_tables), 0, 1, 0, 1},
    {&__pyx_n_s_tag, __pyx_k_tag, sizeof(__pyx_k_tag), 0, 0, 1, 1},
    {&__pyx_n_u_tag, __pyx_k_tag, sizeof(__pyx_k_tag), 0, 1, 0, 1},
    {&__pyx_n_s_tagAttrName, __pyx_k_tagAttrName, sizeof(__pyx_k_tagAttrName), 0, 0, 1, 1},
    {&__pyx_n_s_tagAttrValue, __pyx_k_tagAttrValue, sizeof(__pyx_k_tagAttrValue), 0, 0, 1, 1},
    {&__pyx_n_s_tagStr, __pyx_k_tagStr, sizeof(__pyx_k_tagStr), 0, 0, 1, 1},
    {&__pyx_n_s_tag_body, __pyx_k_tag_body, sizeof(__pyx_k_tag_body), 0, 0, 1, 1},
    {&__pyx_n_s_tb, __pyx_k_tb, sizeof(__pyx_k_tb), 0, 0, 1, 1},
    {&__pyx_n_s_tb_next, __pyx_k_tb_next, sizeof(__pyx_k_tb_next), 0, 0, 1, 1},
    {&__pyx_n_s_termName, __pyx_k_termName, sizeof(__pyx_k_termName), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_testString, __pyx_k_testString, sizeof(__pyx_k_testString), 0, 0, 1, 1},
    {&__pyx_n_s_test_expr, __pyx_k_test_expr, sizeof(__pyx_k_test_expr), 0, 0, 1, 1},
    {&__pyx_n_s_test_string, __pyx_k_test_string, sizeof(__pyx_k_test_string), 0, 0, 1, 1},
    {&__pyx_n_s_tests, __pyx_k_tests, sizeof(__pyx_k_tests), 0, 0, 1, 1},
    {&__pyx_n_s_tflat, __pyx_k_tflat, sizeof(__pyx_k_tflat), 0, 0, 1, 1},
    {&__pyx_n_s_theseTokens, __pyx_k_theseTokens, sizeof(__pyx_k_theseTokens), 0, 0, 1, 1},
    {&__pyx_n_s_thisExpr, __pyx_k_thisExpr, sizeof(__pyx_k_thisExpr), 0, 0, 1, 1},
    {&__pyx_n_s_thisFunc, __pyx_k_thisFunc, sizeof(__pyx_k_thisFunc), 0, 0, 1, 1},
    {&__pyx_n_s_thiscol, __pyx_k_thiscol, sizeof(__pyx_k_thiscol), 0, 0, 1, 1},
    {&__pyx_n_s_thread, __pyx_k_thread, sizeof(__pyx_k_thread), 0, 0, 1, 1},
    {&__pyx_n_s_threading, __pyx_k_threading, sizeof(__pyx_k_threading), 0, 0, 1, 1},
    {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
    {&__pyx_n_s_throwException, __pyx_k_throwException, sizeof(__pyx_k_throwException), 0, 0, 1, 1},
    {&__pyx_n_s_title, __pyx_k_title, sizeof(__pyx_k_title), 0, 0, 1, 1},
    {&__pyx_n_s_tmp, __pyx_k_tmp, sizeof(__pyx_k_tmp), 0, 0, 1, 1},
    {&__pyx_n_s_tmpExprs, __pyx_k_tmpExprs, sizeof(__pyx_k_tmpExprs), 0, 0, 1, 1},
    {&__pyx_n_s_tmpLoc, __pyx_k_tmpLoc, sizeof(__pyx_k_tmpLoc), 0, 0, 1, 1},
    {&__pyx_n_s_tmpOpt, __pyx_k_tmpOpt, sizeof(__pyx_k_tmpOpt), 0, 0, 1, 1},
    {&__pyx_n_s_tmpReqd, __pyx_k_tmpReqd, sizeof(__pyx_k_tmpReqd), 0, 0, 1, 1},
    {&__pyx_n_s_tmploc, __pyx_k_tmploc, sizeof(__pyx_k_tmploc), 0, 0, 1, 1},
    {&__pyx_n_s_tmptokens, __pyx_k_tmptokens, sizeof(__pyx_k_tmptokens), 0, 0, 1, 1},
    {&__pyx_n_s_to, __pyx_k_to, sizeof(__pyx_k_to), 0, 0, 1, 1},
    {&__pyx_n_s_toItem, __pyx_k_toItem, sizeof(__pyx_k_toItem), 0, 0, 1, 1},
    {&__pyx_n_s_to_symbols, __pyx_k_to_symbols, sizeof(__pyx_k_to_symbols), 0, 0, 1, 1},
    {&__pyx_n_s_tok, __pyx_k_tok, sizeof(__pyx_k_tok), 0, 0, 1, 1},
    {&__pyx_n_s_tokenMap, __pyx_k_tokenMap, sizeof(__pyx_k_tokenMap), 0, 0, 1, 1},
    {&__pyx_n_u_tokenMap, __pyx_k_tokenMap, sizeof(__pyx_k_tokenMap), 0, 1, 0, 1},
    {&__pyx_n_s_tokenMap_locals_pa, __pyx_k_tokenMap_locals_pa, sizeof(__pyx_k_tokenMap_locals_pa), 0, 0, 1, 1},
    {&__pyx_n_s_tokenlist, __pyx_k_tokenlist, sizeof(__pyx_k_tokenlist), 0, 0, 1, 1},
    {&__pyx_n_s_tokens, __pyx_k_tokens, sizeof(__pyx_k_tokens), 0, 0, 1, 1},
    {&__pyx_n_s_tokensStart, __pyx_k_tokensStart, sizeof(__pyx_k_tokensStart), 0, 0, 1, 1},
    {&__pyx_n_s_toklist, __pyx_k_toklist, sizeof(__pyx_k_toklist), 0, 0, 1, 1},
    {&__pyx_n_s_tokn, __pyx_k_tokn, sizeof(__pyx_k_tokn), 0, 0, 1, 1},
    {&__pyx_n_s_toks, __pyx_k_toks, sizeof(__pyx_k_toks), 0, 0, 1, 1},
    {&__pyx_n_s_traceParseAction, __pyx_k_traceParseAction, sizeof(__pyx_k_traceParseAction), 0, 0, 1, 1},
    {&__pyx_n_u_traceParseAction, __pyx_k_traceParseAction, sizeof(__pyx_k_traceParseAction), 0, 1, 0, 1},
    {&__pyx_n_s_traceParseAction_locals_z, __pyx_k_traceParseAction_locals_z, sizeof(__pyx_k_traceParseAction_locals_z), 0, 0, 1, 1},
    {&__pyx_n_s_traceback, __pyx_k_traceback, sizeof(__pyx_k_traceback), 0, 0, 1, 1},
    {&__pyx_n_u_traceback, __pyx_k_traceback, sizeof(__pyx_k_traceback), 0, 1, 0, 1},
    {&__pyx_n_s_traceback_2, __pyx_k_traceback_2, sizeof(__pyx_k_traceback_2), 0, 0, 1, 1},
    {&__pyx_n_s_transformString, __pyx_k_transformString, sizeof(__pyx_k_transformString), 0, 0, 1, 1},
    {&__pyx_n_s_trim_arity, __pyx_k_trim_arity, sizeof(__pyx_k_trim_arity), 0, 0, 1, 1},
    {&__pyx_n_s_trim_arity_locals_extract_stack, __pyx_k_trim_arity_locals_extract_stack, sizeof(__pyx_k_trim_arity_locals_extract_stack), 0, 0, 1, 1},
    {&__pyx_n_s_trim_arity_locals_extract_tb, __pyx_k_trim_arity_locals_extract_tb, sizeof(__pyx_k_trim_arity_locals_extract_tb), 0, 0, 1, 1},
    {&__pyx_n_s_trim_arity_locals_lambda, __pyx_k_trim_arity_locals_lambda, sizeof(__pyx_k_trim_arity_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_trim_arity_locals_wrapper, __pyx_k_trim_arity_locals_wrapper, sizeof(__pyx_k_trim_arity_locals_wrapper), 0, 0, 1, 1},
    {&__pyx_n_s_trim_traceback, __pyx_k_trim_traceback, sizeof(__pyx_k_trim_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_tryParse, __pyx_k_tryParse, sizeof(__pyx_k_tryParse), 0, 0, 1, 1},
    {&__pyx_n_s_try_not_ender, __pyx_k_try_not_ender, sizeof(__pyx_k_try_not_ender), 0, 0, 1, 1},
    {&__pyx_n_s_tup, __pyx_k_tup, sizeof(__pyx_k_tup), 0, 0, 1, 1},
    {&__pyx_n_s_types, __pyx_k_types, sizeof(__pyx_k_types), 0, 0, 1, 1},
    {&__pyx_n_u_u, __pyx_k_u, sizeof(__pyx_k_u), 0, 1, 0, 1},
    {&__pyx_n_s_ungroup, __pyx_k_ungroup, sizeof(__pyx_k_ungroup), 0, 0, 1, 1},
    {&__pyx_n_u_ungroup, __pyx_k_ungroup, sizeof(__pyx_k_ungroup), 0, 1, 0, 1},
    {&__pyx_n_s_ungroup_locals_lambda, __pyx_k_ungroup_locals_lambda, sizeof(__pyx_k_ungroup_locals_lambda), 0, 0, 1, 1},
    {&__pyx_n_s_unichr, __pyx_k_unichr, sizeof(__pyx_k_unichr), 0, 0, 1, 1},
    {&__pyx_n_s_unicode, __pyx_k_unicode, sizeof(__pyx_k_unicode), 0, 0, 1, 1},
    {&__pyx_n_s_unicodeString, __pyx_k_unicodeString, sizeof(__pyx_k_unicodeString), 0, 0, 1, 1},
    {&__pyx_n_u_unicodeString, __pyx_k_unicodeString, sizeof(__pyx_k_unicodeString), 0, 1, 0, 1},
    {&__pyx_n_s_unicode_set, __pyx_k_unicode_set, sizeof(__pyx_k_unicode_set), 0, 0, 1, 1},
    {&__pyx_n_u_unicode_set, __pyx_k_unicode_set, sizeof(__pyx_k_unicode_set), 0, 1, 0, 1},
    {&__pyx_n_s_unicode_set__get_chars_for_range, __pyx_k_unicode_set__get_chars_for_range, sizeof(__pyx_k_unicode_set__get_chars_for_range), 0, 0, 1, 1},
    {&__pyx_n_s_unicode_set_alphanums, __pyx_k_unicode_set_alphanums, sizeof(__pyx_k_unicode_set_alphanums), 0, 0, 1, 1},
    {&__pyx_n_s_unicode_set_alphas, __pyx_k_unicode_set_alphas, sizeof(__pyx_k_unicode_set_alphas), 0, 0, 1, 1},
    {&__pyx_n_s_unicode_set_nums, __pyx_k_unicode_set_nums, sizeof(__pyx_k_unicode_set_nums), 0, 0, 1, 1},
    {&__pyx_n_s_unicode_set_printables, __pyx_k_unicode_set_printables, sizeof(__pyx_k_unicode_set_printables), 0, 0, 1, 1},
    {&__pyx_kp_u_unicode_string_literal, __pyx_k_unicode_string_literal, sizeof(__pyx_k_unicode_string_literal), 0, 1, 0, 0},
    {&__pyx_n_s_unquoteResults, __pyx_k_unquoteResults, sizeof(__pyx_k_unquoteResults), 0, 0, 1, 1},
    {&__pyx_n_s_upcaseTokens, __pyx_k_upcaseTokens, sizeof(__pyx_k_upcaseTokens), 0, 0, 1, 1},
    {&__pyx_n_u_upcaseTokens, __pyx_k_upcaseTokens, sizeof(__pyx_k_upcaseTokens), 0, 1, 0, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_update_dict, __pyx_k_update_dict, sizeof(__pyx_k_update_dict), 0, 0, 1, 1},
    {&__pyx_n_s_update_furthest_loc_for_regex, __pyx_k_update_furthest_loc_for_regex, sizeof(__pyx_k_update_furthest_loc_for_regex), 0, 0, 1, 1},
    {&__pyx_n_s_update_wrapper, __pyx_k_update_wrapper, sizeof(__pyx_k_update_wrapper), 0, 0, 1, 1},
    {&__pyx_n_s_upper, __pyx_k_upper, sizeof(__pyx_k_upper), 0, 0, 1, 1},
    {&__pyx_n_s_usage, __pyx_k_usage, sizeof(__pyx_k_usage), 0, 0, 1, 1},
    {&__pyx_n_s_usage_weight, __pyx_k_usage_weight, sizeof(__pyx_k_usage_weight), 0, 0, 1, 1},
    {&__pyx_n_s_useRegex, __pyx_k_useRegex, sizeof(__pyx_k_useRegex), 0, 0, 1, 1},
    {&__pyx_kp_u_use_of_expression_without_follow, __pyx_k_use_of_expression_without_follow, sizeof(__pyx_k_use_of_expression_without_follow), 0, 1, 0, 0},
    {&__pyx_kp_s_user_throwable_exception_thrown, __pyx_k_user_throwable_exception_thrown, sizeof(__pyx_k_user_throwable_exception_thrown), 0, 0, 1, 0},
    {&__pyx_n_s_ustr, __pyx_k_ustr, sizeof(__pyx_k_ustr), 0, 0, 1, 1},
    {&__pyx_n_u_utf8, __pyx_k_utf8, sizeof(__pyx_k_utf8), 0, 1, 0, 1},
    {&__pyx_n_s_uuid, __pyx_k_uuid, sizeof(__pyx_k_uuid), 0, 0, 1, 1},
    {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
    {&__pyx_n_s_validate, __pyx_k_validate, sizeof(__pyx_k_validate), 0, 0, 1, 1},
    {&__pyx_n_s_validateTrace, __pyx_k_validateTrace, sizeof(__pyx_k_validateTrace), 0, 0, 1, 1},
    {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
    {&__pyx_n_u_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 1, 0, 1},
    {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
    {&__pyx_n_s_vars, __pyx_k_vars, sizeof(__pyx_k_vars), 0, 0, 1, 1},
    {&__pyx_n_s_ve, __pyx_k_ve, sizeof(__pyx_k_ve), 0, 0, 1, 1},
    {&__pyx_n_s_verbose, __pyx_k_verbose, sizeof(__pyx_k_verbose), 0, 0, 1, 1},
    {&__pyx_n_s_verbose_stacktrace, __pyx_k_verbose_stacktrace, sizeof(__pyx_k_verbose_stacktrace), 0, 0, 1, 1},
    {&__pyx_n_s_verifyCol, __pyx_k_verifyCol, sizeof(__pyx_k_verifyCol), 0, 0, 1, 1},
    {&__pyx_n_s_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 0, 1, 1},
    {&__pyx_n_u_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 1, 0, 1},
    {&__pyx_n_s_versionTime, __pyx_k_versionTime, sizeof(__pyx_k_versionTime), 0, 0, 1, 1},
    {&__pyx_n_u_versionTime, __pyx_k_versionTime, sizeof(__pyx_k_versionTime), 0, 1, 0, 1},
    {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
    {&__pyx_n_s_vlist, __pyx_k_vlist, sizeof(__pyx_k_vlist), 0, 0, 1, 1},
    {&__pyx_n_s_vv, __pyx_k_vv, sizeof(__pyx_k_vv), 0, 0, 1, 1},
    {&__pyx_n_s_warn, __pyx_k_warn, sizeof(__pyx_k_warn), 0, 0, 1, 1},
    {&__pyx_n_u_warn_2, __pyx_k_warn_2, sizeof(__pyx_k_warn_2), 0, 1, 0, 1},
    {&__pyx_n_s_warn_multiple_tokens_in_named_al, __pyx_k_warn_multiple_tokens_in_named_al, sizeof(__pyx_k_warn_multiple_tokens_in_named_al), 0, 0, 1, 1},
    {&__pyx_n_u_warn_multiple_tokens_in_named_al, __pyx_k_warn_multiple_tokens_in_named_al, sizeof(__pyx_k_warn_multiple_tokens_in_named_al), 0, 1, 0, 1},
    {&__pyx_n_s_warn_name_set_on_empty_Forward, __pyx_k_warn_name_set_on_empty_Forward, sizeof(__pyx_k_warn_name_set_on_empty_Forward), 0, 0, 1, 1},
    {&__pyx_n_u_warn_name_set_on_empty_Forward, __pyx_k_warn_name_set_on_empty_Forward, sizeof(__pyx_k_warn_name_set_on_empty_Forward), 0, 1, 0, 1},
    {&__pyx_n_s_warn_on_incremental_multiline_re, __pyx_k_warn_on_incremental_multiline_re, sizeof(__pyx_k_warn_on_incremental_multiline_re), 0, 0, 1, 1},
    {&__pyx_n_s_warn_on_multiple_string_args_to, __pyx_k_warn_on_multiple_string_args_to, sizeof(__pyx_k_warn_on_multiple_string_args_to), 0, 0, 1, 1},
    {&__pyx_n_s_warn_ungrouped_named_tokens_in_c, __pyx_k_warn_ungrouped_named_tokens_in_c, sizeof(__pyx_k_warn_ungrouped_named_tokens_in_c), 0, 0, 1, 1},
    {&__pyx_n_u_warn_ungrouped_named_tokens_in_c, __pyx_k_warn_ungrouped_named_tokens_in_c, sizeof(__pyx_k_warn_ungrouped_named_tokens_in_c), 0, 1, 0, 1},
    {&__pyx_n_s_warnings, __pyx_k_warnings, sizeof(__pyx_k_warnings), 0, 0, 1, 1},
    {&__pyx_n_s_weakref, __pyx_k_weakref, sizeof(__pyx_k_weakref), 0, 0, 1, 1},
    {&__pyx_n_s_whiteChars, __pyx_k_whiteChars, sizeof(__pyx_k_whiteChars), 0, 0, 1, 1},
    {&__pyx_n_s_whiteStrs, __pyx_k_whiteStrs, sizeof(__pyx_k_whiteStrs), 0, 0, 1, 1},
    {&__pyx_n_s_whitespace, __pyx_k_whitespace, sizeof(__pyx_k_whitespace), 0, 0, 1, 1},
    {&__pyx_n_s_withAttribute, __pyx_k_withAttribute, sizeof(__pyx_k_withAttribute), 0, 0, 1, 1},
    {&__pyx_n_u_withAttribute, __pyx_k_withAttribute, sizeof(__pyx_k_withAttribute), 0, 1, 0, 1},
    {&__pyx_n_s_withClass, __pyx_k_withClass, sizeof(__pyx_k_withClass), 0, 0, 1, 1},
    {&__pyx_n_u_withClass, __pyx_k_withClass, sizeof(__pyx_k_withClass), 0, 1, 0, 1},
    {&__pyx_kp_u_with_up_to, __pyx_k_with_up_to, sizeof(__pyx_k_with_up_to), 0, 1, 0, 0},
    {&__pyx_n_s_wkref, __pyx_k_wkref, sizeof(__pyx_k_wkref), 0, 0, 1, 1},
    {&__pyx_n_s_wordChars, __pyx_k_wordChars, sizeof(__pyx_k_wordChars), 0, 0, 1, 1},
    {&__pyx_n_s_wrapper, __pyx_k_wrapper, sizeof(__pyx_k_wrapper), 0, 0, 1, 1},
    {&__pyx_n_u_wrapper, __pyx_k_wrapper, sizeof(__pyx_k_wrapper), 0, 1, 0, 1},
    {&__pyx_n_s_wraps, __pyx_k_wraps, sizeof(__pyx_k_wraps), 0, 0, 1, 1},
    {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
    {&__pyx_n_s_ws, __pyx_k_ws, sizeof(__pyx_k_ws), 0, 0, 1, 1},
    {&__pyx_n_s_ws_map, __pyx_k_ws_map, sizeof(__pyx_k_ws_map), 0, 0, 1, 1},
    {&__pyx_n_s_wschar, __pyx_k_wschar, sizeof(__pyx_k_wschar), 0, 0, 1, 1},
    {&__pyx_n_s_wslit, __pyx_k_wslit, sizeof(__pyx_k_wslit), 0, 0, 1, 1},
    {&__pyx_n_s_wt, __pyx_k_wt, sizeof(__pyx_k_wt), 0, 0, 1, 1},
    {&__pyx_n_s_xml, __pyx_k_xml, sizeof(__pyx_k_xml), 0, 0, 1, 1},
    {&__pyx_n_s_xmlBodyText, __pyx_k_xmlBodyText, sizeof(__pyx_k_xmlBodyText), 0, 0, 1, 1},
    {&__pyx_n_s_xml_escape, __pyx_k_xml_escape, sizeof(__pyx_k_xml_escape), 0, 0, 1, 1},
    {&__pyx_n_s_xml_escape_locals_genexpr, __pyx_k_xml_escape_locals_genexpr, sizeof(__pyx_k_xml_escape_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_xor, __pyx_k_xor, sizeof(__pyx_k_xor), 0, 0, 1, 1},
    {&__pyx_n_s_xrange, __pyx_k_xrange, sizeof(__pyx_k_xrange), 0, 0, 1, 1},
    {&__pyx_n_s_z, __pyx_k_z, sizeof(__pyx_k_z), 0, 0, 1, 1},
    {&__pyx_n_s_zip, __pyx_k_zip, sizeof(__pyx_k_zip), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(0, 86, __pyx_L1_error)
  __pyx_builtin_chr = __Pyx_GetBuiltinName(__pyx_n_s_chr); if (!__pyx_builtin_chr) __PYX_ERR(0, 193, __pyx_L1_error)
  __pyx_builtin_sum = __Pyx_GetBuiltinName(__pyx_n_s_sum); if (!__pyx_builtin_sum) __PYX_ERR(0, 198, __pyx_L1_error)
  __pyx_builtin_sorted = __Pyx_GetBuiltinName(__pyx_n_s_sorted); if (!__pyx_builtin_sorted) __PYX_ERR(0, 198, __pyx_L1_error)
  __pyx_builtin_reversed = __Pyx_GetBuiltinName(__pyx_n_s_reversed); if (!__pyx_builtin_reversed) __PYX_ERR(0, 198, __pyx_L1_error)
  __pyx_builtin_any = __Pyx_GetBuiltinName(__pyx_n_s_any); if (!__pyx_builtin_any) __PYX_ERR(0, 198, __pyx_L1_error)
  __pyx_builtin_all = __Pyx_GetBuiltinName(__pyx_n_s_all); if (!__pyx_builtin_all) __PYX_ERR(0, 198, __pyx_L1_error)
  __pyx_builtin_min = __Pyx_GetBuiltinName(__pyx_n_s_min); if (!__pyx_builtin_min) __PYX_ERR(0, 198, __pyx_L1_error)
  __pyx_builtin_max = __Pyx_GetBuiltinName(__pyx_n_s_max); if (!__pyx_builtin_max) __PYX_ERR(0, 198, __pyx_L1_error)
  #if PY_MAJOR_VERSION >= 3
  __pyx_builtin_xrange = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_xrange) __PYX_ERR(0, 202, __pyx_L1_error)
  #else
  __pyx_builtin_xrange = __Pyx_GetBuiltinName(__pyx_n_s_xrange); if (!__pyx_builtin_xrange) __PYX_ERR(0, 202, __pyx_L1_error)
  #endif
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) __PYX_ERR(0, 225, __pyx_L1_error)
  __pyx_builtin_staticmethod = __Pyx_GetBuiltinName(__pyx_n_s_staticmethod); if (!__pyx_builtin_staticmethod) __PYX_ERR(0, 355, __pyx_L1_error)
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(0, 503, __pyx_L1_error)
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_n_s_zip); if (!__pyx_builtin_zip) __PYX_ERR(0, 7426, __pyx_L1_error)
  __pyx_builtin_vars = __Pyx_GetBuiltinName(__pyx_n_s_vars); if (!__pyx_builtin_vars) __PYX_ERR(0, 154, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 392, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(0, 601, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 601, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(0, 601, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 1260, __pyx_L1_error)
  __pyx_builtin_NameError = __Pyx_GetBuiltinName(__pyx_n_s_NameError); if (!__pyx_builtin_NameError) __PYX_ERR(0, 1345, __pyx_L1_error)
  __pyx_builtin_map = __Pyx_GetBuiltinName(__pyx_n_s_map); if (!__pyx_builtin_map) __PYX_ERR(0, 1699, __pyx_L1_error)
  __pyx_builtin_SyntaxWarning = __Pyx_GetBuiltinName(__pyx_n_s_SyntaxWarning); if (!__pyx_builtin_SyntaxWarning) __PYX_ERR(0, 2173, __pyx_L1_error)
  __pyx_builtin_Ellipsis = __Pyx_GetBuiltinName(__pyx_n_s_Ellipsis); if (!__pyx_builtin_Ellipsis) __PYX_ERR(0, 2738, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 2836, __pyx_L1_error)
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_n_s_open); if (!__pyx_builtin_open) __PYX_ERR(0, 3147, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s_id); if (!__pyx_builtin_id) __PYX_ERR(0, 3173, __pyx_L1_error)
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_n_s_super); if (!__pyx_builtin_super) __PYX_ERR(0, 3368, __pyx_L1_error)
  __pyx_builtin_SyntaxError = __Pyx_GetBuiltinName(__pyx_n_s_SyntaxError); if (!__pyx_builtin_SyntaxError) __PYX_ERR(0, 4122, __pyx_L1_error)
  __pyx_builtin_filter = __Pyx_GetBuiltinName(__pyx_n_s_filter); if (!__pyx_builtin_filter) __PYX_ERR(0, 7815, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "cPyparsing.pyx":6733
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))             # <<<<<<<<<<<<<<
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 */
  __pyx_slice_ = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice_)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice_);
  __Pyx_GIVEREF(__pyx_slice_);

  /* "cPyparsing.pyx":257
 *     fn = _trim_arity(fn)
 * 
 *     @wraps(fn)             # <<<<<<<<<<<<<<
 *     def pa(s, l, t):
 *         if not bool(fn(s, l, t)):
 */
  __pyx_tuple__8 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);
  __pyx_codeobj__9 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__8, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_pa, 257, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__9)) __PYX_ERR(0, 257, __pyx_L1_error)

  /* "cPyparsing.pyx":395
 *                 frm = ff[0]
 * 
 *                 f_self = frm.f_locals.get('self', None)             # <<<<<<<<<<<<<<
 *                 if isinstance(f_self, ParserElement):
 *                     if frm.f_code.co_name not in ('parseImpl', '_parseNoCache'):
 */
  __pyx_tuple__18 = PyTuple_Pack(2, __pyx_n_u_self, Py_None); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "cPyparsing.pyx":576
 *                 toklist = []
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]             # <<<<<<<<<<<<<<
 *             elif isinstance(toklist, _generatorType):
 *                 self.__toklist = list(toklist)
 */
  __pyx_slice__20 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__20)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__20);
  __Pyx_GIVEREF(__pyx_slice__20);

  /* "cPyparsing.pyx":661
 * 
 *     def __reversed__(self):
 *         return iter(self.__toklist[::-1])             # <<<<<<<<<<<<<<
 * 
 *     def _iterkeys(self):
 */
  __pyx_slice__21 = PySlice_New(Py_None, Py_None, __pyx_int_neg_1); if (unlikely(!__pyx_slice__21)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__21);
  __Pyx_GIVEREF(__pyx_slice__21);

  /* "cPyparsing.pyx":946
 *             item_fn = self.iteritems
 * 
 *         def toItem(obj):             # <<<<<<<<<<<<<<
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 */
  __pyx_tuple__23 = PyTuple_Pack(2, __pyx_n_s_obj, __pyx_n_s_v); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);
  __pyx_codeobj__24 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__23, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_toItem, 946, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__24)) __PYX_ERR(0, 946, __pyx_L1_error)

  /* "cPyparsing.pyx":1200
 *         given, a nested ParseResults will be returned
 *         """
 *         def is_iterable(obj):             # <<<<<<<<<<<<<<
 *             try:
 *                 iter(obj)
 */
  __pyx_tuple__32 = PyTuple_Pack(1, __pyx_n_s_obj); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 1200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);
  __pyx_codeobj__33 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__32, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_is_iterable, 1200, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__33)) __PYX_ERR(0, 1200, __pyx_L1_error)

  /* "cPyparsing.pyx":1308
 *             def extract_stack(limit=0):
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 *                 offset = -3 if system_version == (3, 5, 0) else -2             # <<<<<<<<<<<<<<
 *                 frame_summary = traceback.extract_stack(limit=-offset + limit - 1)[offset]
 *                 return [frame_summary[:2]]
 */
  __pyx_tuple__36 = PyTuple_Pack(3, __pyx_int_3, __pyx_int_5, __pyx_int_0); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "cPyparsing.pyx":1310
 *                 offset = -3 if system_version == (3, 5, 0) else -2
 *                 frame_summary = traceback.extract_stack(limit=-offset + limit - 1)[offset]
 *                 return [frame_summary[:2]]             # <<<<<<<<<<<<<<
 *             def extract_tb(tb, limit=0):
 *                 frames = traceback.extract_tb(tb, limit=limit)
 */
  __pyx_slice__37 = PySlice_New(Py_None, __pyx_int_2, Py_None); if (unlikely(!__pyx_slice__37)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__37);
  __Pyx_GIVEREF(__pyx_slice__37);

  /* "cPyparsing.pyx":1305
 *     if _trim_arity.inspect_tracebacks:
 *         # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *         if system_version[:2] >= (3, 5):             # <<<<<<<<<<<<<<
 *             def extract_stack(limit=0):
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 */
  __pyx_tuple__38 = PyTuple_Pack(2, __pyx_int_3, __pyx_int_5); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 1305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "cPyparsing.pyx":1306
 *         # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *         if system_version[:2] >= (3, 5):
 *             def extract_stack(limit=0):             # <<<<<<<<<<<<<<
 *                 # special handling for Python 3.5.0 - extra deep call stack by 1
 *                 offset = -3 if system_version == (3, 5, 0) else -2
 */
  __pyx_tuple__39 = PyTuple_Pack(3, __pyx_n_s_limit, __pyx_n_s_offset, __pyx_n_s_frame_summary); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 1306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);
  __pyx_codeobj__40 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__39, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_extract_stack, 1306, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__40)) __PYX_ERR(0, 1306, __pyx_L1_error)
  __pyx_tuple__41 = PyTuple_Pack(1, ((PyObject *)__pyx_int_0)); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 1306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "cPyparsing.pyx":1311
 *                 frame_summary = traceback.extract_stack(limit=-offset + limit - 1)[offset]
 *                 return [frame_summary[:2]]
 *             def extract_tb(tb, limit=0):             # <<<<<<<<<<<<<<
 *                 frames = traceback.extract_tb(tb, limit=limit)
 *                 frame_summary = frames[-1]
 */
  __pyx_tuple__42 = PyTuple_Pack(4, __pyx_n_s_tb, __pyx_n_s_limit, __pyx_n_s_frames, __pyx_n_s_frame_summary); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 1311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);
  __pyx_codeobj__43 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__42, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_extract_tb, 1311, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__43)) __PYX_ERR(0, 1311, __pyx_L1_error)

  /* "cPyparsing.pyx":1325
 *     pa_call_line_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)
 * 
 *     def wrapper(*args):             # <<<<<<<<<<<<<<
 *         while 1:
 *             try:
 */
  __pyx_tuple__44 = PyTuple_Pack(3, __pyx_n_s_args, __pyx_n_s_ret, __pyx_n_s_tb); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 1325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__44, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_wrapper, 1325, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) __PYX_ERR(0, 1325, __pyx_L1_error)

  /* "cPyparsing.pyx":1546
 *         self.errmsg = ""
 *         self.modalResults = True # used to mark results names as modal (report only last) or cumulative (list all)
 *         self.debugActions = (None, None, None)  # custom debug actions             # <<<<<<<<<<<<<<
 *         self.re = None
 *         self.callPreparse = True # used to avoid redundant calls to preParse
 */
  __pyx_tuple__46 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 1546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "cPyparsing.pyx":1629
 *         newself = self.copy()
 *         if name.endswith("*"):
 *             name = name[:-1]             # <<<<<<<<<<<<<<
 *             listAllMatches = True
 *         newself.resultsName = name
 */
  __pyx_slice__47 = PySlice_New(Py_None, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_slice__47)) __PYX_ERR(0, 1629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__47);
  __Pyx_GIVEREF(__pyx_slice__47);

  /* "cPyparsing.pyx":1642
 *         if breakFlag:
 *             _parseMethod = self._parse
 *             def breaker(instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *                 import pdb
 *                 # this call to pdb.set_trace() is intentional, not a checkin error
 */
  __pyx_tuple__48 = PyTuple_Pack(5, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_callPreParse, __pyx_n_s_pdb); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 1642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__48, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_breaker, 1642, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(0, 1642, __pyx_L1_error)
  __pyx_tuple__50 = PyTuple_Pack(2, ((PyObject *)Py_True), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 1642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "cPyparsing.pyx":1698
 *         else:
 *             if not all(callable(fn) for fn in fns):
 *                 raise TypeError("parse actions must be callable")             # <<<<<<<<<<<<<<
 *             self.parseAction = list(map(_trim_arity, list(fns)))
 *             self.callDuringTry = kwargs.get("callDuringTry", False)
 */
  __pyx_tuple__51 = PyTuple_Pack(1, __pyx_kp_u_parse_actions_must_be_callable); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 1698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "cPyparsing.pyx":2809
 *         """
 *         if other is Ellipsis:
 *             other = (0, None)             # <<<<<<<<<<<<<<
 *         elif isinstance(other, tuple) and other[:1] == (Ellipsis,):
 *             other = ((0, ) + other[1:] + (None,))[:2]
 */
  __pyx_tuple__54 = PyTuple_Pack(2, __pyx_int_0, Py_None); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 2809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "cPyparsing.pyx":2810
 *         if other is Ellipsis:
 *             other = (0, None)
 *         elif isinstance(other, tuple) and other[:1] == (Ellipsis,):             # <<<<<<<<<<<<<<
 *             other = ((0, ) + other[1:] + (None,))[:2]
 * 
 */
  __pyx_slice__55 = PySlice_New(Py_None, __pyx_int_1, Py_None); if (unlikely(!__pyx_slice__55)) __PYX_ERR(0, 2810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__55);
  __Pyx_GIVEREF(__pyx_slice__55);
  __pyx_tuple__56 = PyTuple_Pack(1, __pyx_builtin_Ellipsis); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 2810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "cPyparsing.pyx":2811
 *             other = (0, None)
 *         elif isinstance(other, tuple) and other[:1] == (Ellipsis,):
 *             other = ((0, ) + other[1:] + (None,))[:2]             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(other, int):
 */
  __pyx_tuple__57 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(0, 2811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "cPyparsing.pyx":2817
 *         elif isinstance(other, tuple):
 *             other = tuple(o if o is not Ellipsis else None for o in other)
 *             other = (other + (None, None))[:2]             # <<<<<<<<<<<<<<
 *             if other[0] is None:
 *                 other = (0, other[1])
 */
  __pyx_tuple__58 = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 2817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "cPyparsing.pyx":2836
 * 
 *         if minElements < 0:
 *             raise ValueError("cannot multiply ParserElement by negative value")             # <<<<<<<<<<<<<<
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 */
  __pyx_tuple__59 = PyTuple_Pack(1, __pyx_kp_u_cannot_multiply_ParserElement_by); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 2836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "cPyparsing.pyx":2838
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")             # <<<<<<<<<<<<<<
 *         if minElements == optElements == 0:
 *             raise ValueError("cannot multiply ParserElement by 0 or (0, 0)")
 */
  __pyx_tuple__60 = PyTuple_Pack(1, __pyx_kp_u_second_tuple_value_must_be_great); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 2838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "cPyparsing.pyx":2840
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:
 *             raise ValueError("cannot multiply ParserElement by 0 or (0, 0)")             # <<<<<<<<<<<<<<
 * 
 *         if optElements:
 */
  __pyx_tuple__61 = PyTuple_Pack(1, __pyx_kp_u_cannot_multiply_ParserElement_by_2); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 2840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "cPyparsing.pyx":2843
 * 
 *         if optElements:
 *             def makeOptionalList(n):             # <<<<<<<<<<<<<<
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))
 */
  __pyx_tuple__62 = PyTuple_Pack(1, __pyx_n_s_n); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 2843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__62, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_makeOptionalList, 2843, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) __PYX_ERR(0, 2843, __pyx_L1_error)

  /* "cPyparsing.pyx":2979
 * 
 *         if len(key) > 2:
 *             warnings.warn("only 1 or 2 index arguments supported ({0}{1})".format(key[:5],             # <<<<<<<<<<<<<<
 *                                                                                 '... [{0}]'.format(len(key))
 *                                                                                 if len(key) > 5 else ''))
 */
  __pyx_slice__64 = PySlice_New(Py_None, __pyx_int_5, Py_None); if (unlikely(!__pyx_slice__64)) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__64);
  __Pyx_GIVEREF(__pyx_slice__64);

  /* "cPyparsing.pyx":3369
 *     def __init__(self, expr, must_skip=False):
 *         super(_PendingSkip, self).__init__()
 *         self.strRepr = str(expr + Empty()).replace('Empty', '...')             # <<<<<<<<<<<<<<
 *         self.name = self.strRepr
 *         self.anchor = expr
 */
  __pyx_tuple__68 = PyTuple_Pack(2, __pyx_n_u_Empty, __pyx_kp_u__67); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(0, 3369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);

  /* "cPyparsing.pyx":3380
 *                 if not t._skipped or t._skipped.asList() == ['']:
 *                     del t[0]
 *                     t.pop("_skipped", None)             # <<<<<<<<<<<<<<
 *             def show_skip(t):
 *                 if t._skipped.asList()[-1:] == ['']:
 */
  __pyx_tuple__69 = PyTuple_Pack(2, __pyx_n_u_skipped_2, Py_None); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 3380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);

  /* "cPyparsing.pyx":3382
 *                     t.pop("_skipped", None)
 *             def show_skip(t):
 *                 if t._skipped.asList()[-1:] == ['']:             # <<<<<<<<<<<<<<
 *                     skipped = t.pop('_skipped')
 *                     t['_skipped'] = 'missing <' + repr(self.anchor) + '>'
 */
  __pyx_slice__70 = PySlice_New(__pyx_int_neg_1, Py_None, Py_None); if (unlikely(!__pyx_slice__70)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__70);
  __Pyx_GIVEREF(__pyx_slice__70);

  /* "cPyparsing.pyx":3377
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 *             def must_skip(t):             # <<<<<<<<<<<<<<
 *                 if not t._skipped or t._skipped.asList() == ['']:
 *                     del t[0]
 */
  __pyx_tuple__71 = PyTuple_Pack(1, __pyx_n_s_t); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 3377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__71, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_must_skip, 3377, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) __PYX_ERR(0, 3377, __pyx_L1_error)

  /* "cPyparsing.pyx":3381
 *                     del t[0]
 *                     t.pop("_skipped", None)
 *             def show_skip(t):             # <<<<<<<<<<<<<<
 *                 if t._skipped.asList()[-1:] == ['']:
 *                     skipped = t.pop('_skipped')
 */
  __pyx_tuple__73 = PyTuple_Pack(2, __pyx_n_s_t, __pyx_n_s_skipped_3); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 3381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);
  __pyx_codeobj__74 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__73, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_show_skip, 3381, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__74)) __PYX_ERR(0, 3381, __pyx_L1_error)

  /* "cPyparsing.pyx":3394
 * 
 *     def parseImpl(self, *args):
 *         raise Exception("use of `...` expression without following SkipTo target expression")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__75 = PyTuple_Pack(1, __pyx_kp_u_use_of_expression_without_follow); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 3394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);

  /* "cPyparsing.pyx":3450
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Literal; use Empty() instead",             # <<<<<<<<<<<<<<
 *                             SyntaxWarning, stacklevel=2)
 *             self.__class__ = Empty
 */
  __pyx_tuple__76 = PyTuple_Pack(2, __pyx_kp_u_null_string_passed_to_Literal_us, __pyx_builtin_SyntaxWarning); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(0, 3450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);

  /* "cPyparsing.pyx":3525
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Keyword; use Empty() instead",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *         self.name = '"%s"' % self.match
 */
  __pyx_tuple__77 = PyTuple_Pack(2, __pyx_kp_u_null_string_passed_to_Keyword_us, __pyx_builtin_SyntaxWarning); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 3525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "cPyparsing.pyx":3782
 * 
 *         if min < 1:
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")             # <<<<<<<<<<<<<<
 * 
 *         self.minLen = min
 */
  __pyx_tuple__78 = PyTuple_Pack(1, __pyx_kp_u_cannot_specify_a_minimum_length); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(0, 3782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);

  /* "cPyparsing.pyx":3887
 *             def charsAsStr(s):
 *                 if len(s) > 4:
 *                     return s[:4] + "..."             # <<<<<<<<<<<<<<
 *                 else:
 *                     return s
 */
  __pyx_slice__81 = PySlice_New(Py_None, __pyx_int_4, Py_None); if (unlikely(!__pyx_slice__81)) __PYX_ERR(0, 3887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__81);
  __Pyx_GIVEREF(__pyx_slice__81);

  /* "cPyparsing.pyx":3885
 *         if self.strRepr is None:
 * 
 *             def charsAsStr(s):             # <<<<<<<<<<<<<<
 *                 if len(s) > 4:
 *                     return s[:4] + "..."
 */
  __pyx_tuple__82 = PyTuple_Pack(1, __pyx_n_s_s); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(0, 3885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__82, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_charsAsStr, 3885, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(0, 3885, __pyx_L1_error)

  /* "cPyparsing.pyx":3973
 *         if isinstance(pattern, basestring):
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",             # <<<<<<<<<<<<<<
 *                               SyntaxWarning, stacklevel=2)
 * 
 */
  __pyx_tuple__84 = PyTuple_Pack(2, __pyx_kp_u_null_string_passed_to_Regex_use, __pyx_builtin_SyntaxWarning); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 3973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);

  /* "cPyparsing.pyx":3993
 * 
 *         else:
 *             raise TypeError("Regex may only be constructed with a string or a compiled RE object")             # <<<<<<<<<<<<<<
 * 
 *         self.re_match = self.re.match
 */
  __pyx_tuple__85 = PyTuple_Pack(1, __pyx_kp_u_Regex_may_only_be_constructed_wi); if (unlikely(!__pyx_tuple__85)) __PYX_ERR(0, 3993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);

  /* "cPyparsing.pyx":4120
 *         """
 *         if self.asGroupList:
 *             warnings.warn("cannot use sub() with Regex(asGroupList=True)",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
  __pyx_tuple__86 = PyTuple_Pack(2, __pyx_kp_u_cannot_use_sub_with_Regex_asGrou, __pyx_builtin_SyntaxWarning); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 4120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);

  /* "cPyparsing.pyx":4125
 * 
 *         if self.asMatch and callable(repl):
 *             warnings.warn("cannot use sub() with a callable with Regex(asMatch=True)",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
  __pyx_tuple__87 = PyTuple_Pack(2, __pyx_kp_u_cannot_use_sub_with_a_callable_w, __pyx_builtin_SyntaxWarning); if (unlikely(!__pyx_tuple__87)) __PYX_ERR(0, 4125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);

  /* "cPyparsing.pyx":4130
 * 
 *         if self.asMatch:
 *             def pa(tokens):             # <<<<<<<<<<<<<<
 *                 return tokens[0].expand(repl)
 *         else:
 */
  __pyx_tuple__88 = PyTuple_Pack(1, __pyx_n_s_tokens); if (unlikely(!__pyx_tuple__88)) __PYX_ERR(0, 4130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);
  __pyx_codeobj__89 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_pa, 4130, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__89)) __PYX_ERR(0, 4130, __pyx_L1_error)

  /* "cPyparsing.pyx":4133
 *                 return tokens[0].expand(repl)
 *         else:
 *             def pa(tokens):             # <<<<<<<<<<<<<<
 *                 return self.re.sub(repl, tokens[0])
 *         return self.addParseAction(pa)
 */
  __pyx_codeobj__90 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_pa, 4133, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__90)) __PYX_ERR(0, 4133, __pyx_L1_error)

  /* "cPyparsing.pyx":4183
 *         quoteChar = quoteChar.strip()
 *         if not quoteChar:
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             raise SyntaxError()
 * 
 */
  __pyx_tuple__92 = PyTuple_Pack(2, __pyx_kp_u_quoteChar_cannot_be_the_empty_st, __pyx_builtin_SyntaxWarning); if (unlikely(!__pyx_tuple__92)) __PYX_ERR(0, 4183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);

  /* "cPyparsing.pyx":4191
 *             endQuoteChar = endQuoteChar.strip()
 *             if not endQuoteChar:
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *                 raise SyntaxError()
 * 
 */
  __pyx_tuple__93 = PyTuple_Pack(2, __pyx_kp_u_endQuoteChar_cannot_be_the_empty, __pyx_builtin_SyntaxWarning); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 4191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);

  /* "cPyparsing.pyx":4358
 * 
 *         if min < 1:
 *             raise ValueError("cannot specify a minimum length < 1; use "             # <<<<<<<<<<<<<<
 *                              "Optional(CharsNotIn()) if zero-length char group is permitted")
 * 
 */
  __pyx_tuple__101 = PyTuple_Pack(1, __pyx_kp_u_cannot_specify_a_minimum_length_2); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 4358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);

  /* "cPyparsing.pyx":4580
 *     def __init__(self):
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected end of line"
 * 
 */
  __pyx_tuple__103 = PyTuple_Pack(2, __pyx_kp_u__19, __pyx_kp_u__10); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);

  /* "cPyparsing.pyx":4883
 *                         tmp.append(SkipTo(skipto_arg)("_skipped*"))
 *                     else:
 *                         raise Exception("cannot construct And with sequence ending in ...")             # <<<<<<<<<<<<<<
 *                 else:
 *                     tmp.append(expr)
 */
  __pyx_tuple__106 = PyTuple_Pack(1, __pyx_kp_u_cannot_construct_And_with_sequen); if (unlikely(!__pyx_tuple__106)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);

  /* "cPyparsing.pyx":5052
 *                 return best_expr._parse(instring, loc, doActions)
 * 
 *             longest = -1, None             # <<<<<<<<<<<<<<
 *             for loc1, expr1 in matches:
 *                 if loc1 <= longest[0]:
 */
  __pyx_tuple__109 = PyTuple_Pack(2, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(0, 5052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);

  /* "cPyparsing.pyx":6366
 *     """
 *     f = _trim_arity(f)
 *     def z(*paArgs):             # <<<<<<<<<<<<<<
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 */
  __pyx_tuple__120 = PyTuple_Pack(7, __pyx_n_s_paArgs, __pyx_n_s_thisFunc, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_ret, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__120)) __PYX_ERR(0, 6366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);
  __pyx_codeobj__121 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__120, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_z, 6366, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__121)) __PYX_ERR(0, 6366, __pyx_L1_error)

  /* "cPyparsing.pyx":6433
 *     """
 *     arrayExpr = Forward()
 *     def countFieldParseAction(s, l, t):             # <<<<<<<<<<<<<<
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 */
  __pyx_tuple__123 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_n); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(0, 6433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);
  __pyx_codeobj__124 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__123, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_countFieldParseAction, 6433, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__124)) __PYX_ERR(0, 6433, __pyx_L1_error)

  /* "cPyparsing.pyx":6470
 *     """
 *     rep = Forward()
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */
  __pyx_tuple__125 = PyTuple_Pack(6, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_tflat, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__125)) __PYX_ERR(0, 6470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__125);
  __Pyx_GIVEREF(__pyx_tuple__125);
  __pyx_codeobj__126 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__125, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_copyTokenToRepeater, 6470, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__126)) __PYX_ERR(0, 6470, __pyx_L1_error)

  /* "cPyparsing.pyx":6507
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 *                 raise ParseException('', 0, '')             # <<<<<<<<<<<<<<
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 */
  __pyx_tuple__127 = PyTuple_Pack(3, __pyx_kp_u__10, __pyx_int_0, __pyx_kp_u__10); if (unlikely(!__pyx_tuple__127)) __PYX_ERR(0, 6507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__127);
  __Pyx_GIVEREF(__pyx_tuple__127);

  /* "cPyparsing.pyx":6504
 *     def copyTokenToRepeater(s, l, t):
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):             # <<<<<<<<<<<<<<
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 */
  __pyx_tuple__128 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_theseTokens); if (unlikely(!__pyx_tuple__128)) __PYX_ERR(0, 6504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__128);
  __Pyx_GIVEREF(__pyx_tuple__128);
  __pyx_codeobj__129 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__128, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_mustMatchTheseTokens, 6504, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__129)) __PYX_ERR(0, 6504, __pyx_L1_error)

  /* "cPyparsing.pyx":6502
 *     e2 = expr.copy()
 *     rep <<= e2
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 *         def mustMatchTheseTokens(s, l, t):
 */
  __pyx_tuple__130 = PyTuple_Pack(6, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_matchTokens, __pyx_n_s_mustMatchTheseTokens, __pyx_n_s_mustMatchTheseTokens); if (unlikely(!__pyx_tuple__130)) __PYX_ERR(0, 6502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__130);
  __Pyx_GIVEREF(__pyx_tuple__130);
  __pyx_codeobj__131 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__130, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_copyTokenToRepeater, 6502, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__131)) __PYX_ERR(0, 6502, __pyx_L1_error)

  /* "cPyparsing.pyx":6517
 *     for c in r"\^-[]":
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")             # <<<<<<<<<<<<<<
 *     s = s.replace("\t", r"\t")
 *     return _ustr(s)
 */
  __pyx_tuple__132 = PyTuple_Pack(2, __pyx_kp_u__19, __pyx_kp_u_n_2); if (unlikely(!__pyx_tuple__132)) __PYX_ERR(0, 6517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__132);
  __Pyx_GIVEREF(__pyx_tuple__132);

  /* "cPyparsing.pyx":6518
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")
 *     s = s.replace("\t", r"\t")             # <<<<<<<<<<<<<<
 *     return _ustr(s)
 * 
 */
  __pyx_tuple__133 = PyTuple_Pack(2, __pyx_kp_u__98, __pyx_kp_u_t_2); if (unlikely(!__pyx_tuple__133)) __PYX_ERR(0, 6518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__133);
  __Pyx_GIVEREF(__pyx_tuple__133);

  /* "cPyparsing.pyx":6554
 *     """
 *     if isinstance(caseless, basestring):
 *         warnings.warn("More than one string argument passed to oneOf, pass "             # <<<<<<<<<<<<<<
 *                       "choices as a list or space-delimited string", stacklevel=2)
 * 
 */
  __pyx_tuple__134 = PyTuple_Pack(1, __pyx_kp_u_More_than_one_string_argument_pa); if (unlikely(!__pyx_tuple__134)) __PYX_ERR(0, 6554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__134);
  __Pyx_GIVEREF(__pyx_tuple__134);

  /* "cPyparsing.pyx":6572
 *         symbols = list(strs)
 *     else:
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",             # <<<<<<<<<<<<<<
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:
 */
  __pyx_tuple__135 = PyTuple_Pack(2, __pyx_kp_u_Invalid_argument_to_oneOf_expect, __pyx_builtin_SyntaxWarning); if (unlikely(!__pyx_tuple__135)) __PYX_ERR(0, 6572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__135);
  __Pyx_GIVEREF(__pyx_tuple__135);

  /* "cPyparsing.pyx":6602
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",             # <<<<<<<<<<<<<<
 *                     SyntaxWarning, stacklevel=2)
 * 
 */
  __pyx_tuple__137 = PyTuple_Pack(2, __pyx_kp_u_Exception_creating_Regex_for_one, __pyx_builtin_SyntaxWarning); if (unlikely(!__pyx_tuple__137)) __PYX_ERR(0, 6602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__137);
  __Pyx_GIVEREF(__pyx_tuple__137);

  /* "cPyparsing.pyx":6683
 *         extractText = lambda s, l, t: s[t._original_start: t._original_end]
 *     else:
 *         def extractText(s, l, t):             # <<<<<<<<<<<<<<
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 */
  __pyx_codeobj__138 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__8, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_extractText, 6683, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__138)) __PYX_ERR(0, 6683, __pyx_L1_error)

  /* "cPyparsing.pyx":6774
 *     a specific column in the input text.
 *     """
 *     def verifyCol(strg, locn, toks):             # <<<<<<<<<<<<<<
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 */
  __pyx_tuple__139 = PyTuple_Pack(3, __pyx_n_s_strg, __pyx_n_s_locn, __pyx_n_s_toks); if (unlikely(!__pyx_tuple__139)) __PYX_ERR(0, 6774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__139);
  __Pyx_GIVEREF(__pyx_tuple__139);
  __pyx_codeobj__140 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__139, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_verifyCol, 6774, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__140)) __PYX_ERR(0, 6774, __pyx_L1_error)

  /* "cPyparsing.pyx":6807
 *         quotedString.parseString("'Now is the Winter of our Discontent'") # -> ["Now is the Winter of our Discontent"]
 *     """
 *     return t[0][1:-1]             # <<<<<<<<<<<<<<
 * 
 * def tokenMap(func, *args):
 */
  __pyx_slice__141 = PySlice_New(__pyx_int_1, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_slice__141)) __PYX_ERR(0, 6807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__141);
  __Pyx_GIVEREF(__pyx_slice__141);

  /* "cPyparsing.pyx":6845
 *         ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']
 *     """
 *     def pa(s, l, t):             # <<<<<<<<<<<<<<
 *         return [func(tokn, *args) for tokn in t]
 * 
 */
  __pyx_tuple__142 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_tokn); if (unlikely(!__pyx_tuple__142)) __PYX_ERR(0, 6845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__142);
  __Pyx_GIVEREF(__pyx_tuple__142);
  __pyx_codeobj__143 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__142, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_pa, 6845, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__143)) __PYX_ERR(0, 6845, __pyx_L1_error)

  /* "cPyparsing.pyx":6895
 *     openTag.setName("<%s>" % resname)
 *     # add start<tagname> results name in parse action now that ungrouped names are not reported at two levels
 *     openTag.addParseAction(lambda t: t.__setitem__("start" + "".join(resname.replace(":", " ").title().split()), t.copy()))             # <<<<<<<<<<<<<<
 *     closeTag = closeTag("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)
 *     openTag.tag = resname
 */
  __pyx_tuple__146 = PyTuple_Pack(2, __pyx_kp_u__145, __pyx_kp_u__16); if (unlikely(!__pyx_tuple__146)) __PYX_ERR(0, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__146);
  __Pyx_GIVEREF(__pyx_tuple__146);

  /* "cPyparsing.pyx":6881
 *                    + tagStr("tag")
 *                    + Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue)))
 *                    + Optional("/", default=[False])("empty").setParseAction(lambda s, l, t: t[0] == '/')             # <<<<<<<<<<<<<<
 *                    + suppress_GT)
 *     else:
 */
  __pyx_tuple__149 = PyTuple_Pack(1, __pyx_kp_u__144); if (unlikely(!__pyx_tuple__149)) __PYX_ERR(0, 6881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__149);
  __Pyx_GIVEREF(__pyx_tuple__149);

  /* "cPyparsing.pyx":6999
 *             attrs = attrDict.items()
 *         attrs = [(k, v) for k, v in attrs]
 *         def pa(s, l, tokens):             # <<<<<<<<<<<<<<
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 */
  __pyx_tuple__151 = PyTuple_Pack(5, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_tokens, __pyx_n_s_attrName, __pyx_n_s_attrValue); if (unlikely(!__pyx_tuple__151)) __PYX_ERR(0, 6999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__151);
  __Pyx_GIVEREF(__pyx_tuple__151);
  __pyx_codeobj__152 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__151, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_pa, 6999, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__152)) __PYX_ERR(0, 6999, __pyx_L1_error)

  /* "cPyparsing.pyx":7126
 *     # captive version of FollowedBy that does not do parse actions or capture results names
 *     class _FB(FollowedBy):
 *         def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *             self.expr.tryParse(instring, loc)
 *             return loc, []
 */
  __pyx_tuple__153 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__153)) __PYX_ERR(0, 7126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__153);
  __Pyx_GIVEREF(__pyx_tuple__153);
  __pyx_codeobj__154 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 7126, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__154)) __PYX_ERR(0, 7126, __pyx_L1_error)
  __pyx_tuple__155 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__155)) __PYX_ERR(0, 7126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__155);
  __Pyx_GIVEREF(__pyx_tuple__155);

  /* "cPyparsing.pyx":7137
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     "if numterms=3, opExpr must be a tuple or list of two expressions")
 *             opExpr1, opExpr2 = opExpr
 */
  __pyx_tuple__156 = PyTuple_Pack(1, __pyx_kp_u_if_numterms_3_opExpr_must_be_a_t); if (unlikely(!__pyx_tuple__156)) __PYX_ERR(0, 7137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__156);
  __Pyx_GIVEREF(__pyx_tuple__156);

  /* "cPyparsing.pyx":7153
 *                              + Group(lastExpr + OneOrMore(opExpr1 + lastExpr + opExpr2 + lastExpr)))
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")             # <<<<<<<<<<<<<<
 *         elif rightLeftAssoc == opAssoc.RIGHT:
 *             if arity == 1:
 */
  __pyx_tuple__157 = PyTuple_Pack(1, __pyx_kp_u_operator_must_be_unary_1_binary); if (unlikely(!__pyx_tuple__157)) __PYX_ERR(0, 7153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__157);
  __Pyx_GIVEREF(__pyx_tuple__157);

  /* "cPyparsing.pyx":7171
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")             # <<<<<<<<<<<<<<
 *         if pa:
 *             if isinstance(pa, (tuple, list)):
 */
  __pyx_tuple__158 = PyTuple_Pack(1, __pyx_kp_u_operator_must_indicate_right_or); if (unlikely(!__pyx_tuple__158)) __PYX_ERR(0, 7171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__158);
  __Pyx_GIVEREF(__pyx_tuple__158);

  /* "cPyparsing.pyx":7258
 *     """
 *     if opener == closer:
 *         raise ValueError("opening and closing strings cannot be the same")             # <<<<<<<<<<<<<<
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 */
  __pyx_tuple__159 = PyTuple_Pack(1, __pyx_kp_u_opening_and_closing_strings_cann); if (unlikely(!__pyx_tuple__159)) __PYX_ERR(0, 7258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__159);
  __Pyx_GIVEREF(__pyx_tuple__159);

  /* "cPyparsing.pyx":7287
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")             # <<<<<<<<<<<<<<
 *     ret = Forward()
 *     if ignoreExpr is not None:
 */
  __pyx_tuple__160 = PyTuple_Pack(1, __pyx_kp_u_opening_and_closing_arguments_mu); if (unlikely(!__pyx_tuple__160)) __PYX_ERR(0, 7287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__160);
  __Pyx_GIVEREF(__pyx_tuple__160);

  /* "cPyparsing.pyx":7379
 *     backup_stack = indentStack[:]
 * 
 *     def reset_stack():             # <<<<<<<<<<<<<<
 *         indentStack[:] = backup_stack
 * 
 */
  __pyx_codeobj__161 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_reset_stack, 7379, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__161)) __PYX_ERR(0, 7379, __pyx_L1_error)

  /* "cPyparsing.pyx":7382
 *         indentStack[:] = backup_stack
 * 
 *     def checkPeerIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s): return
 *         curCol = col(l, s)
 */
  __pyx_tuple__162 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_curCol); if (unlikely(!__pyx_tuple__162)) __PYX_ERR(0, 7382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__162);
  __Pyx_GIVEREF(__pyx_tuple__162);
  __pyx_codeobj__163 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__162, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_checkPeerIndent, 7382, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__163)) __PYX_ERR(0, 7382, __pyx_L1_error)

  /* "cPyparsing.pyx":7390
 *             raise ParseException(s, l, "not a peer entry")
 * 
 *     def checkSubIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 */
  __pyx_codeobj__164 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__162, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_checkSubIndent, 7390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__164)) __PYX_ERR(0, 7390, __pyx_L1_error)

  /* "cPyparsing.pyx":7397
 *             raise ParseException(s, l, "not a subentry")
 * 
 *     def checkUnindent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s): return
 *         curCol = col(l, s)
 */
  __pyx_codeobj__165 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__162, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_checkUnindent, 7397, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__165)) __PYX_ERR(0, 7397, __pyx_L1_error)

  /* "cPyparsing.pyx":7687
 *             [datetime.date(1999, 12, 31)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 */
  __pyx_tuple__167 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_ve); if (unlikely(!__pyx_tuple__167)) __PYX_ERR(0, 7687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__167);
  __Pyx_GIVEREF(__pyx_tuple__167);
  __pyx_codeobj__168 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__167, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_cvt_fn, 7687, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__168)) __PYX_ERR(0, 7687, __pyx_L1_error)

  /* "cPyparsing.pyx":7712
 *             [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 */
  __pyx_codeobj__169 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__167, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_cvt_fn, 7712, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__169)) __PYX_ERR(0, 7712, __pyx_L1_error)

  /* "cPyparsing.pyx":64
 * import re
 * # [CPYPARSING] fix sre_constants deprecation
 * if sys.version_info >= (3, 11):             # <<<<<<<<<<<<<<
 *     sre_constants = re
 * else:
 */
  __pyx_tuple__171 = PyTuple_Pack(2, __pyx_int_3, __pyx_int_11); if (unlikely(!__pyx_tuple__171)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__171);
  __Pyx_GIVEREF(__pyx_tuple__171);

  /* "cPyparsing.pyx":156
 * __diag__._all_names = [nm for nm in vars(__diag__) if nm.startswith("enable_") or nm.startswith("warn_")]
 * 
 * def _enable_all_warnings():             # <<<<<<<<<<<<<<
 *     __diag__.warn_multiple_tokens_in_named_alternation = True
 *     __diag__.warn_ungrouped_named_tokens_in_collection = True
 */
  __pyx_codeobj__172 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_enable_all_warnings, 156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__172)) __PYX_ERR(0, 156, __pyx_L1_error)

  /* "cPyparsing.pyx":205
 * 
 *     # [CPYPARSING] repr logic
 *     def repr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, unicode):
 *             return py_repr(obj).lstrip("u")
 */
  __pyx_codeobj__173 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__32, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_repr, 205, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__173)) __PYX_ERR(0, 205, __pyx_L1_error)

  /* "cPyparsing.pyx":213
 *     # [CPYPARSING] _ustr logic
 *     str = unicode
 *     def _ustr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 */
  __pyx_codeobj__174 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__32, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ustr, 213, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__174)) __PYX_ERR(0, 213, __pyx_L1_error)

  /* "cPyparsing.pyx":229
 * 
 * # [CPYPARSING] custom list_str
 * def list_str(l):             # <<<<<<<<<<<<<<
 *     return "[" + ", ".join(repr(x) for x in l) + "]"
 * 
 */
  __pyx_tuple__175 = PyTuple_Pack(3, __pyx_n_s_l, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__175)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__175);
  __Pyx_GIVEREF(__pyx_tuple__175);
  __pyx_codeobj__176 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_list_str, 229, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__176)) __PYX_ERR(0, 229, __pyx_L1_error)

  /* "cPyparsing.pyx":232
 *     return "[" + ", ".join(repr(x) for x in l) + "]"
 * 
 * _generatorType = type((y for y in range(1)))             # <<<<<<<<<<<<<<
 * 
 * def _xml_escape(data):
 */
  __pyx_tuple__177 = PyTuple_Pack(1, __pyx_int_1); if (unlikely(!__pyx_tuple__177)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__177);
  __Pyx_GIVEREF(__pyx_tuple__177);

  /* "cPyparsing.pyx":234
 * _generatorType = type((y for y in range(1)))
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */
  __pyx_tuple__178 = PyTuple_Pack(7, __pyx_n_s_data, __pyx_n_s_from_symbols, __pyx_n_s_to_symbols, __pyx_n_s_from, __pyx_n_s_to, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__178)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__178);
  __Pyx_GIVEREF(__pyx_tuple__178);
  __pyx_codeobj__179 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_xml_escape, 234, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__179)) __PYX_ERR(0, 234, __pyx_L1_error)

  /* "cPyparsing.pyx":248
 * hexnums = nums + "ABCDEFabcdef"
 * alphanums = alphas + nums
 * _bslash = chr(92)             # <<<<<<<<<<<<<<
 * printables = "".join(c for c in string.printable if c not in string.whitespace)
 * 
 */
  __pyx_tuple__180 = PyTuple_Pack(1, __pyx_int_92); if (unlikely(!__pyx_tuple__180)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__180);
  __Pyx_GIVEREF(__pyx_tuple__180);

  /* "cPyparsing.pyx":252
 * 
 * 
 * def conditionAsParseAction(fn, message=None, fatal=False):             # <<<<<<<<<<<<<<
 *     msg = message if message is not None else "failed user-defined condition"
 *     exc_type = ParseFatalException if fatal else ParseException
 */
  __pyx_tuple__181 = PyTuple_Pack(7, __pyx_n_s_fn, __pyx_n_s_message, __pyx_n_s_fatal, __pyx_n_s_msg, __pyx_n_s_exc_type, __pyx_n_s_pa, __pyx_n_s_pa); if (unlikely(!__pyx_tuple__181)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__181);
  __Pyx_GIVEREF(__pyx_tuple__181);
  __pyx_codeobj__182 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__181, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_conditionAsParseAction, 252, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__182)) __PYX_ERR(0, 252, __pyx_L1_error)
  __pyx_tuple__183 = PyTuple_Pack(2, Py_None, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__183)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__183);
  __Pyx_GIVEREF(__pyx_tuple__183);

  /* "cPyparsing.pyx":267
 *     """base exception class for all parsing runtime exceptions"""
 *     # [CPYPARSING] add slots
 *     __slots__ = ("loc", "msg", "pstr", "parserElement", "args")             # <<<<<<<<<<<<<<
 * 
 *     # Performance tuning: we construct a *lot* of these, so keep this
 */
  __pyx_tuple__184 = PyTuple_Pack(5, __pyx_n_u_loc, __pyx_n_u_msg, __pyx_n_u_pstr, __pyx_n_u_parserElement, __pyx_n_u_args); if (unlikely(!__pyx_tuple__184)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__184);
  __Pyx_GIVEREF(__pyx_tuple__184);

  /* "cPyparsing.pyx":271
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):             # <<<<<<<<<<<<<<
 *         self.loc = loc
 *         if msg is None:
 */
  __pyx_tuple__185 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_pstr, __pyx_n_s_loc, __pyx_n_s_msg, __pyx_n_s_elem); if (unlikely(!__pyx_tuple__185)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__185);
  __Pyx_GIVEREF(__pyx_tuple__185);
  __pyx_codeobj__186 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 271, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__186)) __PYX_ERR(0, 271, __pyx_L1_error)
  __pyx_tuple__187 = PyTuple_Pack(3, ((PyObject *)__pyx_int_0), Py_None, Py_None); if (unlikely(!__pyx_tuple__187)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__187);
  __Pyx_GIVEREF(__pyx_tuple__187);

  /* "cPyparsing.pyx":282
 *         self.args = (pstr, loc, msg)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_exception(cls, pe):
 *         """
 */
  __pyx_tuple__188 = PyTuple_Pack(2, __pyx_n_s_cls, __pyx_n_s_pe); if (unlikely(!__pyx_tuple__188)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__188);
  __Pyx_GIVEREF(__pyx_tuple__188);
  __pyx_codeobj__189 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_from_exception, 282, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__189)) __PYX_ERR(0, 282, __pyx_L1_error)

  /* "cPyparsing.pyx":290
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)
 * 
 *     def __getattr__(self, aname):             # <<<<<<<<<<<<<<
 *         """supported attributes by name are:
 *            - lineno - returns the line number of the exception text
 */
  __pyx_tuple__190 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_aname); if (unlikely(!__pyx_tuple__190)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__190);
  __Pyx_GIVEREF(__pyx_tuple__190);
  __pyx_codeobj__191 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__190, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_getattr, 290, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__191)) __PYX_ERR(0, 290, __pyx_L1_error)

  /* "cPyparsing.pyx":305
 *             raise AttributeError(aname)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if self.pstr:
 *             if self.loc >= len(self.pstr):
 */
  __pyx_tuple__192 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_foundstr); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);
  __pyx_codeobj__193 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 305, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__193)) __PYX_ERR(0, 305, __pyx_L1_error)

  /* "cPyparsing.pyx":315
 *         return ("%s%s  (at char %d), (line:%d, col:%d)" %
 *                    (self.msg, foundstr, self.loc, self.lineno, self.column))
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 *     def markInputline(self, markerString=">!<"):
 */
  __pyx_tuple__194 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__194)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__194);
  __Pyx_GIVEREF(__pyx_tuple__194);
  __pyx_codeobj__195 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_repr_2, 315, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__195)) __PYX_ERR(0, 315, __pyx_L1_error)

  /* "cPyparsing.pyx":317
 *     def __repr__(self):
 *         return _ustr(self)
 *     def markInputline(self, markerString=">!<"):             # <<<<<<<<<<<<<<
 *         """Extracts the exception line from the input string, and marks
 *            the location of the exception with a special symbol.
 */
  __pyx_tuple__196 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_markerString, __pyx_n_s_line_str, __pyx_n_s_line_column); if (unlikely(!__pyx_tuple__196)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__196);
  __Pyx_GIVEREF(__pyx_tuple__196);
  __pyx_codeobj__197 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__196, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_markInputline, 317, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__197)) __PYX_ERR(0, 317, __pyx_L1_error)
  __pyx_tuple__198 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u__14)); if (unlikely(!__pyx_tuple__198)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__198);
  __Pyx_GIVEREF(__pyx_tuple__198);

  /* "cPyparsing.pyx":327
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return "lineno col line".split() + dir(type(self))
 * 
 */
  __pyx_codeobj__199 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_dir, 327, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__199)) __PYX_ERR(0, 327, __pyx_L1_error)

  /* "cPyparsing.pyx":355
 *     __slots__ = ()
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def explain(exc, depth=16):
 *         """
 */
  __pyx_tuple__200 = PyTuple_Pack(12, __pyx_n_s_exc, __pyx_n_s_depth, __pyx_n_s_inspect, __pyx_n_s_ret, __pyx_n_s_callers, __pyx_n_s_seen, __pyx_n_s_i, __pyx_n_s_ff, __pyx_n_s_frm, __pyx_n_s_f_self, __pyx_n_s_self_type, __pyx_n_s_code); if (unlikely(!__pyx_tuple__200)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__200);
  __Pyx_GIVEREF(__pyx_tuple__200);
  __pyx_codeobj__201 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__200, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_explain, 355, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__201)) __PYX_ERR(0, 355, __pyx_L1_error)
  __pyx_tuple__202 = PyTuple_Pack(1, ((PyObject *)__pyx_int_16)); if (unlikely(!__pyx_tuple__202)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__202);
  __Pyx_GIVEREF(__pyx_tuple__202);

  /* "cPyparsing.pyx":459
 *     grammar could be improperly recursive
 *     """
 *     def __init__(self, parseElementList):             # <<<<<<<<<<<<<<
 *         self.parseElementTrace = parseElementList
 * 
 */
  __pyx_tuple__203 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_parseElementList); if (unlikely(!__pyx_tuple__203)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__203);
  __Pyx_GIVEREF(__pyx_tuple__203);
  __pyx_codeobj__204 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__203, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 459, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__204)) __PYX_ERR(0, 459, __pyx_L1_error)

  /* "cPyparsing.pyx":462
 *         self.parseElementTrace = parseElementList
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace
 * 
 */
  __pyx_codeobj__205 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 462, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__205)) __PYX_ERR(0, 462, __pyx_L1_error)

  /* "cPyparsing.pyx":503
 * 
 * 
 * class _ParseResultsWithOffset(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)
 */
  __pyx_tuple__206 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__206)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__206);
  __Pyx_GIVEREF(__pyx_tuple__206);
  __pyx_tuple__207 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__207)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__207);
  __Pyx_GIVEREF(__pyx_tuple__207);

  /* "cPyparsing.pyx":504
 * 
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):             # <<<<<<<<<<<<<<
 *         self.tup = (p1, p2)
 *     def __getitem__(self, i):
 */
  __pyx_tuple__208 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_p1, __pyx_n_s_p2); if (unlikely(!__pyx_tuple__208)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__208);
  __Pyx_GIVEREF(__pyx_tuple__208);
  __pyx_codeobj__209 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__208, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 504, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__209)) __PYX_ERR(0, 504, __pyx_L1_error)

  /* "cPyparsing.pyx":506
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.tup[i]
 *     def __repr__(self):
 */
  __pyx_tuple__210 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_i); if (unlikely(!__pyx_tuple__210)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__210);
  __Pyx_GIVEREF(__pyx_tuple__210);
  __pyx_codeobj__211 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__210, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_getitem, 506, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__211)) __PYX_ERR(0, 506, __pyx_L1_error)

  /* "cPyparsing.pyx":508
 *     def __getitem__(self, i):
 *         return self.tup[i]
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.tup[0])
 *     def setOffset(self, i):
 */
  __pyx_codeobj__212 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_repr_2, 508, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__212)) __PYX_ERR(0, 508, __pyx_L1_error)

  /* "cPyparsing.pyx":510
 *     def __repr__(self):
 *         return repr(self.tup[0])
 *     def setOffset(self, i):             # <<<<<<<<<<<<<<
 *         self.tup = (self.tup[0], i)
 * 
 */
  __pyx_codeobj__213 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__210, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setOffset, 510, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__213)) __PYX_ERR(0, 510, __pyx_L1_error)

  /* "cPyparsing.pyx":513
 *         self.tup = (self.tup[0], i)
 * 
 * class ParseResults(object):             # <<<<<<<<<<<<<<
 *     """Structured parse results, to provide multiple means of access to
 *     the parsed data:
 */
  __pyx_tuple__214 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__214)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__214);
  __Pyx_GIVEREF(__pyx_tuple__214);
  __pyx_tuple__215 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__215)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__215);
  __Pyx_GIVEREF(__pyx_tuple__215);

  /* "cPyparsing.pyx":556
 *         - year: 1999
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):             # <<<<<<<<<<<<<<
 *         if isinstance(toklist, cls):
 *             return toklist
 */
  __pyx_tuple__216 = PyTuple_Pack(6, __pyx_n_s_cls, __pyx_n_s_toklist, __pyx_n_s_name_2, __pyx_n_s_asList, __pyx_n_s_modal, __pyx_n_s_retobj); if (unlikely(!__pyx_tuple__216)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__216);
  __Pyx_GIVEREF(__pyx_tuple__216);
  __pyx_codeobj__217 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__216, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_new, 556, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__217)) __PYX_ERR(0, 556, __pyx_L1_error)
  __pyx_tuple__218 = PyTuple_Pack(4, Py_None, Py_None, ((PyObject *)Py_True), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__218)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__218);
  __Pyx_GIVEREF(__pyx_tuple__218);

  /* "cPyparsing.pyx":565
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if self.__doinit:
 *             self.__doinit = False
 */
  __pyx_tuple__219 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_toklist, __pyx_n_s_name_2, __pyx_n_s_asList, __pyx_n_s_modal, __pyx_n_s_isinstance); if (unlikely(!__pyx_tuple__219)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__219);
  __Pyx_GIVEREF(__pyx_tuple__219);
  __pyx_codeobj__220 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__219, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 565, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__220)) __PYX_ERR(0, 565, __pyx_L1_error)

  /* "cPyparsing.pyx":604
 *                         self[name] = toklist
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]
 */
  __pyx_tuple__221 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_i, __pyx_n_s_v); if (unlikely(!__pyx_tuple__221)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__221);
  __Pyx_GIVEREF(__pyx_tuple__221);
  __pyx_codeobj__222 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__221, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_getitem, 604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__222)) __PYX_ERR(0, 604, __pyx_L1_error)

  /* "cPyparsing.pyx":613
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 */
  __pyx_tuple__223 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_v, __pyx_n_s_isinstance, __pyx_n_s_sub); if (unlikely(!__pyx_tuple__223)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__223);
  __Pyx_GIVEREF(__pyx_tuple__223);
  __pyx_codeobj__224 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__223, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setitem, 613, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__224)) __PYX_ERR(0, 613, __pyx_L1_error)

  /* "cPyparsing.pyx":626
 *             sub.__parent = wkref(self)
 * 
 *     def __delitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 */
  __pyx_tuple__225 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_i, __pyx_n_s_mylen, __pyx_n_s_removed, __pyx_n_s_name_2, __pyx_n_s_occurrences, __pyx_n_s_j, __pyx_n_s_k, __pyx_n_s_value, __pyx_n_s_position); if (unlikely(!__pyx_tuple__225)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__225);
  __Pyx_GIVEREF(__pyx_tuple__225);
  __pyx_codeobj__226 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__225, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_delitem, 626, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__226)) __PYX_ERR(0, 626, __pyx_L1_error)

  /* "cPyparsing.pyx":647
 *             del self.__tokdict[i]
 * 
 *     def __contains__(self, k):             # <<<<<<<<<<<<<<
 *         return k in self.__tokdict
 * 
 */
  __pyx_tuple__227 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_k); if (unlikely(!__pyx_tuple__227)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__227);
  __Pyx_GIVEREF(__pyx_tuple__227);
  __pyx_codeobj__228 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__227, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_contains, 647, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__228)) __PYX_ERR(0, 647, __pyx_L1_error)

  /* "cPyparsing.pyx":650
 *         return k in self.__tokdict
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return len(self.__toklist)
 * 
 */
  __pyx_codeobj__229 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_len_3, 650, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__229)) __PYX_ERR(0, 650, __pyx_L1_error)

  /* "cPyparsing.pyx":653
 *         return len(self.__toklist)
 * 
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return (not not self.__toklist)
 *     __nonzero__ = __bool__
 */
  __pyx_codeobj__230 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_bool, 653, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__230)) __PYX_ERR(0, 653, __pyx_L1_error)

  /* "cPyparsing.pyx":657
 *     __nonzero__ = __bool__
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return iter(self.__toklist)
 * 
 */
  __pyx_codeobj__231 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_iter, 657, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__231)) __PYX_ERR(0, 657, __pyx_L1_error)

  /* "cPyparsing.pyx":660
 *         return iter(self.__toklist)
 * 
 *     def __reversed__(self):             # <<<<<<<<<<<<<<
 *         return iter(self.__toklist[::-1])
 * 
 */
  __pyx_codeobj__232 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_reversed_2, 660, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__232)) __PYX_ERR(0, 660, __pyx_L1_error)

  /* "cPyparsing.pyx":663
 *         return iter(self.__toklist[::-1])
 * 
 *     def _iterkeys(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()
 */
  __pyx_codeobj__233 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_iterkeys_2, 663, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__233)) __PYX_ERR(0, 663, __pyx_L1_error)

  /* "cPyparsing.pyx":669
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */
  __pyx_tuple__234 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__234)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__234);
  __Pyx_GIVEREF(__pyx_tuple__234);
  __pyx_codeobj__235 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_itervalues_2, 669, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__235)) __PYX_ERR(0, 669, __pyx_L1_error)

  /* "cPyparsing.pyx":672
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */
  __pyx_codeobj__236 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_iteritems_2, 672, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__236)) __PYX_ERR(0, 672, __pyx_L1_error)

  /* "cPyparsing.pyx":695
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 *         def keys(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())
 */
  __pyx_codeobj__237 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_keys, 695, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__237)) __PYX_ERR(0, 695, __pyx_L1_error)

  /* "cPyparsing.pyx":699
 *             return list(self.iterkeys())
 * 
 *         def values(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())
 */
  __pyx_codeobj__238 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_values, 699, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__238)) __PYX_ERR(0, 699, __pyx_L1_error)

  /* "cPyparsing.pyx":703
 *             return list(self.itervalues())
 * 
 *         def items(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())
 */
  __pyx_codeobj__239 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_items, 703, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__239)) __PYX_ERR(0, 703, __pyx_L1_error)

  /* "cPyparsing.pyx":707
 *             return list(self.iteritems())
 * 
 *     def haskeys(self):             # <<<<<<<<<<<<<<
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 */
  __pyx_codeobj__240 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_haskeys, 707, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__240)) __PYX_ERR(0, 707, __pyx_L1_error)

  /* "cPyparsing.pyx":712
 *         return bool(self.__tokdict)
 * 
 *     def pop(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Removes and returns item at specified index (default= ``last``).
 */
  __pyx_tuple__241 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_args, __pyx_n_s_kwargs, __pyx_n_s_k, __pyx_n_s_v, __pyx_n_s_index, __pyx_n_s_ret, __pyx_n_s_defaultvalue); if (unlikely(!__pyx_tuple__241)) __PYX_ERR(0, 712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__241);
  __Pyx_GIVEREF(__pyx_tuple__241);
  __pyx_codeobj__242 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__241, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_pop, 712, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__242)) __PYX_ERR(0, 712, __pyx_L1_error)

  /* "cPyparsing.pyx":767
 *             return defaultvalue
 * 
 *     def get(self, key, defaultValue=None):             # <<<<<<<<<<<<<<
 *         """
 *         Returns named result matching the given key, or if there is no
 */
  __pyx_tuple__243 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_key, __pyx_n_s_defaultValue); if (unlikely(!__pyx_tuple__243)) __PYX_ERR(0, 767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__243);
  __Pyx_GIVEREF(__pyx_tuple__243);
  __pyx_codeobj__244 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__243, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_get, 767, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__244)) __PYX_ERR(0, 767, __pyx_L1_error)

  /* "cPyparsing.pyx":790
 *             return defaultValue
 * 
 *     def insert(self, index, insStr):             # <<<<<<<<<<<<<<
 *         """
 *         Inserts new element at location index in the list of parsed tokens.
 */
  __pyx_tuple__245 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_index, __pyx_n_s_insStr, __pyx_n_s_name_2, __pyx_n_s_occurrences, __pyx_n_s_k, __pyx_n_s_value, __pyx_n_s_position); if (unlikely(!__pyx_tuple__245)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__245);
  __Pyx_GIVEREF(__pyx_tuple__245);
  __pyx_codeobj__246 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__245, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_insert, 790, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__246)) __PYX_ERR(0, 790, __pyx_L1_error)

  /* "cPyparsing.pyx":811
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         Add single element to end of ParseResults list of elements.
 */
  __pyx_tuple__247 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_item); if (unlikely(!__pyx_tuple__247)) __PYX_ERR(0, 811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__247);
  __Pyx_GIVEREF(__pyx_tuple__247);
  __pyx_codeobj__248 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__247, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_append, 811, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__248)) __PYX_ERR(0, 811, __pyx_L1_error)

  /* "cPyparsing.pyx":826
 *         self.__toklist.append(item)
 * 
 *     def extend(self, itemseq):             # <<<<<<<<<<<<<<
 *         """
 *         Add sequence of elements to end of ParseResults list of elements.
 */
  __pyx_tuple__249 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_itemseq); if (unlikely(!__pyx_tuple__249)) __PYX_ERR(0, 826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__249);
  __Pyx_GIVEREF(__pyx_tuple__249);
  __pyx_codeobj__250 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__249, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_extend, 826, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__250)) __PYX_ERR(0, 826, __pyx_L1_error)

  /* "cPyparsing.pyx":845
 *             self.__toklist.extend(itemseq)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         """
 *         Clear all elements and results names.
 */
  __pyx_codeobj__251 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_clear, 845, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__251)) __PYX_ERR(0, 845, __pyx_L1_error)

  /* "cPyparsing.pyx":852
 *         self.__tokdict.clear()
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
 */
  __pyx_tuple__252 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_name_2); if (unlikely(!__pyx_tuple__252)) __PYX_ERR(0, 852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__252);
  __Pyx_GIVEREF(__pyx_tuple__252);
  __pyx_codeobj__253 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__252, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_getattr, 852, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__253)) __PYX_ERR(0, 852, __pyx_L1_error)

  /* "cPyparsing.pyx":858
 *             return ""
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         ret = self.copy()
 *         ret += other
 */
  __pyx_tuple__254 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__254)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__254);
  __Pyx_GIVEREF(__pyx_tuple__254);
  __pyx_codeobj__255 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_add, 858, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__255)) __PYX_ERR(0, 858, __pyx_L1_error)

  /* "cPyparsing.pyx":863
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */
  __pyx_tuple__256 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_offset, __pyx_n_s_addoffset, __pyx_n_s_otheritems, __pyx_n_s_otherdictitems, __pyx_n_s_k, __pyx_n_s_v, __pyx_n_s_k, __pyx_n_s_vlist, __pyx_n_s_v); if (unlikely(!__pyx_tuple__256)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__256);
  __Pyx_GIVEREF(__pyx_tuple__256);
  __pyx_codeobj__257 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__256, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_iadd, 863, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__257)) __PYX_ERR(0, 863, __pyx_L1_error)

  /* "cPyparsing.pyx":879
 *         return self
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 */
  __pyx_tuple__258 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__258)) __PYX_ERR(0, 879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__258);
  __Pyx_GIVEREF(__pyx_tuple__258);
  __pyx_codeobj__259 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_radd, 879, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__259)) __PYX_ERR(0, 879, __pyx_L1_error)

  /* "cPyparsing.pyx":887
 *             return other + self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 */
  __pyx_codeobj__260 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_repr_2, 887, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__260)) __PYX_ERR(0, 887, __pyx_L1_error)

  /* "cPyparsing.pyx":890
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */
  __pyx_codeobj__261 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 890, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__261)) __PYX_ERR(0, 890, __pyx_L1_error)

  /* "cPyparsing.pyx":893
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 *     def _asStringList(self, sep=''):             # <<<<<<<<<<<<<<
 *         out = []
 *         for item in self.__toklist:
 */
  __pyx_tuple__262 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_sep, __pyx_n_s_out, __pyx_n_s_item); if (unlikely(!__pyx_tuple__262)) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__262);
  __Pyx_GIVEREF(__pyx_tuple__262);
  __pyx_codeobj__263 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__262, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_asStringList, 893, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__263)) __PYX_ERR(0, 893, __pyx_L1_error)
  __pyx_tuple__264 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u__10)); if (unlikely(!__pyx_tuple__264)) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__264);
  __Pyx_GIVEREF(__pyx_tuple__264);

  /* "cPyparsing.pyx":904
 *         return out
 * 
 *     def asList(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the parse results as a nested list of matching tokens, all converted to strings.
 */
  __pyx_tuple__265 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_res); if (unlikely(!__pyx_tuple__265)) __PYX_ERR(0, 904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__265);
  __Pyx_GIVEREF(__pyx_tuple__265);
  __pyx_codeobj__266 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__265, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_asList, 904, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__266)) __PYX_ERR(0, 904, __pyx_L1_error)

  /* "cPyparsing.pyx":921
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */
  __pyx_tuple__267 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_item_fn, __pyx_n_s_toItem, __pyx_n_s_toItem, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__267)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__267);
  __Pyx_GIVEREF(__pyx_tuple__267);
  __pyx_codeobj__268 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__267, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_asDict, 921, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__268)) __PYX_ERR(0, 921, __pyx_L1_error)

  /* "cPyparsing.pyx":957
 *         return dict((k, toItem(v)) for k, v in item_fn())
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a new copy of a :class:`ParseResults` object.
 */
  __pyx_tuple__269 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__269)) __PYX_ERR(0, 957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__269);
  __Pyx_GIVEREF(__pyx_tuple__269);
  __pyx_codeobj__270 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__269, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_copy, 957, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__270)) __PYX_ERR(0, 957, __pyx_L1_error)

  /* "cPyparsing.pyx":969
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */
  __pyx_tuple__271 = PyTuple_Pack(16, __pyx_n_s_self, __pyx_n_s_doctag, __pyx_n_s_namedItemsOnly, __pyx_n_s_indent, __pyx_n_s_formatted, __pyx_n_s_nl, __pyx_n_s_out, __pyx_n_s_namedItems, __pyx_n_s_nextLevelIndent, __pyx_n_s_selfTag, __pyx_n_s_i, __pyx_n_s_res, __pyx_n_s_resTag, __pyx_n_s_xmlBodyText, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__271)) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__271);
  __Pyx_GIVEREF(__pyx_tuple__271);
  __pyx_codeobj__272 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 16, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__271, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_asXML, 969, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__272)) __PYX_ERR(0, 969, __pyx_L1_error)
  __pyx_tuple__273 = PyTuple_Pack(4, Py_None, ((PyObject *)Py_False), ((PyObject*)__pyx_kp_u__10), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__273)) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__273);
  __Pyx_GIVEREF(__pyx_tuple__273);

  /* "cPyparsing.pyx":1030
 *         return "".join(out)
 * 
 *     def __lookup(self, sub):             # <<<<<<<<<<<<<<
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 */
  __pyx_tuple__274 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_sub, __pyx_n_s_k, __pyx_n_s_vlist, __pyx_n_s_v, __pyx_n_s_loc); if (unlikely(!__pyx_tuple__274)) __PYX_ERR(0, 1030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__274);
  __Pyx_GIVEREF(__pyx_tuple__274);
  __pyx_codeobj__275 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__274, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_lookup, 1030, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__275)) __PYX_ERR(0, 1030, __pyx_L1_error)

  /* "cPyparsing.pyx":1037
 *         return None
 * 
 *     def getName(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Returns the results name for this token expression. Useful when several
 */
  __pyx_tuple__276 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_par); if (unlikely(!__pyx_tuple__276)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__276);
  __Pyx_GIVEREF(__pyx_tuple__276);
  __pyx_codeobj__277 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__276, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_getName, 1037, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__277)) __PYX_ERR(0, 1037, __pyx_L1_error)

  /* "cPyparsing.pyx":1077
 *             return None
 * 
 *     def dump(self, indent='', full=True, include_list=True, _depth=0):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of
 */
  __pyx_tuple__278 = PyTuple_Pack(15, __pyx_n_s_self, __pyx_n_s_indent, __pyx_n_s_full, __pyx_n_s_include_list, __pyx_n_s_depth_2, __pyx_n_s_out, __pyx_n_s_NL, __pyx_n_s_items, __pyx_n_s_k, __pyx_n_s_v, __pyx_n_s_i, __pyx_n_s_vv, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__278)) __PYX_ERR(0, 1077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__278);
  __Pyx_GIVEREF(__pyx_tuple__278);
  __pyx_codeobj__279 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 15, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__278, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_dump, 1077, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__279)) __PYX_ERR(0, 1077, __pyx_L1_error)
  __pyx_tuple__280 = PyTuple_Pack(4, ((PyObject*)__pyx_kp_u__10), ((PyObject *)Py_True), ((PyObject *)Py_True), ((PyObject *)__pyx_int_0)); if (unlikely(!__pyx_tuple__280)) __PYX_ERR(0, 1077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__280);
  __Pyx_GIVEREF(__pyx_tuple__280);

  /* "cPyparsing.pyx":1142
 *         return "".join(out)
 * 
 *     def pprint(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Pretty-printer for parsed results as a list, using the
 */
  __pyx_tuple__281 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_args, __pyx_n_s_kwargs); if (unlikely(!__pyx_tuple__281)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__281);
  __Pyx_GIVEREF(__pyx_tuple__281);
  __pyx_codeobj__282 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__281, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_pprint, 1142, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__282)) __PYX_ERR(0, 1142, __pyx_L1_error)

  /* "cPyparsing.pyx":1170
 * 
 *     # add support for pickle protocol
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 */
  __pyx_codeobj__283 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_getstate, 1170, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__283)) __PYX_ERR(0, 1170, __pyx_L1_error)

  /* "cPyparsing.pyx":1177
 *                  self.__name))
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.__toklist = state[0]
 *         self.__tokdict, par, inAccumNames, self.__name = state[1]
 */
  __pyx_tuple__284 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_state, __pyx_n_s_par, __pyx_n_s_inAccumNames); if (unlikely(!__pyx_tuple__284)) __PYX_ERR(0, 1177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__284);
  __Pyx_GIVEREF(__pyx_tuple__284);
  __pyx_codeobj__285 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__284, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setstate, 1177, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__285)) __PYX_ERR(0, 1177, __pyx_L1_error)

  /* "cPyparsing.pyx":1187
 *             self.__parent = None
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 */
  __pyx_codeobj__286 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_getnewargs, 1187, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__286)) __PYX_ERR(0, 1187, __pyx_L1_error)

  /* "cPyparsing.pyx":1190
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return dir(type(self)) + list(self.keys())
 * 
 */
  __pyx_codeobj__287 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_dir, 1190, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__287)) __PYX_ERR(0, 1190, __pyx_L1_error)

  /* "cPyparsing.pyx":1193
 *         return dir(type(self)) + list(self.keys())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_dict(cls, other, name=None):
 *         """
 */
  __pyx_tuple__288 = PyTuple_Pack(8, __pyx_n_s_cls, __pyx_n_s_other, __pyx_n_s_name_2, __pyx_n_s_is_iterable, __pyx_n_s_is_iterable, __pyx_n_s_ret, __pyx_n_s_k, __pyx_n_s_v); if (unlikely(!__pyx_tuple__288)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__288);
  __Pyx_GIVEREF(__pyx_tuple__288);
  __pyx_codeobj__289 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__288, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_from_dict, 1193, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__289)) __PYX_ERR(0, 1193, __pyx_L1_error)

  /* "cPyparsing.pyx":1223
 * MutableMapping.register(ParseResults)
 * 
 * def col (loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current column within a string, counting newlines as line separators.
 *    The first column is number 1.
 */
  __pyx_tuple__290 = PyTuple_Pack(3, __pyx_n_s_loc, __pyx_n_s_strg, __pyx_n_s_s); if (unlikely(!__pyx_tuple__290)) __PYX_ERR(0, 1223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__290);
  __Pyx_GIVEREF(__pyx_tuple__290);
  __pyx_codeobj__291 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__290, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_col, 1223, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__291)) __PYX_ERR(0, 1223, __pyx_L1_error)

  /* "cPyparsing.pyx":1237
 *     return 1 if 0 < loc < len(s) and s[loc-1] == '\n' else loc - s.rfind("\n", 0, loc)
 * 
 * def lineno(loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current line number within a string, counting newlines as line separators.
 *     The first line is number 1.
 */
  __pyx_tuple__292 = PyTuple_Pack(2, __pyx_n_s_loc, __pyx_n_s_strg); if (unlikely(!__pyx_tuple__292)) __PYX_ERR(0, 1237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__292);
  __Pyx_GIVEREF(__pyx_tuple__292);
  __pyx_codeobj__293 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__292, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_lineno, 1237, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__293)) __PYX_ERR(0, 1237, __pyx_L1_error)

  /* "cPyparsing.pyx":1249
 *     return strg.count("\n", 0, loc) + 1
 * 
 * def line(loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *        """
 */
  __pyx_tuple__294 = PyTuple_Pack(4, __pyx_n_s_loc, __pyx_n_s_strg, __pyx_n_s_lastCR, __pyx_n_s_nextCR); if (unlikely(!__pyx_tuple__294)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__294);
  __Pyx_GIVEREF(__pyx_tuple__294);
  __pyx_codeobj__295 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__294, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_line, 1249, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__295)) __PYX_ERR(0, 1249, __pyx_L1_error)

  /* "cPyparsing.pyx":1259
 *         return strg[lastCR + 1:]
 * 
 * def _defaultStartDebugAction(instring, loc, expr):             # <<<<<<<<<<<<<<
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 */
  __pyx_tuple__296 = PyTuple_Pack(3, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_expr); if (unlikely(!__pyx_tuple__296)) __PYX_ERR(0, 1259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__296);
  __Pyx_GIVEREF(__pyx_tuple__296);
  __pyx_codeobj__297 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__296, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_defaultStartDebugAction, 1259, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__297)) __PYX_ERR(0, 1259, __pyx_L1_error)

  /* "cPyparsing.pyx":1262
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):             # <<<<<<<<<<<<<<
 *     # [CPYPARSING] use custom list_str
 *     print("Matched " + _ustr(expr) + " -> " + list_str(toks.asList()))
 */
  __pyx_tuple__298 = PyTuple_Pack(5, __pyx_n_s_instring, __pyx_n_s_startloc, __pyx_n_s_endloc, __pyx_n_s_expr, __pyx_n_s_toks); if (unlikely(!__pyx_tuple__298)) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__298);
  __Pyx_GIVEREF(__pyx_tuple__298);
  __pyx_codeobj__299 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__298, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_defaultSuccessDebugAction, 1262, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__299)) __PYX_ERR(0, 1262, __pyx_L1_error)

  /* "cPyparsing.pyx":1266
 *     print("Matched " + _ustr(expr) + " -> " + list_str(toks.asList()))
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):             # <<<<<<<<<<<<<<
 *     print("Exception raised:" + _ustr(exc))
 * 
 */
  __pyx_tuple__300 = PyTuple_Pack(4, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_expr, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__300)) __PYX_ERR(0, 1266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__300);
  __Pyx_GIVEREF(__pyx_tuple__300);
  __pyx_codeobj__301 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__300, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_defaultExceptionDebugAction, 1266, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__301)) __PYX_ERR(0, 1266, __pyx_L1_error)

  /* "cPyparsing.pyx":1269
 *     print("Exception raised:" + _ustr(exc))
 * 
 * def nullDebugAction(*args):             # <<<<<<<<<<<<<<
 *     """'Do-nothing' debug action, to suppress debugging output during parsing."""
 *     pass
 */
  __pyx_tuple__302 = PyTuple_Pack(1, __pyx_n_s_args); if (unlikely(!__pyx_tuple__302)) __PYX_ERR(0, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__302);
  __Pyx_GIVEREF(__pyx_tuple__302);
  __pyx_codeobj__303 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__302, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_nullDebugAction, 1269, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__303)) __PYX_ERR(0, 1269, __pyx_L1_error)

  /* "cPyparsing.pyx":1296
 * # this version is Python 2.x-3.x cross-compatible
 * 'decorator to trim function calls to match the arity of the target'
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)
 */
  __pyx_tuple__304 = PyTuple_Pack(12, __pyx_n_s_func, __pyx_n_s_maxargs, __pyx_n_s_limit, __pyx_n_s_foundArity, __pyx_n_s_extract_stack, __pyx_n_s_extract_stack, __pyx_n_s_extract_tb, __pyx_n_s_extract_tb, __pyx_n_s_pa_call_line_synth, __pyx_n_s_wrapper, __pyx_n_s_wrapper, __pyx_n_s_func_name); if (unlikely(!__pyx_tuple__304)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__304);
  __Pyx_GIVEREF(__pyx_tuple__304);
  __pyx_codeobj__305 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__304, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_trim_arity, 1296, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__305)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __pyx_tuple__306 = PyTuple_Pack(1, ((PyObject *)__pyx_int_2)); if (unlikely(!__pyx_tuple__306)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__306);
  __Pyx_GIVEREF(__pyx_tuple__306);

  /* "cPyparsing.pyx":1377
 * 
 * # [CPYPARSING] caches are normal global classes
 * class _UnboundedCache(object):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         self.not_in_cache = object()
 */
  __pyx_tuple__307 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__307)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__307);
  __Pyx_GIVEREF(__pyx_tuple__307);
  __pyx_tuple__308 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__308)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__308);
  __Pyx_GIVEREF(__pyx_tuple__308);

  /* "cPyparsing.pyx":1378
 * # [CPYPARSING] caches are normal global classes
 * class _UnboundedCache(object):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.not_in_cache = object()
 *         # [CPYPARSING] add self.cache
 */
  __pyx_codeobj__309 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 1378, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__309)) __PYX_ERR(0, 1378, __pyx_L1_error)

  /* "cPyparsing.pyx":1383
 *         self.cache = {}
 * 
 *     def get(self, key):             # <<<<<<<<<<<<<<
 *         return self.cache.get(key, self.not_in_cache)
 * 
 */
  __pyx_tuple__310 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_key); if (unlikely(!__pyx_tuple__310)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__310);
  __Pyx_GIVEREF(__pyx_tuple__310);
  __pyx_codeobj__311 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__310, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_get, 1383, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__311)) __PYX_ERR(0, 1383, __pyx_L1_error)

  /* "cPyparsing.pyx":1386
 *         return self.cache.get(key, self.not_in_cache)
 * 
 *     def set(self, key, value):             # <<<<<<<<<<<<<<
 *         self.cache[key] = value
 * 
 */
  __pyx_tuple__312 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_key, __pyx_n_s_value); if (unlikely(!__pyx_tuple__312)) __PYX_ERR(0, 1386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__312);
  __Pyx_GIVEREF(__pyx_tuple__312);
  __pyx_codeobj__313 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__312, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_set, 1386, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__313)) __PYX_ERR(0, 1386, __pyx_L1_error)

  /* "cPyparsing.pyx":1390
 * 
 *     # [CPYPARSING] add update
 *     def update(self, update_dict):             # <<<<<<<<<<<<<<
 *         self.cache.update(update_dict)
 * 
 */
  __pyx_tuple__314 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_update_dict); if (unlikely(!__pyx_tuple__314)) __PYX_ERR(0, 1390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__314);
  __Pyx_GIVEREF(__pyx_tuple__314);
  __pyx_codeobj__315 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_update, 1390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__315)) __PYX_ERR(0, 1390, __pyx_L1_error)

  /* "cPyparsing.pyx":1393
 *         self.cache.update(update_dict)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         self.cache.clear()
 * 
 */
  __pyx_codeobj__316 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_clear, 1393, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__316)) __PYX_ERR(0, 1393, __pyx_L1_error)

  /* "cPyparsing.pyx":1396
 *         self.cache.clear()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return len(self.cache)
 * 
 */
  __pyx_codeobj__317 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_len_3, 1396, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__317)) __PYX_ERR(0, 1396, __pyx_L1_error)

  /* "cPyparsing.pyx":1400
 * 
 *     # [CPYPARSING] add __reduce__
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         return (self.__class__, (), {"cache": self.cache})
 * 
 */
  __pyx_codeobj__318 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_reduce, 1400, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__318)) __PYX_ERR(0, 1400, __pyx_L1_error)

  /* "cPyparsing.pyx":1404
 * 
 * if _OrderedDict is not None:
 *     class _FifoCache(object):             # <<<<<<<<<<<<<<
 *         def __init__(self, size):
 *             self.not_in_cache = object()
 */
  __pyx_tuple__319 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__319)) __PYX_ERR(0, 1404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__319);
  __Pyx_GIVEREF(__pyx_tuple__319);
  __pyx_tuple__320 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__320)) __PYX_ERR(0, 1404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__320);
  __Pyx_GIVEREF(__pyx_tuple__320);

  /* "cPyparsing.pyx":1405
 * if _OrderedDict is not None:
 *     class _FifoCache(object):
 *         def __init__(self, size):             # <<<<<<<<<<<<<<
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 */
  __pyx_tuple__321 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_size); if (unlikely(!__pyx_tuple__321)) __PYX_ERR(0, 1405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__321);
  __Pyx_GIVEREF(__pyx_tuple__321);
  __pyx_codeobj__322 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__321, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 1405, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__322)) __PYX_ERR(0, 1405, __pyx_L1_error)

  /* "cPyparsing.pyx":1411
 *             self.cache = _OrderedDict()
 * 
 *         def get(self, key):             # <<<<<<<<<<<<<<
 *             return self.cache.get(key, self.not_in_cache)
 * 
 */
  __pyx_codeobj__323 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__310, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_get, 1411, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__323)) __PYX_ERR(0, 1411, __pyx_L1_error)

  /* "cPyparsing.pyx":1414
 *             return self.cache.get(key, self.not_in_cache)
 * 
 *         def set(self, key, value):             # <<<<<<<<<<<<<<
 *             self.cache[key] = value
 *             while len(self.cache) > self.size:
 */
  __pyx_codeobj__324 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__312, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_set, 1414, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__324)) __PYX_ERR(0, 1414, __pyx_L1_error)

  /* "cPyparsing.pyx":1423
 * 
 *         # [CPYPARSING] add update
 *         def update(self, update_dict):             # <<<<<<<<<<<<<<
 *             self.cache.update(update_dict)
 *             while len(self.cache) > self.size:
 */
  __pyx_codeobj__325 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_update, 1423, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__325)) __PYX_ERR(0, 1423, __pyx_L1_error)

  /* "cPyparsing.pyx":1431
 *                     pass
 * 
 *         def clear(self):             # <<<<<<<<<<<<<<
 *             self.cache.clear()
 * 
 */
  __pyx_codeobj__326 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_clear, 1431, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__326)) __PYX_ERR(0, 1431, __pyx_L1_error)

  /* "cPyparsing.pyx":1434
 *             self.cache.clear()
 * 
 *         def __len__(self):             # <<<<<<<<<<<<<<
 *             return len(self.cache)
 * 
 */
  __pyx_codeobj__327 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_len_3, 1434, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__327)) __PYX_ERR(0, 1434, __pyx_L1_error)

  /* "cPyparsing.pyx":1438
 * 
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):             # <<<<<<<<<<<<<<
 *             return (self.__class__, (self.size,), {"cache": self.cache})
 * 
 */
  __pyx_codeobj__328 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_reduce, 1438, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__328)) __PYX_ERR(0, 1438, __pyx_L1_error)

  /* "cPyparsing.pyx":1442
 * 
 * else:
 *     class _FifoCache(object):             # <<<<<<<<<<<<<<
 *         def __init__(self, size):
 *             self.not_in_cache = object()
 */
  __pyx_tuple__329 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__329)) __PYX_ERR(0, 1442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__329);
  __Pyx_GIVEREF(__pyx_tuple__329);
  __pyx_tuple__330 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__330)) __PYX_ERR(0, 1442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__330);
  __Pyx_GIVEREF(__pyx_tuple__330);

  /* "cPyparsing.pyx":1443
 * else:
 *     class _FifoCache(object):
 *         def __init__(self, size):             # <<<<<<<<<<<<<<
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 */
  __pyx_codeobj__331 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__321, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 1443, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__331)) __PYX_ERR(0, 1443, __pyx_L1_error)

  /* "cPyparsing.pyx":1450
 *             self.key_fifo = collections.deque([], self.size)
 * 
 *         def get(self, key):             # <<<<<<<<<<<<<<
 *             return self.cache.get(key, self.not_in_cache)
 * 
 */
  __pyx_codeobj__332 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__310, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_get, 1450, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__332)) __PYX_ERR(0, 1450, __pyx_L1_error)

  /* "cPyparsing.pyx":1453
 *             return self.cache.get(key, self.not_in_cache)
 * 
 *         def set(self, key, value):             # <<<<<<<<<<<<<<
 *             self.cache[key] = value
 *             while len(self.key_fifo) > self.size:
 */
  __pyx_codeobj__333 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__312, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_set, 1453, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__333)) __PYX_ERR(0, 1453, __pyx_L1_error)

  /* "cPyparsing.pyx":1459
 *             self.key_fifo.append(key)
 * 
 *         def clear(self):             # <<<<<<<<<<<<<<
 *             self.cache.clear()
 *             self.key_fifo.clear()
 */
  __pyx_codeobj__334 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_clear, 1459, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__334)) __PYX_ERR(0, 1459, __pyx_L1_error)

  /* "cPyparsing.pyx":1463
 *             self.key_fifo.clear()
 * 
 *         def __len__(self):             # <<<<<<<<<<<<<<
 *             return len(self.cache)
 * 
 */
  __pyx_codeobj__335 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_len_3, 1463, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__335)) __PYX_ERR(0, 1463, __pyx_L1_error)

  /* "cPyparsing.pyx":1467
 * 
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):             # <<<<<<<<<<<<<<
 *             return (self.__class__, (self.size,), {"cache": self.cache, "key_fifo": self.key_fifo})
 * 
 */
  __pyx_codeobj__336 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_reduce, 1467, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__336)) __PYX_ERR(0, 1467, __pyx_L1_error)

  /* "cPyparsing.pyx":1471
 * 
 * 
 * class ParserElement(object):             # <<<<<<<<<<<<<<
 *     """Abstract base level parser element class."""
 *     DEFAULT_WHITE_CHARS = " \n\t\r"
 */
  __pyx_tuple__337 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__337)) __PYX_ERR(0, 1471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__337);
  __Pyx_GIVEREF(__pyx_tuple__337);
  __pyx_tuple__338 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__338)) __PYX_ERR(0, 1471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__338);
  __Pyx_GIVEREF(__pyx_tuple__338);

  /* "cPyparsing.pyx":1476
 *     verbose_stacktrace = False
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultWhitespaceChars(chars):
 *         r"""
 */
  __pyx_tuple__340 = PyTuple_Pack(1, __pyx_n_s_chars); if (unlikely(!__pyx_tuple__340)) __PYX_ERR(0, 1476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__340);
  __Pyx_GIVEREF(__pyx_tuple__340);
  __pyx_codeobj__341 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__340, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setDefaultWhitespaceChars, 1476, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__341)) __PYX_ERR(0, 1476, __pyx_L1_error)

  /* "cPyparsing.pyx":1492
 *         ParserElement.DEFAULT_WHITE_CHARS = chars
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def inlineLiteralsUsing(cls):
 *         """
 */
  __pyx_tuple__342 = PyTuple_Pack(1, __pyx_n_s_cls); if (unlikely(!__pyx_tuple__342)) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__342);
  __Pyx_GIVEREF(__pyx_tuple__342);
  __pyx_codeobj__343 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__342, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_inlineLiteralsUsing, 1492, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__343)) __PYX_ERR(0, 1492, __pyx_L1_error)

  /* "cPyparsing.pyx":1514
 *         ParserElement._literalStringClass = cls
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _trim_traceback(cls, tb):
 *         while tb.tb_next:
 */
  __pyx_tuple__344 = PyTuple_Pack(2, __pyx_n_s_cls, __pyx_n_s_tb); if (unlikely(!__pyx_tuple__344)) __PYX_ERR(0, 1514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__344);
  __Pyx_GIVEREF(__pyx_tuple__344);
  __pyx_codeobj__345 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__344, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_trim_traceback, 1514, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__345)) __PYX_ERR(0, 1514, __pyx_L1_error)

  /* "cPyparsing.pyx":1523
 *     _all_parse_elements = None
 *     parse_element_index = None
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def collectParseElements():
 *         ParserElement._all_parse_elements = []
 */
  __pyx_codeobj__346 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_collectParseElements, 1523, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__346)) __PYX_ERR(0, 1523, __pyx_L1_error)

  /* "cPyparsing.pyx":1528
 *         return ParserElement._all_parse_elements
 * 
 *     def __init__(self, savelist=False):             # <<<<<<<<<<<<<<
 *         self.parseAction = list()
 *         self.failAction = None
 */
  __pyx_tuple__347 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_savelist); if (unlikely(!__pyx_tuple__347)) __PYX_ERR(0, 1528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__347);
  __Pyx_GIVEREF(__pyx_tuple__347);
  __pyx_codeobj__348 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__347, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 1528, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__348)) __PYX_ERR(0, 1528, __pyx_L1_error)
  __pyx_tuple__349 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__349)) __PYX_ERR(0, 1528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__349);
  __Pyx_GIVEREF(__pyx_tuple__349);

  /* "cPyparsing.pyx":1555
 *             ParserElement._all_parse_elements.append(wkref(self))
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Make a copy of this :class:`ParserElement`.  Useful for defining
 */
  __pyx_tuple__350 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_cpy); if (unlikely(!__pyx_tuple__350)) __PYX_ERR(0, 1555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__350);
  __Pyx_GIVEREF(__pyx_tuple__350);
  __pyx_codeobj__351 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__350, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_copy, 1555, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__351)) __PYX_ERR(0, 1555, __pyx_L1_error)

  /* "cPyparsing.pyx":1588
 *         return cpy
 * 
 *     def setName(self, name):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for this expression, makes debugging and exception messages clearer.
 */
  __pyx_codeobj__352 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__252, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setName, 1588, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__352)) __PYX_ERR(0, 1588, __pyx_L1_error)

  /* "cPyparsing.pyx":1603
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for referencing matching tokens as a nested attribute
 */
  __pyx_tuple__353 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_name_2, __pyx_n_s_listAllMatches); if (unlikely(!__pyx_tuple__353)) __PYX_ERR(0, 1603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__353);
  __Pyx_GIVEREF(__pyx_tuple__353);
  __pyx_codeobj__354 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__353, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setResultsName_2, 1603, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__354)) __PYX_ERR(0, 1603, __pyx_L1_error)

  /* "cPyparsing.pyx":1626
 *         return self._setResultsName(name, listAllMatches)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         newself = self.copy()
 *         if name.endswith("*"):
 */
  __pyx_tuple__355 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_name_2, __pyx_n_s_listAllMatches, __pyx_n_s_newself); if (unlikely(!__pyx_tuple__355)) __PYX_ERR(0, 1626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__355);
  __Pyx_GIVEREF(__pyx_tuple__355);
  __pyx_codeobj__356 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__355, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setResultsName, 1626, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__356)) __PYX_ERR(0, 1626, __pyx_L1_error)

  /* "cPyparsing.pyx":1635
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set ``breakFlag`` to True to enable, False to
 */
  __pyx_tuple__357 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_breakFlag, __pyx_n_s_parseMethod, __pyx_n_s_breaker, __pyx_n_s_breaker); if (unlikely(!__pyx_tuple__357)) __PYX_ERR(0, 1635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__357);
  __Pyx_GIVEREF(__pyx_tuple__357);
  __pyx_codeobj__358 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__357, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setBreak, 1635, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__358)) __PYX_ERR(0, 1635, __pyx_L1_error)

  /* "cPyparsing.pyx":1654
 *         return self
 * 
 *     def setParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Define one or more actions to perform when successfully matching parse element definition.
 */
  __pyx_tuple__359 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_fns, __pyx_n_s_kwargs, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__359)) __PYX_ERR(0, 1654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__359);
  __Pyx_GIVEREF(__pyx_tuple__359);
  __pyx_codeobj__360 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__359, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setParseAction, 1654, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__360)) __PYX_ERR(0, 1654, __pyx_L1_error)

  /* "cPyparsing.pyx":1703
 *         return self
 * 
 *     def addParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Add one or more parse actions to expression's list of parse actions. See :class:`setParseAction`.
 */
  __pyx_tuple__361 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_fns, __pyx_n_s_kwargs); if (unlikely(!__pyx_tuple__361)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__361);
  __Pyx_GIVEREF(__pyx_tuple__361);
  __pyx_codeobj__362 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__361, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_addParseAction, 1703, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__362)) __PYX_ERR(0, 1703, __pyx_L1_error)

  /* "cPyparsing.pyx":1713
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         :class:`setParseAction` for function call signatures. Unlike ``setParseAction``,
 */
  __pyx_tuple__363 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_fns, __pyx_n_s_kwargs, __pyx_n_s_fn); if (unlikely(!__pyx_tuple__363)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__363);
  __Pyx_GIVEREF(__pyx_tuple__363);
  __pyx_codeobj__364 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__363, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_addCondition, 1713, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__364)) __PYX_ERR(0, 1713, __pyx_L1_error)

  /* "cPyparsing.pyx":1738
 *         return self
 * 
 *     def setFailAction(self, fn):             # <<<<<<<<<<<<<<
 *         """Define action to perform if parsing fails at this expression.
 *            Fail acton fn is a callable function that takes the arguments
 */
  __pyx_tuple__365 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_fn); if (unlikely(!__pyx_tuple__365)) __PYX_ERR(0, 1738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__365);
  __Pyx_GIVEREF(__pyx_tuple__365);
  __pyx_codeobj__366 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__365, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setFailAction, 1738, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__366)) __PYX_ERR(0, 1738, __pyx_L1_error)

  /* "cPyparsing.pyx":1770
 *     #                 exprsFound = True
 *     #     return loc
 *     def _skipIgnorables(self, instring, loc):             # <<<<<<<<<<<<<<
 *         exprsFound = True
 *         while exprsFound:
 */
  __pyx_tuple__367 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_exprsFound, __pyx_n_s_e, __pyx_n_s_dummy); if (unlikely(!__pyx_tuple__367)) __PYX_ERR(0, 1770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__367);
  __Pyx_GIVEREF(__pyx_tuple__367);
  __pyx_codeobj__368 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__367, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_skipIgnorables, 1770, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__368)) __PYX_ERR(0, 1770, __pyx_L1_error)

  /* "cPyparsing.pyx":1783
 *         return loc
 * 
 *     def preParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)
 */
  __pyx_tuple__369 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_wt, __pyx_n_s_instrlen); if (unlikely(!__pyx_tuple__369)) __PYX_ERR(0, 1783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__369);
  __Pyx_GIVEREF(__pyx_tuple__369);
  __pyx_codeobj__370 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__369, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_preParse, 1783, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__370)) __PYX_ERR(0, 1783, __pyx_L1_error)

  /* "cPyparsing.pyx":1795
 *         return loc
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
  __pyx_codeobj__371 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 1795, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__371)) __PYX_ERR(0, 1795, __pyx_L1_error)

  /* "cPyparsing.pyx":1798
 *         return loc, []
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return tokenlist
 * 
 */
  __pyx_tuple__372 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_tokenlist); if (unlikely(!__pyx_tuple__372)) __PYX_ERR(0, 1798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__372);
  __Pyx_GIVEREF(__pyx_tuple__372);
  __pyx_codeobj__373 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__372, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_postParse, 1798, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__373)) __PYX_ERR(0, 1798, __pyx_L1_error)

  /* "cPyparsing.pyx":1899
 * 
 *     #     return loc, retTokens
 *     def _parseNoCache(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] TRY, MATCH, FAIL are constants
 *         debugging = (self.debug)  # and doActions)
 */
  __pyx_tuple__374 = PyTuple_Pack(14, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_callPreParse, __pyx_n_s_debugging, __pyx_n_s_preloc, __pyx_n_s_tokensStart, __pyx_n_s_tokens, __pyx_n_s_err, __pyx_n_s_retTokens, __pyx_n_s_fn, __pyx_n_s_parse_action_exc, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__374)) __PYX_ERR(0, 1899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__374);
  __Pyx_GIVEREF(__pyx_tuple__374);
  __pyx_codeobj__375 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 14, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__374, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseNoCache, 1899, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__375)) __PYX_ERR(0, 1899, __pyx_L1_error)

  /* "cPyparsing.pyx":2000
 *     #     else:
 *     #         return got[0]
 *     def tryParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 */
  __pyx_tuple__376 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc); if (unlikely(!__pyx_tuple__376)) __PYX_ERR(0, 2000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__376);
  __Pyx_GIVEREF(__pyx_tuple__376);
  __pyx_codeobj__377 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__376, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_tryParse, 2000, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__377)) __PYX_ERR(0, 2000, __pyx_L1_error)

  /* "cPyparsing.pyx":2006
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def canParseNext(self, instring, loc):             # <<<<<<<<<<<<<<
 *         try:
 *             self.tryParse(instring, loc)
 */
  __pyx_codeobj__378 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__376, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_canParseNext, 2006, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__378)) __PYX_ERR(0, 2006, __pyx_L1_error)

  /* "cPyparsing.pyx":2054
 *     #                 return value
 *     #             return value[0], value[1].copy()
 *     def _parseCache(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] HIT, MISS are constants
 *         # [CPYPARSING] include packrat_context, merge callPreParse and doActions
 */
  __pyx_tuple__379 = PyTuple_Pack(18, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_callPreParse, __pyx_n_s_lookup_2, __pyx_n_s_cache, __pyx_n_s_value, __pyx_n_s_debugging, __pyx_n_s_preloc, __pyx_n_s_tokensStart, __pyx_n_s_tokens, __pyx_n_s_err, __pyx_n_s_retTokens, __pyx_n_s_fn, __pyx_n_s_parse_action_exc, __pyx_n_s_exc, __pyx_n_s_pe); if (unlikely(!__pyx_tuple__379)) __PYX_ERR(0, 2054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__379);
  __Pyx_GIVEREF(__pyx_tuple__379);
  __pyx_codeobj__380 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 18, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__379, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseCache, 2054, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__380)) __PYX_ERR(0, 2054, __pyx_L1_error)

  /* "cPyparsing.pyx":2169
 * 
 *     # [CPYPARSING] add _update_furthest_loc_for_regex
 *     def _update_furthest_loc_for_regex(self, instring, loc, flags=0):             # <<<<<<<<<<<<<<
 *         if ParserElement._incrementalEnabled:
 *             if flags & re.MULTILINE:
 */
  __pyx_tuple__381 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_flags, __pyx_n_s_next_linebreak_loc); if (unlikely(!__pyx_tuple__381)) __PYX_ERR(0, 2169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__381);
  __Pyx_GIVEREF(__pyx_tuple__381);
  __pyx_codeobj__382 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__381, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_update_furthest_loc_for_regex, 2169, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__382)) __PYX_ERR(0, 2169, __pyx_L1_error)

  /* "cPyparsing.pyx":2183
 *     # [CPYPARSING] add _parseIncremental
 *     _incremental_parent_usefullness_obj = [False]  # caches at start loc can't be reused, so start usefullness at False
 *     def _parseIncremental(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         """Version of ParserElement._parseCache that can reuse caches from common prefix/suffix parses.
 *         Note that unlike _parseCache, _parseIncremental is not thread-safe."""
 */
  __pyx_tuple__383 = PyTuple_Pack(36, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_callPreParse, __pyx_n_s_prefixes_and_suffixes, __pyx_n_s_reversed_instring, __pyx_n_s_other_instring, __pyx_n_s_common_prefix_len, __pyx_n_s_common_suffix_len, __pyx_n_s_lookup_bools, __pyx_n_s_cache, __pyx_n_s_hit, __pyx_n_s_prefix_len, __pyx_n_s_suffix_len, __pyx_n_s_is_instring, __pyx_n_s_prefix_lookup, __pyx_n_s_cache_result, __pyx_n_s_cache_furthest_loc, __pyx_n_s_cache_item, __pyx_n_s_cache_usefullness_obj, __pyx_n_s_loc_in_suffix, __pyx_n_s_suffix_lookup, __pyx_n_s_lookup_2, __pyx_n_s_outer_parent_usefullness_obj, __pyx_n_s_debugging, __pyx_n_s_preloc, __pyx_n_s_tokensStart, __pyx_n_s_tokens, __pyx_n_s_err, __pyx_n_s_retTokens, __pyx_n_s_fn, __pyx_n_s_parse_action_exc, __pyx_n_s_exc, __pyx_n_s_new_loc, __pyx_n_s_ret_toks); if (unlikely(!__pyx_tuple__383)) __PYX_ERR(0, 2183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__383);
  __Pyx_GIVEREF(__pyx_tuple__383);
  __pyx_codeobj__384 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 36, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__383, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseIncremental, 2183, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__384)) __PYX_ERR(0, 2183, __pyx_L1_error)

  /* "cPyparsing.pyx":2398
 *     _parse = _parseNoCache
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def resetCache():
 *         # [CPYPARSING] don't reset in incremental mode
 */
  __pyx_codeobj__385 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_resetCache, 2398, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__385)) __PYX_ERR(0, 2398, __pyx_L1_error)

  /* "cPyparsing.pyx":2413
 *     _incrementalEnabled = False
 *     _incrementalWithResets = False
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enableIncremental(
 *         cache_size_limit=None,
 */
  __pyx_tuple__386 = PyTuple_Pack(3, __pyx_n_s_cache_size_limit, __pyx_n_s_still_reset_cache, __pyx_n_s_cache_successes); if (unlikely(!__pyx_tuple__386)) __PYX_ERR(0, 2413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__386);
  __Pyx_GIVEREF(__pyx_tuple__386);
  __pyx_codeobj__387 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__386, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_enableIncremental, 2413, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__387)) __PYX_ERR(0, 2413, __pyx_L1_error)
  __pyx_tuple__388 = PyTuple_Pack(3, Py_None, ((PyObject *)Py_False), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__388)) __PYX_ERR(0, 2413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__388);
  __Pyx_GIVEREF(__pyx_tuple__388);

  /* "cPyparsing.pyx":2439
 * 
 *     _packratEnabled = False
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enablePackrat(cache_size_limit=128):
 *         """Enables "packrat" parsing, which adds memoizing to the parsing logic.
 */
  __pyx_tuple__389 = PyTuple_Pack(1, __pyx_n_s_cache_size_limit); if (unlikely(!__pyx_tuple__389)) __PYX_ERR(0, 2439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__389);
  __Pyx_GIVEREF(__pyx_tuple__389);
  __pyx_codeobj__390 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__389, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_enablePackrat, 2439, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__390)) __PYX_ERR(0, 2439, __pyx_L1_error)
  __pyx_tuple__391 = PyTuple_Pack(1, ((PyObject *)__pyx_int_128)); if (unlikely(!__pyx_tuple__391)) __PYX_ERR(0, 2439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__391);
  __Pyx_GIVEREF(__pyx_tuple__391);

  /* "cPyparsing.pyx":2474
 *             ParserElement._parse = ParserElement._parseCache
 * 
 *     def parseString(self, instring, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression with the given string.
 */
  __pyx_tuple__392 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_parseAll, __pyx_n_s_e, __pyx_n_s_loc, __pyx_n_s_tokens, __pyx_n_s_se, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__392)) __PYX_ERR(0, 2474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__392);
  __Pyx_GIVEREF(__pyx_tuple__392);
  __pyx_codeobj__393 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__392, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseString, 2474, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__393)) __PYX_ERR(0, 2474, __pyx_L1_error)

  /* "cPyparsing.pyx":2532
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */
  __pyx_tuple__394 = PyTuple_Pack(15, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_maxMatches, __pyx_n_s_overlap, __pyx_n_s_e, __pyx_n_s_instrlen, __pyx_n_s_loc, __pyx_n_s_preparseFn, __pyx_n_s_parseFn, __pyx_n_s_matches, __pyx_n_s_preloc, __pyx_n_s_nextLoc, __pyx_n_s_tokens, __pyx_n_s_nextloc, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__394)) __PYX_ERR(0, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__394);
  __Pyx_GIVEREF(__pyx_tuple__394);
  __pyx_codeobj__52 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 15, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__394, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_scanString, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__52)) __PYX_ERR(0, 2532, __pyx_L1_error)

  /* "cPyparsing.pyx":2606
 *                 raise exc
 * 
 *     def transformString(self, instring):             # <<<<<<<<<<<<<<
 *         """
 *         Extension to :class:`scanString`, to modify matching text with modified tokens that may
 */
  __pyx_tuple__395 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_out, __pyx_n_s_lastE, __pyx_n_s_t, __pyx_n_s_s, __pyx_n_s_e, __pyx_n_s_exc, __pyx_n_s_o); if (unlikely(!__pyx_tuple__395)) __PYX_ERR(0, 2606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__395);
  __Pyx_GIVEREF(__pyx_tuple__395);
  __pyx_codeobj__396 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__395, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_transformString, 2606, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__396)) __PYX_ERR(0, 2606, __pyx_L1_error)

  /* "cPyparsing.pyx":2654
 *                 raise exc
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):             # <<<<<<<<<<<<<<
 *         """
 *         Another extension to :class:`scanString`, simplifying the access to the tokens found
 */
  __pyx_tuple__397 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_maxMatches, __pyx_n_s_exc, __pyx_n_s_t, __pyx_n_s_s, __pyx_n_s_e); if (unlikely(!__pyx_tuple__397)) __PYX_ERR(0, 2654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__397);
  __Pyx_GIVEREF(__pyx_tuple__397);
  __pyx_codeobj__398 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__397, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_searchString, 2654, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__398)) __PYX_ERR(0, 2654, __pyx_L1_error)

  /* "cPyparsing.pyx":2686
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */
  __pyx_tuple__399 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_maxsplit, __pyx_n_s_includeSeparators, __pyx_n_s_splits, __pyx_n_s_last, __pyx_n_s_t, __pyx_n_s_s, __pyx_n_s_e); if (unlikely(!__pyx_tuple__399)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__399);
  __Pyx_GIVEREF(__pyx_tuple__399);
  __pyx_codeobj__53 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__399, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_split, 2686, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__53)) __PYX_ERR(0, 2686, __pyx_L1_error)

  /* "cPyparsing.pyx":2711
 *         yield instring[last:]
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator - returns :class:`And`. Adding strings to a ParserElement
 */
  __pyx_codeobj__400 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_add, 2711, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__400)) __PYX_ERR(0, 2711, __pyx_L1_error)

  /* "cPyparsing.pyx":2749
 *         return And([self, other])
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator when left operand is not a :class:`ParserElement`
 */
  __pyx_codeobj__401 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_radd, 2749, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__401)) __PYX_ERR(0, 2749, __pyx_L1_error)

  /* "cPyparsing.pyx":2764
 *         return other + self
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator, returns :class:`And` with error stop
 */
  __pyx_codeobj__402 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_sub_2, 2764, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__402)) __PYX_ERR(0, 2764, __pyx_L1_error)

  /* "cPyparsing.pyx":2776
 *         return self + And._ErrorStop() + other
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator when left operand is not a :class:`ParserElement`
 */
  __pyx_codeobj__403 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_rsub, 2776, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__403)) __PYX_ERR(0, 2776, __pyx_L1_error)

  /* "cPyparsing.pyx":2788
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of ``expr * 3`` in place of
 */
  __pyx_tuple__404 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_minElements, __pyx_n_s_optElements, __pyx_n_s_makeOptionalList, __pyx_n_s_makeOptionalList, __pyx_n_s_ret, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__404)) __PYX_ERR(0, 2788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__404);
  __Pyx_GIVEREF(__pyx_tuple__404);
  __pyx_codeobj__405 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__404, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_mul, 2788, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__405)) __PYX_ERR(0, 2788, __pyx_L1_error)

  /* "cPyparsing.pyx":2862
 *         return ret
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */
  __pyx_codeobj__406 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_rmul, 2862, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__406)) __PYX_ERR(0, 2862, __pyx_L1_error)

  /* "cPyparsing.pyx":2865
 *         return self.__mul__(other)
 * 
 *     def __or__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator - returns :class:`MatchFirst`
 */
  __pyx_codeobj__407 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_or, 2865, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__407)) __PYX_ERR(0, 2865, __pyx_L1_error)

  /* "cPyparsing.pyx":2880
 *         return MatchFirst([self, other])
 * 
 *     def __ror__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator when left operand is not a :class:`ParserElement`
 */
  __pyx_codeobj__408 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ror, 2880, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__408)) __PYX_ERR(0, 2880, __pyx_L1_error)

  /* "cPyparsing.pyx":2892
 *         return other | self
 * 
 *     def __xor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator - returns :class:`Or`
 */
  __pyx_codeobj__409 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_xor, 2892, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__409)) __PYX_ERR(0, 2892, __pyx_L1_error)

  /* "cPyparsing.pyx":2904
 *         return Or([self, other])
 * 
 *     def __rxor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator when left operand is not a :class:`ParserElement`
 */
  __pyx_codeobj__410 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_rxor, 2904, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__410)) __PYX_ERR(0, 2904, __pyx_L1_error)

  /* "cPyparsing.pyx":2916
 *         return other ^ self
 * 
 *     def __and__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator - returns :class:`Each`
 */
  __pyx_codeobj__411 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_and, 2916, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__411)) __PYX_ERR(0, 2916, __pyx_L1_error)

  /* "cPyparsing.pyx":2928
 *         return Each([self, other])
 * 
 *     def __rand__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator when left operand is not a :class:`ParserElement`
 */
  __pyx_codeobj__412 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_rand, 2928, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__412)) __PYX_ERR(0, 2928, __pyx_L1_error)

  /* "cPyparsing.pyx":2940
 *         return other & self
 * 
 *     def __invert__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ~ operator - returns :class:`NotAny`
 */
  __pyx_codeobj__413 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_invert, 2940, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__413)) __PYX_ERR(0, 2940, __pyx_L1_error)

  /* "cPyparsing.pyx":2946
 *         return NotAny(self)
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         # must implement __iter__ to override legacy use of sequential access to __getitem__ to
 *         # iterate over a sequence
 */
  __pyx_codeobj__414 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_iter, 2946, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__414)) __PYX_ERR(0, 2946, __pyx_L1_error)

  /* "cPyparsing.pyx":2951
 *         raise TypeError('%r object is not iterable' % self.__class__.__name__)
 * 
 *     def __getitem__(self, key):             # <<<<<<<<<<<<<<
 *         """
 *         use ``[]`` indexing notation as a short form for expression repetition:
 */
  __pyx_tuple__415 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_key, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__415)) __PYX_ERR(0, 2951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__415);
  __Pyx_GIVEREF(__pyx_tuple__415);
  __pyx_codeobj__416 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__415, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_getitem, 2951, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__416)) __PYX_ERR(0, 2951, __pyx_L1_error)

  /* "cPyparsing.pyx":2987
 *         return ret
 * 
 *     def __call__(self, name=None):             # <<<<<<<<<<<<<<
 *         """
 *         Shortcut for :class:`setResultsName`, with ``listAllMatches=False``.
 */
  __pyx_codeobj__417 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__252, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_call, 2987, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__417)) __PYX_ERR(0, 2987, __pyx_L1_error)

  /* "cPyparsing.pyx":3007
 *             return self.copy()
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         """
 *         Suppresses the output of this :class:`ParserElement`; useful to keep punctuation from
 */
  __pyx_codeobj__418 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_suppress, 3007, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__418)) __PYX_ERR(0, 3007, __pyx_L1_error)

  /* "cPyparsing.pyx":3014
 *         return Suppress(self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """
 *         Disables the skipping of whitespace before matching the characters in the
 */
  __pyx_codeobj__419 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_leaveWhitespace, 3014, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__419)) __PYX_ERR(0, 3014, __pyx_L1_error)

  /* "cPyparsing.pyx":3023
 *         return self
 * 
 *     def setWhitespaceChars(self, chars):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides the default whitespace chars
 */
  __pyx_tuple__420 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_chars); if (unlikely(!__pyx_tuple__420)) __PYX_ERR(0, 3023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__420);
  __Pyx_GIVEREF(__pyx_tuple__420);
  __pyx_codeobj__421 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__420, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setWhitespaceChars, 3023, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__421)) __PYX_ERR(0, 3023, __pyx_L1_error)

  /* "cPyparsing.pyx":3032
 *         return self
 * 
 *     def parseWithTabs(self):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides default behavior to expand ``<TAB>``s to spaces before parsing the input string.
 */
  __pyx_codeobj__422 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseWithTabs, 3032, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__422)) __PYX_ERR(0, 3032, __pyx_L1_error)

  /* "cPyparsing.pyx":3041
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Define expression to be ignored (e.g., comments) while doing pattern
 */
  __pyx_codeobj__423 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ignore, 3041, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__423)) __PYX_ERR(0, 3041, __pyx_L1_error)

  /* "cPyparsing.pyx":3065
 *         return self
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */
  __pyx_tuple__424 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_startAction, __pyx_n_s_successAction, __pyx_n_s_exceptionAction); if (unlikely(!__pyx_tuple__424)) __PYX_ERR(0, 3065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__424);
  __Pyx_GIVEREF(__pyx_tuple__424);
  __pyx_codeobj__425 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__424, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setDebugActions, 3065, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__425)) __PYX_ERR(0, 3065, __pyx_L1_error)

  /* "cPyparsing.pyx":3075
 *         return self
 * 
 *     def setDebug(self, flag=True):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */
  __pyx_tuple__426 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_flag); if (unlikely(!__pyx_tuple__426)) __PYX_ERR(0, 3075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__426);
  __Pyx_GIVEREF(__pyx_tuple__426);
  __pyx_codeobj__427 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__426, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setDebug, 3075, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__427)) __PYX_ERR(0, 3075, __pyx_L1_error)

  /* "cPyparsing.pyx":3118
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */
  __pyx_codeobj__428 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 3118, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__428)) __PYX_ERR(0, 3118, __pyx_L1_error)

  /* "cPyparsing.pyx":3121
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */
  __pyx_codeobj__429 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_repr_2, 3121, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__429)) __PYX_ERR(0, 3121, __pyx_L1_error)

  /* "cPyparsing.pyx":3124
 *         return _ustr(self)
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         self.streamlined = True
 *         self.strRepr = None
 */
  __pyx_codeobj__430 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_streamline, 3124, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__430)) __PYX_ERR(0, 3124, __pyx_L1_error)

  /* "cPyparsing.pyx":3129
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
  __pyx_codeobj__431 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__203, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_checkRecursion, 3129, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__431)) __PYX_ERR(0, 3129, __pyx_L1_error)

  /* "cPyparsing.pyx":3132
 *         pass
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         """
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 */
  __pyx_tuple__432 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_validateTrace); if (unlikely(!__pyx_tuple__432)) __PYX_ERR(0, 3132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__432);
  __Pyx_GIVEREF(__pyx_tuple__432);
  __pyx_codeobj__433 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__432, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_validate, 3132, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__433)) __PYX_ERR(0, 3132, __pyx_L1_error)

  /* "cPyparsing.pyx":3138
 *         self.checkRecursion([])
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on the given file or filename.
 */
  __pyx_tuple__434 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_file_or_filename, __pyx_n_s_parseAll, __pyx_n_s_file_contents, __pyx_n_s_f_2, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__434)) __PYX_ERR(0, 3138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__434);
  __Pyx_GIVEREF(__pyx_tuple__434);
  __pyx_codeobj__435 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__434, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseFile, 3138, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__435)) __PYX_ERR(0, 3138, __pyx_L1_error)

  /* "cPyparsing.pyx":3160
 *                 raise exc
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if self is other:
 *             return True
 */
  __pyx_codeobj__436 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_eq, 3160, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__436)) __PYX_ERR(0, 3160, __pyx_L1_error)

  /* "cPyparsing.pyx":3169
 *         return False
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */
  __pyx_codeobj__437 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ne, 3169, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__437)) __PYX_ERR(0, 3169, __pyx_L1_error)

  /* "cPyparsing.pyx":3172
 *         return not (self == other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return id(self)
 * 
 */
  __pyx_codeobj__438 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_hash, 3172, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__438)) __PYX_ERR(0, 3172, __pyx_L1_error)

  /* "cPyparsing.pyx":3175
 *         return id(self)
 * 
 *     def __req__(self, other):             # <<<<<<<<<<<<<<
 *         return self == other
 * 
 */
  __pyx_codeobj__439 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_req, 3175, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__439)) __PYX_ERR(0, 3175, __pyx_L1_error)

  /* "cPyparsing.pyx":3178
 *         return self == other
 * 
 *     def __rne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */
  __pyx_codeobj__440 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_rne, 3178, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__440)) __PYX_ERR(0, 3178, __pyx_L1_error)

  /* "cPyparsing.pyx":3181
 *         return not (self == other)
 * 
 *     def matches(self, testString, parseAll=True):             # <<<<<<<<<<<<<<
 *         """
 *         Method for quick testing of a parser against a test string. Good for simple
 */
  __pyx_tuple__441 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_testString, __pyx_n_s_parseAll); if (unlikely(!__pyx_tuple__441)) __PYX_ERR(0, 3181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__441);
  __Pyx_GIVEREF(__pyx_tuple__441);
  __pyx_codeobj__442 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__441, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_matches, 3181, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__442)) __PYX_ERR(0, 3181, __pyx_L1_error)

  /* "cPyparsing.pyx":3201
 *             return False
 * 
 *     def runTests(self, tests, parseAll=True, comment='#',             # <<<<<<<<<<<<<<
 *                  fullDump=True, printResults=True, failureTests=False, postParse=None,
 *                  file=None):
 */
  __pyx_tuple__443 = PyTuple_Pack(23, __pyx_n_s_self, __pyx_n_s_tests, __pyx_n_s_parseAll, __pyx_n_s_comment, __pyx_n_s_fullDump, __pyx_n_s_printResults, __pyx_n_s_failureTests, __pyx_n_s_postParse, __pyx_n_s_file, __pyx_n_s_print_2, __pyx_n_s_allResults, __pyx_n_s_comments, __pyx_n_s_success, __pyx_n_s_NL, __pyx_n_s_BOM, __pyx_n_s_t, __pyx_n_s_out, __pyx_n_s_result, __pyx_n_s_pe, __pyx_n_s_fatal, __pyx_n_s_exc, __pyx_n_s_pp_value, __pyx_n_s_e); if (unlikely(!__pyx_tuple__443)) __PYX_ERR(0, 3201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__443);
  __Pyx_GIVEREF(__pyx_tuple__443);
  __pyx_codeobj__444 = (PyObject*)__Pyx_PyCode_New(9, 0, 0, 23, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__443, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_runTests, 3201, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__444)) __PYX_ERR(0, 3201, __pyx_L1_error)
  __pyx_tuple__445 = PyTuple_Pack(7, ((PyObject *)Py_True), ((PyObject*)__pyx_kp_u__65), ((PyObject *)Py_True), ((PyObject *)Py_True), ((PyObject *)Py_False), Py_None, Py_None); if (unlikely(!__pyx_tuple__445)) __PYX_ERR(0, 3201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__445);
  __Pyx_GIVEREF(__pyx_tuple__445);

  /* "cPyparsing.pyx":3367
 *     # internal placeholder class to hold a place were '...' is added to a parser element,
 *     # once another ParserElement is added, this placeholder will be replaced with a SkipTo
 *     def __init__(self, expr, must_skip=False):             # <<<<<<<<<<<<<<
 *         super(_PendingSkip, self).__init__()
 *         self.strRepr = str(expr + Empty()).replace('Empty', '...')
 */
  __pyx_tuple__446 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_must_skip); if (unlikely(!__pyx_tuple__446)) __PYX_ERR(0, 3367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__446);
  __Pyx_GIVEREF(__pyx_tuple__446);
  __pyx_codeobj__447 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3367, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__447)) __PYX_ERR(0, 3367, __pyx_L1_error)

  /* "cPyparsing.pyx":3374
 *         self.must_skip = must_skip
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 */
  __pyx_tuple__448 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_skipper, __pyx_n_s_must_skip, __pyx_n_s_must_skip, __pyx_n_s_show_skip, __pyx_n_s_show_skip); if (unlikely(!__pyx_tuple__448)) __PYX_ERR(0, 3374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__448);
  __Pyx_GIVEREF(__pyx_tuple__448);
  __pyx_codeobj__449 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__448, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_add, 3374, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__449)) __PYX_ERR(0, 3374, __pyx_L1_error)

  /* "cPyparsing.pyx":3390
 *         return self.anchor + skipper + other
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.strRepr
 * 
 */
  __pyx_codeobj__450 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_repr_2, 3390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__450)) __PYX_ERR(0, 3390, __pyx_L1_error)

  /* "cPyparsing.pyx":3393
 *         return self.strRepr
 * 
 *     def parseImpl(self, *args):             # <<<<<<<<<<<<<<
 *         raise Exception("use of `...` expression without following SkipTo target expression")
 * 
 */
  __pyx_tuple__451 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_args); if (unlikely(!__pyx_tuple__451)) __PYX_ERR(0, 3393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__451);
  __Pyx_GIVEREF(__pyx_tuple__451);
  __pyx_codeobj__452 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__451, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 3393, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__452)) __PYX_ERR(0, 3393, __pyx_L1_error)

  /* "cPyparsing.pyx":3401
 *     matching patterns.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Token, self).__init__(savelist=False)
 * 
 */
  __pyx_codeobj__453 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3401, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__453)) __PYX_ERR(0, 3401, __pyx_L1_error)

  /* "cPyparsing.pyx":3408
 *     """An empty token, will always match.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 */
  __pyx_codeobj__454 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3408, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__454)) __PYX_ERR(0, 3408, __pyx_L1_error)

  /* "cPyparsing.pyx":3418
 *     """A token that will never match.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 */
  __pyx_codeobj__455 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3418, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__455)) __PYX_ERR(0, 3418, __pyx_L1_error)

  /* "cPyparsing.pyx":3425
 *         self.errmsg = "Unmatchable token"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_codeobj__456 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 3425, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__456)) __PYX_ERR(0, 3425, __pyx_L1_error)

  /* "cPyparsing.pyx":3443
 *     use :class:`Keyword` or :class:`CaselessKeyword`.
 *     """
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(Literal, self).__init__()
 *         self.match = matchString
 */
  __pyx_tuple__457 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_matchString); if (unlikely(!__pyx_tuple__457)) __PYX_ERR(0, 3443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__457);
  __Pyx_GIVEREF(__pyx_tuple__457);
  __pyx_codeobj__458 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__457, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3443, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__458)) __PYX_ERR(0, 3443, __pyx_L1_error)

  /* "cPyparsing.pyx":3472
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] == self.firstMatchChar and instring.startswith(self.match, loc):
 *             return loc + self.matchLen, self.match
 */
  __pyx_codeobj__459 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 3472, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__459)) __PYX_ERR(0, 3472, __pyx_L1_error)

  /* "cPyparsing.pyx":3481
 * 
 * class _SingleCharLiteral(Literal):
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] == self.firstMatchChar:
 *             return loc + 1, self.match
 */
  __pyx_codeobj__460 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 3481, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__460)) __PYX_ERR(0, 3481, __pyx_L1_error)

  /* "cPyparsing.pyx":3516
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):             # <<<<<<<<<<<<<<
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 */
  __pyx_tuple__462 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_matchString, __pyx_n_s_identChars, __pyx_n_s_caseless); if (unlikely(!__pyx_tuple__462)) __PYX_ERR(0, 3516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__462);
  __Pyx_GIVEREF(__pyx_tuple__462);
  __pyx_codeobj__463 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__462, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3516, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__463)) __PYX_ERR(0, 3516, __pyx_L1_error)

  /* "cPyparsing.pyx":3560
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)
 */
  __pyx_codeobj__464 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 3560, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__464)) __PYX_ERR(0, 3560, __pyx_L1_error)

  /* "cPyparsing.pyx":3582
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */
  __pyx_tuple__465 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_c); if (unlikely(!__pyx_tuple__465)) __PYX_ERR(0, 3582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__465);
  __Pyx_GIVEREF(__pyx_tuple__465);
  __pyx_codeobj__466 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__465, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_copy, 3582, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__466)) __PYX_ERR(0, 3582, __pyx_L1_error)

  /* "cPyparsing.pyx":3587
 *         return c
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultKeywordChars(chars):
 *         """Overrides the default Keyword chars
 */
  __pyx_codeobj__467 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__340, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setDefaultKeywordChars, 3587, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__467)) __PYX_ERR(0, 3587, __pyx_L1_error)

  /* "cPyparsing.pyx":3604
 *     (Contrast with example for :class:`CaselessKeyword`.)
 *     """
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 */
  __pyx_codeobj__468 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__457, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__468)) __PYX_ERR(0, 3604, __pyx_L1_error)

  /* "cPyparsing.pyx":3620
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString
 */
  __pyx_codeobj__469 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 3620, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__469)) __PYX_ERR(0, 3620, __pyx_L1_error)

  /* "cPyparsing.pyx":3638
 *     (Contrast with example for :class:`CaselessLiteral`.)
 *     """
 *     def __init__(self, matchString, identChars=None):             # <<<<<<<<<<<<<<
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 */
  __pyx_tuple__470 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_matchString, __pyx_n_s_identChars); if (unlikely(!__pyx_tuple__470)) __PYX_ERR(0, 3638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__470);
  __Pyx_GIVEREF(__pyx_tuple__470);
  __pyx_codeobj__471 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__470, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3638, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__471)) __PYX_ERR(0, 3638, __pyx_L1_error)

  /* "cPyparsing.pyx":3674
 *         patt.parseString("ATCAXCGAAXGGA") # -> (['ATCAXCGAAXGGA'], {'mismatches': [[4, 9]], 'original': ['ATCATCGAATGGA']})
 *     """
 *     def __init__(self, match_string, maxMismatches=1):             # <<<<<<<<<<<<<<
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 */
  __pyx_tuple__472 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_match_string, __pyx_n_s_maxMismatches); if (unlikely(!__pyx_tuple__472)) __PYX_ERR(0, 3674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__472);
  __Pyx_GIVEREF(__pyx_tuple__472);
  __pyx_codeobj__473 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__472, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3674, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__473)) __PYX_ERR(0, 3674, __pyx_L1_error)

  /* "cPyparsing.pyx":3683
 *         self.mayReturnEmpty = False
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         start = loc
 *         instrlen = len(instring)
 */
  __pyx_tuple__474 = PyTuple_Pack(15, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_start, __pyx_n_s_instrlen, __pyx_n_s_maxloc, __pyx_n_s_match_string, __pyx_n_s_match_stringloc, __pyx_n_s_mismatches_2, __pyx_n_s_maxMismatches, __pyx_n_s_s_m, __pyx_n_s_src, __pyx_n_s_mat, __pyx_n_s_results); if (unlikely(!__pyx_tuple__474)) __PYX_ERR(0, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__474);
  __Pyx_GIVEREF(__pyx_tuple__474);
  __pyx_codeobj__475 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 15, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__474, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 3683, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__475)) __PYX_ERR(0, 3683, __pyx_L1_error)

  /* "cPyparsing.pyx":3763
 *         csv_value = Word(printables, excludeChars=",")
 *     """
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */
  __pyx_tuple__476 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_initChars, __pyx_n_s_bodyChars, __pyx_n_s_min, __pyx_n_s_max, __pyx_n_s_exact, __pyx_n_s_asKeyword, __pyx_n_s_excludeChars, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__476)) __PYX_ERR(0, 3763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__476);
  __Pyx_GIVEREF(__pyx_tuple__476);
  __pyx_codeobj__477 = (PyObject*)__Pyx_PyCode_New(8, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__476, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3763, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__477)) __PYX_ERR(0, 3763, __pyx_L1_error)
  __pyx_tuple__478 = PyTuple_Pack(6, Py_None, ((PyObject *)__pyx_int_1), ((PyObject *)__pyx_int_0), ((PyObject *)__pyx_int_0), ((PyObject *)Py_False), Py_None); if (unlikely(!__pyx_tuple__478)) __PYX_ERR(0, 3763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__478);
  __Pyx_GIVEREF(__pyx_tuple__478);

  /* "cPyparsing.pyx":3849
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] not in self.initChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_tuple__479 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_start, __pyx_n_s_instrlen, __pyx_n_s_bodychars, __pyx_n_s_maxloc, __pyx_n_s_throwException); if (unlikely(!__pyx_tuple__479)) __PYX_ERR(0, 3849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__479);
  __Pyx_GIVEREF(__pyx_tuple__479);
  __pyx_codeobj__480 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__479, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 3849, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__480)) __PYX_ERR(0, 3849, __pyx_L1_error)

  /* "cPyparsing.pyx":3877
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */
  __pyx_tuple__481 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_charsAsStr, __pyx_n_s_charsAsStr); if (unlikely(!__pyx_tuple__481)) __PYX_ERR(0, 3877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__481);
  __Pyx_GIVEREF(__pyx_tuple__481);
  __pyx_codeobj__482 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__481, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 3877, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__482)) __PYX_ERR(0, 3877, __pyx_L1_error)

  /* "cPyparsing.pyx":3912
 *     #     self._update_furthest_loc_for_regex(instring, loc)
 *     #     return loc, result.group()
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */
  __pyx_tuple__483 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_result); if (unlikely(!__pyx_tuple__483)) __PYX_ERR(0, 3912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__483);
  __Pyx_GIVEREF(__pyx_tuple__483);
  __pyx_codeobj__484 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__483, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 3912, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__484)) __PYX_ERR(0, 3912, __pyx_L1_error)

  /* "cPyparsing.pyx":3930
 *     characters.
 *     """
 *     def __init__(self, charset, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Char, self).__init__(charset, exact=1, asKeyword=asKeyword, excludeChars=excludeChars)
 *         self.reString = "[%s]" % _escapeRegexRangeChars(''.join(self.initChars))
 */
  __pyx_tuple__485 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_charset, __pyx_n_s_asKeyword, __pyx_n_s_excludeChars); if (unlikely(!__pyx_tuple__485)) __PYX_ERR(0, 3930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__485);
  __Pyx_GIVEREF(__pyx_tuple__485);
  __pyx_codeobj__486 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__485, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3930, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__486)) __PYX_ERR(0, 3930, __pyx_L1_error)
  __pyx_tuple__487 = PyTuple_Pack(2, ((PyObject *)Py_False), Py_None); if (unlikely(!__pyx_tuple__487)) __PYX_ERR(0, 3930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__487);
  __Pyx_GIVEREF(__pyx_tuple__487);

  /* "cPyparsing.pyx":3963
 * 
 *     """
 *     def __init__(self, pattern, flags=0, asGroupList=False, asMatch=False):             # <<<<<<<<<<<<<<
 *         """The parameters ``pattern`` and ``flags`` are passed
 *         to the ``re.compile()`` function as-is. See the Python
 */
  __pyx_tuple__488 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_pattern, __pyx_n_s_flags, __pyx_n_s_asGroupList, __pyx_n_s_asMatch); if (unlikely(!__pyx_tuple__488)) __PYX_ERR(0, 3963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__488);
  __Pyx_GIVEREF(__pyx_tuple__488);
  __pyx_codeobj__489 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__488, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 3963, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__489)) __PYX_ERR(0, 3963, __pyx_L1_error)
  __pyx_tuple__490 = PyTuple_Pack(3, ((PyObject *)__pyx_int_0), ((PyObject *)Py_False), ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__490)) __PYX_ERR(0, 3963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__490);
  __Pyx_GIVEREF(__pyx_tuple__490);

  /* "cPyparsing.pyx":4026
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */
  __pyx_tuple__491 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_result, __pyx_n_s_ret, __pyx_n_s_d, __pyx_n_s_k, __pyx_n_s_v); if (unlikely(!__pyx_tuple__491)) __PYX_ERR(0, 4026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__491);
  __Pyx_GIVEREF(__pyx_tuple__491);
  __pyx_codeobj__492 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__491, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4026, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__492)) __PYX_ERR(0, 4026, __pyx_L1_error)

  /* "cPyparsing.pyx":4057
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImplAsGroupList(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */
  __pyx_tuple__493 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_result, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__493)) __PYX_ERR(0, 4057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__493);
  __Pyx_GIVEREF(__pyx_tuple__493);
  __pyx_codeobj__494 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__493, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImplAsGroupList, 4057, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__494)) __PYX_ERR(0, 4057, __pyx_L1_error)

  /* "cPyparsing.pyx":4084
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImplAsMatch(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */
  __pyx_codeobj__495 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__493, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImplAsMatch, 4084, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__495)) __PYX_ERR(0, 4084, __pyx_L1_error)

  /* "cPyparsing.pyx":4097
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Regex, self).__str__()
 */
  __pyx_codeobj__496 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 4097, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__496)) __PYX_ERR(0, 4097, __pyx_L1_error)

  /* "cPyparsing.pyx":4108
 *         return self.strRepr
 * 
 *     def sub(self, repl):             # <<<<<<<<<<<<<<
 *         r"""
 *         Return Regex with an attached parse action to transform the parsed
 */
  __pyx_tuple__497 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_repl, __pyx_n_s_pa, __pyx_n_s_pa, __pyx_n_s_pa); if (unlikely(!__pyx_tuple__497)) __PYX_ERR(0, 4108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__497);
  __Pyx_GIVEREF(__pyx_tuple__497);
  __pyx_codeobj__498 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__497, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_sub, 4108, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__498)) __PYX_ERR(0, 4108, __pyx_L1_error)

  /* "cPyparsing.pyx":4176
 *         [['This is the quote with "embedded" quotes']]
 *     """
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False,             # <<<<<<<<<<<<<<
 *                  unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):
 *         super(QuotedString, self).__init__()
 */
  __pyx_tuple__499 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_quoteChar, __pyx_n_s_escChar, __pyx_n_s_escQuote, __pyx_n_s_multiline, __pyx_n_s_unquoteResults, __pyx_n_s_endQuoteChar, __pyx_n_s_convertWhitespaceEscapes, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__499)) __PYX_ERR(0, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__499);
  __Pyx_GIVEREF(__pyx_tuple__499);
  __pyx_codeobj__500 = (PyObject*)__Pyx_PyCode_New(8, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__499, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4176, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__500)) __PYX_ERR(0, 4176, __pyx_L1_error)
  __pyx_tuple__501 = PyTuple_Pack(6, Py_None, Py_None, ((PyObject *)Py_False), ((PyObject *)Py_True), Py_None, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__501)) __PYX_ERR(0, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__501);
  __Pyx_GIVEREF(__pyx_tuple__501);

  /* "cPyparsing.pyx":4281
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = instring[loc] == self.firstQuoteChar and self.re_match(instring, loc) or None
 *         if not result:
 */
  __pyx_tuple__502 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_result, __pyx_n_s_ret, __pyx_n_s_ws_map, __pyx_n_s_wslit, __pyx_n_s_wschar); if (unlikely(!__pyx_tuple__502)) __PYX_ERR(0, 4281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__502);
  __Pyx_GIVEREF(__pyx_tuple__502);
  __pyx_codeobj__503 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__502, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4281, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__503)) __PYX_ERR(0, 4281, __pyx_L1_error)

  /* "cPyparsing.pyx":4320
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(QuotedString, self).__str__()
 */
  __pyx_codeobj__504 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 4320, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__504)) __PYX_ERR(0, 4320, __pyx_L1_error)

  /* "cPyparsing.pyx":4352
 *         ['dkls', 'lsdkjf', 's12 34', '@!#', '213']
 *     """
 *     def __init__(self, notChars, min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 */
  __pyx_tuple__505 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_notChars, __pyx_n_s_min, __pyx_n_s_max, __pyx_n_s_exact); if (unlikely(!__pyx_tuple__505)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__505);
  __Pyx_GIVEREF(__pyx_tuple__505);
  __pyx_codeobj__506 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__505, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4352, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__506)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __pyx_tuple__507 = PyTuple_Pack(3, ((PyObject *)__pyx_int_1), ((PyObject *)__pyx_int_0), ((PyObject *)__pyx_int_0)); if (unlikely(!__pyx_tuple__507)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__507);
  __Pyx_GIVEREF(__pyx_tuple__507);

  /* "cPyparsing.pyx":4394
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_tuple__508 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_start, __pyx_n_s_notchars, __pyx_n_s_maxlen); if (unlikely(!__pyx_tuple__508)) __PYX_ERR(0, 4394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__508);
  __Pyx_GIVEREF(__pyx_tuple__508);
  __pyx_codeobj__509 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__508, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4394, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__509)) __PYX_ERR(0, 4394, __pyx_L1_error)

  /* "cPyparsing.pyx":4410
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(CharsNotIn, self).__str__()
 */
  __pyx_codeobj__510 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 4410, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__510)) __PYX_ERR(0, 4410, __pyx_L1_error)

  /* "cPyparsing.pyx":4458
 *         u'\u3000': '<IDEOGRAPHIC_SPACE>',
 *         }
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */
  __pyx_tuple__529 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_ws, __pyx_n_s_min, __pyx_n_s_max, __pyx_n_s_exact, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__529)) __PYX_ERR(0, 4458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__529);
  __Pyx_GIVEREF(__pyx_tuple__529);
  __pyx_codeobj__530 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__529, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4458, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__530)) __PYX_ERR(0, 4458, __pyx_L1_error)
  __pyx_tuple__531 = PyTuple_Pack(4, ((PyObject*)__pyx_kp_u__102), ((PyObject *)__pyx_int_1), ((PyObject *)__pyx_int_0), ((PyObject *)__pyx_int_0)); if (unlikely(!__pyx_tuple__531)) __PYX_ERR(0, 4458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__531);
  __Pyx_GIVEREF(__pyx_tuple__531);

  /* "cPyparsing.pyx":4494
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] not in self.matchWhite:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_tuple__532 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_start, __pyx_n_s_maxloc); if (unlikely(!__pyx_tuple__532)) __PYX_ERR(0, 4494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__532);
  __Pyx_GIVEREF(__pyx_tuple__532);
  __pyx_codeobj__533 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__532, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4494, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__533)) __PYX_ERR(0, 4494, __pyx_L1_error)

  /* "cPyparsing.pyx":4511
 * 
 * class _PositionToken(Token):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 */
  __pyx_codeobj__534 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4511, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__534)) __PYX_ERR(0, 4511, __pyx_L1_error)

  /* "cPyparsing.pyx":4521
 *     tabular report scraping.
 *     """
 *     def __init__(self, colno):             # <<<<<<<<<<<<<<
 *         super(GoToColumn, self).__init__()
 *         self.col = colno
 */
  __pyx_tuple__535 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_colno); if (unlikely(!__pyx_tuple__535)) __PYX_ERR(0, 4521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__535);
  __Pyx_GIVEREF(__pyx_tuple__535);
  __pyx_codeobj__536 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__535, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4521, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__536)) __PYX_ERR(0, 4521, __pyx_L1_error)

  /* "cPyparsing.pyx":4525
 *         self.col = colno
 * 
 *     def preParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 */
  __pyx_tuple__537 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_instrlen); if (unlikely(!__pyx_tuple__537)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__537);
  __Pyx_GIVEREF(__pyx_tuple__537);
  __pyx_codeobj__538 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__537, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_preParse, 4525, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__538)) __PYX_ERR(0, 4525, __pyx_L1_error)

  /* "cPyparsing.pyx":4534
 *         return loc
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 */
  __pyx_tuple__539 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_thiscol, __pyx_n_s_newloc, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__539)) __PYX_ERR(0, 4534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__539);
  __Pyx_GIVEREF(__pyx_tuple__539);
  __pyx_codeobj__540 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__539, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4534, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__540)) __PYX_ERR(0, 4534, __pyx_L1_error)

  /* "cPyparsing.pyx":4565
 * 
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"
 */
  __pyx_codeobj__541 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4565, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__541)) __PYX_ERR(0, 4565, __pyx_L1_error)

  /* "cPyparsing.pyx":4569
 *         self.errmsg = "Expected start of line"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) == 1:
 *             return loc, []
 */
  __pyx_codeobj__542 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4569, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__542)) __PYX_ERR(0, 4569, __pyx_L1_error)

  /* "cPyparsing.pyx":4578
 *     parse string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 */
  __pyx_codeobj__543 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4578, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__543)) __PYX_ERR(0, 4578, __pyx_L1_error)

  /* "cPyparsing.pyx":4583
 *         self.errmsg = "Expected end of line"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 */
  __pyx_codeobj__544 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4583, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__544)) __PYX_ERR(0, 4583, __pyx_L1_error)

  /* "cPyparsing.pyx":4598
 *     string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"
 */
  __pyx_codeobj__545 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4598, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__545)) __PYX_ERR(0, 4598, __pyx_L1_error)

  /* "cPyparsing.pyx":4610
 *     #             return ParseException(instring, loc, self.errmsg, self)
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 */
  __pyx_codeobj__546 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4610, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__546)) __PYX_ERR(0, 4610, __pyx_L1_error)

  /* "cPyparsing.pyx":4620
 *     """Matches if current position is at the end of the parse string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"
 */
  __pyx_codeobj__547 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4620, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__547)) __PYX_ERR(0, 4620, __pyx_L1_error)

  /* "cPyparsing.pyx":4635
 *     #     else:
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_codeobj__548 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4635, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__548)) __PYX_ERR(0, 4635, __pyx_L1_error)

  /* "cPyparsing.pyx":4654
 *     a line.
 *     """
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 */
  __pyx_tuple__549 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_tuple__549)) __PYX_ERR(0, 4654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__549);
  __Pyx_GIVEREF(__pyx_tuple__549);
  __pyx_codeobj__550 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__549, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4654, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__550)) __PYX_ERR(0, 4654, __pyx_L1_error)

  /* "cPyparsing.pyx":4659
 *         self.errmsg = "Not at the start of a word"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars
 */
  __pyx_codeobj__551 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4659, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__551)) __PYX_ERR(0, 4659, __pyx_L1_error)

  /* "cPyparsing.pyx":4674
 *     of a line.
 *     """
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 */
  __pyx_codeobj__552 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__549, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4674, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__552)) __PYX_ERR(0, 4674, __pyx_L1_error)

  /* "cPyparsing.pyx":4680
 *         self.errmsg = "Not at the end of a word"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 */
  __pyx_tuple__553 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_instrlen); if (unlikely(!__pyx_tuple__553)) __PYX_ERR(0, 4680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__553);
  __Pyx_GIVEREF(__pyx_tuple__553);
  __pyx_codeobj__554 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__553, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4680, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__554)) __PYX_ERR(0, 4680, __pyx_L1_error)

  /* "cPyparsing.pyx":4693
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */
  __pyx_tuple__555 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_exprs, __pyx_n_s_savelist, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__555)) __PYX_ERR(0, 4693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__555);
  __Pyx_GIVEREF(__pyx_tuple__555);
  __pyx_codeobj__556 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__555, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4693, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__556)) __PYX_ERR(0, 4693, __pyx_L1_error)

  /* "cPyparsing.pyx":4717
 * 
 *     # [CPYPARSING] fix append
 *     def append(self, other):             # <<<<<<<<<<<<<<
 *         if (self.parseAction
 *                 or self.resultsName is not None
 */
  __pyx_codeobj__557 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_append, 4717, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__557)) __PYX_ERR(0, 4717, __pyx_L1_error)

  /* "cPyparsing.pyx":4745
 *         return self
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """Extends ``leaveWhitespace`` defined in base class, and also invokes ``leaveWhitespace`` on
 *            all contained expressions."""
 */
  __pyx_tuple__558 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_e, __pyx_n_s_e); if (unlikely(!__pyx_tuple__558)) __PYX_ERR(0, 4745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__558);
  __Pyx_GIVEREF(__pyx_tuple__558);
  __pyx_codeobj__559 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__558, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_leaveWhitespace, 4745, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__559)) __PYX_ERR(0, 4745, __pyx_L1_error)

  /* "cPyparsing.pyx":4754
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */
  __pyx_tuple__560 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_e); if (unlikely(!__pyx_tuple__560)) __PYX_ERR(0, 4754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__560);
  __Pyx_GIVEREF(__pyx_tuple__560);
  __pyx_codeobj__561 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__560, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ignore, 4754, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__561)) __PYX_ERR(0, 4754, __pyx_L1_error)

  /* "cPyparsing.pyx":4766
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseExpression, self).__str__()
 */
  __pyx_codeobj__562 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 4766, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__562)) __PYX_ERR(0, 4766, __pyx_L1_error)

  /* "cPyparsing.pyx":4776
 *         return self.strRepr
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).streamline()
 * 
 */
  __pyx_tuple__563 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_e, __pyx_n_s_other); if (unlikely(!__pyx_tuple__563)) __PYX_ERR(0, 4776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__563);
  __Pyx_GIVEREF(__pyx_tuple__563);
  __pyx_codeobj__564 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__563, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_streamline, 4776, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__564)) __PYX_ERR(0, 4776, __pyx_L1_error)

  /* "cPyparsing.pyx":4824
 *         return self
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         tmp = (validateTrace if validateTrace is not None else [])[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_tuple__565 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_validateTrace, __pyx_n_s_tmp, __pyx_n_s_e); if (unlikely(!__pyx_tuple__565)) __PYX_ERR(0, 4824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__565);
  __Pyx_GIVEREF(__pyx_tuple__565);
  __pyx_codeobj__566 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__565, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_validate, 4824, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__566)) __PYX_ERR(0, 4824, __pyx_L1_error)

  /* "cPyparsing.pyx":4830
 *         self.checkRecursion([])
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 */
  __pyx_tuple__567 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_ret, __pyx_n_s_e); if (unlikely(!__pyx_tuple__567)) __PYX_ERR(0, 4830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__567);
  __Pyx_GIVEREF(__pyx_tuple__567);
  __pyx_codeobj__568 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__567, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_copy, 4830, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__568)) __PYX_ERR(0, 4830, __pyx_L1_error)

  /* "cPyparsing.pyx":4835
 *         return ret
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in self.exprs:
 */
  __pyx_tuple__569 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_name_2, __pyx_n_s_listAllMatches, __pyx_n_s_e); if (unlikely(!__pyx_tuple__569)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__569);
  __Pyx_GIVEREF(__pyx_tuple__569);
  __pyx_codeobj__570 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__569, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setResultsName, 4835, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__570)) __PYX_ERR(0, 4835, __pyx_L1_error)

  /* "cPyparsing.pyx":4868
 * 
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 */
  __pyx_codeobj__571 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__281, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4868, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__571)) __PYX_ERR(0, 4868, __pyx_L1_error)

  /* "cPyparsing.pyx":4873
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         exprs = list(exprs)
 *         if exprs and Ellipsis in exprs:
 */
  __pyx_tuple__572 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_exprs, __pyx_n_s_savelist, __pyx_n_s_tmp, __pyx_n_s_i, __pyx_n_s_expr, __pyx_n_s_skipto_arg, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__572)) __PYX_ERR(0, 4873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__572);
  __Pyx_GIVEREF(__pyx_tuple__572);
  __pyx_codeobj__573 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__572, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 4873, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__573)) __PYX_ERR(0, 4873, __pyx_L1_error)

  /* "cPyparsing.pyx":4893
 *         self.callPreparse = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 */
  __pyx_tuple__574 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_i, __pyx_n_s_e, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_e, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__574)) __PYX_ERR(0, 4893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__574);
  __Pyx_GIVEREF(__pyx_tuple__574);
  __pyx_codeobj__575 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__574, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_streamline, 4893, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__575)) __PYX_ERR(0, 4893, __pyx_L1_error)

  /* "cPyparsing.pyx":4944
 *     #             resultlist += exprtokens
 *     #     return loc, resultlist
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 */
  __pyx_tuple__576 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_resultlist, __pyx_n_s_errorStop, __pyx_n_s_e, __pyx_n_s_exprtokens, __pyx_n_s_pe); if (unlikely(!__pyx_tuple__576)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__576);
  __Pyx_GIVEREF(__pyx_tuple__576);
  __pyx_codeobj__577 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__576, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 4944, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__577)) __PYX_ERR(0, 4944, __pyx_L1_error)

  /* "cPyparsing.pyx":4969
 *         return loc, resultlist
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */
  __pyx_codeobj__578 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_iadd, 4969, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__578)) __PYX_ERR(0, 4969, __pyx_L1_error)

  /* "cPyparsing.pyx":4974
 *         return self.append(other)  # And([self, other])
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_tuple__579 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_parseElementList, __pyx_n_s_subRecCheckList, __pyx_n_s_e); if (unlikely(!__pyx_tuple__579)) __PYX_ERR(0, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__579);
  __Pyx_GIVEREF(__pyx_tuple__579);
  __pyx_codeobj__580 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__579, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_checkRecursion, 4974, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__580)) __PYX_ERR(0, 4974, __pyx_L1_error)

  /* "cPyparsing.pyx":4981
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_codeobj__581 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 4981, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__581)) __PYX_ERR(0, 4981, __pyx_L1_error)

  /* "cPyparsing.pyx":5008
 *         [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
  __pyx_codeobj__582 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__555, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5008, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__582)) __PYX_ERR(0, 5008, __pyx_L1_error)

  /* "cPyparsing.pyx":5015
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */
  __pyx_codeobj__583 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_streamline, 5015, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__583)) __PYX_ERR(0, 5015, __pyx_L1_error)

  /* "cPyparsing.pyx":5021
 *         return self
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */
  __pyx_tuple__584 = PyTuple_Pack(15, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_maxExcLoc, __pyx_n_s_maxException, __pyx_n_s_matches, __pyx_n_s_e, __pyx_n_s_loc2, __pyx_n_s_err, __pyx_n_s_best_expr, __pyx_n_s_longest, __pyx_n_s_loc1, __pyx_n_s_expr1, __pyx_n_s_toks); if (unlikely(!__pyx_tuple__584)) __PYX_ERR(0, 5021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__584);
  __Pyx_GIVEREF(__pyx_tuple__584);
  __pyx_codeobj__585 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 15, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__584, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5021, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__585)) __PYX_ERR(0, 5021, __pyx_L1_error)

  /* "cPyparsing.pyx":5082
 * 
 * 
 *     def __ixor__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */
  __pyx_codeobj__586 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ixor, 5082, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__586)) __PYX_ERR(0, 5082, __pyx_L1_error)

  /* "cPyparsing.pyx":5087
 *         return self.append(other)  # Or([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_codeobj__587 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 5087, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__587)) __PYX_ERR(0, 5087, __pyx_L1_error)

  /* "cPyparsing.pyx":5096
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_codeobj__588 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__579, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_checkRecursion, 5096, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__588)) __PYX_ERR(0, 5096, __pyx_L1_error)

  /* "cPyparsing.pyx":5101
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */
  __pyx_tuple__589 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_name_2, __pyx_n_s_listAllMatches, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__589)) __PYX_ERR(0, 5101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__589);
  __Pyx_GIVEREF(__pyx_tuple__589);
  __pyx_codeobj__590 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__589, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setResultsName, 5101, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__590)) __PYX_ERR(0, 5101, __pyx_L1_error)

  /* "cPyparsing.pyx":5131
 *         print(number.searchString("123 3.1416 789")) #  Better -> [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
  __pyx_codeobj__591 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__555, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5131, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__591)) __PYX_ERR(0, 5131, __pyx_L1_error)

  /* "cPyparsing.pyx":5138
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */
  __pyx_codeobj__592 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_streamline, 5138, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__592)) __PYX_ERR(0, 5138, __pyx_L1_error)

  /* "cPyparsing.pyx":5149
 * 
 *     # [CPYPARSING] add setAdaptiveMode
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def setAdaptiveMode(
 *         cls,
 */
  __pyx_tuple__593 = PyTuple_Pack(5, __pyx_n_s_cls, __pyx_n_s_on, __pyx_n_s_usage_weight, __pyx_n_s_allow_unused_expr_order, __pyx_n_s_adaptive_usage_check_rate); if (unlikely(!__pyx_tuple__593)) __PYX_ERR(0, 5149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__593);
  __Pyx_GIVEREF(__pyx_tuple__593);
  __pyx_codeobj__594 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__593, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setAdaptiveMode, 5149, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__594)) __PYX_ERR(0, 5149, __pyx_L1_error)
  __pyx_tuple__595 = PyTuple_Pack(3, ((PyObject *)__pyx_int_1), ((PyObject *)Py_False), Py_None); if (unlikely(!__pyx_tuple__595)) __PYX_ERR(0, 5149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__595);
  __Pyx_GIVEREF(__pyx_tuple__595);

  /* "cPyparsing.pyx":5165
 * 
 *     # [CPYPARSING] implement adaptive mode
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.adaptive_mode:
 *             if self.expr_order is None:
 */
  __pyx_tuple__596 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_maxExcLoc, __pyx_n_s_maxException, __pyx_n_s_i, __pyx_n_s_ind_or_e, __pyx_n_s_ind, __pyx_n_s_e, __pyx_n_s_ret, __pyx_n_s_err, __pyx_n_s_usage); if (unlikely(!__pyx_tuple__596)) __PYX_ERR(0, 5165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__596);
  __Pyx_GIVEREF(__pyx_tuple__596);
  __pyx_codeobj__597 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__596, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5165, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__597)) __PYX_ERR(0, 5165, __pyx_L1_error)

  /* "cPyparsing.pyx":5225
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ior__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */
  __pyx_codeobj__598 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ior, 5225, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__598)) __PYX_ERR(0, 5225, __pyx_L1_error)

  /* "cPyparsing.pyx":5230
 *         return self.append(other)  # MatchFirst([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_codeobj__599 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 5230, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__599)) __PYX_ERR(0, 5230, __pyx_L1_error)

  /* "cPyparsing.pyx":5239
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_codeobj__600 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__579, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_checkRecursion, 5239, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__600)) __PYX_ERR(0, 5239, __pyx_L1_error)

  /* "cPyparsing.pyx":5244
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */
  __pyx_codeobj__601 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__589, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setResultsName, 5244, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__601)) __PYX_ERR(0, 5244, __pyx_L1_error)

  /* "cPyparsing.pyx":5316
 *         - size: 20
 *     """
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_codeobj__602 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__555, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5316, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__602)) __PYX_ERR(0, 5316, __pyx_L1_error)

  /* "cPyparsing.pyx":5323
 *         self.saveAsList = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Each, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_codeobj__603 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_streamline, 5323, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__603)) __PYX_ERR(0, 5323, __pyx_L1_error)

  /* "cPyparsing.pyx":5328
 *         return self
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */
  __pyx_tuple__604 = PyTuple_Pack(27, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_opt1, __pyx_n_s_opt2, __pyx_n_s_tmpLoc, __pyx_n_s_tmpReqd, __pyx_n_s_tmpOpt, __pyx_n_s_matchOrder, __pyx_n_s_keepMatching, __pyx_n_s_tmpExprs, __pyx_n_s_failed, __pyx_n_s_e, __pyx_n_s_missing_2, __pyx_n_s_resultlist, __pyx_n_s_results, __pyx_n_s_finalResults, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_e, __pyx_n_s_e, __pyx_n_s_e, __pyx_n_s_e, __pyx_n_s_e, __pyx_n_s_genexpr, __pyx_n_s_e); if (unlikely(!__pyx_tuple__604)) __PYX_ERR(0, 5328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__604);
  __Pyx_GIVEREF(__pyx_tuple__604);
  __pyx_codeobj__605 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 27, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__604, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5328, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__605)) __PYX_ERR(0, 5328, __pyx_L1_error)

  /* "cPyparsing.pyx":5377
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_codeobj__606 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 5377, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__606)) __PYX_ERR(0, 5377, __pyx_L1_error)

  /* "cPyparsing.pyx":5386
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_codeobj__607 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__579, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_checkRecursion, 5386, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__607)) __PYX_ERR(0, 5386, __pyx_L1_error)

  /* "cPyparsing.pyx":5396
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 */
  __pyx_tuple__608 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_savelist); if (unlikely(!__pyx_tuple__608)) __PYX_ERR(0, 5396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__608);
  __Pyx_GIVEREF(__pyx_tuple__608);
  __pyx_codeobj__609 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__608, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5396, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__609)) __PYX_ERR(0, 5396, __pyx_L1_error)

  /* "cPyparsing.pyx":5421
 *     #     else:
 *     #         return ParseException("", loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_codeobj__610 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5421, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__610)) __PYX_ERR(0, 5421, __pyx_L1_error)

  /* "cPyparsing.pyx":5428
 * 
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 */
  __pyx_codeobj__611 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_leaveWhitespace, 5428, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__611)) __PYX_ERR(0, 5428, __pyx_L1_error)

  /* "cPyparsing.pyx":5435
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */
  __pyx_codeobj__612 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ignore, 5435, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__612)) __PYX_ERR(0, 5435, __pyx_L1_error)

  /* "cPyparsing.pyx":5447
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 */
  __pyx_codeobj__613 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_streamline, 5447, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__613)) __PYX_ERR(0, 5447, __pyx_L1_error)

  /* "cPyparsing.pyx":5453
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 */
  __pyx_tuple__614 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_parseElementList, __pyx_n_s_subRecCheckList); if (unlikely(!__pyx_tuple__614)) __PYX_ERR(0, 5453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__614);
  __Pyx_GIVEREF(__pyx_tuple__614);
  __pyx_codeobj__615 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__614, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_checkRecursion, 5453, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__615)) __PYX_ERR(0, 5453, __pyx_L1_error)

  /* "cPyparsing.pyx":5460
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         if validateTrace is None:
 *             validateTrace = []
 */
  __pyx_tuple__616 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_validateTrace, __pyx_n_s_tmp); if (unlikely(!__pyx_tuple__616)) __PYX_ERR(0, 5460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__616);
  __Pyx_GIVEREF(__pyx_tuple__616);
  __pyx_codeobj__617 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__616, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_validate, 5460, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__617)) __PYX_ERR(0, 5460, __pyx_L1_error)

  /* "cPyparsing.pyx":5468
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 */
  __pyx_codeobj__618 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 5468, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__618)) __PYX_ERR(0, 5468, __pyx_L1_error)

  /* "cPyparsing.pyx":5501
 *         [['shape', 'SQUARE'], ['color', 'BLACK'], ['posn', 'upper left']]
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True
 */
  __pyx_tuple__619 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_expr); if (unlikely(!__pyx_tuple__619)) __PYX_ERR(0, 5501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__619);
  __Pyx_GIVEREF(__pyx_tuple__619);
  __pyx_codeobj__620 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__619, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5501, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__620)) __PYX_ERR(0, 5501, __pyx_L1_error)

  /* "cPyparsing.pyx":5518
 * 
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # by using self._expr.parse and deleting the contents of the returned ParseResults list
 *         # we keep any named results that were defined in the FollowedBy expression
 */
  __pyx_tuple__622 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s__621, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__622)) __PYX_ERR(0, 5518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__622);
  __Pyx_GIVEREF(__pyx_tuple__622);
  __pyx_codeobj__623 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__622, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5518, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__623)) __PYX_ERR(0, 5518, __pyx_L1_error)

  /* "cPyparsing.pyx":5555
 * 
 *     """
 *     def __init__(self, expr, retreat=None):             # <<<<<<<<<<<<<<
 *         super(PrecededBy, self).__init__(expr)
 *         self.expr = self.expr().leaveWhitespace()
 */
  __pyx_tuple__624 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_retreat); if (unlikely(!__pyx_tuple__624)) __PYX_ERR(0, 5555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__624);
  __Pyx_GIVEREF(__pyx_tuple__624);
  __pyx_codeobj__625 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__624, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5555, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__625)) __PYX_ERR(0, 5555, __pyx_L1_error)

  /* "cPyparsing.pyx":5578
 *         self.parseAction.append(lambda s, l, t: t.__delitem__(slice(None, None)))
 * 
 *     def parseImpl(self, instring, loc=0, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.exact:
 *             if loc < self.retreat:
 */
  __pyx_tuple__626 = PyTuple_Pack(12, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_start, __pyx_n_s__621, __pyx_n_s_ret, __pyx_n_s_test_expr, __pyx_n_s_instring_slice, __pyx_n_s_last_expr, __pyx_n_s_offset, __pyx_n_s_pbe); if (unlikely(!__pyx_tuple__626)) __PYX_ERR(0, 5578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__626);
  __Pyx_GIVEREF(__pyx_tuple__626);
  __pyx_codeobj__627 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__626, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5578, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__627)) __PYX_ERR(0, 5578, __pyx_L1_error)
  __pyx_tuple__628 = PyTuple_Pack(2, ((PyObject *)__pyx_int_0), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__628)) __PYX_ERR(0, 5578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__628);
  __Pyx_GIVEREF(__pyx_tuple__628);

  /* "cPyparsing.pyx":5625
 *         integer = Word(nums) + ~Char(".")
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(NotAny, self).__init__(expr)
 *         # ~ self.leaveWhitespace()
 */
  __pyx_codeobj__629 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__619, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5625, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__629)) __PYX_ERR(0, 5625, __pyx_L1_error)

  /* "cPyparsing.pyx":5638
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_codeobj__630 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5638, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__630)) __PYX_ERR(0, 5638, __pyx_L1_error)

  /* "cPyparsing.pyx":5643
 *         return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_codeobj__631 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 5643, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__631)) __PYX_ERR(0, 5643, __pyx_L1_error)

  /* "cPyparsing.pyx":5653
 * 
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_tuple__632 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_stopOn, __pyx_n_s_ender); if (unlikely(!__pyx_tuple__632)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__632);
  __Pyx_GIVEREF(__pyx_tuple__632);
  __pyx_codeobj__633 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__632, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5653, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__633)) __PYX_ERR(0, 5653, __pyx_L1_error)

  /* "cPyparsing.pyx":5661
 *         self.stopOn(ender)
 * 
 *     def stopOn(self, ender):             # <<<<<<<<<<<<<<
 *         if isinstance(ender, basestring):
 *             ender = self._literalStringClass(ender)
 */
  __pyx_tuple__634 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_ender); if (unlikely(!__pyx_tuple__634)) __PYX_ERR(0, 5661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__634);
  __Pyx_GIVEREF(__pyx_tuple__634);
  __pyx_codeobj__635 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__634, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_stopOn, 5661, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__635)) __PYX_ERR(0, 5661, __pyx_L1_error)

  /* "cPyparsing.pyx":5720
 * 
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 */
  __pyx_tuple__636 = PyTuple_Pack(12, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_self_expr_parse, __pyx_n_s_self_skip_ignorables, __pyx_n_s_check_ender, __pyx_n_s_try_not_ender, __pyx_n_s_tokens, __pyx_n_s_hasIgnoreExprs, __pyx_n_s_preloc, __pyx_n_s_tmptokens); if (unlikely(!__pyx_tuple__636)) __PYX_ERR(0, 5720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__636);
  __Pyx_GIVEREF(__pyx_tuple__636);
  __pyx_codeobj__637 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__636, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5720, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__637)) __PYX_ERR(0, 5720, __pyx_L1_error)

  /* "cPyparsing.pyx":5749
 *         return loc, tokens
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 */
  __pyx_codeobj__638 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__569, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setResultsName, 5749, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__638)) __PYX_ERR(0, 5749, __pyx_L1_error)

  /* "cPyparsing.pyx":5789
 *     """
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_codeobj__639 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 5789, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__639)) __PYX_ERR(0, 5789, __pyx_L1_error)

  /* "cPyparsing.pyx":5809
 *     Example: similar to :class:`OneOrMore`
 *     """
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True
 */
  __pyx_tuple__640 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_stopOn); if (unlikely(!__pyx_tuple__640)) __PYX_ERR(0, 5809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__640);
  __Pyx_GIVEREF(__pyx_tuple__640);
  __pyx_codeobj__641 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__640, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5809, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__641)) __PYX_ERR(0, 5809, __pyx_L1_error)

  /* "cPyparsing.pyx":5823
 *     #         return loc, []
 *     #     return got
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 */
  __pyx_codeobj__642 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5823, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__642)) __PYX_ERR(0, 5823, __pyx_L1_error)

  /* "cPyparsing.pyx":5829
 *             return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_codeobj__643 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 5829, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__643)) __PYX_ERR(0, 5829, __pyx_L1_error)

  /* "cPyparsing.pyx":5839
 * 
 * 
 * class _NullToken(object):             # <<<<<<<<<<<<<<
 *     def __bool__(self):
 *         return False
 */
  __pyx_tuple__644 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__644)) __PYX_ERR(0, 5839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__644);
  __Pyx_GIVEREF(__pyx_tuple__644);
  __pyx_tuple__645 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__645)) __PYX_ERR(0, 5839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__645);
  __Pyx_GIVEREF(__pyx_tuple__645);

  /* "cPyparsing.pyx":5840
 * 
 * class _NullToken(object):
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 *     __nonzero__ = __bool__
 */
  __pyx_codeobj__646 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_bool, 5840, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__646)) __PYX_ERR(0, 5840, __pyx_L1_error)

  /* "cPyparsing.pyx":5843
 *         return False
 *     __nonzero__ = __bool__
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
  __pyx_codeobj__647 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 5843, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__647)) __PYX_ERR(0, 5843, __pyx_L1_error)

  /* "cPyparsing.pyx":5885
 *     __optionalNotMatched = _NullToken()
 * 
 *     def __init__(self, expr, default=__optionalNotMatched):             # <<<<<<<<<<<<<<
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 */
  __pyx_tuple__648 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_default); if (unlikely(!__pyx_tuple__648)) __PYX_ERR(0, 5885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__648);
  __Pyx_GIVEREF(__pyx_tuple__648);
  __pyx_codeobj__649 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__648, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5885, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__649)) __PYX_ERR(0, 5885, __pyx_L1_error)

  /* "cPyparsing.pyx":5912
 *     #         loc, tokens = got
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_tuple__650 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_tokens); if (unlikely(!__pyx_tuple__650)) __PYX_ERR(0, 5912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__650);
  __Pyx_GIVEREF(__pyx_tuple__650);
  __pyx_codeobj__651 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__650, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 5912, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__651)) __PYX_ERR(0, 5912, __pyx_L1_error)

  /* "cPyparsing.pyx":5926
 *         return loc, tokens
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_codeobj__652 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 5926, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__652)) __PYX_ERR(0, 5926, __pyx_L1_error)

  /* "cPyparsing.pyx":5994
 *     """
 *     # [CPYPARSING] use kwargs to detect include
 *     def __init__(self, other, ignore=None, failOn=None, **kwargs):             # <<<<<<<<<<<<<<
 *         include_ = kwargs.get("include", False)  # include=False
 * 
 */
  __pyx_tuple__653 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_ignore, __pyx_n_s_failOn, __pyx_n_s_kwargs, __pyx_n_s_include_2); if (unlikely(!__pyx_tuple__653)) __PYX_ERR(0, 5994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__653);
  __Pyx_GIVEREF(__pyx_tuple__653);
  __pyx_codeobj__654 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__653, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 5994, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__654)) __PYX_ERR(0, 5994, __pyx_L1_error)

  /* "cPyparsing.pyx":6010
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         startloc = loc
 *         instrlen = len(instring)
 */
  __pyx_tuple__655 = PyTuple_Pack(14, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_startloc, __pyx_n_s_instrlen, __pyx_n_s_expr, __pyx_n_s_expr_parse, __pyx_n_s_self_failOn_canParseNext, __pyx_n_s_self_ignoreExpr_tryParse, __pyx_n_s_tmploc, __pyx_n_s_skiptext, __pyx_n_s_skipresult, __pyx_n_s_mat); if (unlikely(!__pyx_tuple__655)) __PYX_ERR(0, 6010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__655);
  __Pyx_GIVEREF(__pyx_tuple__655);
  __pyx_codeobj__656 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 14, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__655, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_parseImpl, 6010, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__656)) __PYX_ERR(0, 6010, __pyx_L1_error)

  /* "cPyparsing.pyx":6084
 *     parser created using ``Forward``.
 *     """
 *     def __init__(self, other=None):             # <<<<<<<<<<<<<<
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 */
  __pyx_codeobj__657 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 6084, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__657)) __PYX_ERR(0, 6084, __pyx_L1_error)

  /* "cPyparsing.pyx":6087
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 *     def __lshift__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */
  __pyx_codeobj__658 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_lshift, 6087, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__658)) __PYX_ERR(0, 6087, __pyx_L1_error)

  /* "cPyparsing.pyx":6100
 *         return self
 * 
 *     def __ilshift__(self, other):             # <<<<<<<<<<<<<<
 *         return self << other
 * 
 */
  __pyx_codeobj__659 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ilshift, 6100, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__659)) __PYX_ERR(0, 6100, __pyx_L1_error)

  /* "cPyparsing.pyx":6103
 *         return self << other
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         return self
 */
  __pyx_codeobj__660 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_leaveWhitespace, 6103, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__660)) __PYX_ERR(0, 6103, __pyx_L1_error)

  /* "cPyparsing.pyx":6107
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamlined = True
 */
  __pyx_codeobj__661 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_streamline, 6107, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__661)) __PYX_ERR(0, 6107, __pyx_L1_error)

  /* "cPyparsing.pyx":6114
 *         return self
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         if validateTrace is None:
 *             validateTrace = []
 */
  __pyx_codeobj__662 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__616, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_validate, 6114, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__662)) __PYX_ERR(0, 6114, __pyx_L1_error)

  /* "cPyparsing.pyx":6124
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_codeobj__663 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_str_2, 6124, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__663)) __PYX_ERR(0, 6124, __pyx_L1_error)

  /* "cPyparsing.pyx":6134
 *         return self.strRepr
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return super(Forward, self).copy()
 */
  __pyx_codeobj__664 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__269, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_copy, 6134, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__664)) __PYX_ERR(0, 6134, __pyx_L1_error)

  /* "cPyparsing.pyx":6142
 *             return ret
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_name_set_on_empty_Forward:
 *             if self.expr is None:
 */
  __pyx_codeobj__665 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__353, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_setResultsName, 6142, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__665)) __PYX_ERR(0, 6142, __pyx_L1_error)

  /* "cPyparsing.pyx":6157
 *     Abstract subclass of :class:`ParseExpression`, for converting parsed results.
 *     """
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(TokenConverter, self).__init__(expr)  # , savelist)
 *         self.saveAsList = False
 */
  __pyx_codeobj__666 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__608, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 6157, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__666)) __PYX_ERR(0, 6157, __pyx_L1_error)

  /* "cPyparsing.pyx":6179
 *         print(real.parseString('3. 1416')) # -> Exception: Expected W:(0123...)
 *     """
 *     def __init__(self, expr, joinString="", adjacent=True):             # <<<<<<<<<<<<<<
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 */
  __pyx_tuple__667 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_joinString, __pyx_n_s_adjacent); if (unlikely(!__pyx_tuple__667)) __PYX_ERR(0, 6179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__667);
  __Pyx_GIVEREF(__pyx_tuple__667);
  __pyx_codeobj__668 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__667, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 6179, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__668)) __PYX_ERR(0, 6179, __pyx_L1_error)
  __pyx_tuple__669 = PyTuple_Pack(2, ((PyObject*)__pyx_kp_u__10), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__669)) __PYX_ERR(0, 6179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__669);
  __Pyx_GIVEREF(__pyx_tuple__669);

  /* "cPyparsing.pyx":6189
 *         self.callPreparse = True
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)
 */
  __pyx_codeobj__670 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ignore, 6189, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__670)) __PYX_ERR(0, 6189, __pyx_L1_error)

  /* "cPyparsing.pyx":6196
 *         return self
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 */
  __pyx_tuple__671 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_tokenlist, __pyx_n_s_retToks); if (unlikely(!__pyx_tuple__671)) __PYX_ERR(0, 6196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__671);
  __Pyx_GIVEREF(__pyx_tuple__671);
  __pyx_codeobj__672 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__671, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_postParse, 6196, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__672)) __PYX_ERR(0, 6196, __pyx_L1_error)

  /* "cPyparsing.pyx":6221
 *         print(func.parseString("fn a, b, 100"))  # -> ['fn', ['a', 'b', '100']]
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_codeobj__673 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__619, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 6221, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__673)) __PYX_ERR(0, 6221, __pyx_L1_error)

  /* "cPyparsing.pyx":6225
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return [tokenlist]
 * 
 */
  __pyx_codeobj__674 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__372, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_postParse, 6225, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__674)) __PYX_ERR(0, 6225, __pyx_L1_error)

  /* "cPyparsing.pyx":6267
 *     See more examples at :class:`ParseResults` of accessing fields by results name.
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_codeobj__675 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__619, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 6267, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__675)) __PYX_ERR(0, 6267, __pyx_L1_error)

  /* "cPyparsing.pyx":6271
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 */
  __pyx_tuple__676 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_tokenlist, __pyx_n_s_i, __pyx_n_s_tok, __pyx_n_s_ikey, __pyx_n_s_dictvalue); if (unlikely(!__pyx_tuple__676)) __PYX_ERR(0, 6271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__676);
  __Pyx_GIVEREF(__pyx_tuple__676);
  __pyx_codeobj__677 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__676, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_postParse, 6271, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__677)) __PYX_ERR(0, 6271, __pyx_L1_error)

  /* "cPyparsing.pyx":6318
 *     (See also :class:`delimitedList`.)
 *     """
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return []
 * 
 */
  __pyx_codeobj__678 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__372, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_postParse, 6318, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__678)) __PYX_ERR(0, 6318, __pyx_L1_error)

  /* "cPyparsing.pyx":6321
 *         return []
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_codeobj__679 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_suppress, 6321, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__679)) __PYX_ERR(0, 6321, __pyx_L1_error)

  /* "cPyparsing.pyx":6325
 * 
 * 
 * class OnlyOnce(object):             # <<<<<<<<<<<<<<
 *     """Wrapper for parse actions, to ensure they are only called once.
 *     """
 */
  __pyx_tuple__680 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__680)) __PYX_ERR(0, 6325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__680);
  __Pyx_GIVEREF(__pyx_tuple__680);
  __pyx_tuple__681 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__681)) __PYX_ERR(0, 6325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__681);
  __Pyx_GIVEREF(__pyx_tuple__681);

  /* "cPyparsing.pyx":6328
 *     """Wrapper for parse actions, to ensure they are only called once.
 *     """
 *     def __init__(self, methodCall):             # <<<<<<<<<<<<<<
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 */
  __pyx_tuple__682 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_methodCall); if (unlikely(!__pyx_tuple__682)) __PYX_ERR(0, 6328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__682);
  __Pyx_GIVEREF(__pyx_tuple__682);
  __pyx_codeobj__683 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__682, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 6328, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__683)) __PYX_ERR(0, 6328, __pyx_L1_error)

  /* "cPyparsing.pyx":6331
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 *     def __call__(self, s, l, t):             # <<<<<<<<<<<<<<
 *         if not self.called:
 *             results = self.callable(s, l, t)
 */
  __pyx_tuple__684 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_results); if (unlikely(!__pyx_tuple__684)) __PYX_ERR(0, 6331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__684);
  __Pyx_GIVEREF(__pyx_tuple__684);
  __pyx_codeobj__685 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__684, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_call, 6331, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__685)) __PYX_ERR(0, 6331, __pyx_L1_error)

  /* "cPyparsing.pyx":6337
 *             return results
 *         raise ParseException(s, l, "")
 *     def reset(self):             # <<<<<<<<<<<<<<
 *         self.called = False
 * 
 */
  __pyx_codeobj__686 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_reset, 6337, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__686)) __PYX_ERR(0, 6337, __pyx_L1_error)

  /* "cPyparsing.pyx":6340
 *         self.called = False
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """Decorator for debugging parse actions.
 * 
 */
  __pyx_tuple__687 = PyTuple_Pack(3, __pyx_n_s_f_2, __pyx_n_s_z, __pyx_n_s_z); if (unlikely(!__pyx_tuple__687)) __PYX_ERR(0, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__687);
  __Pyx_GIVEREF(__pyx_tuple__687);
  __pyx_codeobj__688 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__687, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_traceParseAction, 6340, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__688)) __PYX_ERR(0, 6340, __pyx_L1_error)

  /* "cPyparsing.pyx":6388
 * # global helpers
 * #
 * def delimitedList(expr, delim=",", combine=False):             # <<<<<<<<<<<<<<
 *     """Helper to define a delimited list of expressions - the delimiter
 *     defaults to ','. By default, the list elements and delimiters can
 */
  __pyx_tuple__689 = PyTuple_Pack(4, __pyx_n_s_expr, __pyx_n_s_delim, __pyx_n_s_combine, __pyx_n_s_dlName); if (unlikely(!__pyx_tuple__689)) __PYX_ERR(0, 6388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__689);
  __Pyx_GIVEREF(__pyx_tuple__689);
  __pyx_codeobj__690 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__689, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_delimitedList, 6388, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__690)) __PYX_ERR(0, 6388, __pyx_L1_error)
  __pyx_tuple__691 = PyTuple_Pack(2, ((PyObject*)__pyx_kp_u__34), ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__691)) __PYX_ERR(0, 6388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__691);
  __Pyx_GIVEREF(__pyx_tuple__691);

  /* "cPyparsing.pyx":6409
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """Helper to define a counted list of expressions.
 * 
 */
  __pyx_tuple__692 = PyTuple_Pack(5, __pyx_n_s_expr, __pyx_n_s_intExpr, __pyx_n_s_arrayExpr, __pyx_n_s_countFieldParseAction, __pyx_n_s_countFieldParseAction); if (unlikely(!__pyx_tuple__692)) __PYX_ERR(0, 6409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__692);
  __Pyx_GIVEREF(__pyx_tuple__692);
  __pyx_codeobj__693 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__692, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_countedArray, 6409, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__693)) __PYX_ERR(0, 6409, __pyx_L1_error)

  /* "cPyparsing.pyx":6445
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')
 * 
 * def _flatten(L):             # <<<<<<<<<<<<<<
 *     ret = []
 *     for i in L:
 */
  __pyx_tuple__694 = PyTuple_Pack(3, __pyx_n_s_L, __pyx_n_s_ret, __pyx_n_s_i); if (unlikely(!__pyx_tuple__694)) __PYX_ERR(0, 6445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__694);
  __Pyx_GIVEREF(__pyx_tuple__694);
  __pyx_codeobj__695 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__694, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_flatten, 6445, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__695)) __PYX_ERR(0, 6445, __pyx_L1_error)

  /* "cPyparsing.pyx":6454
 *     return ret
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */
  __pyx_tuple__696 = PyTuple_Pack(4, __pyx_n_s_expr, __pyx_n_s_rep, __pyx_n_s_copyTokenToRepeater, __pyx_n_s_copyTokenToRepeater); if (unlikely(!__pyx_tuple__696)) __PYX_ERR(0, 6454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__696);
  __Pyx_GIVEREF(__pyx_tuple__696);
  __pyx_codeobj__697 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__696, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_matchPreviousLiteral, 6454, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__697)) __PYX_ERR(0, 6454, __pyx_L1_error)

  /* "cPyparsing.pyx":6484
 *     return rep
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */
  __pyx_tuple__698 = PyTuple_Pack(5, __pyx_n_s_expr, __pyx_n_s_rep, __pyx_n_s_e2, __pyx_n_s_copyTokenToRepeater, __pyx_n_s_copyTokenToRepeater); if (unlikely(!__pyx_tuple__698)) __PYX_ERR(0, 6484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__698);
  __Pyx_GIVEREF(__pyx_tuple__698);
  __pyx_codeobj__699 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__698, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_matchPreviousExpr, 6484, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__699)) __PYX_ERR(0, 6484, __pyx_L1_error)

  /* "cPyparsing.pyx":6513
 *     return rep
 * 
 * def _escapeRegexRangeChars(s):             # <<<<<<<<<<<<<<
 *     # ~  escape these chars: ^-[]
 *     for c in r"\^-[]":
 */
  __pyx_tuple__700 = PyTuple_Pack(2, __pyx_n_s_s, __pyx_n_s_c); if (unlikely(!__pyx_tuple__700)) __PYX_ERR(0, 6513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__700);
  __Pyx_GIVEREF(__pyx_tuple__700);
  __pyx_codeobj__701 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__700, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_escapeRegexRangeChars, 6513, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__701)) __PYX_ERR(0, 6513, __pyx_L1_error)

  /* "cPyparsing.pyx":6521
 *     return _ustr(s)
 * 
 * def oneOf(strs, caseless=False, useRegex=True, asKeyword=False):             # <<<<<<<<<<<<<<
 *     """Helper to quickly define a set of alternative Literals, and makes
 *     sure to do longest-first testing when there is a conflict,
 */
  __pyx_tuple__702 = PyTuple_Pack(16, __pyx_n_s_strs, __pyx_n_s_caseless, __pyx_n_s_useRegex, __pyx_n_s_asKeyword, __pyx_n_s_isequal, __pyx_n_s_masks, __pyx_n_s_parseElementClass, __pyx_n_s_symbols, __pyx_n_s_i, __pyx_n_s_cur, __pyx_n_s_j, __pyx_n_s_other, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__702)) __PYX_ERR(0, 6521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__702);
  __Pyx_GIVEREF(__pyx_tuple__702);
  __pyx_codeobj__703 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 16, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__702, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_oneOf, 6521, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__703)) __PYX_ERR(0, 6521, __pyx_L1_error)
  __pyx_tuple__704 = PyTuple_Pack(3, ((PyObject *)Py_False), ((PyObject *)Py_True), ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__704)) __PYX_ERR(0, 6521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__704);
  __Pyx_GIVEREF(__pyx_tuple__704);

  /* "cPyparsing.pyx":6608
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))
 * 
 * def dictOf(key, value):             # <<<<<<<<<<<<<<
 *     """Helper to easily and clearly define a dictionary by specifying
 *     the respective patterns for the key and value.  Takes care of
 */
  __pyx_tuple__705 = PyTuple_Pack(2, __pyx_n_s_key, __pyx_n_s_value); if (unlikely(!__pyx_tuple__705)) __PYX_ERR(0, 6608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__705);
  __Pyx_GIVEREF(__pyx_tuple__705);
  __pyx_codeobj__706 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__705, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_dictOf, 6608, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__706)) __PYX_ERR(0, 6608, __pyx_L1_error)

  /* "cPyparsing.pyx":6647
 *     return Dict(OneOrMore(Group(key + value)))
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """Helper to return the original, untokenized text for a given
 *     expression.  Useful to restore the parsed fields of an HTML start
 */
  __pyx_tuple__707 = PyTuple_Pack(7, __pyx_n_s_expr, __pyx_n_s_asString, __pyx_n_s_locMarker, __pyx_n_s_endlocMarker, __pyx_n_s_matchExpr, __pyx_n_s_extractText, __pyx_n_s_extractText); if (unlikely(!__pyx_tuple__707)) __PYX_ERR(0, 6647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__707);
  __Pyx_GIVEREF(__pyx_tuple__707);
  __pyx_codeobj__708 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__707, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_originalTextFor, 6647, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__708)) __PYX_ERR(0, 6647, __pyx_L1_error)

  /* "cPyparsing.pyx":6689
 *     return matchExpr
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """Helper to undo pyparsing's default grouping of And expressions,
 *     even if all but one are non-empty.
 */
  __pyx_tuple__709 = PyTuple_Pack(1, __pyx_n_s_expr); if (unlikely(!__pyx_tuple__709)) __PYX_ERR(0, 6689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__709);
  __Pyx_GIVEREF(__pyx_tuple__709);
  __pyx_codeobj__710 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__709, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_ungroup, 6689, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__710)) __PYX_ERR(0, 6689, __pyx_L1_error)

  /* "cPyparsing.pyx":6695
 *     return TokenConverter(expr).addParseAction(lambda t: t[0])
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to decorate a returned token with its starting and ending
 *     locations in the input string.
 */
  __pyx_tuple__711 = PyTuple_Pack(2, __pyx_n_s_expr, __pyx_n_s_locator); if (unlikely(!__pyx_tuple__711)) __PYX_ERR(0, 6695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__711);
  __Pyx_GIVEREF(__pyx_tuple__711);
  __pyx_codeobj__712 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__711, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_locatedExpr, 6695, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__712)) __PYX_ERR(0, 6695, __pyx_L1_error)

  /* "cPyparsing.pyx":6725
 * 
 * # convenience constants for positional expressions
 * empty       = Empty().setName("empty")             # <<<<<<<<<<<<<<
 * lineStart   = LineStart().setName("lineStart")
 * lineEnd     = LineEnd().setName("lineEnd")
 */
  __pyx_tuple__713 = PyTuple_Pack(1, __pyx_n_u_empty); if (unlikely(!__pyx_tuple__713)) __PYX_ERR(0, 6725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__713);
  __Pyx_GIVEREF(__pyx_tuple__713);

  /* "cPyparsing.pyx":6726
 * # convenience constants for positional expressions
 * empty       = Empty().setName("empty")
 * lineStart   = LineStart().setName("lineStart")             # <<<<<<<<<<<<<<
 * lineEnd     = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")
 */
  __pyx_tuple__714 = PyTuple_Pack(1, __pyx_n_u_lineStart); if (unlikely(!__pyx_tuple__714)) __PYX_ERR(0, 6726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__714);
  __Pyx_GIVEREF(__pyx_tuple__714);

  /* "cPyparsing.pyx":6727
 * empty       = Empty().setName("empty")
 * lineStart   = LineStart().setName("lineStart")
 * lineEnd     = LineEnd().setName("lineEnd")             # <<<<<<<<<<<<<<
 * stringStart = StringStart().setName("stringStart")
 * stringEnd   = StringEnd().setName("stringEnd")
 */
  __pyx_tuple__715 = PyTuple_Pack(1, __pyx_n_u_lineEnd); if (unlikely(!__pyx_tuple__715)) __PYX_ERR(0, 6727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__715);
  __Pyx_GIVEREF(__pyx_tuple__715);

  /* "cPyparsing.pyx":6728
 * lineStart   = LineStart().setName("lineStart")
 * lineEnd     = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")             # <<<<<<<<<<<<<<
 * stringEnd   = StringEnd().setName("stringEnd")
 * 
 */
  __pyx_tuple__716 = PyTuple_Pack(1, __pyx_n_u_stringStart); if (unlikely(!__pyx_tuple__716)) __PYX_ERR(0, 6728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__716);
  __Pyx_GIVEREF(__pyx_tuple__716);

  /* "cPyparsing.pyx":6729
 * lineEnd     = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")
 * stringEnd   = StringEnd().setName("stringEnd")             # <<<<<<<<<<<<<<
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 */
  __pyx_tuple__717 = PyTuple_Pack(1, __pyx_n_u_stringEnd); if (unlikely(!__pyx_tuple__717)) __PYX_ERR(0, 6729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__717);
  __Pyx_GIVEREF(__pyx_tuple__717);

  /* "cPyparsing.pyx":6732
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))             # <<<<<<<<<<<<<<
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 */
  __pyx_tuple__719 = PyTuple_Pack(1, __pyx_kp_u_0_xX_0_9a_fA_F); if (unlikely(!__pyx_tuple__719)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__719);
  __Pyx_GIVEREF(__pyx_tuple__719);

  /* "cPyparsing.pyx":6733
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))             # <<<<<<<<<<<<<<
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 */
  __pyx_tuple__720 = PyTuple_Pack(1, __pyx_kp_u_0_0_7); if (unlikely(!__pyx_tuple__720)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__720);
  __Pyx_GIVEREF(__pyx_tuple__720);

  /* "cPyparsing.pyx":6734
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)             # <<<<<<<<<<<<<<
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 */
  __pyx_tuple__722 = PyTuple_Pack(1, __pyx_kp_u__721); if (unlikely(!__pyx_tuple__722)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__722);
  __Pyx_GIVEREF(__pyx_tuple__722);

  /* "cPyparsing.pyx":6735
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)             # <<<<<<<<<<<<<<
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 */
  __pyx_tuple__723 = PyTuple_Pack(1, __pyx_kp_u__105); if (unlikely(!__pyx_tuple__723)) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__723);
  __Pyx_GIVEREF(__pyx_tuple__723);

  /* "cPyparsing.pyx":6736
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"             # <<<<<<<<<<<<<<
 * 
 * def srange(s):
 */
  __pyx_tuple__724 = PyTuple_Pack(1, __pyx_kp_u__2); if (unlikely(!__pyx_tuple__724)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__724);
  __Pyx_GIVEREF(__pyx_tuple__724);
  __pyx_tuple__725 = PyTuple_Pack(1, __pyx_kp_u__17); if (unlikely(!__pyx_tuple__725)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__725);
  __Pyx_GIVEREF(__pyx_tuple__725);
  __pyx_tuple__726 = PyTuple_Pack(1, __pyx_n_u_negate); if (unlikely(!__pyx_tuple__726)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__726);
  __Pyx_GIVEREF(__pyx_tuple__726);
  __pyx_tuple__727 = PyTuple_Pack(1, __pyx_n_u_body); if (unlikely(!__pyx_tuple__727)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__727);
  __Pyx_GIVEREF(__pyx_tuple__727);

  /* "cPyparsing.pyx":6738
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""Helper to easily define string ranges for use in Word
 *     construction. Borrows syntax from regexp '[]' string range
 */
  __pyx_tuple__728 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_expanded, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__728)) __PYX_ERR(0, 6738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__728);
  __Pyx_GIVEREF(__pyx_tuple__728);
  __pyx_codeobj__729 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__728, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_srange, 6738, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__729)) __PYX_ERR(0, 6738, __pyx_L1_error)

  /* "cPyparsing.pyx":6770
 *         return ""
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """Helper method for defining parse actions that require matching at
 *     a specific column in the input text.
 */
  __pyx_tuple__730 = PyTuple_Pack(3, __pyx_n_s_n, __pyx_n_s_verifyCol, __pyx_n_s_verifyCol); if (unlikely(!__pyx_tuple__730)) __PYX_ERR(0, 6770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__730);
  __Pyx_GIVEREF(__pyx_tuple__730);
  __pyx_codeobj__731 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__730, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_matchOnlyAtCol, 6770, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__731)) __PYX_ERR(0, 6770, __pyx_L1_error)

  /* "cPyparsing.pyx":6779
 *     return verifyCol
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """Helper method for common parse actions that simply return
 *     a literal value.  Especially useful when used with
 */
  __pyx_tuple__732 = PyTuple_Pack(1, __pyx_n_s_replStr); if (unlikely(!__pyx_tuple__732)) __PYX_ERR(0, 6779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__732);
  __Pyx_GIVEREF(__pyx_tuple__732);
  __pyx_codeobj__733 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__732, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_replaceWith, 6779, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__733)) __PYX_ERR(0, 6779, __pyx_L1_error)

  /* "cPyparsing.pyx":6794
 *     return lambda s, l, t: [replStr]
 * 
 * def removeQuotes(s, l, t):             # <<<<<<<<<<<<<<
 *     """Helper parse action for removing quotation marks from parsed
 *     quoted strings.
 */
  __pyx_codeobj__734 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__8, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_removeQuotes, 6794, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__734)) __PYX_ERR(0, 6794, __pyx_L1_error)

  /* "cPyparsing.pyx":6809
 *     return t[0][1:-1]
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """Helper to define a parse action by mapping a function to all
 *     elements of a ParseResults list. If any additional args are passed,
 */
  __pyx_tuple__735 = PyTuple_Pack(5, __pyx_n_s_func, __pyx_n_s_args, __pyx_n_s_pa, __pyx_n_s_pa, __pyx_n_s_func_name); if (unlikely(!__pyx_tuple__735)) __PYX_ERR(0, 6809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__735);
  __Pyx_GIVEREF(__pyx_tuple__735);
  __pyx_codeobj__736 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__735, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_tokenMap, 6809, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__736)) __PYX_ERR(0, 6809, __pyx_L1_error)

  /* "cPyparsing.pyx":6865
 * Deprecated in favor of :class:`pyparsing_common.downcaseTokens`"""
 * 
 * def _makeTags(tagStr, xml,             # <<<<<<<<<<<<<<
 *               suppress_LT=Suppress("<"),
 *               suppress_GT=Suppress(">")):
 */
  __pyx_tuple__737 = PyTuple_Pack(9, __pyx_n_s_tagStr, __pyx_n_s_xml, __pyx_n_s_suppress_LT, __pyx_n_s_suppress_GT, __pyx_n_s_resname, __pyx_n_s_tagAttrName, __pyx_n_s_tagAttrValue, __pyx_n_s_openTag, __pyx_n_s_closeTag); if (unlikely(!__pyx_tuple__737)) __PYX_ERR(0, 6865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__737);
  __Pyx_GIVEREF(__pyx_tuple__737);
  __pyx_codeobj__738 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__737, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_makeTags, 6865, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__738)) __PYX_ERR(0, 6865, __pyx_L1_error)

  /* "cPyparsing.pyx":6866
 * 
 * def _makeTags(tagStr, xml,
 *               suppress_LT=Suppress("<"),             # <<<<<<<<<<<<<<
 *               suppress_GT=Suppress(">")):
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 */
  __pyx_tuple__739 = PyTuple_Pack(1, __pyx_kp_u__26); if (unlikely(!__pyx_tuple__739)) __PYX_ERR(0, 6866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__739);
  __Pyx_GIVEREF(__pyx_tuple__739);

  /* "cPyparsing.pyx":6867
 * def _makeTags(tagStr, xml,
 *               suppress_LT=Suppress("<"),
 *               suppress_GT=Suppress(">")):             # <<<<<<<<<<<<<<
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):
 */
  __pyx_tuple__740 = PyTuple_Pack(1, __pyx_kp_u__27); if (unlikely(!__pyx_tuple__740)) __PYX_ERR(0, 6867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__740);
  __Pyx_GIVEREF(__pyx_tuple__740);

  /* "cPyparsing.pyx":6902
 *     return openTag, closeTag
 * 
 * def makeHTMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """Helper to construct opening and closing tag expressions for HTML,
 *     given a tag name. Matches tags in either upper or lower case,
 */
  __pyx_tuple__741 = PyTuple_Pack(1, __pyx_n_s_tagStr); if (unlikely(!__pyx_tuple__741)) __PYX_ERR(0, 6902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__741);
  __Pyx_GIVEREF(__pyx_tuple__741);
  __pyx_codeobj__742 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__741, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_makeHTMLTags, 6902, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__742)) __PYX_ERR(0, 6902, __pyx_L1_error)

  /* "cPyparsing.pyx":6926
 *     return _makeTags(tagStr, False)
 * 
 * def makeXMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """Helper to construct opening and closing tag expressions for XML,
 *     given a tag name. Matches tags only in the given upper/lower case.
 */
  __pyx_codeobj__743 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__741, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_makeXMLTags, 6926, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__743)) __PYX_ERR(0, 6926, __pyx_L1_error)

  /* "cPyparsing.pyx":6935
 * 
 * # [CPYPARSING] withAttribute must be a class
 * class BaseWithAttribute(object):             # <<<<<<<<<<<<<<
 *     ANY_VALUE = object()
 * 
 */
  __pyx_tuple__744 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__744)) __PYX_ERR(0, 6935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__744);
  __Pyx_GIVEREF(__pyx_tuple__744);
  __pyx_tuple__745 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__745)) __PYX_ERR(0, 6935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__745);
  __Pyx_GIVEREF(__pyx_tuple__745);

  /* "cPyparsing.pyx":6938
 *     ANY_VALUE = object()
 * 
 *     def __call__(self, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         """Helper to create a validating parse action to be used with start
 *         tags created with :class:`makeXMLTags` or
 */
  __pyx_tuple__746 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_args, __pyx_n_s_attrDict, __pyx_n_s_attrs, __pyx_n_s_pa, __pyx_n_s_pa, __pyx_n_s_k, __pyx_n_s_v); if (unlikely(!__pyx_tuple__746)) __PYX_ERR(0, 6938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__746);
  __Pyx_GIVEREF(__pyx_tuple__746);
  __pyx_codeobj__747 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__746, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_call, 6938, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__747)) __PYX_ERR(0, 6938, __pyx_L1_error)

  /* "cPyparsing.pyx":7011
 * withAttribute = BaseWithAttribute()
 * 
 * def withClass(classname, namespace=''):             # <<<<<<<<<<<<<<
 *     """Simplified version of :class:`withAttribute` when
 *     matching on a div class - made difficult because ``class`` is
 */
  __pyx_tuple__748 = PyTuple_Pack(3, __pyx_n_s_classname, __pyx_n_s_namespace, __pyx_n_s_classattr); if (unlikely(!__pyx_tuple__748)) __PYX_ERR(0, 7011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__748);
  __Pyx_GIVEREF(__pyx_tuple__748);
  __pyx_codeobj__749 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__748, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_withClass, 7011, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__749)) __PYX_ERR(0, 7011, __pyx_L1_error)

  /* "cPyparsing.pyx":7053
 * opAssoc.RIGHT = object()
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):             # <<<<<<<<<<<<<<
 *     """Helper method for constructing grammars of expressions made up of
 *     operators working in a precedence hierarchy.  Operators may be unary
 */
  __pyx_tuple__750 = PyTuple_Pack(18, __pyx_n_s_baseExpr, __pyx_n_s_opList, __pyx_n_s_lpar, __pyx_n_s_rpar, __pyx_n_s_FB, __pyx_n_s_ret, __pyx_n_s_lastExpr, __pyx_n_s_i, __pyx_n_s_operDef, __pyx_n_s_opExpr, __pyx_n_s_arity, __pyx_n_s_rightLeftAssoc, __pyx_n_s_pa, __pyx_n_s_termName, __pyx_n_s_opExpr1, __pyx_n_s_opExpr2, __pyx_n_s_thisExpr, __pyx_n_s_matchExpr); if (unlikely(!__pyx_tuple__750)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__750);
  __Pyx_GIVEREF(__pyx_tuple__750);
  __pyx_codeobj__751 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 18, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__750, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_infixNotation, 7053, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__751)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __pyx_tuple__752 = PyTuple_Pack(1, __pyx_kp_u__22); if (unlikely(!__pyx_tuple__752)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__752);
  __Pyx_GIVEREF(__pyx_tuple__752);
  __pyx_tuple__753 = PyTuple_Pack(1, __pyx_kp_u__13); if (unlikely(!__pyx_tuple__753)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__753);
  __Pyx_GIVEREF(__pyx_tuple__753);

  /* "cPyparsing.pyx":7186
 * dropped in a future release."""
 * 
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")             # <<<<<<<<<<<<<<
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'
 */
  __pyx_tuple__754 = PyTuple_Pack(1, __pyx_kp_u_n_r_x_x_0_9a_fA_F); if (unlikely(!__pyx_tuple__754)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__754);
  __Pyx_GIVEREF(__pyx_tuple__754);
  __pyx_tuple__756 = PyTuple_Pack(1, __pyx_kp_u_string_enclosed_in_double_quotes); if (unlikely(!__pyx_tuple__756)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__756);
  __Pyx_GIVEREF(__pyx_tuple__756);

  /* "cPyparsing.pyx":7187
 * 
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")             # <<<<<<<<<<<<<<
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'
 *                        | Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 */
  __pyx_tuple__757 = PyTuple_Pack(1, __pyx_kp_u_n_r_x_x_0_9a_fA_F_2); if (unlikely(!__pyx_tuple__757)) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__757);
  __Pyx_GIVEREF(__pyx_tuple__757);
  __pyx_tuple__758 = PyTuple_Pack(1, __pyx_kp_u_string_enclosed_in_single_quotes); if (unlikely(!__pyx_tuple__758)) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__758);
  __Pyx_GIVEREF(__pyx_tuple__758);

  /* "cPyparsing.pyx":7189
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'
 *                        | Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")             # <<<<<<<<<<<<<<
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 */
  __pyx_tuple__759 = PyTuple_Pack(1, __pyx_kp_u_quotedString_using_single_or_dou); if (unlikely(!__pyx_tuple__759)) __PYX_ERR(0, 7189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__759);
  __Pyx_GIVEREF(__pyx_tuple__759);

  /* "cPyparsing.pyx":7190
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'
 *                        | Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")             # <<<<<<<<<<<<<<
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):
 */
  __pyx_tuple__760 = PyTuple_Pack(1, __pyx_n_u_u); if (unlikely(!__pyx_tuple__760)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__760);
  __Pyx_GIVEREF(__pyx_tuple__760);
  __pyx_tuple__761 = PyTuple_Pack(1, __pyx_kp_u_unicode_string_literal); if (unlikely(!__pyx_tuple__761)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__761);
  __Pyx_GIVEREF(__pyx_tuple__761);

  /* "cPyparsing.pyx":7192
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """Helper method for defining nested lists enclosed in opening and
 *     closing delimiters ("(" and ")" are the default).
 */
  __pyx_tuple__762 = PyTuple_Pack(5, __pyx_n_s_opener, __pyx_n_s_closer, __pyx_n_s_content, __pyx_n_s_ignoreExpr, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__762)) __PYX_ERR(0, 7192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__762);
  __Pyx_GIVEREF(__pyx_tuple__762);
  __pyx_codeobj__763 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__762, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_nestedExpr, 7192, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__763)) __PYX_ERR(0, 7192, __pyx_L1_error)

  /* "cPyparsing.pyx":7296
 *     return ret
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """Helper method for defining space-delimited indentation blocks,
 *     such as those used to define block statements in Python source code.
 */
  __pyx_tuple__764 = PyTuple_Pack(17, __pyx_n_s_blockStatementExpr, __pyx_n_s_indentStack, __pyx_n_s_indent, __pyx_n_s_backup_stack, __pyx_n_s_reset_stack, __pyx_n_s_reset_stack, __pyx_n_s_checkPeerIndent, __pyx_n_s_checkPeerIndent, __pyx_n_s_checkSubIndent, __pyx_n_s_checkSubIndent, __pyx_n_s_checkUnindent, __pyx_n_s_checkUnindent, __pyx_n_s_NL, __pyx_n_s_INDENT, __pyx_n_s_PEER, __pyx_n_s_UNDENT, __pyx_n_s_smExpr); if (unlikely(!__pyx_tuple__764)) __PYX_ERR(0, 7296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__764);
  __Pyx_GIVEREF(__pyx_tuple__764);
  __pyx_codeobj__765 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 17, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__764, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_indentedBlock, 7296, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__765)) __PYX_ERR(0, 7296, __pyx_L1_error)

  /* "cPyparsing.pyx":7422
 *     return smExpr.setName('indented block')
 * 
 * alphas8bit = srange(r"[\0xc0-\0xd6\0xd8-\0xf6\0xf8-\0xff]")             # <<<<<<<<<<<<<<
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")
 * 
 */
  __pyx_tuple__766 = PyTuple_Pack(1, __pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff); if (unlikely(!__pyx_tuple__766)) __PYX_ERR(0, 7422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__766);
  __Pyx_GIVEREF(__pyx_tuple__766);

  /* "cPyparsing.pyx":7423
 * 
 * alphas8bit = srange(r"[\0xc0-\0xd6\0xd8-\0xf6\0xf8-\0xff]")
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")             # <<<<<<<<<<<<<<
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 */
  __pyx_tuple__767 = PyTuple_Pack(1, __pyx_kp_u_0xa1_0xbf_0xd7_0xf7); if (unlikely(!__pyx_tuple__767)) __PYX_ERR(0, 7423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__767);
  __Pyx_GIVEREF(__pyx_tuple__767);

  /* "cPyparsing.pyx":7425
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))             # <<<<<<<<<<<<<<
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) +");").setName("common HTML entity")
 */
  __pyx_tuple__769 = PyTuple_Pack(1, __pyx_kp_u_any_tag); if (unlikely(!__pyx_tuple__769)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__769);
  __Pyx_GIVEREF(__pyx_tuple__769);

  /* "cPyparsing.pyx":7427
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) +");").setName("common HTML entity")             # <<<<<<<<<<<<<<
 * def replaceHTMLEntity(t):
 *     """Helper parser action to replace common HTML entities with their special characters"""
 */
  __pyx_tuple__772 = PyTuple_Pack(1, __pyx_kp_u_common_HTML_entity); if (unlikely(!__pyx_tuple__772)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__772);
  __Pyx_GIVEREF(__pyx_tuple__772);

  /* "cPyparsing.pyx":7428
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) +");").setName("common HTML entity")
 * def replaceHTMLEntity(t):             # <<<<<<<<<<<<<<
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)
 */
  __pyx_codeobj__773 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__71, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_replaceHTMLEntity, 7428, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__773)) __PYX_ERR(0, 7428, __pyx_L1_error)

  /* "cPyparsing.pyx":7433
 * 
 * # it's easy to get these comment structures wrong - they're very common, so may as well make them available
 * cStyleComment = Combine(Regex(r"/\*(?:[^*]|\*(?!/))*") + '*[inserted by cython to avoid comment closer]/').setName("C style comment")             # <<<<<<<<<<<<<<
 * "Comment of the form ``/[inserted by cython to avoid comment start]* ... *[inserted by cython to avoid comment closer]/``"
 * 
 */
  __pyx_tuple__775 = PyTuple_Pack(1, __pyx_kp_u__774); if (unlikely(!__pyx_tuple__775)) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__775);
  __Pyx_GIVEREF(__pyx_tuple__775);
  __pyx_tuple__777 = PyTuple_Pack(1, __pyx_kp_u_C_style_comment); if (unlikely(!__pyx_tuple__777)) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__777);
  __Pyx_GIVEREF(__pyx_tuple__777);

  /* "cPyparsing.pyx":7436
 * "Comment of the form ``/[inserted by cython to avoid comment start]* ... *[inserted by cython to avoid comment closer]/``"
 * 
 * htmlComment = Regex(r"<!--[\s\S]*?-->").setName("HTML comment")             # <<<<<<<<<<<<<<
 * "Comment of the form ``<!-- ... -->``"
 * 
 */
  __pyx_tuple__778 = PyTuple_Pack(1, __pyx_kp_u_s_S); if (unlikely(!__pyx_tuple__778)) __PYX_ERR(0, 7436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__778);
  __Pyx_GIVEREF(__pyx_tuple__778);
  __pyx_tuple__779 = PyTuple_Pack(1, __pyx_kp_u_HTML_comment); if (unlikely(!__pyx_tuple__779)) __PYX_ERR(0, 7436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__779);
  __Pyx_GIVEREF(__pyx_tuple__779);

  /* "cPyparsing.pyx":7439
 * "Comment of the form ``<!-- ... -->``"
 * 
 * restOfLine = Regex(r".*").leaveWhitespace().setName("rest of line")             # <<<<<<<<<<<<<<
 * dblSlashComment = Regex(r"//(?:\\\n|[^\n])*").setName("// comment")
 * "Comment of the form ``// ... (to end of line)``"
 */
  __pyx_tuple__781 = PyTuple_Pack(1, __pyx_kp_u__780); if (unlikely(!__pyx_tuple__781)) __PYX_ERR(0, 7439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__781);
  __Pyx_GIVEREF(__pyx_tuple__781);
  __pyx_tuple__782 = PyTuple_Pack(1, __pyx_kp_u_rest_of_line); if (unlikely(!__pyx_tuple__782)) __PYX_ERR(0, 7439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__782);
  __Pyx_GIVEREF(__pyx_tuple__782);

  /* "cPyparsing.pyx":7440
 * 
 * restOfLine = Regex(r".*").leaveWhitespace().setName("rest of line")
 * dblSlashComment = Regex(r"//(?:\\\n|[^\n])*").setName("// comment")             # <<<<<<<<<<<<<<
 * "Comment of the form ``// ... (to end of line)``"
 * 
 */
  __pyx_tuple__783 = PyTuple_Pack(1, __pyx_kp_u_n_n); if (unlikely(!__pyx_tuple__783)) __PYX_ERR(0, 7440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__783);
  __Pyx_GIVEREF(__pyx_tuple__783);
  __pyx_tuple__784 = PyTuple_Pack(1, __pyx_kp_u_comment_2); if (unlikely(!__pyx_tuple__784)) __PYX_ERR(0, 7440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__784);
  __Pyx_GIVEREF(__pyx_tuple__784);

  /* "cPyparsing.pyx":7443
 * "Comment of the form ``// ... (to end of line)``"
 * 
 * cppStyleComment = Combine(Regex(r"/\*(?:[^*]|\*(?!/))*") + '*[inserted by cython to avoid comment closer]/' | dblSlashComment).setName("C++ style comment")             # <<<<<<<<<<<<<<
 * "Comment of either form :class:`cStyleComment` or :class:`dblSlashComment`"
 * 
 */
  __pyx_tuple__785 = PyTuple_Pack(1, __pyx_kp_u_C_style_comment_2); if (unlikely(!__pyx_tuple__785)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__785);
  __Pyx_GIVEREF(__pyx_tuple__785);

  /* "cPyparsing.pyx":7449
 * "Same as :class:`cppStyleComment`"
 * 
 * pythonStyleComment = Regex(r"#.*").setName("Python style comment")             # <<<<<<<<<<<<<<
 * "Comment of the form ``# ... (to end of line)``"
 * 
 */
  __pyx_tuple__787 = PyTuple_Pack(1, __pyx_kp_u__786); if (unlikely(!__pyx_tuple__787)) __PYX_ERR(0, 7449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__787);
  __Pyx_GIVEREF(__pyx_tuple__787);
  __pyx_tuple__788 = PyTuple_Pack(1, __pyx_kp_u_Python_style_comment); if (unlikely(!__pyx_tuple__788)) __PYX_ERR(0, 7449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__788);
  __Pyx_GIVEREF(__pyx_tuple__788);

  /* "cPyparsing.pyx":7453
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',')
 *                                   + Optional(Word(" \t")             # <<<<<<<<<<<<<<
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 */
  __pyx_tuple__790 = PyTuple_Pack(1, __pyx_kp_u__789); if (unlikely(!__pyx_tuple__790)) __PYX_ERR(0, 7453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__790);
  __Pyx_GIVEREF(__pyx_tuple__790);

  /* "cPyparsing.pyx":7454
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',')
 *                                   + Optional(Word(" \t")
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 * """(Deprecated) Predefined expression of 1 or more printable words or
 */
  __pyx_tuple__791 = PyTuple_Pack(1, __pyx_kp_u__34); if (unlikely(!__pyx_tuple__791)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__791);
  __Pyx_GIVEREF(__pyx_tuple__791);
  __pyx_tuple__792 = PyTuple_Pack(1, __pyx_n_u_commaItem); if (unlikely(!__pyx_tuple__792)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__792);
  __Pyx_GIVEREF(__pyx_tuple__792);

  /* "cPyparsing.pyx":7455
 *                                   + Optional(Word(" \t")
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")             # <<<<<<<<<<<<<<
 * """(Deprecated) Predefined expression of 1 or more printable words or
 * quoted strings, separated by commas.
 */
  __pyx_tuple__793 = PyTuple_Pack(1, __pyx_n_u_commaSeparatedList); if (unlikely(!__pyx_tuple__793)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__793);
  __Pyx_GIVEREF(__pyx_tuple__793);

  /* "cPyparsing.pyx":7657
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))             # <<<<<<<<<<<<<<
 *                            + "::"
 *                            + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 */
  __pyx_tuple__794 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_6); if (unlikely(!__pyx_tuple__794)) __PYX_ERR(0, 7657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__794);
  __Pyx_GIVEREF(__pyx_tuple__794);

  /* "cPyparsing.pyx":7669
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDate(fmt="%Y-%m-%d"):
 *         """
 */
  __pyx_tuple__796 = PyTuple_Pack(3, __pyx_n_s_fmt, __pyx_n_s_cvt_fn, __pyx_n_s_cvt_fn); if (unlikely(!__pyx_tuple__796)) __PYX_ERR(0, 7669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__796);
  __Pyx_GIVEREF(__pyx_tuple__796);
  __pyx_codeobj__797 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__796, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_convertToDate, 7669, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__797)) __PYX_ERR(0, 7669, __pyx_L1_error)
  __pyx_tuple__798 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u_Y_m_d)); if (unlikely(!__pyx_tuple__798)) __PYX_ERR(0, 7669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__798);
  __Pyx_GIVEREF(__pyx_tuple__798);

  /* "cPyparsing.pyx":7694
 *         return cvt_fn
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):
 *         """Helper to create a parse action for converting parsed
 */
  __pyx_codeobj__799 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__796, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_convertToDatetime, 7694, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__799)) __PYX_ERR(0, 7694, __pyx_L1_error)
  __pyx_tuple__800 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u_Y_m_dT_H_M_S_f)); if (unlikely(!__pyx_tuple__800)) __PYX_ERR(0, 7694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__800);
  __Pyx_GIVEREF(__pyx_tuple__800);

  /* "cPyparsing.pyx":7729
 * 
 *     _html_stripper = anyOpenTag.suppress() | anyCloseTag.suppress()
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def stripHTMLTags(s, l, tokens):
 *         """Parse action to remove HTML tags from web page HTML source
 */
  __pyx_tuple__801 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_tokens); if (unlikely(!__pyx_tuple__801)) __PYX_ERR(0, 7729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__801);
  __Pyx_GIVEREF(__pyx_tuple__801);
  __pyx_codeobj__802 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__801, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_stripHTMLTags, 7729, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__802)) __PYX_ERR(0, 7729, __pyx_L1_error)

  /* "cPyparsing.pyx":7763
 * 
 * 
 * class _lazyclassproperty(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, fn):
 *         self.fn = fn
 */
  __pyx_tuple__803 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__803)) __PYX_ERR(0, 7763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__803);
  __Pyx_GIVEREF(__pyx_tuple__803);
  __pyx_tuple__804 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__804)) __PYX_ERR(0, 7763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__804);
  __Pyx_GIVEREF(__pyx_tuple__804);

  /* "cPyparsing.pyx":7764
 * 
 * class _lazyclassproperty(object):
 *     def __init__(self, fn):             # <<<<<<<<<<<<<<
 *         self.fn = fn
 *         self.__doc__ = fn.__doc__
 */
  __pyx_codeobj__805 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__365, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 7764, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__805)) __PYX_ERR(0, 7764, __pyx_L1_error)

  /* "cPyparsing.pyx":7769
 *         self.__name__ = fn.__name__
 * 
 *     def __get__(self, obj, cls):             # <<<<<<<<<<<<<<
 *         if cls is None:
 *             cls = type(obj)
 */
  __pyx_tuple__806 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_obj, __pyx_n_s_cls, __pyx_n_s_attrname, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__806)) __PYX_ERR(0, 7769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__806);
  __Pyx_GIVEREF(__pyx_tuple__806);
  __pyx_codeobj__807 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__806, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_get_2, 7769, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__807)) __PYX_ERR(0, 7769, __pyx_L1_error)

  /* "cPyparsing.pyx":7781
 * 
 * 
 * class unicode_set(object):             # <<<<<<<<<<<<<<
 *     """
 *     A set of Unicode characters, for language-specific strings for
 */
  __pyx_tuple__808 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__808)) __PYX_ERR(0, 7781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__808);
  __Pyx_GIVEREF(__pyx_tuple__808);
  __pyx_tuple__809 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__809)) __PYX_ERR(0, 7781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__809);
  __Pyx_GIVEREF(__pyx_tuple__809);

  /* "cPyparsing.pyx":7797
 *     _ranges = []
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _get_chars_for_ranges(cls):
 *         ret = []
 */
  __pyx_tuple__810 = PyTuple_Pack(5, __pyx_n_s_cls, __pyx_n_s_ret, __pyx_n_s_cc, __pyx_n_s_rr, __pyx_n_s_c); if (unlikely(!__pyx_tuple__810)) __PYX_ERR(0, 7797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__810);
  __Pyx_GIVEREF(__pyx_tuple__810);
  __pyx_codeobj__811 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__810, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_get_chars_for_ranges, 7797, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__811)) __PYX_ERR(0, 7797, __pyx_L1_error)

  /* "cPyparsing.pyx":7807
 *         return [unichr(c) for c in sorted(set(ret))]
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def printables(cls):
 *         "all non-whitespace characters in this range"
 */
  __pyx_codeobj__812 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__342, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_printables, 7807, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__812)) __PYX_ERR(0, 7807, __pyx_L1_error)

  /* "cPyparsing.pyx":7812
 *         return u''.join(filterfalse(unicode.isspace, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def alphas(cls):
 *         "all alphabetic characters in this range"
 */
  __pyx_codeobj__813 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__342, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_alphas, 7812, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__813)) __PYX_ERR(0, 7812, __pyx_L1_error)

  /* "cPyparsing.pyx":7817
 *         return u''.join(filter(unicode.isalpha, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def nums(cls):
 *         "all numeric digit characters in this range"
 */
  __pyx_codeobj__814 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__342, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_nums, 7817, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__814)) __PYX_ERR(0, 7817, __pyx_L1_error)

  /* "cPyparsing.pyx":7822
 *         return u''.join(filter(unicode.isdigit, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def alphanums(cls):
 *         "all alphanumeric characters in this range"
 */
  __pyx_codeobj__815 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__342, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_alphanums, 7822, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__815)) __PYX_ERR(0, 7822, __pyx_L1_error)

  /* "cPyparsing.pyx":7836
 *     class Latin1(unicode_set):
 *         "Unicode set for Latin-1 Unicode Character Range"
 *         _ranges = [(0x0020, 0x007e), (0x00a0, 0x00ff),]             # <<<<<<<<<<<<<<
 * 
 *     class LatinA(unicode_set):
 */
  __pyx_tuple__816 = PyTuple_Pack(2, __pyx_int_32, __pyx_int_126); if (unlikely(!__pyx_tuple__816)) __PYX_ERR(0, 7836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__816);
  __Pyx_GIVEREF(__pyx_tuple__816);
  __pyx_tuple__817 = PyTuple_Pack(2, __pyx_int_160, __pyx_int_255); if (unlikely(!__pyx_tuple__817)) __PYX_ERR(0, 7836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__817);
  __Pyx_GIVEREF(__pyx_tuple__817);

  /* "cPyparsing.pyx":7840
 *     class LatinA(unicode_set):
 *         "Unicode set for Latin-A Unicode Character Range"
 *         _ranges = [(0x0100, 0x017f),]             # <<<<<<<<<<<<<<
 * 
 *     class LatinB(unicode_set):
 */
  __pyx_tuple__818 = PyTuple_Pack(2, __pyx_int_256, __pyx_int_383); if (unlikely(!__pyx_tuple__818)) __PYX_ERR(0, 7840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__818);
  __Pyx_GIVEREF(__pyx_tuple__818);

  /* "cPyparsing.pyx":7844
 *     class LatinB(unicode_set):
 *         "Unicode set for Latin-B Unicode Character Range"
 *         _ranges = [(0x0180, 0x024f),]             # <<<<<<<<<<<<<<
 * 
 *     class Greek(unicode_set):
 */
  __pyx_tuple__819 = PyTuple_Pack(2, __pyx_int_384, __pyx_int_591); if (unlikely(!__pyx_tuple__819)) __PYX_ERR(0, 7844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__819);
  __Pyx_GIVEREF(__pyx_tuple__819);

  /* "cPyparsing.pyx":7849
 *         "Unicode set for Greek Unicode Character Ranges"
 *         _ranges = [
 *             (0x0370, 0x03ff), (0x1f00, 0x1f15), (0x1f18, 0x1f1d), (0x1f20, 0x1f45), (0x1f48, 0x1f4d),             # <<<<<<<<<<<<<<
 *             (0x1f50, 0x1f57), (0x1f59,), (0x1f5b,), (0x1f5d,), (0x1f5f, 0x1f7d), (0x1f80, 0x1fb4), (0x1fb6, 0x1fc4),
 *             (0x1fc6, 0x1fd3), (0x1fd6, 0x1fdb), (0x1fdd, 0x1fef), (0x1ff2, 0x1ff4), (0x1ff6, 0x1ffe),
 */
  __pyx_tuple__820 = PyTuple_Pack(2, __pyx_int_880, __pyx_int_1023); if (unlikely(!__pyx_tuple__820)) __PYX_ERR(0, 7849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__820);
  __Pyx_GIVEREF(__pyx_tuple__820);
  __pyx_tuple__821 = PyTuple_Pack(2, __pyx_int_7936, __pyx_int_7957); if (unlikely(!__pyx_tuple__821)) __PYX_ERR(0, 7849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__821);
  __Pyx_GIVEREF(__pyx_tuple__821);
  __pyx_tuple__822 = PyTuple_Pack(2, __pyx_int_7960, __pyx_int_7965); if (unlikely(!__pyx_tuple__822)) __PYX_ERR(0, 7849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__822);
  __Pyx_GIVEREF(__pyx_tuple__822);
  __pyx_tuple__823 = PyTuple_Pack(2, __pyx_int_7968, __pyx_int_8005); if (unlikely(!__pyx_tuple__823)) __PYX_ERR(0, 7849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__823);
  __Pyx_GIVEREF(__pyx_tuple__823);
  __pyx_tuple__824 = PyTuple_Pack(2, __pyx_int_8008, __pyx_int_8013); if (unlikely(!__pyx_tuple__824)) __PYX_ERR(0, 7849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__824);
  __Pyx_GIVEREF(__pyx_tuple__824);

  /* "cPyparsing.pyx":7850
 *         _ranges = [
 *             (0x0370, 0x03ff), (0x1f00, 0x1f15), (0x1f18, 0x1f1d), (0x1f20, 0x1f45), (0x1f48, 0x1f4d),
 *             (0x1f50, 0x1f57), (0x1f59,), (0x1f5b,), (0x1f5d,), (0x1f5f, 0x1f7d), (0x1f80, 0x1fb4), (0x1fb6, 0x1fc4),             # <<<<<<<<<<<<<<
 *             (0x1fc6, 0x1fd3), (0x1fd6, 0x1fdb), (0x1fdd, 0x1fef), (0x1ff2, 0x1ff4), (0x1ff6, 0x1ffe),
 *         ]
 */
  __pyx_tuple__825 = PyTuple_Pack(2, __pyx_int_8016, __pyx_int_8023); if (unlikely(!__pyx_tuple__825)) __PYX_ERR(0, 7850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__825);
  __Pyx_GIVEREF(__pyx_tuple__825);
  __pyx_tuple__826 = PyTuple_Pack(1, __pyx_int_8025); if (unlikely(!__pyx_tuple__826)) __PYX_ERR(0, 7850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__826);
  __Pyx_GIVEREF(__pyx_tuple__826);
  __pyx_tuple__827 = PyTuple_Pack(1, __pyx_int_8027); if (unlikely(!__pyx_tuple__827)) __PYX_ERR(0, 7850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__827);
  __Pyx_GIVEREF(__pyx_tuple__827);
  __pyx_tuple__828 = PyTuple_Pack(1, __pyx_int_8029); if (unlikely(!__pyx_tuple__828)) __PYX_ERR(0, 7850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__828);
  __Pyx_GIVEREF(__pyx_tuple__828);
  __pyx_tuple__829 = PyTuple_Pack(2, __pyx_int_8031, __pyx_int_8061); if (unlikely(!__pyx_tuple__829)) __PYX_ERR(0, 7850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__829);
  __Pyx_GIVEREF(__pyx_tuple__829);
  __pyx_tuple__830 = PyTuple_Pack(2, __pyx_int_8064, __pyx_int_8116); if (unlikely(!__pyx_tuple__830)) __PYX_ERR(0, 7850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__830);
  __Pyx_GIVEREF(__pyx_tuple__830);
  __pyx_tuple__831 = PyTuple_Pack(2, __pyx_int_8118, __pyx_int_8132); if (unlikely(!__pyx_tuple__831)) __PYX_ERR(0, 7850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__831);
  __Pyx_GIVEREF(__pyx_tuple__831);

  /* "cPyparsing.pyx":7851
 *             (0x0370, 0x03ff), (0x1f00, 0x1f15), (0x1f18, 0x1f1d), (0x1f20, 0x1f45), (0x1f48, 0x1f4d),
 *             (0x1f50, 0x1f57), (0x1f59,), (0x1f5b,), (0x1f5d,), (0x1f5f, 0x1f7d), (0x1f80, 0x1fb4), (0x1fb6, 0x1fc4),
 *             (0x1fc6, 0x1fd3), (0x1fd6, 0x1fdb), (0x1fdd, 0x1fef), (0x1ff2, 0x1ff4), (0x1ff6, 0x1ffe),             # <<<<<<<<<<<<<<
 *         ]
 * 
 */
  __pyx_tuple__832 = PyTuple_Pack(2, __pyx_int_8134, __pyx_int_8147); if (unlikely(!__pyx_tuple__832)) __PYX_ERR(0, 7851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__832);
  __Pyx_GIVEREF(__pyx_tuple__832);
  __pyx_tuple__833 = PyTuple_Pack(2, __pyx_int_8150, __pyx_int_8155); if (unlikely(!__pyx_tuple__833)) __PYX_ERR(0, 7851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__833);
  __Pyx_GIVEREF(__pyx_tuple__833);
  __pyx_tuple__834 = PyTuple_Pack(2, __pyx_int_8157, __pyx_int_8175); if (unlikely(!__pyx_tuple__834)) __PYX_ERR(0, 7851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__834);
  __Pyx_GIVEREF(__pyx_tuple__834);
  __pyx_tuple__835 = PyTuple_Pack(2, __pyx_int_8178, __pyx_int_8180); if (unlikely(!__pyx_tuple__835)) __PYX_ERR(0, 7851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__835);
  __Pyx_GIVEREF(__pyx_tuple__835);
  __pyx_tuple__836 = PyTuple_Pack(2, __pyx_int_8182, __pyx_int_8190); if (unlikely(!__pyx_tuple__836)) __PYX_ERR(0, 7851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__836);
  __Pyx_GIVEREF(__pyx_tuple__836);

  /* "cPyparsing.pyx":7856
 *     class Cyrillic(unicode_set):
 *         "Unicode set for Cyrillic Unicode Character Range"
 *         _ranges = [(0x0400, 0x04ff)]             # <<<<<<<<<<<<<<
 * 
 *     class Chinese(unicode_set):
 */
  __pyx_tuple__837 = PyTuple_Pack(2, __pyx_int_1024, __pyx_int_1279); if (unlikely(!__pyx_tuple__837)) __PYX_ERR(0, 7856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__837);
  __Pyx_GIVEREF(__pyx_tuple__837);

  /* "cPyparsing.pyx":7860
 *     class Chinese(unicode_set):
 *         "Unicode set for Chinese Unicode Character Range"
 *         _ranges = [(0x4e00, 0x9fff), (0x3000, 0x303f),]             # <<<<<<<<<<<<<<
 * 
 *     class Japanese(unicode_set):
 */
  __pyx_tuple__838 = PyTuple_Pack(2, __pyx_int_19968, __pyx_int_40959); if (unlikely(!__pyx_tuple__838)) __PYX_ERR(0, 7860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__838);
  __Pyx_GIVEREF(__pyx_tuple__838);
  __pyx_tuple__839 = PyTuple_Pack(2, __pyx_int_12288, __pyx_int_12351); if (unlikely(!__pyx_tuple__839)) __PYX_ERR(0, 7860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__839);
  __Pyx_GIVEREF(__pyx_tuple__839);

  /* "cPyparsing.pyx":7868
 *         class Kanji(unicode_set):
 *             "Unicode set for Kanji Unicode Character Range"
 *             _ranges = [(0x4E00, 0x9Fbf), (0x3000, 0x303f),]             # <<<<<<<<<<<<<<
 * 
 *         class Hiragana(unicode_set):
 */
  __pyx_tuple__840 = PyTuple_Pack(2, __pyx_int_19968, __pyx_int_40895); if (unlikely(!__pyx_tuple__840)) __PYX_ERR(0, 7868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__840);
  __Pyx_GIVEREF(__pyx_tuple__840);

  /* "cPyparsing.pyx":7872
 *         class Hiragana(unicode_set):
 *             "Unicode set for Hiragana Unicode Character Range"
 *             _ranges = [(0x3040, 0x309f),]             # <<<<<<<<<<<<<<
 * 
 *         class Katakana(unicode_set):
 */
  __pyx_tuple__841 = PyTuple_Pack(2, __pyx_int_12352, __pyx_int_12447); if (unlikely(!__pyx_tuple__841)) __PYX_ERR(0, 7872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__841);
  __Pyx_GIVEREF(__pyx_tuple__841);

  /* "cPyparsing.pyx":7876
 *         class Katakana(unicode_set):
 *             "Unicode set for Katakana  Unicode Character Range"
 *             _ranges = [(0x30a0, 0x30ff),]             # <<<<<<<<<<<<<<
 * 
 *     class Korean(unicode_set):
 */
  __pyx_tuple__842 = PyTuple_Pack(2, __pyx_int_12448, __pyx_int_12543); if (unlikely(!__pyx_tuple__842)) __PYX_ERR(0, 7876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__842);
  __Pyx_GIVEREF(__pyx_tuple__842);

  /* "cPyparsing.pyx":7880
 *     class Korean(unicode_set):
 *         "Unicode set for Korean Unicode Character Range"
 *         _ranges = [(0xac00, 0xd7af), (0x1100, 0x11ff), (0x3130, 0x318f), (0xa960, 0xa97f), (0xd7b0, 0xd7ff), (0x3000, 0x303f),]             # <<<<<<<<<<<<<<
 * 
 *     class CJK(Chinese, Japanese, Korean):
 */
  __pyx_tuple__843 = PyTuple_Pack(2, __pyx_int_44032, __pyx_int_55215); if (unlikely(!__pyx_tuple__843)) __PYX_ERR(0, 7880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__843);
  __Pyx_GIVEREF(__pyx_tuple__843);
  __pyx_tuple__844 = PyTuple_Pack(2, __pyx_int_4352, __pyx_int_4607); if (unlikely(!__pyx_tuple__844)) __PYX_ERR(0, 7880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__844);
  __Pyx_GIVEREF(__pyx_tuple__844);
  __pyx_tuple__845 = PyTuple_Pack(2, __pyx_int_12592, __pyx_int_12687); if (unlikely(!__pyx_tuple__845)) __PYX_ERR(0, 7880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__845);
  __Pyx_GIVEREF(__pyx_tuple__845);
  __pyx_tuple__846 = PyTuple_Pack(2, __pyx_int_43360, __pyx_int_43391); if (unlikely(!__pyx_tuple__846)) __PYX_ERR(0, 7880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__846);
  __Pyx_GIVEREF(__pyx_tuple__846);
  __pyx_tuple__847 = PyTuple_Pack(2, __pyx_int_55216, __pyx_int_55295); if (unlikely(!__pyx_tuple__847)) __PYX_ERR(0, 7880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__847);
  __Pyx_GIVEREF(__pyx_tuple__847);

  /* "cPyparsing.pyx":7888
 *     class Thai(unicode_set):
 *         "Unicode set for Thai Unicode Character Range"
 *         _ranges = [(0x0e01, 0x0e3a), (0x0e3f, 0x0e5b),]             # <<<<<<<<<<<<<<
 * 
 *     class Arabic(unicode_set):
 */
  __pyx_tuple__848 = PyTuple_Pack(2, __pyx_int_3585, __pyx_int_3642); if (unlikely(!__pyx_tuple__848)) __PYX_ERR(0, 7888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__848);
  __Pyx_GIVEREF(__pyx_tuple__848);
  __pyx_tuple__849 = PyTuple_Pack(2, __pyx_int_3647, __pyx_int_3675); if (unlikely(!__pyx_tuple__849)) __PYX_ERR(0, 7888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__849);
  __Pyx_GIVEREF(__pyx_tuple__849);

  /* "cPyparsing.pyx":7892
 *     class Arabic(unicode_set):
 *         "Unicode set for Arabic Unicode Character Range"
 *         _ranges = [(0x0600, 0x061b), (0x061e, 0x06ff), (0x0700, 0x077f),]             # <<<<<<<<<<<<<<
 * 
 *     class Hebrew(unicode_set):
 */
  __pyx_tuple__850 = PyTuple_Pack(2, __pyx_int_1536, __pyx_int_1563); if (unlikely(!__pyx_tuple__850)) __PYX_ERR(0, 7892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__850);
  __Pyx_GIVEREF(__pyx_tuple__850);
  __pyx_tuple__851 = PyTuple_Pack(2, __pyx_int_1566, __pyx_int_1791); if (unlikely(!__pyx_tuple__851)) __PYX_ERR(0, 7892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__851);
  __Pyx_GIVEREF(__pyx_tuple__851);
  __pyx_tuple__852 = PyTuple_Pack(2, __pyx_int_1792, __pyx_int_1919); if (unlikely(!__pyx_tuple__852)) __PYX_ERR(0, 7892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__852);
  __Pyx_GIVEREF(__pyx_tuple__852);

  /* "cPyparsing.pyx":7896
 *     class Hebrew(unicode_set):
 *         "Unicode set for Hebrew Unicode Character Range"
 *         _ranges = [(0x0590, 0x05ff),]             # <<<<<<<<<<<<<<
 * 
 *     class Devanagari(unicode_set):
 */
  __pyx_tuple__853 = PyTuple_Pack(2, __pyx_int_1424, __pyx_int_1535); if (unlikely(!__pyx_tuple__853)) __PYX_ERR(0, 7896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__853);
  __Pyx_GIVEREF(__pyx_tuple__853);

  /* "cPyparsing.pyx":7900
 *     class Devanagari(unicode_set):
 *         "Unicode set for Devanagari Unicode Character Range"
 *         _ranges = [(0x0900, 0x097f), (0xa8e0, 0xa8ff)]             # <<<<<<<<<<<<<<
 * 
 * pyparsing_unicode.Japanese._ranges = (pyparsing_unicode.Japanese.Kanji._ranges
 */
  __pyx_tuple__854 = PyTuple_Pack(2, __pyx_int_2304, __pyx_int_2431); if (unlikely(!__pyx_tuple__854)) __PYX_ERR(0, 7900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__854);
  __Pyx_GIVEREF(__pyx_tuple__854);
  __pyx_tuple__855 = PyTuple_Pack(2, __pyx_int_43232, __pyx_int_43263); if (unlikely(!__pyx_tuple__855)) __PYX_ERR(0, 7900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__855);
  __Pyx_GIVEREF(__pyx_tuple__855);

  /* "cPyparsing.pyx":7950
 *         """
 * 
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             self._save_context = {}
 * 
 */
  __pyx_codeobj__868 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_init, 7950, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__868)) __PYX_ERR(0, 7950, __pyx_L1_error)

  /* "cPyparsing.pyx":7953
 *             self._save_context = {}
 * 
 *         def save(self):             # <<<<<<<<<<<<<<
 *             self._save_context["default_whitespace"] = ParserElement.DEFAULT_WHITE_CHARS
 *             self._save_context["default_keyword_chars"] = Keyword.DEFAULT_KEYWORD_CHARS
 */
  __pyx_codeobj__869 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__252, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_save, 7953, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__869)) __PYX_ERR(0, 7953, __pyx_L1_error)

  /* "cPyparsing.pyx":7969
 *             return self
 * 
 *         def restore(self):             # <<<<<<<<<<<<<<
 *             # reset pyparsing global state
 *             if (
 */
  __pyx_tuple__870 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_name_2, __pyx_n_s_value); if (unlikely(!__pyx_tuple__870)) __PYX_ERR(0, 7969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__870);
  __Pyx_GIVEREF(__pyx_tuple__870);
  __pyx_codeobj__871 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__870, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_restore, 7969, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__871)) __PYX_ERR(0, 7969, __pyx_L1_error)

  /* "cPyparsing.pyx":7988
 *             __compat__.collect_all_And_tokens = self._save_context["__compat__"]
 * 
 *         def __enter__(self):             # <<<<<<<<<<<<<<
 *             return self.save()
 * 
 */
  __pyx_codeobj__872 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_enter, 7988, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__872)) __PYX_ERR(0, 7988, __pyx_L1_error)

  /* "cPyparsing.pyx":7991
 *             return self.save()
 * 
 *         def __exit__(self, *args):             # <<<<<<<<<<<<<<
 *             return self.restore()
 * 
 */
  __pyx_codeobj__873 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__451, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_exit, 7991, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__873)) __PYX_ERR(0, 7991, __pyx_L1_error)

  /* "cPyparsing.pyx":7998
 *         A mixin class to add parse results assertion methods to normal unittest.TestCase classes.
 *         """
 *         def assertParseResultsEquals(             # <<<<<<<<<<<<<<
 *             self, result, expected_list=None, expected_dict=None, msg=None
 *         ):
 */
  __pyx_tuple__874 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_result, __pyx_n_s_expected_list, __pyx_n_s_expected_dict, __pyx_n_s_msg); if (unlikely(!__pyx_tuple__874)) __PYX_ERR(0, 7998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__874);
  __Pyx_GIVEREF(__pyx_tuple__874);
  __pyx_codeobj__875 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__874, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_assertParseResultsEquals, 7998, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__875)) __PYX_ERR(0, 7998, __pyx_L1_error)

  /* "cPyparsing.pyx":8010
 *                 self.assertEqual(expected_dict, result.asDict(), msg=msg)
 * 
 *         def assertParseAndCheckList(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_list, msg=None, verbose=True
 *         ):
 */
  __pyx_tuple__876 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_test_string, __pyx_n_s_expected_list, __pyx_n_s_msg, __pyx_n_s_verbose, __pyx_n_s_result); if (unlikely(!__pyx_tuple__876)) __PYX_ERR(0, 8010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__876);
  __Pyx_GIVEREF(__pyx_tuple__876);
  __pyx_codeobj__877 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__876, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_assertParseAndCheckList, 8010, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__877)) __PYX_ERR(0, 8010, __pyx_L1_error)
  __pyx_tuple__878 = PyTuple_Pack(2, Py_None, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__878)) __PYX_ERR(0, 8010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__878);
  __Pyx_GIVEREF(__pyx_tuple__878);

  /* "cPyparsing.pyx":8022
 *             self.assertParseResultsEquals(result, expected_list=expected_list, msg=msg)
 * 
 *         def assertParseAndCheckDict(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_dict, msg=None, verbose=True
 *         ):
 */
  __pyx_tuple__879 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_test_string, __pyx_n_s_expected_dict, __pyx_n_s_msg, __pyx_n_s_verbose, __pyx_n_s_result); if (unlikely(!__pyx_tuple__879)) __PYX_ERR(0, 8022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__879);
  __Pyx_GIVEREF(__pyx_tuple__879);
  __pyx_codeobj__880 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__879, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_assertParseAndCheckDict, 8022, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__880)) __PYX_ERR(0, 8022, __pyx_L1_error)

  /* "cPyparsing.pyx":8034
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)
 * 
 *         def assertRunTestResults(             # <<<<<<<<<<<<<<
 *             self, run_tests_report, expected_parse_results=None, msg=None
 *         ):
 */
  __pyx_tuple__881 = PyTuple_Pack(21, __pyx_n_s_self, __pyx_n_s_run_tests_report, __pyx_n_s_expected_parse_results, __pyx_n_s_msg, __pyx_n_s_run_test_success, __pyx_n_s_run_test_results, __pyx_n_s_merged, __pyx_n_s_test_string, __pyx_n_s_result, __pyx_n_s_expected, __pyx_n_s_fail_msg, __pyx_n_s_expected_exception, __pyx_n_s_expected_list, __pyx_n_s_expected_dict, __pyx_n_s_rpt, __pyx_n_s_expected, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__881)) __PYX_ERR(0, 8034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__881);
  __Pyx_GIVEREF(__pyx_tuple__881);
  __pyx_codeobj__882 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 21, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__881, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_assertRunTestResults, 8034, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__882)) __PYX_ERR(0, 8034, __pyx_L1_error)

  /* "cPyparsing.pyx":8097
 *             )
 * 
 *         @contextmanager             # <<<<<<<<<<<<<<
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):
 */
  __pyx_tuple__883 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_exc_type, __pyx_n_s_msg); if (unlikely(!__pyx_tuple__883)) __PYX_ERR(0, 8097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__883);
  __Pyx_GIVEREF(__pyx_tuple__883);
  __pyx_codeobj__170 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__883, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cPyparsing_pyx, __pyx_n_s_assertRaisesParseException, 8097, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__170)) __PYX_ERR(0, 8097, __pyx_L1_error)

  /* "cPyparsing.pyx":8105
 * if __name__ == "__main__":
 * 
 *     selectToken    = CaselessLiteral("select")             # <<<<<<<<<<<<<<
 *     fromToken      = CaselessLiteral("from")
 * 
 */
  __pyx_tuple__884 = PyTuple_Pack(1, __pyx_n_u_select); if (unlikely(!__pyx_tuple__884)) __PYX_ERR(0, 8105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__884);
  __Pyx_GIVEREF(__pyx_tuple__884);

  /* "cPyparsing.pyx":8106
 * 
 *     selectToken    = CaselessLiteral("select")
 *     fromToken      = CaselessLiteral("from")             # <<<<<<<<<<<<<<
 * 
 *     ident          = Word(alphas, alphanums + "_$")
 */
  __pyx_tuple__885 = PyTuple_Pack(1, __pyx_n_u_from_2); if (unlikely(!__pyx_tuple__885)) __PYX_ERR(0, 8106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__885);
  __Pyx_GIVEREF(__pyx_tuple__885);

  /* "cPyparsing.pyx":8111
 * 
 *     columnName     = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     columnNameList = Group(delimitedList(columnName)).setName("columns")             # <<<<<<<<<<<<<<
 *     columnSpec     = ('*' | columnNameList)
 * 
 */
  __pyx_tuple__886 = PyTuple_Pack(1, __pyx_n_u_columns); if (unlikely(!__pyx_tuple__886)) __PYX_ERR(0, 8111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__886);
  __Pyx_GIVEREF(__pyx_tuple__886);

  /* "cPyparsing.pyx":8115
 * 
 *     tableName      = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     tableNameList  = Group(delimitedList(tableName)).setName("tables")             # <<<<<<<<<<<<<<
 * 
 *     simpleSQL      = selectToken("command") + columnSpec("columns") + fromToken + tableNameList("tables")
 */
  __pyx_tuple__887 = PyTuple_Pack(1, __pyx_n_u_tables); if (unlikely(!__pyx_tuple__887)) __PYX_ERR(0, 8115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__887);
  __Pyx_GIVEREF(__pyx_tuple__887);

  /* "cPyparsing.pyx":8117
 *     tableNameList  = Group(delimitedList(tableName)).setName("tables")
 * 
 *     simpleSQL      = selectToken("command") + columnSpec("columns") + fromToken + tableNameList("tables")             # <<<<<<<<<<<<<<
 * 
 *     # demo runTests method, including embedded comments in test string
 */
  __pyx_tuple__888 = PyTuple_Pack(1, __pyx_n_u_command); if (unlikely(!__pyx_tuple__888)) __PYX_ERR(0, 8117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__888);
  __Pyx_GIVEREF(__pyx_tuple__888);

  /* "cPyparsing.pyx":8120
 * 
 *     # demo runTests method, including embedded comments in test string
 *     simpleSQL.runTests("""             # <<<<<<<<<<<<<<
 *         # '*' as column list and dotted table name
 *         select * from SYS.XYZZY
 */
  __pyx_tuple__889 = PyTuple_Pack(1, __pyx_kp_u_as_column_list_and_dotted_table); if (unlikely(!__pyx_tuple__889)) __PYX_ERR(0, 8120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__889);
  __Pyx_GIVEREF(__pyx_tuple__889);

  /* "cPyparsing.pyx":8144
 *         """)
 * 
 *     pyparsing_common.number.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         -100
 */
  __pyx_tuple__890 = PyTuple_Pack(1, __pyx_kp_u_100_100_100_3_14159_6_02e23_1e); if (unlikely(!__pyx_tuple__890)) __PYX_ERR(0, 8144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__890);
  __Pyx_GIVEREF(__pyx_tuple__890);

  /* "cPyparsing.pyx":8163
 *         """)
 * 
 *     pyparsing_common.hex_integer.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         FF
 */
  __pyx_tuple__891 = PyTuple_Pack(1, __pyx_kp_u_100_FF); if (unlikely(!__pyx_tuple__891)) __PYX_ERR(0, 8163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__891);
  __Pyx_GIVEREF(__pyx_tuple__891);

  /* "cPyparsing.pyx":8170
 *     import uuid
 *     pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))
 *     pyparsing_common.uuid.runTests("""             # <<<<<<<<<<<<<<
 *         12345678-1234-5678-1234-567812345678
 *         """)
 */
  __pyx_tuple__892 = PyTuple_Pack(1, __pyx_kp_u_12345678_1234_5678_1234_5678123); if (unlikely(!__pyx_tuple__892)) __PYX_ERR(0, 8170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__892);
  __Pyx_GIVEREF(__pyx_tuple__892);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  __pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_get.method_name = &__pyx_n_s_get;
  __pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_items.method_name = &__pyx_n_s_items;
  __pyx_umethod_PyList_Type_pop.type = (PyObject*)&PyList_Type;
  __pyx_umethod_PyList_Type_pop.method_name = &__pyx_n_s_pop;
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_11 = PyInt_FromLong(11); if (unlikely(!__pyx_int_11)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_16 = PyInt_FromLong(16); if (unlikely(!__pyx_int_16)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_32 = PyInt_FromLong(32); if (unlikely(!__pyx_int_32)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_92 = PyInt_FromLong(92); if (unlikely(!__pyx_int_92)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_126 = PyInt_FromLong(126); if (unlikely(!__pyx_int_126)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_160 = PyInt_FromLong(160); if (unlikely(!__pyx_int_160)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_255 = PyInt_FromLong(255); if (unlikely(!__pyx_int_255)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_256 = PyInt_FromLong(256); if (unlikely(!__pyx_int_256)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_383 = PyInt_FromLong(383); if (unlikely(!__pyx_int_383)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_384 = PyInt_FromLong(384); if (unlikely(!__pyx_int_384)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_591 = PyInt_FromLong(591); if (unlikely(!__pyx_int_591)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_880 = PyInt_FromLong(880); if (unlikely(!__pyx_int_880)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1023 = PyInt_FromLong(1023); if (unlikely(!__pyx_int_1023)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1024 = PyInt_FromLong(1024); if (unlikely(!__pyx_int_1024)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1279 = PyInt_FromLong(1279); if (unlikely(!__pyx_int_1279)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1328 = PyInt_FromLong(1328); if (unlikely(!__pyx_int_1328)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1424 = PyInt_FromLong(1424); if (unlikely(!__pyx_int_1424)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1535 = PyInt_FromLong(1535); if (unlikely(!__pyx_int_1535)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1536 = PyInt_FromLong(1536); if (unlikely(!__pyx_int_1536)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1563 = PyInt_FromLong(1563); if (unlikely(!__pyx_int_1563)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1566 = PyInt_FromLong(1566); if (unlikely(!__pyx_int_1566)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1791 = PyInt_FromLong(1791); if (unlikely(!__pyx_int_1791)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1792 = PyInt_FromLong(1792); if (unlikely(!__pyx_int_1792)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1919 = PyInt_FromLong(1919); if (unlikely(!__pyx_int_1919)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2304 = PyInt_FromLong(2304); if (unlikely(!__pyx_int_2304)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2431 = PyInt_FromLong(2431); if (unlikely(!__pyx_int_2431)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3585 = PyInt_FromLong(3585); if (unlikely(!__pyx_int_3585)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3642 = PyInt_FromLong(3642); if (unlikely(!__pyx_int_3642)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3647 = PyInt_FromLong(3647); if (unlikely(!__pyx_int_3647)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3675 = PyInt_FromLong(3675); if (unlikely(!__pyx_int_3675)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4352 = PyInt_FromLong(4352); if (unlikely(!__pyx_int_4352)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4607 = PyInt_FromLong(4607); if (unlikely(!__pyx_int_4607)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7936 = PyInt_FromLong(7936); if (unlikely(!__pyx_int_7936)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7957 = PyInt_FromLong(7957); if (unlikely(!__pyx_int_7957)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7960 = PyInt_FromLong(7960); if (unlikely(!__pyx_int_7960)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7965 = PyInt_FromLong(7965); if (unlikely(!__pyx_int_7965)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7968 = PyInt_FromLong(7968); if (unlikely(!__pyx_int_7968)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8005 = PyInt_FromLong(8005); if (unlikely(!__pyx_int_8005)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8008 = PyInt_FromLong(8008); if (unlikely(!__pyx_int_8008)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8013 = PyInt_FromLong(8013); if (unlikely(!__pyx_int_8013)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8016 = PyInt_FromLong(8016); if (unlikely(!__pyx_int_8016)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8023 = PyInt_FromLong(8023); if (unlikely(!__pyx_int_8023)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8025 = PyInt_FromLong(8025); if (unlikely(!__pyx_int_8025)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8027 = PyInt_FromLong(8027); if (unlikely(!__pyx_int_8027)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8029 = PyInt_FromLong(8029); if (unlikely(!__pyx_int_8029)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8031 = PyInt_FromLong(8031); if (unlikely(!__pyx_int_8031)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8061 = PyInt_FromLong(8061); if (unlikely(!__pyx_int_8061)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8064 = PyInt_FromLong(8064); if (unlikely(!__pyx_int_8064)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8116 = PyInt_FromLong(8116); if (unlikely(!__pyx_int_8116)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8118 = PyInt_FromLong(8118); if (unlikely(!__pyx_int_8118)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8132 = PyInt_FromLong(8132); if (unlikely(!__pyx_int_8132)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8134 = PyInt_FromLong(8134); if (unlikely(!__pyx_int_8134)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8147 = PyInt_FromLong(8147); if (unlikely(!__pyx_int_8147)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8150 = PyInt_FromLong(8150); if (unlikely(!__pyx_int_8150)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8155 = PyInt_FromLong(8155); if (unlikely(!__pyx_int_8155)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8157 = PyInt_FromLong(8157); if (unlikely(!__pyx_int_8157)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8175 = PyInt_FromLong(8175); if (unlikely(!__pyx_int_8175)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8178 = PyInt_FromLong(8178); if (unlikely(!__pyx_int_8178)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8180 = PyInt_FromLong(8180); if (unlikely(!__pyx_int_8180)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8182 = PyInt_FromLong(8182); if (unlikely(!__pyx_int_8182)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8190 = PyInt_FromLong(8190); if (unlikely(!__pyx_int_8190)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12288 = PyInt_FromLong(12288L); if (unlikely(!__pyx_int_12288)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12351 = PyInt_FromLong(12351L); if (unlikely(!__pyx_int_12351)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12352 = PyInt_FromLong(12352L); if (unlikely(!__pyx_int_12352)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12447 = PyInt_FromLong(12447L); if (unlikely(!__pyx_int_12447)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12448 = PyInt_FromLong(12448L); if (unlikely(!__pyx_int_12448)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12543 = PyInt_FromLong(12543L); if (unlikely(!__pyx_int_12543)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12592 = PyInt_FromLong(12592L); if (unlikely(!__pyx_int_12592)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12687 = PyInt_FromLong(12687L); if (unlikely(!__pyx_int_12687)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_19968 = PyInt_FromLong(19968L); if (unlikely(!__pyx_int_19968)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_40895 = PyInt_FromLong(40895L); if (unlikely(!__pyx_int_40895)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_40959 = PyInt_FromLong(40959L); if (unlikely(!__pyx_int_40959)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_43232 = PyInt_FromLong(43232L); if (unlikely(!__pyx_int_43232)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_43263 = PyInt_FromLong(43263L); if (unlikely(!__pyx_int_43263)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_43360 = PyInt_FromLong(43360L); if (unlikely(!__pyx_int_43360)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_43391 = PyInt_FromLong(43391L); if (unlikely(!__pyx_int_43391)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_44032 = PyInt_FromLong(44032L); if (unlikely(!__pyx_int_44032)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_55215 = PyInt_FromLong(55215L); if (unlikely(!__pyx_int_55215)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_55216 = PyInt_FromLong(55216L); if (unlikely(!__pyx_int_55216)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_55295 = PyInt_FromLong(55295L); if (unlikely(!__pyx_int_55295)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  /* Common.init */
  if (likely(__Pyx_check_twos_complement() == 0)); else

if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* SizeCheck.init */
  if (likely(__Pyx_check_sane_Py_ssize_t() == 0)); else

if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_7genexpr__pyx_v_10cPyparsing_nm = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct__genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr)) __PYX_ERR(0, 230, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct__genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct__genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr)) __PYX_ERR(0, 232, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr) < 0) __PYX_ERR(0, 232, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr) < 0) __PYX_ERR(0, 232, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr)) __PYX_ERR(0, 239, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr) < 0) __PYX_ERR(0, 239, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr) < 0) __PYX_ERR(0, 239, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr)) __PYX_ERR(0, 249, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr) < 0) __PYX_ERR(0, 249, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_3_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr) < 0) __PYX_ERR(0, 249, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_3_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction)) __PYX_ERR(0, 252, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction) < 0) __PYX_ERR(0, 252, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction = &__pyx_type_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction) < 0) __PYX_ERR(0, 252, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_4_conditionAsParseAction->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues)) __PYX_ERR(0, 669, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues) < 0) __PYX_ERR(0, 669, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues = &__pyx_type_10cPyparsing___pyx_scope_struct_5__itervalues;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues) < 0) __PYX_ERR(0, 669, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_5__itervalues->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr)) __PYX_ERR(0, 670, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr) < 0) __PYX_ERR(0, 670, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr) < 0) __PYX_ERR(0, 670, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems)) __PYX_ERR(0, 672, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems) < 0) __PYX_ERR(0, 672, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems = &__pyx_type_10cPyparsing___pyx_scope_struct_7__iteritems;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems) < 0) __PYX_ERR(0, 672, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_7__iteritems->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr)) __PYX_ERR(0, 673, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr) < 0) __PYX_ERR(0, 673, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_8_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr) < 0) __PYX_ERR(0, 673, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_8_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_9___iadd___spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__)) __PYX_ERR(0, 863, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_9___iadd___spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__) < 0) __PYX_ERR(0, 863, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__ = &__pyx_type_10cPyparsing___pyx_scope_struct_9___iadd__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__) < 0) __PYX_ERR(0, 863, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_9___iadd__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr)) __PYX_ERR(0, 891, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr) < 0) __PYX_ERR(0, 891, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_10_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr) < 0) __PYX_ERR(0, 891, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_10_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_11_asDict_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict)) __PYX_ERR(0, 921, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_11_asDict_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict) < 0) __PYX_ERR(0, 921, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict = &__pyx_type_10cPyparsing___pyx_scope_struct_11_asDict;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict) < 0) __PYX_ERR(0, 921, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_11_asDict->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr)) __PYX_ERR(0, 955, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr) < 0) __PYX_ERR(0, 955, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_12_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr) < 0) __PYX_ERR(0, 955, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_12_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr)) __PYX_ERR(0, 975, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr) < 0) __PYX_ERR(0, 975, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr) < 0) __PYX_ERR(0, 975, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr)) __PYX_ERR(0, 1107, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr) < 0) __PYX_ERR(0, 1107, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_14_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr) < 0) __PYX_ERR(0, 1107, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_14_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr)) __PYX_ERR(0, 1119, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr) < 0) __PYX_ERR(0, 1119, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr) < 0) __PYX_ERR(0, 1119, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity)) __PYX_ERR(0, 1296, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity) < 0) __PYX_ERR(0, 1296, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity = &__pyx_type_10cPyparsing___pyx_scope_struct_16__trim_arity;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity) < 0) __PYX_ERR(0, 1296, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_16__trim_arity->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak)) __PYX_ERR(0, 1635, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak) < 0) __PYX_ERR(0, 1635, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak = &__pyx_type_10cPyparsing___pyx_scope_struct_17_setBreak;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak) < 0) __PYX_ERR(0, 1635, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_17_setBreak->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr)) __PYX_ERR(0, 1697, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr) < 0) __PYX_ERR(0, 1697, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_18_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr) < 0) __PYX_ERR(0, 1697, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_18_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_19_scanString_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString)) __PYX_ERR(0, 2532, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_19_scanString_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString) < 0) __PYX_ERR(0, 2532, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString = &__pyx_type_10cPyparsing___pyx_scope_struct_19_scanString;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString) < 0) __PYX_ERR(0, 2532, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_19_scanString->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_20_split = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_20_split_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_20_split)) __PYX_ERR(0, 2686, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_20_split_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_20_split) < 0) __PYX_ERR(0, 2686, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_20_split = &__pyx_type_10cPyparsing___pyx_scope_struct_20_split;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_20_split) < 0) __PYX_ERR(0, 2686, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_20_split->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_20_split->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_20_split->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_20_split->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_21___mul___spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__)) __PYX_ERR(0, 2788, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_21___mul___spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__) < 0) __PYX_ERR(0, 2788, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__ = &__pyx_type_10cPyparsing___pyx_scope_struct_21___mul__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__) < 0) __PYX_ERR(0, 2788, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_21___mul__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr)) __PYX_ERR(0, 2816, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr) < 0) __PYX_ERR(0, 2816, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_22_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr) < 0) __PYX_ERR(0, 2816, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_22_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_23___add___spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__)) __PYX_ERR(0, 3374, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_23___add___spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__) < 0) __PYX_ERR(0, 3374, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__ = &__pyx_type_10cPyparsing___pyx_scope_struct_23___add__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__) < 0) __PYX_ERR(0, 3374, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_23___add__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_24___init___spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__)) __PYX_ERR(0, 3763, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_24___init___spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__) < 0) __PYX_ERR(0, 3763, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_24___init__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__) < 0) __PYX_ERR(0, 3763, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_24___init__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr)) __PYX_ERR(0, 3767, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr) < 0) __PYX_ERR(0, 3767, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_25_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr) < 0) __PYX_ERR(0, 3767, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_25_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr)) __PYX_ERR(0, 3769, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr) < 0) __PYX_ERR(0, 3769, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_26_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr) < 0) __PYX_ERR(0, 3769, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_26_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_27_sub_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub)) __PYX_ERR(0, 4108, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_27_sub_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub) < 0) __PYX_ERR(0, 4108, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub = &__pyx_type_10cPyparsing___pyx_scope_struct_27_sub;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub) < 0) __PYX_ERR(0, 4108, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_27_sub->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_28___init___spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__)) __PYX_ERR(0, 4176, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_28___init___spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__) < 0) __PYX_ERR(0, 4176, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_28___init__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__) < 0) __PYX_ERR(0, 4176, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_28___init__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr)) __PYX_ERR(0, 4216, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr) < 0) __PYX_ERR(0, 4216, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_29_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr) < 0) __PYX_ERR(0, 4216, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_29_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_30___init___spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__)) __PYX_ERR(0, 4458, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_30___init___spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__) < 0) __PYX_ERR(0, 4458, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_30___init__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__) < 0) __PYX_ERR(0, 4458, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_30___init__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr)) __PYX_ERR(0, 4461, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr) < 0) __PYX_ERR(0, 4461, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_31_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr) < 0) __PYX_ERR(0, 4461, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_31_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr)) __PYX_ERR(0, 4463, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr) < 0) __PYX_ERR(0, 4463, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr) < 0) __PYX_ERR(0, 4463, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_33___init___spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__)) __PYX_ERR(0, 4693, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_33___init___spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__) < 0) __PYX_ERR(0, 4693, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_33___init__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__) < 0) __PYX_ERR(0, 4693, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_33___init__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr)) __PYX_ERR(0, 4705, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr) < 0) __PYX_ERR(0, 4705, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_34_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr) < 0) __PYX_ERR(0, 4705, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_34_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr)) __PYX_ERR(0, 4888, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr) < 0) __PYX_ERR(0, 4888, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr) < 0) __PYX_ERR(0, 4888, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr)) __PYX_ERR(0, 4896, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr) < 0) __PYX_ERR(0, 4896, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_36_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr) < 0) __PYX_ERR(0, 4896, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_36_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr)) __PYX_ERR(0, 4908, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr) < 0) __PYX_ERR(0, 4908, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr) < 0) __PYX_ERR(0, 4908, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr)) __PYX_ERR(0, 4986, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr) < 0) __PYX_ERR(0, 4986, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_38_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr) < 0) __PYX_ERR(0, 4986, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_38_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr)) __PYX_ERR(0, 5011, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr) < 0) __PYX_ERR(0, 5011, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr) < 0) __PYX_ERR(0, 5011, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr)) __PYX_ERR(0, 5018, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr) < 0) __PYX_ERR(0, 5018, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_40_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr) < 0) __PYX_ERR(0, 5018, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_40_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr)) __PYX_ERR(0, 5092, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr) < 0) __PYX_ERR(0, 5092, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr) < 0) __PYX_ERR(0, 5092, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr)) __PYX_ERR(0, 5104, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr) < 0) __PYX_ERR(0, 5104, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_42_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr) < 0) __PYX_ERR(0, 5104, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_42_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr)) __PYX_ERR(0, 5134, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr) < 0) __PYX_ERR(0, 5134, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr) < 0) __PYX_ERR(0, 5134, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr)) __PYX_ERR(0, 5141, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr) < 0) __PYX_ERR(0, 5141, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_44_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr) < 0) __PYX_ERR(0, 5141, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_44_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr)) __PYX_ERR(0, 5235, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr) < 0) __PYX_ERR(0, 5235, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr) < 0) __PYX_ERR(0, 5235, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr)) __PYX_ERR(0, 5247, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr) < 0) __PYX_ERR(0, 5247, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_46_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr) < 0) __PYX_ERR(0, 5247, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_46_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr)) __PYX_ERR(0, 5318, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr) < 0) __PYX_ERR(0, 5318, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr) < 0) __PYX_ERR(0, 5318, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr)) __PYX_ERR(0, 5325, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr) < 0) __PYX_ERR(0, 5325, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_48_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr) < 0) __PYX_ERR(0, 5325, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_48_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr)) __PYX_ERR(0, 5330, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr) < 0) __PYX_ERR(0, 5330, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr) < 0) __PYX_ERR(0, 5330, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr)) __PYX_ERR(0, 5363, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr) < 0) __PYX_ERR(0, 5363, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_50_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr) < 0) __PYX_ERR(0, 5363, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_50_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr)) __PYX_ERR(0, 5382, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr) < 0) __PYX_ERR(0, 5382, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr) < 0) __PYX_ERR(0, 5382, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction)) __PYX_ERR(0, 6340, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction) < 0) __PYX_ERR(0, 6340, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction = &__pyx_type_10cPyparsing___pyx_scope_struct_52_traceParseAction;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction) < 0) __PYX_ERR(0, 6340, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_52_traceParseAction->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray)) __PYX_ERR(0, 6409, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray) < 0) __PYX_ERR(0, 6409, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray = &__pyx_type_10cPyparsing___pyx_scope_struct_53_countedArray;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray) < 0) __PYX_ERR(0, 6409, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_53_countedArray->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral)) __PYX_ERR(0, 6454, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral) < 0) __PYX_ERR(0, 6454, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral = &__pyx_type_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral) < 0) __PYX_ERR(0, 6454, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_54_matchPreviousLiteral->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr)) __PYX_ERR(0, 6477, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr) < 0) __PYX_ERR(0, 6477, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_55_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr) < 0) __PYX_ERR(0, 6477, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_55_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr)) __PYX_ERR(0, 6484, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr) < 0) __PYX_ERR(0, 6484, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr = &__pyx_type_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr) < 0) __PYX_ERR(0, 6484, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_56_matchPreviousExpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater)) __PYX_ERR(0, 6502, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater) < 0) __PYX_ERR(0, 6502, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater = &__pyx_type_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater) < 0) __PYX_ERR(0, 6502, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_57_copyTokenToRepeater->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf)) __PYX_ERR(0, 6521, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf) < 0) __PYX_ERR(0, 6521, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf = &__pyx_type_10cPyparsing___pyx_scope_struct_58_oneOf;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf) < 0) __PYX_ERR(0, 6521, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_58_oneOf->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr)) __PYX_ERR(0, 6598, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr) < 0) __PYX_ERR(0, 6598, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr) < 0) __PYX_ERR(0, 6598, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr)) __PYX_ERR(0, 6600, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr) < 0) __PYX_ERR(0, 6600, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_60_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr) < 0) __PYX_ERR(0, 6600, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_60_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr)) __PYX_ERR(0, 6606, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr) < 0) __PYX_ERR(0, 6606, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_61_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr) < 0) __PYX_ERR(0, 6606, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_61_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_62_srange_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange)) __PYX_ERR(0, 6738, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_62_srange_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange) < 0) __PYX_ERR(0, 6738, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange = &__pyx_type_10cPyparsing___pyx_scope_struct_62_srange;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange) < 0) __PYX_ERR(0, 6738, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_62_srange->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr)) __PYX_ERR(0, 6764, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr) < 0) __PYX_ERR(0, 6764, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr) < 0) __PYX_ERR(0, 6764, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr)) __PYX_ERR(0, 6766, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr) < 0) __PYX_ERR(0, 6766, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr) < 0) __PYX_ERR(0, 6766, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol)) __PYX_ERR(0, 6770, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol) < 0) __PYX_ERR(0, 6770, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol = &__pyx_type_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol) < 0) __PYX_ERR(0, 6770, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_65_matchOnlyAtCol->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith)) __PYX_ERR(0, 6779, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith) < 0) __PYX_ERR(0, 6779, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith = &__pyx_type_10cPyparsing___pyx_scope_struct_66_replaceWith;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith) < 0) __PYX_ERR(0, 6779, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_66_replaceWith->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap)) __PYX_ERR(0, 6809, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap) < 0) __PYX_ERR(0, 6809, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap = &__pyx_type_10cPyparsing___pyx_scope_struct_67_tokenMap;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap) < 0) __PYX_ERR(0, 6809, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_67_tokenMap->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags)) __PYX_ERR(0, 6865, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags) < 0) __PYX_ERR(0, 6865, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags = &__pyx_type_10cPyparsing___pyx_scope_struct_68__makeTags;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags) < 0) __PYX_ERR(0, 6865, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_68__makeTags->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_69___call___spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__)) __PYX_ERR(0, 6938, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_69___call___spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__) < 0) __PYX_ERR(0, 6938, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__ = &__pyx_type_10cPyparsing___pyx_scope_struct_69___call__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__) < 0) __PYX_ERR(0, 6938, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_69___call__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock)) __PYX_ERR(0, 7296, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock) < 0) __PYX_ERR(0, 7296, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock = &__pyx_type_10cPyparsing___pyx_scope_struct_70_indentedBlock;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock) < 0) __PYX_ERR(0, 7296, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_70_indentedBlock->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr)) __PYX_ERR(0, 7661, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr) < 0) __PYX_ERR(0, 7661, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_71_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr) < 0) __PYX_ERR(0, 7661, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_71_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate)) __PYX_ERR(0, 7669, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate) < 0) __PYX_ERR(0, 7669, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate = &__pyx_type_10cPyparsing___pyx_scope_struct_72_convertToDate;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate) < 0) __PYX_ERR(0, 7669, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_72_convertToDate->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime)) __PYX_ERR(0, 7694, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime) < 0) __PYX_ERR(0, 7694, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime = &__pyx_type_10cPyparsing___pyx_scope_struct_73_convertToDatetime;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime) < 0) __PYX_ERR(0, 7694, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_73_convertToDatetime->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_74___get___spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__)) __PYX_ERR(0, 7769, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_74___get___spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__) < 0) __PYX_ERR(0, 7769, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__ = &__pyx_type_10cPyparsing___pyx_scope_struct_74___get__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__) < 0) __PYX_ERR(0, 7769, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_74___get__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr)) __PYX_ERR(0, 7772, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr) < 0) __PYX_ERR(0, 7772, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_75_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr) < 0) __PYX_ERR(0, 7772, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_75_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr)) __PYX_ERR(0, 8058, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr) < 0) __PYX_ERR(0, 8058, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_76_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr) < 0) __PYX_ERR(0, 8058, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_76_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr)) __PYX_ERR(0, 8062, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr) < 0) __PYX_ERR(0, 8062, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr) < 0) __PYX_ERR(0, 8062, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr)) __PYX_ERR(0, 8076, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr) < 0) __PYX_ERR(0, 8076, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_78_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr) < 0) __PYX_ERR(0, 8076, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_78_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr)) __PYX_ERR(0, 8079, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr) < 0) __PYX_ERR(0, 8079, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_79_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr) < 0) __PYX_ERR(0, 8079, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_79_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException_spec, NULL); if (unlikely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException)) __PYX_ERR(0, 8097, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException_spec, __pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException) < 0) __PYX_ERR(0, 8097, __pyx_L1_error)
  #else
  __pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException = &__pyx_type_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException) < 0) __PYX_ERR(0, 8097, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException->tp_dictoffset && __pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_10cPyparsing___pyx_scope_struct_80_assertRaisesParseException->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_cPyparsing(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_cPyparsing},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "cPyparsing",
      __pyx_k_cPyparsing_is_an_alternative_im, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initcPyparsing(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initcPyparsing(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_cPyparsing(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_cPyparsing(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_cPyparsing(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  PyObject *(*__pyx_t_16)(PyObject *);
  int __pyx_t_17;
  int __pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *(*__pyx_t_20)(PyObject *);
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'cPyparsing' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("cPyparsing", __pyx_methods, __pyx_k_cPyparsing_is_an_alternative_im, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to cPyparsing pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_cPyparsing(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_cPyparsing) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "cPyparsing")) {
      if (unlikely((PyDict_SetItemString(modules, "cPyparsing", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "cPyparsing.pyx":41
 * 
 * # [CPYPARSING] automatically updated by constants.py prior to compilation
 * __version__ = "2.4.7.2.3.0"             # <<<<<<<<<<<<<<
 * __versionTime__ = "24 Nov 2023 01:45 UTC"
 * _FILE_NAME = "cPyparsing.pyx"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_version, __pyx_kp_u_2_4_7_2_3_0) < 0) __PYX_ERR(0, 41, __pyx_L1_error)

  /* "cPyparsing.pyx":42
 * # [CPYPARSING] automatically updated by constants.py prior to compilation
 * __version__ = "2.4.7.2.3.0"
 * __versionTime__ = "24 Nov 2023 01:45 UTC"             # <<<<<<<<<<<<<<
 * _FILE_NAME = "cPyparsing.pyx"
 * _WRAP_CALL_LINE_NUM = 1328
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_versionTime, __pyx_kp_u_24_Nov_2023_01_45_UTC) < 0) __PYX_ERR(0, 42, __pyx_L1_error)

  /* "cPyparsing.pyx":43
 * __version__ = "2.4.7.2.3.0"
 * __versionTime__ = "24 Nov 2023 01:45 UTC"
 * _FILE_NAME = "cPyparsing.pyx"             # <<<<<<<<<<<<<<
 * _WRAP_CALL_LINE_NUM = 1328
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FILE_NAME, __pyx_kp_u_cPyparsing_pyx) < 0) __PYX_ERR(0, 43, __pyx_L1_error)

  /* "cPyparsing.pyx":44
 * __versionTime__ = "24 Nov 2023 01:45 UTC"
 * _FILE_NAME = "cPyparsing.pyx"
 * _WRAP_CALL_LINE_NUM = 1328             # <<<<<<<<<<<<<<
 * 
 * # [CPYPARSING] author
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_WRAP_CALL_LINE_NUM, __pyx_int_1328) < 0) __PYX_ERR(0, 44, __pyx_L1_error)

  /* "cPyparsing.pyx":47
 * 
 * # [CPYPARSING] author
 * __author__ = "Evan Hubinger <evanjhub@gmail.com>"             # <<<<<<<<<<<<<<
 * 
 * # [CPYPARSING] store python builtins
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_author, __pyx_kp_u_Evan_Hubinger_evanjhub_gmail_com) < 0) __PYX_ERR(0, 47, __pyx_L1_error)

  /* "cPyparsing.pyx":50
 * 
 * # [CPYPARSING] store python builtins
 * py_str = str             # <<<<<<<<<<<<<<
 * py_repr = repr
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_py_str, __pyx_t_2) < 0) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":51
 * # [CPYPARSING] store python builtins
 * py_str = str
 * py_repr = repr             # <<<<<<<<<<<<<<
 * 
 * #-----------------------------------------------------------------------------------------------------------------------
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_repr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_py_repr, __pyx_t_2) < 0) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":57
 * #-----------------------------------------------------------------------------------------------------------------------
 * 
 * import string             # <<<<<<<<<<<<<<
 * from weakref import ref as wkref
 * import copy
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_string, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_string, __pyx_t_2) < 0) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":58
 * 
 * import string
 * from weakref import ref as wkref             # <<<<<<<<<<<<<<
 * import copy
 * import sys
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_ref);
  __Pyx_GIVEREF(__pyx_n_s_ref);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_ref)) __PYX_ERR(0, 58, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_weakref, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_ref); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_wkref, __pyx_t_2) < 0) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":59
 * import string
 * from weakref import ref as wkref
 * import copy             # <<<<<<<<<<<<<<
 * import sys
 * import warnings
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_copy, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_copy, __pyx_t_3) < 0) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":60
 * from weakref import ref as wkref
 * import copy
 * import sys             # <<<<<<<<<<<<<<
 * import warnings
 * import re
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_sys, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_3) < 0) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":61
 * import copy
 * import sys
 * import warnings             # <<<<<<<<<<<<<<
 * import re
 * # [CPYPARSING] fix sre_constants deprecation
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_warnings, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_warnings, __pyx_t_3) < 0) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":62
 * import sys
 * import warnings
 * import re             # <<<<<<<<<<<<<<
 * # [CPYPARSING] fix sre_constants deprecation
 * if sys.version_info >= (3, 11):
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_re, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_3) < 0) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":64
 * import re
 * # [CPYPARSING] fix sre_constants deprecation
 * if sys.version_info >= (3, 11):             # <<<<<<<<<<<<<<
 *     sre_constants = re
 * else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sys); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_version_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_tuple__171, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":65
 * # [CPYPARSING] fix sre_constants deprecation
 * if sys.version_info >= (3, 11):
 *     sre_constants = re             # <<<<<<<<<<<<<<
 * else:
 *     import sre_constants
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_sre_constants, __pyx_t_3) < 0) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":64
 * import re
 * # [CPYPARSING] fix sre_constants deprecation
 * if sys.version_info >= (3, 11):             # <<<<<<<<<<<<<<
 *     sre_constants = re
 * else:
 */
    goto __pyx_L2;
  }

  /* "cPyparsing.pyx":67
 *     sre_constants = re
 * else:
 *     import sre_constants             # <<<<<<<<<<<<<<
 * import collections
 * import pprint
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_sre_constants, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_sre_constants, __pyx_t_3) < 0) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L2:;

  /* "cPyparsing.pyx":68
 * else:
 *     import sre_constants
 * import collections             # <<<<<<<<<<<<<<
 * import pprint
 * import traceback
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_collections, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_collections, __pyx_t_3) < 0) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":69
 *     import sre_constants
 * import collections
 * import pprint             # <<<<<<<<<<<<<<
 * import traceback
 * import types
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_pprint, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pprint, __pyx_t_3) < 0) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":70
 * import collections
 * import pprint
 * import traceback             # <<<<<<<<<<<<<<
 * import types
 * from datetime import datetime
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_traceback_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_traceback_2, __pyx_t_3) < 0) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":71
 * import pprint
 * import traceback
 * import types             # <<<<<<<<<<<<<<
 * from datetime import datetime
 * from operator import itemgetter
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_types, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_types, __pyx_t_3) < 0) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":72
 * import traceback
 * import types
 * from datetime import datetime             # <<<<<<<<<<<<<<
 * from operator import itemgetter
 * import itertools
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_datetime);
  __Pyx_GIVEREF(__pyx_n_s_datetime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_datetime)) __PYX_ERR(0, 72, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_datetime, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_datetime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_3) < 0) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":73
 * import types
 * from datetime import datetime
 * from operator import itemgetter             # <<<<<<<<<<<<<<
 * import itertools
 * # [CPYPARSING] import update_wrapper
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_itemgetter);
  __Pyx_GIVEREF(__pyx_n_s_itemgetter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_itemgetter)) __PYX_ERR(0, 73, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_operator, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_itemgetter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_itemgetter, __pyx_t_2) < 0) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":74
 * from datetime import datetime
 * from operator import itemgetter
 * import itertools             # <<<<<<<<<<<<<<
 * # [CPYPARSING] import update_wrapper
 * from functools import wraps, update_wrapper
 */
  __pyx_t_3 = __Pyx_ImportDottedModule(__pyx_n_s_itertools, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_itertools, __pyx_t_3) < 0) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":76
 * import itertools
 * # [CPYPARSING] import update_wrapper
 * from functools import wraps, update_wrapper             # <<<<<<<<<<<<<<
 * from contextlib import contextmanager
 * # [CPYPARSING] import commonprefix
 */
  __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_wraps);
  __Pyx_GIVEREF(__pyx_n_s_wraps);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_wraps)) __PYX_ERR(0, 76, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_update_wrapper);
  __Pyx_GIVEREF(__pyx_n_s_update_wrapper);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_update_wrapper)) __PYX_ERR(0, 76, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_functools, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_wraps); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_wraps, __pyx_t_3) < 0) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_update_wrapper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_update_wrapper, __pyx_t_3) < 0) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":77
 * # [CPYPARSING] import update_wrapper
 * from functools import wraps, update_wrapper
 * from contextlib import contextmanager             # <<<<<<<<<<<<<<
 * # [CPYPARSING] import commonprefix
 * from os.path import commonprefix
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_contextmanager);
  __Pyx_GIVEREF(__pyx_n_s_contextmanager);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_contextmanager)) __PYX_ERR(0, 77, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_contextlib, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_contextmanager); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_contextmanager, __pyx_t_2) < 0) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":79
 * from contextlib import contextmanager
 * # [CPYPARSING] import commonprefix
 * from os.path import commonprefix             # <<<<<<<<<<<<<<
 * # [CPYPARSING] import defaultdict
 * from collections import defaultdict
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_commonprefix);
  __Pyx_GIVEREF(__pyx_n_s_commonprefix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_commonprefix)) __PYX_ERR(0, 79, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_os_path, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_commonprefix); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_commonprefix, __pyx_t_3) < 0) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":81
 * from os.path import commonprefix
 * # [CPYPARSING] import defaultdict
 * from collections import defaultdict             # <<<<<<<<<<<<<<
 * 
 * try:
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_defaultdict);
  __Pyx_GIVEREF(__pyx_n_s_defaultdict);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_defaultdict)) __PYX_ERR(0, 81, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_defaultdict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_defaultdict, __pyx_t_2) < 0) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":83
 * from collections import defaultdict
 * 
 * try:             # <<<<<<<<<<<<<<
 *     # Python 3
 *     from itertools import filterfalse
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "cPyparsing.pyx":85
 * try:
 *     # Python 3
 *     from itertools import filterfalse             # <<<<<<<<<<<<<<
 * except ImportError:
 *     from itertools import ifilterfalse as filterfalse
 */
      __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 85, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_n_s_filterfalse);
      __Pyx_GIVEREF(__pyx_n_s_filterfalse);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_filterfalse)) __PYX_ERR(0, 85, __pyx_L3_error);
      __pyx_t_2 = __Pyx_Import(__pyx_n_s_itertools, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 85, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_filterfalse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 85, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_filterfalse, __pyx_t_3) < 0) __PYX_ERR(0, 85, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":83
 * from collections import defaultdict
 * 
 * try:             # <<<<<<<<<<<<<<
 *     # Python 3
 *     from itertools import filterfalse
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":86
 *     # Python 3
 *     from itertools import filterfalse
 * except ImportError:             # <<<<<<<<<<<<<<
 *     from itertools import ifilterfalse as filterfalse
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ImportError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_8) < 0) __PYX_ERR(0, 86, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "cPyparsing.pyx":87
 *     from itertools import filterfalse
 * except ImportError:
 *     from itertools import ifilterfalse as filterfalse             # <<<<<<<<<<<<<<
 * 
 * try:
 */
      __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 87, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_n_s_ifilterfalse);
      __Pyx_GIVEREF(__pyx_n_s_ifilterfalse);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_n_s_ifilterfalse)) __PYX_ERR(0, 87, __pyx_L5_except_error);
      __pyx_t_10 = __Pyx_Import(__pyx_n_s_itertools, __pyx_t_9, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 87, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_ImportFrom(__pyx_t_10, __pyx_n_s_ifilterfalse); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 87, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_filterfalse, __pyx_t_9) < 0) __PYX_ERR(0, 87, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "cPyparsing.pyx":83
 * from collections import defaultdict
 * 
 * try:             # <<<<<<<<<<<<<<
 *     # Python 3
 *     from itertools import filterfalse
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_5, __pyx_t_6);
    __pyx_L8_try_end:;
  }

  /* "cPyparsing.pyx":89
 *     from itertools import ifilterfalse as filterfalse
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from _thread import RLock
 * except ImportError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "cPyparsing.pyx":90
 * 
 * try:
 *     from _thread import RLock             # <<<<<<<<<<<<<<
 * except ImportError:
 *     from threading import RLock
 */
      __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 90, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_n_s_RLock);
      __Pyx_GIVEREF(__pyx_n_s_RLock);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_n_s_RLock)) __PYX_ERR(0, 90, __pyx_L11_error);
      __pyx_t_3 = __Pyx_Import(__pyx_n_s_thread, __pyx_t_8, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 90, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_RLock); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 90, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_RLock, __pyx_t_8) < 0) __PYX_ERR(0, 90, __pyx_L11_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":89
 *     from itertools import ifilterfalse as filterfalse
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from _thread import RLock
 * except ImportError:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L16_try_end;
    __pyx_L11_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":91
 * try:
 *     from _thread import RLock
 * except ImportError:             # <<<<<<<<<<<<<<
 *     from threading import RLock
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ImportError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_2) < 0) __PYX_ERR(0, 91, __pyx_L13_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_2);

      /* "cPyparsing.pyx":92
 *     from _thread import RLock
 * except ImportError:
 *     from threading import RLock             # <<<<<<<<<<<<<<
 * 
 * try:
 */
      __pyx_t_10 = PyList_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 92, __pyx_L13_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_n_s_RLock);
      __Pyx_GIVEREF(__pyx_n_s_RLock);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_10, 0, __pyx_n_s_RLock)) __PYX_ERR(0, 92, __pyx_L13_except_error);
      __pyx_t_9 = __Pyx_Import(__pyx_n_s_threading, __pyx_t_10, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 92, __pyx_L13_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_ImportFrom(__pyx_t_9, __pyx_n_s_RLock); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 92, __pyx_L13_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_RLock, __pyx_t_10) < 0) __PYX_ERR(0, 92, __pyx_L13_except_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L12_exception_handled;
    }
    goto __pyx_L13_except_error;

    /* "cPyparsing.pyx":89
 *     from itertools import ifilterfalse as filterfalse
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from _thread import RLock
 * except ImportError:
 */
    __pyx_L13_except_error:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L12_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_1);
    __pyx_L16_try_end:;
  }

  /* "cPyparsing.pyx":94
 *     from threading import RLock
 * 
 * try:             # <<<<<<<<<<<<<<
 *     # Python 3
 *     from collections.abc import Iterable
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "cPyparsing.pyx":96
 * try:
 *     # Python 3
 *     from collections.abc import Iterable             # <<<<<<<<<<<<<<
 *     from collections.abc import MutableMapping, Mapping
 * except ImportError:
 */
      __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 96, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_n_s_Iterable);
      __Pyx_GIVEREF(__pyx_n_s_Iterable);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_Iterable)) __PYX_ERR(0, 96, __pyx_L19_error);
      __pyx_t_8 = __Pyx_Import(__pyx_n_s_collections_abc, __pyx_t_2, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 96, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_8, __pyx_n_s_Iterable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 96, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_Iterable, __pyx_t_2) < 0) __PYX_ERR(0, 96, __pyx_L19_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":97
 *     # Python 3
 *     from collections.abc import Iterable
 *     from collections.abc import MutableMapping, Mapping             # <<<<<<<<<<<<<<
 * except ImportError:
 *     # Python 2.7
 */
      __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 97, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_n_s_MutableMapping);
      __Pyx_GIVEREF(__pyx_n_s_MutableMapping);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_n_s_MutableMapping)) __PYX_ERR(0, 97, __pyx_L19_error);
      __Pyx_INCREF(__pyx_n_s_Mapping);
      __Pyx_GIVEREF(__pyx_n_s_Mapping);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 1, __pyx_n_s_Mapping)) __PYX_ERR(0, 97, __pyx_L19_error);
      __pyx_t_2 = __Pyx_Import(__pyx_n_s_collections_abc, __pyx_t_8, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 97, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_MutableMapping); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 97, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_MutableMapping, __pyx_t_8) < 0) __PYX_ERR(0, 97, __pyx_L19_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Mapping); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 97, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_Mapping, __pyx_t_8) < 0) __PYX_ERR(0, 97, __pyx_L19_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":94
 *     from threading import RLock
 * 
 * try:             # <<<<<<<<<<<<<<
 *     # Python 3
 *     from collections.abc import Iterable
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L24_try_end;
    __pyx_L19_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":98
 *     from collections.abc import Iterable
 *     from collections.abc import MutableMapping, Mapping
 * except ImportError:             # <<<<<<<<<<<<<<
 *     # Python 2.7
 *     from collections import Iterable
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ImportError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_8, &__pyx_t_3) < 0) __PYX_ERR(0, 98, __pyx_L21_except_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_3);

      /* "cPyparsing.pyx":100
 * except ImportError:
 *     # Python 2.7
 *     from collections import Iterable             # <<<<<<<<<<<<<<
 *     from collections import MutableMapping, Mapping
 * 
 */
      __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 100, __pyx_L21_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_n_s_Iterable);
      __Pyx_GIVEREF(__pyx_n_s_Iterable);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_n_s_Iterable)) __PYX_ERR(0, 100, __pyx_L21_except_error);
      __pyx_t_10 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_9, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 100, __pyx_L21_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_ImportFrom(__pyx_t_10, __pyx_n_s_Iterable); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 100, __pyx_L21_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_Iterable, __pyx_t_9) < 0) __PYX_ERR(0, 100, __pyx_L21_except_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "cPyparsing.pyx":101
 *     # Python 2.7
 *     from collections import Iterable
 *     from collections import MutableMapping, Mapping             # <<<<<<<<<<<<<<
 * 
 * try:
 */
      __pyx_t_10 = PyList_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 101, __pyx_L21_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_n_s_MutableMapping);
      __Pyx_GIVEREF(__pyx_n_s_MutableMapping);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_10, 0, __pyx_n_s_MutableMapping)) __PYX_ERR(0, 101, __pyx_L21_except_error);
      __Pyx_INCREF(__pyx_n_s_Mapping);
      __Pyx_GIVEREF(__pyx_n_s_Mapping);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_10, 1, __pyx_n_s_Mapping)) __PYX_ERR(0, 101, __pyx_L21_except_error);
      __pyx_t_9 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_10, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 101, __pyx_L21_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_ImportFrom(__pyx_t_9, __pyx_n_s_MutableMapping); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 101, __pyx_L21_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_MutableMapping, __pyx_t_10) < 0) __PYX_ERR(0, 101, __pyx_L21_except_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_ImportFrom(__pyx_t_9, __pyx_n_s_Mapping); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 101, __pyx_L21_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_Mapping, __pyx_t_10) < 0) __PYX_ERR(0, 101, __pyx_L21_except_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L20_exception_handled;
    }
    goto __pyx_L21_except_error;

    /* "cPyparsing.pyx":94
 *     from threading import RLock
 * 
 * try:             # <<<<<<<<<<<<<<
 *     # Python 3
 *     from collections.abc import Iterable
 */
    __pyx_L21_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L20_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_5, __pyx_t_6);
    __pyx_L24_try_end:;
  }

  /* "cPyparsing.pyx":103
 *     from collections import MutableMapping, Mapping
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "cPyparsing.pyx":104
 * 
 * try:
 *     from collections import OrderedDict as _OrderedDict             # <<<<<<<<<<<<<<
 * except ImportError:
 *     try:
 */
      __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 104, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_n_s_OrderedDict_2);
      __Pyx_GIVEREF(__pyx_n_s_OrderedDict_2);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_OrderedDict_2)) __PYX_ERR(0, 104, __pyx_L27_error);
      __pyx_t_8 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_3, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 104, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_8, __pyx_n_s_OrderedDict_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 104, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_OrderedDict, __pyx_t_3) < 0) __PYX_ERR(0, 104, __pyx_L27_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":103
 *     from collections import MutableMapping, Mapping
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L32_try_end;
    __pyx_L27_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":105
 * try:
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:             # <<<<<<<<<<<<<<
 *     try:
 *         from ordereddict import OrderedDict as _OrderedDict
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ImportError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 105, __pyx_L29_except_error)
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_2);

      /* "cPyparsing.pyx":106
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 *     try:             # <<<<<<<<<<<<<<
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_13);
        /*try:*/ {

          /* "cPyparsing.pyx":107
 * except ImportError:
 *     try:
 *         from ordereddict import OrderedDict as _OrderedDict             # <<<<<<<<<<<<<<
 *     except ImportError:
 *         _OrderedDict = None
 */
          __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 107, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_n_s_OrderedDict_2);
          __Pyx_GIVEREF(__pyx_n_s_OrderedDict_2);
          if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_n_s_OrderedDict_2)) __PYX_ERR(0, 107, __pyx_L35_error);
          __pyx_t_10 = __Pyx_Import(__pyx_n_s_ordereddict, __pyx_t_9, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 107, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = __Pyx_ImportFrom(__pyx_t_10, __pyx_n_s_OrderedDict_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 107, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (PyDict_SetItem(__pyx_d, __pyx_n_s_OrderedDict, __pyx_t_9) < 0) __PYX_ERR(0, 107, __pyx_L35_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "cPyparsing.pyx":106
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 *     try:             # <<<<<<<<<<<<<<
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:
 */
        }
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L42_try_end;
        __pyx_L35_error:;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "cPyparsing.pyx":108
 *     try:
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:             # <<<<<<<<<<<<<<
 *         _OrderedDict = None
 * 
 */
        __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ImportError);
        if (__pyx_t_7) {
          __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_10, &__pyx_t_9, &__pyx_t_14) < 0) __PYX_ERR(0, 108, __pyx_L37_except_error)
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_14);

          /* "cPyparsing.pyx":109
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:
 *         _OrderedDict = None             # <<<<<<<<<<<<<<
 * 
 * try:
 */
          if (PyDict_SetItem(__pyx_d, __pyx_n_s_OrderedDict, Py_None) < 0) __PYX_ERR(0, 109, __pyx_L37_except_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          goto __pyx_L36_exception_handled;
        }
        goto __pyx_L37_except_error;

        /* "cPyparsing.pyx":106
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 *     try:             # <<<<<<<<<<<<<<
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:
 */
        __pyx_L37_except_error:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
        goto __pyx_L29_except_error;
        __pyx_L36_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
        __pyx_L42_try_end:;
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L28_exception_handled;
    }
    goto __pyx_L29_except_error;

    /* "cPyparsing.pyx":103
 *     from collections import MutableMapping, Mapping
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 */
    __pyx_L29_except_error:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L28_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_1);
    __pyx_L32_try_end:;
  }

  /* "cPyparsing.pyx":111
 *         _OrderedDict = None
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from types import SimpleNamespace
 * except ImportError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "cPyparsing.pyx":112
 * 
 * try:
 *     from types import SimpleNamespace             # <<<<<<<<<<<<<<
 * except ImportError:
 *     class SimpleNamespace: pass
 */
      __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L45_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_n_s_SimpleNamespace);
      __Pyx_GIVEREF(__pyx_n_s_SimpleNamespace);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_SimpleNamespace)) __PYX_ERR(0, 112, __pyx_L45_error);
      __pyx_t_3 = __Pyx_Import(__pyx_n_s_types, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 112, __pyx_L45_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_SimpleNamespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L45_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_SimpleNamespace, __pyx_t_2) < 0) __PYX_ERR(0, 112, __pyx_L45_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":111
 *         _OrderedDict = None
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from types import SimpleNamespace
 * except ImportError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L50_try_end;
    __pyx_L45_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":113
 * try:
 *     from types import SimpleNamespace
 * except ImportError:             # <<<<<<<<<<<<<<
 *     class SimpleNamespace: pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ImportError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_2, &__pyx_t_8) < 0) __PYX_ERR(0, 113, __pyx_L47_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "cPyparsing.pyx":114
 *     from types import SimpleNamespace
 * except ImportError:
 *     class SimpleNamespace: pass             # <<<<<<<<<<<<<<
 * 
 * # version compatibility configuration
 */
      __pyx_t_14 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_SimpleNamespace, __pyx_n_s_SimpleNamespace, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 114, __pyx_L47_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_9 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_n_s_SimpleNamespace, __pyx_empty_tuple, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 114, __pyx_L47_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_SimpleNamespace, __pyx_t_9) < 0) __PYX_ERR(0, 114, __pyx_L47_except_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L46_exception_handled;
    }
    goto __pyx_L47_except_error;

    /* "cPyparsing.pyx":111
 *         _OrderedDict = None
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from types import SimpleNamespace
 * except ImportError:
 */
    __pyx_L47_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L46_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_5, __pyx_t_6);
    __pyx_L50_try_end:;
  }

  /* "cPyparsing.pyx":117
 * 
 * # version compatibility configuration
 * __compat__ = SimpleNamespace()             # <<<<<<<<<<<<<<
 * __compat__.__doc__ = """
 *     A cross-version compatibility configuration for pyparsing features that will be
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_SimpleNamespace); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_compat, __pyx_t_2) < 0) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":118
 * # version compatibility configuration
 * __compat__ = SimpleNamespace()
 * __compat__.__doc__ = """             # <<<<<<<<<<<<<<
 *     A cross-version compatibility configuration for pyparsing features that will be
 *     released in a future version. By setting values in this configuration to True,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_compat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_doc, __pyx_kp_u_A_cross_version_compatibility_c) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":129
 *        pre-2.3.0 handling of named results
 * """
 * __compat__.collect_all_And_tokens = True             # <<<<<<<<<<<<<<
 * 
 * __diag__ = SimpleNamespace()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_compat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_collect_all_And_tokens, Py_True) < 0) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":131
 * __compat__.collect_all_And_tokens = True
 * 
 * __diag__ = SimpleNamespace()             # <<<<<<<<<<<<<<
 * __diag__.__doc__ = """
 * Diagnostic configuration (all default to False)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SimpleNamespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_diag, __pyx_t_8) < 0) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":132
 * 
 * __diag__ = SimpleNamespace()
 * __diag__.__doc__ = """             # <<<<<<<<<<<<<<
 * Diagnostic configuration (all default to False)
 *      - warn_multiple_tokens_in_named_alternation - flag to enable warnings when a results
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_diag); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_doc, __pyx_kp_u_Diagnostic_configuration_all_de) < 0) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":147
 *        calls to ParserElement.setName()
 * """
 * __diag__.warn_multiple_tokens_in_named_alternation = False             # <<<<<<<<<<<<<<
 * __diag__.warn_ungrouped_named_tokens_in_collection = False
 * __diag__.warn_name_set_on_empty_Forward = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_diag); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_warn_multiple_tokens_in_named_al, Py_False) < 0) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":148
 * """
 * __diag__.warn_multiple_tokens_in_named_alternation = False
 * __diag__.warn_ungrouped_named_tokens_in_collection = False             # <<<<<<<<<<<<<<
 * __diag__.warn_name_set_on_empty_Forward = False
 * __diag__.warn_on_multiple_string_args_to_oneof = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_diag); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_warn_ungrouped_named_tokens_in_c, Py_False) < 0) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":149
 * __diag__.warn_multiple_tokens_in_named_alternation = False
 * __diag__.warn_ungrouped_named_tokens_in_collection = False
 * __diag__.warn_name_set_on_empty_Forward = False             # <<<<<<<<<<<<<<
 * __diag__.warn_on_multiple_string_args_to_oneof = False
 * # [CPYPARSING] add warn_on_incremental_multiline_regex
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_diag); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_warn_name_set_on_empty_Forward, Py_False) < 0) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":150
 * __diag__.warn_ungrouped_named_tokens_in_collection = False
 * __diag__.warn_name_set_on_empty_Forward = False
 * __diag__.warn_on_multiple_string_args_to_oneof = False             # <<<<<<<<<<<<<<
 * # [CPYPARSING] add warn_on_incremental_multiline_regex
 * __diag__.warn_on_incremental_multiline_regex = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_diag); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_warn_on_multiple_string_args_to, Py_False) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":152
 * __diag__.warn_on_multiple_string_args_to_oneof = False
 * # [CPYPARSING] add warn_on_incremental_multiline_regex
 * __diag__.warn_on_incremental_multiline_regex = False             # <<<<<<<<<<<<<<
 * __diag__.enable_debug_on_named_expressions = False
 * __diag__._all_names = [nm for nm in vars(__diag__) if nm.startswith("enable_") or nm.startswith("warn_")]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_diag); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_warn_on_incremental_multiline_re, Py_False) < 0) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":153
 * # [CPYPARSING] add warn_on_incremental_multiline_regex
 * __diag__.warn_on_incremental_multiline_regex = False
 * __diag__.enable_debug_on_named_expressions = False             # <<<<<<<<<<<<<<
 * __diag__._all_names = [nm for nm in vars(__diag__) if nm.startswith("enable_") or nm.startswith("warn_")]
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_diag); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_enable_debug_on_named_expression, Py_False) < 0) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":154
 * __diag__.warn_on_incremental_multiline_regex = False
 * __diag__.enable_debug_on_named_expressions = False
 * __diag__._all_names = [nm for nm in vars(__diag__) if nm.startswith("enable_") or nm.startswith("warn_")]             # <<<<<<<<<<<<<<
 * 
 * def _enable_all_warnings():
 */
  { /* enter inner scope */
    __pyx_t_8 = PyList_New(0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 154, __pyx_L55_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_diag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 154, __pyx_L55_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_vars, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 154, __pyx_L55_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_15 = 0;
      __pyx_t_16 = NULL;
    } else {
      __pyx_t_15 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 154, __pyx_L55_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_16 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 154, __pyx_L55_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_16)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 154, __pyx_L55_error)
            #endif
            if (__pyx_t_15 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_15); __Pyx_INCREF(__pyx_t_3); __pyx_t_15++; if (unlikely((0 < 0))) __PYX_ERR(0, 154, __pyx_L55_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_15); __pyx_t_15++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 154, __pyx_L55_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 154, __pyx_L55_error)
            #endif
            if (__pyx_t_15 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_15); __Pyx_INCREF(__pyx_t_3); __pyx_t_15++; if (unlikely((0 < 0))) __PYX_ERR(0, 154, __pyx_L55_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_15); __pyx_t_15++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 154, __pyx_L55_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_16(__pyx_t_2);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 154, __pyx_L55_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XGOTREF(__pyx_7genexpr__pyx_v_10cPyparsing_nm);
      __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_10cPyparsing_nm, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_7genexpr__pyx_v_10cPyparsing_nm, __pyx_n_s_startswith); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 154, __pyx_L55_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_9 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_n_u_enable_2};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 154, __pyx_L55_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_17 < 0))) __PYX_ERR(0, 154, __pyx_L55_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!__pyx_t_17) {
      } else {
        __pyx_t_4 = __pyx_t_17;
        goto __pyx_L59_bool_binop_done;
      }
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_7genexpr__pyx_v_10cPyparsing_nm, __pyx_n_s_startswith); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 154, __pyx_L55_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_9 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_n_u_warn_2};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 154, __pyx_L55_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_17 < 0))) __PYX_ERR(0, 154, __pyx_L55_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_4 = __pyx_t_17;
      __pyx_L59_bool_binop_done:;
      if (__pyx_t_4) {
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_8, (PyObject*)__pyx_7genexpr__pyx_v_10cPyparsing_nm))) __PYX_ERR(0, 154, __pyx_L55_error)
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_7genexpr__pyx_v_10cPyparsing_nm);
    __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_10cPyparsing_nm, Py_None);
    goto __pyx_L62_exit_scope;
    __pyx_L55_error:;
    __Pyx_GOTREF(__pyx_7genexpr__pyx_v_10cPyparsing_nm);
    __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_10cPyparsing_nm, Py_None);
    goto __pyx_L1_error;
    __pyx_L62_exit_scope:;
  } /* exit inner scope */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_diag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_all_names, __pyx_t_8) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":156
 * __diag__._all_names = [nm for nm in vars(__diag__) if nm.startswith("enable_") or nm.startswith("warn_")]
 * 
 * def _enable_all_warnings():             # <<<<<<<<<<<<<<
 *     __diag__.warn_multiple_tokens_in_named_alternation = True
 *     __diag__.warn_ungrouped_named_tokens_in_collection = True
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_1_enable_all_warnings, 0, __pyx_n_s_enable_all_warnings, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__172)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_enable_all_warnings, __pyx_t_2) < 0) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":163
 *     # [CPYPARSING] add warn_on_incremental_multiline_regex
 *     __diag__.warn_on_incremental_multiline_regex = True
 * __diag__.enable_all_warnings = _enable_all_warnings             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_enable_all_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_diag); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_enable_all_warnings_2, __pyx_t_2) < 0) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":166
 * 
 * 
 * __all__ = ['__version__', '__versionTime__', '__author__', '__compat__', '__diag__',             # <<<<<<<<<<<<<<
 *            'And', 'CaselessKeyword', 'CaselessLiteral', 'CharsNotIn', 'Combine', 'Dict', 'Each', 'Empty',
 *            'FollowedBy', 'Forward', 'GoToColumn', 'Group', 'Keyword', 'LineEnd', 'LineStart', 'Literal',
 */
  __pyx_t_8 = PyList_New(116); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_n_u_version);
  __Pyx_GIVEREF(__pyx_n_u_version);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_n_u_version)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_versionTime);
  __Pyx_GIVEREF(__pyx_n_u_versionTime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 1, __pyx_n_u_versionTime)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_author);
  __Pyx_GIVEREF(__pyx_n_u_author);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 2, __pyx_n_u_author)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_compat);
  __Pyx_GIVEREF(__pyx_n_u_compat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 3, __pyx_n_u_compat)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_diag);
  __Pyx_GIVEREF(__pyx_n_u_diag);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 4, __pyx_n_u_diag)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_And);
  __Pyx_GIVEREF(__pyx_n_u_And);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 5, __pyx_n_u_And)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_CaselessKeyword);
  __Pyx_GIVEREF(__pyx_n_u_CaselessKeyword);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 6, __pyx_n_u_CaselessKeyword)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_CaselessLiteral);
  __Pyx_GIVEREF(__pyx_n_u_CaselessLiteral);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 7, __pyx_n_u_CaselessLiteral)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_CharsNotIn);
  __Pyx_GIVEREF(__pyx_n_u_CharsNotIn);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 8, __pyx_n_u_CharsNotIn)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Combine);
  __Pyx_GIVEREF(__pyx_n_u_Combine);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 9, __pyx_n_u_Combine)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Dict);
  __Pyx_GIVEREF(__pyx_n_u_Dict);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 10, __pyx_n_u_Dict)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Each);
  __Pyx_GIVEREF(__pyx_n_u_Each);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 11, __pyx_n_u_Each)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Empty);
  __Pyx_GIVEREF(__pyx_n_u_Empty);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 12, __pyx_n_u_Empty)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_FollowedBy);
  __Pyx_GIVEREF(__pyx_n_u_FollowedBy);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 13, __pyx_n_u_FollowedBy)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Forward);
  __Pyx_GIVEREF(__pyx_n_u_Forward);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 14, __pyx_n_u_Forward)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_GoToColumn);
  __Pyx_GIVEREF(__pyx_n_u_GoToColumn);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 15, __pyx_n_u_GoToColumn)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Group);
  __Pyx_GIVEREF(__pyx_n_u_Group);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 16, __pyx_n_u_Group)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Keyword);
  __Pyx_GIVEREF(__pyx_n_u_Keyword);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 17, __pyx_n_u_Keyword)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_LineEnd);
  __Pyx_GIVEREF(__pyx_n_u_LineEnd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 18, __pyx_n_u_LineEnd)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_LineStart);
  __Pyx_GIVEREF(__pyx_n_u_LineStart);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 19, __pyx_n_u_LineStart)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Literal);
  __Pyx_GIVEREF(__pyx_n_u_Literal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 20, __pyx_n_u_Literal)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_PrecededBy);
  __Pyx_GIVEREF(__pyx_n_u_PrecededBy);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 21, __pyx_n_u_PrecededBy)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_MatchFirst);
  __Pyx_GIVEREF(__pyx_n_u_MatchFirst);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 22, __pyx_n_u_MatchFirst)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_NoMatch);
  __Pyx_GIVEREF(__pyx_n_u_NoMatch);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 23, __pyx_n_u_NoMatch)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_NotAny);
  __Pyx_GIVEREF(__pyx_n_u_NotAny);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 24, __pyx_n_u_NotAny)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_OneOrMore);
  __Pyx_GIVEREF(__pyx_n_u_OneOrMore);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 25, __pyx_n_u_OneOrMore)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_OnlyOnce);
  __Pyx_GIVEREF(__pyx_n_u_OnlyOnce);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 26, __pyx_n_u_OnlyOnce)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Optional);
  __Pyx_GIVEREF(__pyx_n_u_Optional);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 27, __pyx_n_u_Optional)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Or);
  __Pyx_GIVEREF(__pyx_n_u_Or);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 28, __pyx_n_u_Or)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ParseBaseException);
  __Pyx_GIVEREF(__pyx_n_u_ParseBaseException);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 29, __pyx_n_u_ParseBaseException)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ParseElementEnhance);
  __Pyx_GIVEREF(__pyx_n_u_ParseElementEnhance);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 30, __pyx_n_u_ParseElementEnhance)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ParseException);
  __Pyx_GIVEREF(__pyx_n_u_ParseException);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 31, __pyx_n_u_ParseException)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ParseExpression);
  __Pyx_GIVEREF(__pyx_n_u_ParseExpression);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 32, __pyx_n_u_ParseExpression)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ParseFatalException);
  __Pyx_GIVEREF(__pyx_n_u_ParseFatalException);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 33, __pyx_n_u_ParseFatalException)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ParseResults);
  __Pyx_GIVEREF(__pyx_n_u_ParseResults);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 34, __pyx_n_u_ParseResults)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ParseSyntaxException);
  __Pyx_GIVEREF(__pyx_n_u_ParseSyntaxException);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 35, __pyx_n_u_ParseSyntaxException)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ParserElement);
  __Pyx_GIVEREF(__pyx_n_u_ParserElement);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 36, __pyx_n_u_ParserElement)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_QuotedString);
  __Pyx_GIVEREF(__pyx_n_u_QuotedString);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 37, __pyx_n_u_QuotedString)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_RecursiveGrammarException);
  __Pyx_GIVEREF(__pyx_n_u_RecursiveGrammarException);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 38, __pyx_n_u_RecursiveGrammarException)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Regex);
  __Pyx_GIVEREF(__pyx_n_u_Regex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 39, __pyx_n_u_Regex)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_SkipTo);
  __Pyx_GIVEREF(__pyx_n_u_SkipTo);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 40, __pyx_n_u_SkipTo)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_StringEnd);
  __Pyx_GIVEREF(__pyx_n_u_StringEnd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 41, __pyx_n_u_StringEnd)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_StringStart);
  __Pyx_GIVEREF(__pyx_n_u_StringStart);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 42, __pyx_n_u_StringStart)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Suppress);
  __Pyx_GIVEREF(__pyx_n_u_Suppress);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 43, __pyx_n_u_Suppress)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Token);
  __Pyx_GIVEREF(__pyx_n_u_Token);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 44, __pyx_n_u_Token)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_TokenConverter);
  __Pyx_GIVEREF(__pyx_n_u_TokenConverter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 45, __pyx_n_u_TokenConverter)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_White);
  __Pyx_GIVEREF(__pyx_n_u_White);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 46, __pyx_n_u_White)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Word);
  __Pyx_GIVEREF(__pyx_n_u_Word);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 47, __pyx_n_u_Word)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_WordEnd);
  __Pyx_GIVEREF(__pyx_n_u_WordEnd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 48, __pyx_n_u_WordEnd)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_WordStart);
  __Pyx_GIVEREF(__pyx_n_u_WordStart);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 49, __pyx_n_u_WordStart)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ZeroOrMore);
  __Pyx_GIVEREF(__pyx_n_u_ZeroOrMore);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 50, __pyx_n_u_ZeroOrMore)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_Char);
  __Pyx_GIVEREF(__pyx_n_u_Char);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 51, __pyx_n_u_Char)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_alphanums);
  __Pyx_GIVEREF(__pyx_n_u_alphanums);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 52, __pyx_n_u_alphanums)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_alphas);
  __Pyx_GIVEREF(__pyx_n_u_alphas);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 53, __pyx_n_u_alphas)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_alphas8bit);
  __Pyx_GIVEREF(__pyx_n_u_alphas8bit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 54, __pyx_n_u_alphas8bit)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_anyCloseTag);
  __Pyx_GIVEREF(__pyx_n_u_anyCloseTag);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 55, __pyx_n_u_anyCloseTag)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_anyOpenTag);
  __Pyx_GIVEREF(__pyx_n_u_anyOpenTag);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 56, __pyx_n_u_anyOpenTag)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_cStyleComment);
  __Pyx_GIVEREF(__pyx_n_u_cStyleComment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 57, __pyx_n_u_cStyleComment)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_col);
  __Pyx_GIVEREF(__pyx_n_u_col);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 58, __pyx_n_u_col)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_commaSeparatedList);
  __Pyx_GIVEREF(__pyx_n_u_commaSeparatedList);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 59, __pyx_n_u_commaSeparatedList)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_commonHTMLEntity);
  __Pyx_GIVEREF(__pyx_n_u_commonHTMLEntity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 60, __pyx_n_u_commonHTMLEntity)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_countedArray);
  __Pyx_GIVEREF(__pyx_n_u_countedArray);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 61, __pyx_n_u_countedArray)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_cppStyleComment);
  __Pyx_GIVEREF(__pyx_n_u_cppStyleComment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 62, __pyx_n_u_cppStyleComment)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_dblQuotedString);
  __Pyx_GIVEREF(__pyx_n_u_dblQuotedString);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 63, __pyx_n_u_dblQuotedString)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_dblSlashComment);
  __Pyx_GIVEREF(__pyx_n_u_dblSlashComment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 64, __pyx_n_u_dblSlashComment)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_delimitedList);
  __Pyx_GIVEREF(__pyx_n_u_delimitedList);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 65, __pyx_n_u_delimitedList)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_dictOf);
  __Pyx_GIVEREF(__pyx_n_u_dictOf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 66, __pyx_n_u_dictOf)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_downcaseTokens);
  __Pyx_GIVEREF(__pyx_n_u_downcaseTokens);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 67, __pyx_n_u_downcaseTokens)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_empty);
  __Pyx_GIVEREF(__pyx_n_u_empty);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 68, __pyx_n_u_empty)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_hexnums);
  __Pyx_GIVEREF(__pyx_n_u_hexnums);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 69, __pyx_n_u_hexnums)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_htmlComment);
  __Pyx_GIVEREF(__pyx_n_u_htmlComment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 70, __pyx_n_u_htmlComment)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_javaStyleComment);
  __Pyx_GIVEREF(__pyx_n_u_javaStyleComment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 71, __pyx_n_u_javaStyleComment)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_line);
  __Pyx_GIVEREF(__pyx_n_u_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 72, __pyx_n_u_line)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_lineEnd);
  __Pyx_GIVEREF(__pyx_n_u_lineEnd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 73, __pyx_n_u_lineEnd)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_lineStart);
  __Pyx_GIVEREF(__pyx_n_u_lineStart);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 74, __pyx_n_u_lineStart)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_lineno);
  __Pyx_GIVEREF(__pyx_n_u_lineno);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 75, __pyx_n_u_lineno)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_makeHTMLTags);
  __Pyx_GIVEREF(__pyx_n_u_makeHTMLTags);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 76, __pyx_n_u_makeHTMLTags)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_makeXMLTags);
  __Pyx_GIVEREF(__pyx_n_u_makeXMLTags);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 77, __pyx_n_u_makeXMLTags)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_matchOnlyAtCol);
  __Pyx_GIVEREF(__pyx_n_u_matchOnlyAtCol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 78, __pyx_n_u_matchOnlyAtCol)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_matchPreviousExpr);
  __Pyx_GIVEREF(__pyx_n_u_matchPreviousExpr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 79, __pyx_n_u_matchPreviousExpr)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_matchPreviousLiteral);
  __Pyx_GIVEREF(__pyx_n_u_matchPreviousLiteral);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 80, __pyx_n_u_matchPreviousLiteral)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_nestedExpr);
  __Pyx_GIVEREF(__pyx_n_u_nestedExpr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 81, __pyx_n_u_nestedExpr)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_nullDebugAction);
  __Pyx_GIVEREF(__pyx_n_u_nullDebugAction);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 82, __pyx_n_u_nullDebugAction)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_nums);
  __Pyx_GIVEREF(__pyx_n_u_nums);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 83, __pyx_n_u_nums)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_oneOf);
  __Pyx_GIVEREF(__pyx_n_u_oneOf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 84, __pyx_n_u_oneOf)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_opAssoc);
  __Pyx_GIVEREF(__pyx_n_u_opAssoc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 85, __pyx_n_u_opAssoc)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_operatorPrecedence);
  __Pyx_GIVEREF(__pyx_n_u_operatorPrecedence);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 86, __pyx_n_u_operatorPrecedence)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_printables);
  __Pyx_GIVEREF(__pyx_n_u_printables);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 87, __pyx_n_u_printables)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_punc8bit);
  __Pyx_GIVEREF(__pyx_n_u_punc8bit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 88, __pyx_n_u_punc8bit)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_pythonStyleComment);
  __Pyx_GIVEREF(__pyx_n_u_pythonStyleComment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 89, __pyx_n_u_pythonStyleComment)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_quotedString);
  __Pyx_GIVEREF(__pyx_n_u_quotedString);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 90, __pyx_n_u_quotedString)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_removeQuotes);
  __Pyx_GIVEREF(__pyx_n_u_removeQuotes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 91, __pyx_n_u_removeQuotes)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_replaceHTMLEntity);
  __Pyx_GIVEREF(__pyx_n_u_replaceHTMLEntity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 92, __pyx_n_u_replaceHTMLEntity)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_replaceWith);
  __Pyx_GIVEREF(__pyx_n_u_replaceWith);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 93, __pyx_n_u_replaceWith)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_restOfLine);
  __Pyx_GIVEREF(__pyx_n_u_restOfLine);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 94, __pyx_n_u_restOfLine)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_sglQuotedString);
  __Pyx_GIVEREF(__pyx_n_u_sglQuotedString);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 95, __pyx_n_u_sglQuotedString)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_srange);
  __Pyx_GIVEREF(__pyx_n_u_srange);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 96, __pyx_n_u_srange)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_stringEnd);
  __Pyx_GIVEREF(__pyx_n_u_stringEnd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 97, __pyx_n_u_stringEnd)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_stringStart);
  __Pyx_GIVEREF(__pyx_n_u_stringStart);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 98, __pyx_n_u_stringStart)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_traceParseAction);
  __Pyx_GIVEREF(__pyx_n_u_traceParseAction);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 99, __pyx_n_u_traceParseAction)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_unicodeString);
  __Pyx_GIVEREF(__pyx_n_u_unicodeString);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 100, __pyx_n_u_unicodeString)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_upcaseTokens);
  __Pyx_GIVEREF(__pyx_n_u_upcaseTokens);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 101, __pyx_n_u_upcaseTokens)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_withAttribute);
  __Pyx_GIVEREF(__pyx_n_u_withAttribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 102, __pyx_n_u_withAttribute)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_indentedBlock);
  __Pyx_GIVEREF(__pyx_n_u_indentedBlock);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 103, __pyx_n_u_indentedBlock)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_originalTextFor);
  __Pyx_GIVEREF(__pyx_n_u_originalTextFor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 104, __pyx_n_u_originalTextFor)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ungroup);
  __Pyx_GIVEREF(__pyx_n_u_ungroup);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 105, __pyx_n_u_ungroup)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_infixNotation);
  __Pyx_GIVEREF(__pyx_n_u_infixNotation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 106, __pyx_n_u_infixNotation)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_locatedExpr);
  __Pyx_GIVEREF(__pyx_n_u_locatedExpr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 107, __pyx_n_u_locatedExpr)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_withClass);
  __Pyx_GIVEREF(__pyx_n_u_withClass);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 108, __pyx_n_u_withClass)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_CloseMatch);
  __Pyx_GIVEREF(__pyx_n_u_CloseMatch);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 109, __pyx_n_u_CloseMatch)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_tokenMap);
  __Pyx_GIVEREF(__pyx_n_u_tokenMap);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 110, __pyx_n_u_tokenMap)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_pyparsing_common);
  __Pyx_GIVEREF(__pyx_n_u_pyparsing_common);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 111, __pyx_n_u_pyparsing_common)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_pyparsing_unicode);
  __Pyx_GIVEREF(__pyx_n_u_pyparsing_unicode);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 112, __pyx_n_u_pyparsing_unicode)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_unicode_set);
  __Pyx_GIVEREF(__pyx_n_u_unicode_set);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 113, __pyx_n_u_unicode_set)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_conditionAsParseAction);
  __Pyx_GIVEREF(__pyx_n_u_conditionAsParseAction);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 114, __pyx_n_u_conditionAsParseAction)) __PYX_ERR(0, 166, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_re);
  __Pyx_GIVEREF(__pyx_n_u_re);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 115, __pyx_n_u_re)) __PYX_ERR(0, 166, __pyx_L1_error);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_all_2, __pyx_t_8) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":188
 *            ]
 * 
 * system_version = tuple(sys.version_info)[:3]             # <<<<<<<<<<<<<<
 * PY_3 = system_version[0] == 3
 * if PY_3:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_sys); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_version_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PySequence_Tuple(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyTuple_GetSlice(__pyx_t_8, 0, 3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_system_version, __pyx_t_2) < 0) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":189
 * 
 * system_version = tuple(sys.version_info)[:3]
 * PY_3 = system_version[0] == 3             # <<<<<<<<<<<<<<
 * if PY_3:
 *     _MAX_INT = sys.maxsize
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_system_version); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_t_8, __pyx_int_3, 3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PY_3, __pyx_t_2) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":190
 * system_version = tuple(sys.version_info)[:3]
 * PY_3 = system_version[0] == 3
 * if PY_3:             # <<<<<<<<<<<<<<
 *     _MAX_INT = sys.maxsize
 *     basestring = str
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PY_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":191
 * PY_3 = system_version[0] == 3
 * if PY_3:
 *     _MAX_INT = sys.maxsize             # <<<<<<<<<<<<<<
 *     basestring = str
 *     unichr = chr
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_maxsize); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_MAX_INT, __pyx_t_8) < 0) __PYX_ERR(0, 191, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":192
 * if PY_3:
 *     _MAX_INT = sys.maxsize
 *     basestring = str             # <<<<<<<<<<<<<<
 *     unichr = chr
 *     unicode = str
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_basestring, __pyx_t_8) < 0) __PYX_ERR(0, 192, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":193
 *     _MAX_INT = sys.maxsize
 *     basestring = str
 *     unichr = chr             # <<<<<<<<<<<<<<
 *     unicode = str
 *     _ustr = str
 */
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_unichr, __pyx_builtin_chr) < 0) __PYX_ERR(0, 193, __pyx_L1_error)

    /* "cPyparsing.pyx":194
 *     basestring = str
 *     unichr = chr
 *     unicode = str             # <<<<<<<<<<<<<<
 *     _ustr = str
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_unicode, __pyx_t_8) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":195
 *     unichr = chr
 *     unicode = str
 *     _ustr = str             # <<<<<<<<<<<<<<
 * 
 *     # build list of single arg builtins, that can be used as parse actions
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_ustr, __pyx_t_8) < 0) __PYX_ERR(0, 195, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":198
 * 
 *     # build list of single arg builtins, that can be used as parse actions
 *     singleArgBuiltins = [sum, len, sorted, reversed, list, tuple, set, any, all, min, max]             # <<<<<<<<<<<<<<
 * 
 * else:
 */
    __pyx_t_8 = __Pyx_GetBuiltinName(__pyx_n_s_len_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = PyList_New(11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_builtin_sum);
    __Pyx_GIVEREF(__pyx_builtin_sum);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_builtin_sum)) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_t_8)) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_sorted);
    __Pyx_GIVEREF(__pyx_builtin_sorted);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_builtin_sorted)) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_reversed);
    __Pyx_GIVEREF(__pyx_builtin_reversed);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_builtin_reversed)) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_INCREF((PyObject *)(&PyList_Type));
    __Pyx_GIVEREF((PyObject *)(&PyList_Type));
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, ((PyObject *)(&PyList_Type)))) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_INCREF((PyObject *)(&PyTuple_Type));
    __Pyx_GIVEREF((PyObject *)(&PyTuple_Type));
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, ((PyObject *)(&PyTuple_Type)))) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_INCREF((PyObject *)(&PySet_Type));
    __Pyx_GIVEREF((PyObject *)(&PySet_Type));
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 6, ((PyObject *)(&PySet_Type)))) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_any);
    __Pyx_GIVEREF(__pyx_builtin_any);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 7, __pyx_builtin_any)) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_all);
    __Pyx_GIVEREF(__pyx_builtin_all);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 8, __pyx_builtin_all)) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_min);
    __Pyx_GIVEREF(__pyx_builtin_min);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 9, __pyx_builtin_min)) __PYX_ERR(0, 198, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_max);
    __Pyx_GIVEREF(__pyx_builtin_max);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 10, __pyx_builtin_max)) __PYX_ERR(0, 198, __pyx_L1_error);
    __pyx_t_8 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_singleArgBuiltins, __pyx_t_2) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":190
 * system_version = tuple(sys.version_info)[:3]
 * PY_3 = system_version[0] == 3
 * if PY_3:             # <<<<<<<<<<<<<<
 *     _MAX_INT = sys.maxsize
 *     basestring = str
 */
    goto __pyx_L63;
  }

  /* "cPyparsing.pyx":201
 * 
 * else:
 *     _MAX_INT = sys.maxint             # <<<<<<<<<<<<<<
 *     range = xrange
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_maxint); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_MAX_INT, __pyx_t_8) < 0) __PYX_ERR(0, 201, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":202
 * else:
 *     _MAX_INT = sys.maxint
 *     range = xrange             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] repr logic
 */
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_range, __pyx_builtin_xrange) < 0) __PYX_ERR(0, 202, __pyx_L1_error)

    /* "cPyparsing.pyx":205
 * 
 *     # [CPYPARSING] repr logic
 *     def repr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, unicode):
 *             return py_repr(obj).lstrip("u")
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_3repr, 0, __pyx_n_s_repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__173)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_repr, __pyx_t_8) < 0) __PYX_ERR(0, 205, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":212
 * 
 *     # [CPYPARSING] _ustr logic
 *     str = unicode             # <<<<<<<<<<<<<<
 *     def _ustr(obj):
 *         if isinstance(obj, py_str):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_str, __pyx_t_8) < 0) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":213
 *     # [CPYPARSING] _ustr logic
 *     str = unicode
 *     def _ustr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5_ustr, 0, __pyx_n_s_ustr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__174)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_ustr, __pyx_t_8) < 0) __PYX_ERR(0, 213, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":219
 * 
 *     # build list of single arg builtins, tolerant of Python version, that can be used as parse actions
 *     singleArgBuiltins = []             # <<<<<<<<<<<<<<
 *     import __builtin__
 * 
 */
    __pyx_t_8 = PyList_New(0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_singleArgBuiltins, __pyx_t_8) < 0) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":220
 *     # build list of single arg builtins, tolerant of Python version, that can be used as parse actions
 *     singleArgBuiltins = []
 *     import __builtin__             # <<<<<<<<<<<<<<
 * 
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 */
    __pyx_t_8 = __Pyx_ImportDottedModule(__pyx_n_s_builtin, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_builtin, __pyx_t_8) < 0) __PYX_ERR(0, 220, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":222
 *     import __builtin__
 * 
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():             # <<<<<<<<<<<<<<
 *         try:
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 */
    __pyx_t_8 = PyUnicode_Split(__pyx_kp_u_sum_len_sorted_reversed_list_tup, ((PyObject *)NULL), -1L); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __pyx_t_8; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 222, __pyx_L1_error)
        #endif
        if (__pyx_t_15 >= __pyx_temp) break;
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_8 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_15); __Pyx_INCREF(__pyx_t_8); __pyx_t_15++; if (unlikely((0 < 0))) __PYX_ERR(0, 222, __pyx_L1_error)
      #else
      __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_15); __pyx_t_15++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      #endif
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_fname, __pyx_t_8) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":223
 * 
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 *         try:             # <<<<<<<<<<<<<<
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_1);
        /*try:*/ {

          /* "cPyparsing.pyx":224
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 *         try:
 *             singleArgBuiltins.append(getattr(__builtin__, fname))             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             continue
 */
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_singleArgBuiltins); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 224, __pyx_L66_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_builtin); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 224, __pyx_L66_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_fname); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 224, __pyx_L66_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_9 = __Pyx_GetAttr(__pyx_t_3, __pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 224, __pyx_L66_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_18 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_9); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 224, __pyx_L66_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":223
 * 
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 *         try:             # <<<<<<<<<<<<<<
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:
 */
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L73_try_end;
        __pyx_L66_error:;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "cPyparsing.pyx":225
 *         try:
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             continue
 * 
 */
        __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
        if (__pyx_t_7) {
          __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_8, &__pyx_t_14) < 0) __PYX_ERR(0, 225, __pyx_L68_except_error)
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_14);

          /* "cPyparsing.pyx":226
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:
 *             continue             # <<<<<<<<<<<<<<
 * 
 * # [CPYPARSING] custom list_str
 */
          goto __pyx_L74_except_continue;
          __pyx_L74_except_continue:;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          goto __pyx_L72_try_continue;
        }
        goto __pyx_L68_except_error;

        /* "cPyparsing.pyx":223
 * 
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 *         try:             # <<<<<<<<<<<<<<
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:
 */
        __pyx_L68_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_1);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_1);
        goto __pyx_L1_error;
        __pyx_L72_try_continue:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_1);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_1);
        goto __pyx_L64_continue;
        __pyx_L73_try_end:;
      }

      /* "cPyparsing.pyx":222
 *     import __builtin__
 * 
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():             # <<<<<<<<<<<<<<
 *         try:
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 */
      __pyx_L64_continue:;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L63:;

  /* "cPyparsing.pyx":229
 * 
 * # [CPYPARSING] custom list_str
 * def list_str(l):             # <<<<<<<<<<<<<<
 *     return "[" + ", ".join(repr(x) for x in l) + "]"
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7list_str, 0, __pyx_n_s_list_str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__176)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_list_str, __pyx_t_2) < 0) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":232
 *     return "[" + ", ".join(repr(x) for x in l) + "]"
 * 
 * _generatorType = type((y for y in range(1)))             # <<<<<<<<<<<<<<
 * 
 * def _xml_escape(data):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_range); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__177, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_pf_10cPyparsing_78genexpr(NULL, __pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_generatorType, ((PyObject *)Py_TYPE(__pyx_t_2))) < 0) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":234
 * _generatorType = type((y for y in range(1)))
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9_xml_escape, 0, __pyx_n_s_xml_escape, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__179)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_xml_escape, __pyx_t_2) < 0) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":244
 *     return data
 * 
 * alphas = string.ascii_uppercase + string.ascii_lowercase             # <<<<<<<<<<<<<<
 * nums = "0123456789"
 * hexnums = nums + "ABCDEFabcdef"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_string); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ascii_uppercase); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_string); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ascii_lowercase); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_14, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_alphas, __pyx_t_2) < 0) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":245
 * 
 * alphas = string.ascii_uppercase + string.ascii_lowercase
 * nums = "0123456789"             # <<<<<<<<<<<<<<
 * hexnums = nums + "ABCDEFabcdef"
 * alphanums = alphas + nums
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_nums, __pyx_kp_u_0123456789) < 0) __PYX_ERR(0, 245, __pyx_L1_error)

  /* "cPyparsing.pyx":246
 * alphas = string.ascii_uppercase + string.ascii_lowercase
 * nums = "0123456789"
 * hexnums = nums + "ABCDEFabcdef"             # <<<<<<<<<<<<<<
 * alphanums = alphas + nums
 * _bslash = chr(92)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_nums); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = PyNumber_Add(__pyx_t_2, __pyx_n_u_ABCDEFabcdef); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_hexnums, __pyx_t_8) < 0) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":247
 * nums = "0123456789"
 * hexnums = nums + "ABCDEFabcdef"
 * alphanums = alphas + nums             # <<<<<<<<<<<<<<
 * _bslash = chr(92)
 * printables = "".join(c for c in string.printable if c not in string.whitespace)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_alphas); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_nums); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_14 = PyNumber_Add(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_alphanums, __pyx_t_14) < 0) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":248
 * hexnums = nums + "ABCDEFabcdef"
 * alphanums = alphas + nums
 * _bslash = chr(92)             # <<<<<<<<<<<<<<
 * printables = "".join(c for c in string.printable if c not in string.whitespace)
 * 
 */
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_builtin_chr, __pyx_tuple__180, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_bslash, __pyx_t_14) < 0) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":249
 * alphanums = alphas + nums
 * _bslash = chr(92)
 * printables = "".join(c for c in string.printable if c not in string.whitespace)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_string); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_printable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __pyx_pf_10cPyparsing_81genexpr(NULL, __pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyUnicode_Join(__pyx_kp_u__10, __pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_printables, __pyx_t_14) < 0) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":252
 * 
 * 
 * def conditionAsParseAction(fn, message=None, fatal=False):             # <<<<<<<<<<<<<<
 *     msg = message if message is not None else "failed user-defined condition"
 *     exc_type = ParseFatalException if fatal else ParseException
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11conditionAsParseAction, 0, __pyx_n_s_conditionAsParseAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__182)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__183);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_conditionAsParseAction, __pyx_t_14) < 0) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":264
 *     return pa
 * 
 * class ParseBaseException(Exception):             # <<<<<<<<<<<<<<
 *     """base exception class for all parsing runtime exceptions"""
 *     # [CPYPARSING] add slots
 */
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_INCREF((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0]));
  __Pyx_GIVEREF((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0]));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, ((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])))) __PYX_ERR(0, 264, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_8, __pyx_t_2, __pyx_n_s_ParseBaseException, __pyx_n_s_ParseBaseException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_base_exception_class_for_all_par); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_2 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 264, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":267
 *     """base exception class for all parsing runtime exceptions"""
 *     # [CPYPARSING] add slots
 *     __slots__ = ("loc", "msg", "pstr", "parserElement", "args")             # <<<<<<<<<<<<<<
 * 
 *     # Performance tuning: we construct a *lot* of these, so keep this
 */
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_slots, __pyx_tuple__184) < 0) __PYX_ERR(0, 267, __pyx_L1_error)

  /* "cPyparsing.pyx":271
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):             # <<<<<<<<<<<<<<
 *         self.loc = loc
 *         if msg is None:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18ParseBaseException_1__init__, 0, __pyx_n_s_ParseBaseException___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__186)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__187);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":282
 *         self.args = (pstr, loc, msg)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_exception(cls, pe):
 *         """
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18ParseBaseException_3_from_exception, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_ParseBaseException__from_excepti, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__189)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_3 = __Pyx_Method_ClassMethod(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_from_exception, __pyx_t_3) < 0) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":290
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)
 * 
 *     def __getattr__(self, aname):             # <<<<<<<<<<<<<<
 *         """supported attributes by name are:
 *            - lineno - returns the line number of the exception text
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18ParseBaseException_5__getattr__, 0, __pyx_n_s_ParseBaseException___getattr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__191)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_getattr, __pyx_t_3) < 0) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":305
 *             raise AttributeError(aname)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if self.pstr:
 *             if self.loc >= len(self.pstr):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18ParseBaseException_7__str__, 0, __pyx_n_s_ParseBaseException___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__193)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_3) < 0) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":315
 *         return ("%s%s  (at char %d), (line:%d, col:%d)" %
 *                    (self.msg, foundstr, self.loc, self.lineno, self.column))
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 *     def markInputline(self, markerString=">!<"):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18ParseBaseException_9__repr__, 0, __pyx_n_s_ParseBaseException___repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__195)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_repr_2, __pyx_t_3) < 0) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":317
 *     def __repr__(self):
 *         return _ustr(self)
 *     def markInputline(self, markerString=">!<"):             # <<<<<<<<<<<<<<
 *         """Extracts the exception line from the input string, and marks
 *            the location of the exception with a special symbol.
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18ParseBaseException_11markInputline, 0, __pyx_n_s_ParseBaseException_markInputline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__197)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__198);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_markInputline, __pyx_t_3) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":327
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return "lineno col line".split() + dir(type(self))
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18ParseBaseException_13__dir__, 0, __pyx_n_s_ParseBaseException___dir, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__199)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_dir, __pyx_t_3) < 0) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":264
 *     return pa
 * 
 * class ParseBaseException(Exception):             # <<<<<<<<<<<<<<
 *     """base exception class for all parsing runtime exceptions"""
 *     # [CPYPARSING] add slots
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(__pyx_t_8, __pyx_n_s_ParseBaseException, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseBaseException, __pyx_t_3) < 0) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":330
 *         return "lineno col line".split() + dir(type(self))
 * 
 * class ParseException(ParseBaseException):             # <<<<<<<<<<<<<<
 *     """
 *     Exception thrown when parse expressions don't match class;
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2)) __PYX_ERR(0, 330, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_2, __pyx_n_s_ParseException, __pyx_n_s_ParseException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Exception_thrown_when_parse_exp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__pyx_t_2 != __pyx_t_8) {
    if (unlikely((PyDict_SetItemString(__pyx_t_3, "__orig_bases__", __pyx_t_8) < 0))) __PYX_ERR(0, 330, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":353
 *     """
 *     # [CPYPARSING] add slots
 *     __slots__ = ()             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_slots, __pyx_empty_tuple) < 0) __PYX_ERR(0, 353, __pyx_L1_error)

  /* "cPyparsing.pyx":355
 *     __slots__ = ()
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def explain(exc, depth=16):
 *         """
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_14ParseException_1explain, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParseException_explain, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__201)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__202);
  __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_8); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_explain, __pyx_t_14) < 0) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":330
 *         return "lineno col line".split() + dir(type(self))
 * 
 * class ParseException(ParseBaseException):             # <<<<<<<<<<<<<<
 *     """
 *     Exception thrown when parse expressions don't match class;
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_ParseException, __pyx_t_2, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseException, __pyx_t_14) < 0) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":425
 * 
 * 
 * class ParseFatalException(ParseBaseException):             # <<<<<<<<<<<<<<
 *     """user-throwable exception thrown when inconsistent parse content
 *        is found; stops all parsing immediately"""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_2)) __PYX_ERR(0, 425, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_2, __pyx_n_s_ParseFatalException, __pyx_n_s_ParseFatalException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_user_throwable_exception_thrown); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_2 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 425, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":429
 *        is found; stops all parsing immediately"""
 *     # [CPYPARSING] add slots
 *     __slots__ = ()             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_slots, __pyx_empty_tuple) < 0) __PYX_ERR(0, 429, __pyx_L1_error)

  /* "cPyparsing.pyx":425
 * 
 * 
 * class ParseFatalException(ParseBaseException):             # <<<<<<<<<<<<<<
 *     """user-throwable exception thrown when inconsistent parse content
 *        is found; stops all parsing immediately"""
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_ParseFatalException, __pyx_t_2, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseFatalException, __pyx_t_9) < 0) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":432
 *     pass
 * 
 * class ParseSyntaxException(ParseFatalException):             # <<<<<<<<<<<<<<
 *     """just like :class:`ParseFatalException`, but thrown internally
 *     when an :class:`ErrorStop<And._ErrorStop>` ('-' operator) indicates
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ParseFatalException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_2, __pyx_n_s_ParseSyntaxException, __pyx_n_s_ParseSyntaxException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_just_like_class_ParseFatalExcept); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_2 != __pyx_t_3) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_3) < 0))) __PYX_ERR(0, 432, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":439
 *     """
 *     # [CPYPARSING] add slots
 *     __slots__ = ()             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_slots, __pyx_empty_tuple) < 0) __PYX_ERR(0, 439, __pyx_L1_error)

  /* "cPyparsing.pyx":432
 *     pass
 * 
 * class ParseSyntaxException(ParseFatalException):             # <<<<<<<<<<<<<<
 *     """just like :class:`ParseFatalException`, but thrown internally
 *     when an :class:`ErrorStop<And._ErrorStop>` ('-' operator) indicates
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_ParseSyntaxException, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseSyntaxException, __pyx_t_3) < 0) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":455
 *         #~ self.reparseLoc = restartLoc
 * 
 * class RecursiveGrammarException(Exception):             # <<<<<<<<<<<<<<
 *     """exception thrown by :class:`ParserElement.validate` if the
 *     grammar could be improperly recursive
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0]));
  __Pyx_GIVEREF((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0]));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])))) __PYX_ERR(0, 455, __pyx_L1_error);
  __pyx_t_14 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_14, __pyx_n_s_RecursiveGrammarException, __pyx_n_s_RecursiveGrammarException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_exception_thrown_by_class_Parser); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__pyx_t_14 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_3, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 455, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":459
 *     grammar could be improperly recursive
 *     """
 *     def __init__(self, parseElementList):             # <<<<<<<<<<<<<<
 *         self.parseElementTrace = parseElementList
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_25RecursiveGrammarException_1__init__, 0, __pyx_n_s_RecursiveGrammarException___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__204)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":462
 *         self.parseElementTrace = parseElementList
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_25RecursiveGrammarException_3__str__, 0, __pyx_n_s_RecursiveGrammarException___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__205)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_str_2, __pyx_t_2) < 0) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":455
 *         #~ self.reparseLoc = restartLoc
 * 
 * class RecursiveGrammarException(Exception):             # <<<<<<<<<<<<<<
 *     """exception thrown by :class:`ParserElement.validate` if the
 *     grammar could be improperly recursive
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_RecursiveGrammarException, __pyx_t_14, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_RecursiveGrammarException, __pyx_t_2) < 0) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":503
 * 
 * 
 * class _ParseResultsWithOffset(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)
 */
  __pyx_t_14 = __Pyx_PEP560_update_bases(__pyx_tuple__207); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_14, __pyx_n_s_ParseResultsWithOffset, __pyx_n_s_ParseResultsWithOffset, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__pyx_t_14 != __pyx_tuple__207) {
    if (unlikely((PyDict_SetItemString(__pyx_t_3, "__orig_bases__", __pyx_tuple__207) < 0))) __PYX_ERR(0, 503, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":504
 * 
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):             # <<<<<<<<<<<<<<
 *         self.tup = (p1, p2)
 *     def __getitem__(self, i):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_1__init__, 0, __pyx_n_s_ParseResultsWithOffset___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__209)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":506
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.tup[i]
 *     def __repr__(self):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_3__getitem__, 0, __pyx_n_s_ParseResultsWithOffset___getite, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__211)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_getitem, __pyx_t_2) < 0) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":508
 *     def __getitem__(self, i):
 *         return self.tup[i]
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.tup[0])
 *     def setOffset(self, i):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_5__repr__, 0, __pyx_n_s_ParseResultsWithOffset___repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__212)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_repr_2, __pyx_t_2) < 0) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":510
 *     def __repr__(self):
 *         return repr(self.tup[0])
 *     def setOffset(self, i):             # <<<<<<<<<<<<<<
 *         self.tup = (self.tup[0], i)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_7setOffset, 0, __pyx_n_s_ParseResultsWithOffset_setOffse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__213)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_setOffset, __pyx_t_2) < 0) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":503
 * 
 * 
 * class _ParseResultsWithOffset(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_ParseResultsWithOffset, __pyx_t_14, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseResultsWithOffset, __pyx_t_2) < 0) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":513
 *         self.tup = (self.tup[0], i)
 * 
 * class ParseResults(object):             # <<<<<<<<<<<<<<
 *     """Structured parse results, to provide multiple means of access to
 *     the parsed data:
 */
  __pyx_t_14 = __Pyx_PEP560_update_bases(__pyx_tuple__215); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_14, __pyx_n_s_ParseResults, __pyx_n_s_ParseResults, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Structured_parse_results_to_prov); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__pyx_t_14 != __pyx_tuple__215) {
    if (unlikely((PyDict_SetItemString(__pyx_t_3, "__orig_bases__", __pyx_tuple__215) < 0))) __PYX_ERR(0, 513, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":556
 *         - year: 1999
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):             # <<<<<<<<<<<<<<
 *         if isinstance(toklist, cls):
 *             return toklist
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_1__new__, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParseResults___new, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__217)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__218);
  if (__Pyx_SetNewInClass(__pyx_t_3, __pyx_n_s_new, __pyx_t_2) < 0) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":565
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if self.__doinit:
 *             self.__doinit = False
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_3__init__, 0, __pyx_n_s_ParseResults___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__220)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults), 1)) __PYX_ERR(0, 565, __pyx_L1_error)
  __pyx_t_8 = __Pyx_GetBuiltinName(__pyx_n_s_isinstance); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_t_2)->__pyx_arg_isinstance = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_10cPyparsing_89__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":604
 *                         self[name] = toklist
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_5__getitem__, 0, __pyx_n_s_ParseResults___getitem, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__222)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_getitem, __pyx_t_2) < 0) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":613
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_7__setitem__, 0, __pyx_n_s_ParseResults___setitem, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__224)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults1), 1)) __PYX_ERR(0, 613, __pyx_L1_error)
  __pyx_t_8 = __Pyx_GetBuiltinName(__pyx_n_s_isinstance); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_t_2)->__pyx_arg_isinstance = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_10cPyparsing_91__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_setitem, __pyx_t_2) < 0) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":626
 *             sub.__parent = wkref(self)
 * 
 *     def __delitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_9__delitem__, 0, __pyx_n_s_ParseResults___delitem, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__226)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_delitem, __pyx_t_2) < 0) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":647
 *             del self.__tokdict[i]
 * 
 *     def __contains__(self, k):             # <<<<<<<<<<<<<<
 *         return k in self.__tokdict
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_11__contains__, 0, __pyx_n_s_ParseResults___contains, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__228)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_contains, __pyx_t_2) < 0) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":650
 *         return k in self.__tokdict
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return len(self.__toklist)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_13__len__, 0, __pyx_n_s_ParseResults___len, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__229)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_len_3, __pyx_t_2) < 0) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":653
 *         return len(self.__toklist)
 * 
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return (not not self.__toklist)
 *     __nonzero__ = __bool__
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_15__bool__, 0, __pyx_n_s_ParseResults___bool, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__230)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_bool, __pyx_t_2) < 0) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":655
 *     def __bool__(self):
 *         return (not not self.__toklist)
 *     __nonzero__ = __bool__             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  __pyx_t_2 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_bool);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_bool);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_nonzero, __pyx_t_2) < 0) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":657
 *     __nonzero__ = __bool__
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return iter(self.__toklist)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_17__iter__, 0, __pyx_n_s_ParseResults___iter, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__231)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_iter, __pyx_t_2) < 0) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":660
 *         return iter(self.__toklist)
 * 
 *     def __reversed__(self):             # <<<<<<<<<<<<<<
 *         return iter(self.__toklist[::-1])
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_19__reversed__, 0, __pyx_n_s_ParseResults___reversed, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__232)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_reversed_2, __pyx_t_2) < 0) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":663
 *         return iter(self.__toklist[::-1])
 * 
 *     def _iterkeys(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_21_iterkeys, 0, __pyx_n_s_ParseResults__iterkeys, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__233)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_iterkeys_2, __pyx_t_2) < 0) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":669
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_23_itervalues, 0, __pyx_n_s_ParseResults__itervalues, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__235)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_itervalues_2, __pyx_t_2) < 0) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":672
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_25_iteritems, 0, __pyx_n_s_ParseResults__iteritems, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__236)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_iteritems_2, __pyx_t_2) < 0) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":675
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 *     if PY_3:             # <<<<<<<<<<<<<<
 *         keys = _iterkeys
 *         """Returns an iterator of all named result keys."""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PY_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":676
 * 
 *     if PY_3:
 *         keys = _iterkeys             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result keys."""
 * 
 */
    __pyx_t_2 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_iterkeys_2);
    if (unlikely(!__pyx_t_2)) {
      PyErr_Clear();
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_iterkeys_2);
    }
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_keys, __pyx_t_2) < 0) __PYX_ERR(0, 676, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":679
 *         """Returns an iterator of all named result keys."""
 * 
 *         values = _itervalues             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result values."""
 * 
 */
    __pyx_t_2 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_itervalues_2);
    if (unlikely(!__pyx_t_2)) {
      PyErr_Clear();
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_itervalues_2);
    }
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_values, __pyx_t_2) < 0) __PYX_ERR(0, 679, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":682
 *         """Returns an iterator of all named result values."""
 * 
 *         items = _iteritems             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result key-value tuples."""
 * 
 */
    __pyx_t_2 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_iteritems_2);
    if (unlikely(!__pyx_t_2)) {
      PyErr_Clear();
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_iteritems_2);
    }
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_items, __pyx_t_2) < 0) __PYX_ERR(0, 682, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":675
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 *     if PY_3:             # <<<<<<<<<<<<<<
 *         keys = _iterkeys
 *         """Returns an iterator of all named result keys."""
 */
    goto __pyx_L77;
  }

  /* "cPyparsing.pyx":686
 * 
 *     else:
 *         iterkeys = _iterkeys             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result keys (Python 2.x only)."""
 * 
 */
  /*else*/ {
    __pyx_t_2 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_iterkeys_2);
    if (unlikely(!__pyx_t_2)) {
      PyErr_Clear();
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_iterkeys_2);
    }
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_iterkeys, __pyx_t_2) < 0) __PYX_ERR(0, 686, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":689
 *         """Returns an iterator of all named result keys (Python 2.x only)."""
 * 
 *         itervalues = _itervalues             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result values (Python 2.x only)."""
 * 
 */
    __pyx_t_2 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_itervalues_2);
    if (unlikely(!__pyx_t_2)) {
      PyErr_Clear();
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_itervalues_2);
    }
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 689, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_itervalues, __pyx_t_2) < 0) __PYX_ERR(0, 689, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":692
 *         """Returns an iterator of all named result values (Python 2.x only)."""
 * 
 *         iteritems = _iteritems             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 */
    __pyx_t_2 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_iteritems_2);
    if (unlikely(!__pyx_t_2)) {
      PyErr_Clear();
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_iteritems_2);
    }
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_iteritems, __pyx_t_2) < 0) __PYX_ERR(0, 692, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":695
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 *         def keys(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())
 */
    __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_27keys, 0, __pyx_n_s_ParseResults_keys, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__237)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_keys, __pyx_t_2) < 0) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":699
 *             return list(self.iterkeys())
 * 
 *         def values(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())
 */
    __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_29values, 0, __pyx_n_s_ParseResults_values, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__238)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_values, __pyx_t_2) < 0) __PYX_ERR(0, 699, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":703
 *             return list(self.itervalues())
 * 
 *         def items(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())
 */
    __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_31items, 0, __pyx_n_s_ParseResults_items, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__239)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_items, __pyx_t_2) < 0) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L77:;

  /* "cPyparsing.pyx":707
 *             return list(self.iteritems())
 * 
 *     def haskeys(self):             # <<<<<<<<<<<<<<
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_33haskeys, 0, __pyx_n_s_ParseResults_haskeys, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__240)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_haskeys, __pyx_t_2) < 0) __PYX_ERR(0, 707, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":712
 *         return bool(self.__tokdict)
 * 
 *     def pop(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Removes and returns item at specified index (default= ``last``).
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_35pop, 0, __pyx_n_s_ParseResults_pop, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__242)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_pop, __pyx_t_2) < 0) __PYX_ERR(0, 712, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":767
 *             return defaultvalue
 * 
 *     def get(self, key, defaultValue=None):             # <<<<<<<<<<<<<<
 *         """
 *         Returns named result matching the given key, or if there is no
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_37get, 0, __pyx_n_s_ParseResults_get, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__244)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_get, __pyx_t_2) < 0) __PYX_ERR(0, 767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":790
 *             return defaultValue
 * 
 *     def insert(self, index, insStr):             # <<<<<<<<<<<<<<
 *         """
 *         Inserts new element at location index in the list of parsed tokens.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_39insert, 0, __pyx_n_s_ParseResults_insert, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__246)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_insert, __pyx_t_2) < 0) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":811
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         Add single element to end of ParseResults list of elements.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_41append, 0, __pyx_n_s_ParseResults_append, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__248)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_append, __pyx_t_2) < 0) __PYX_ERR(0, 811, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":826
 *         self.__toklist.append(item)
 * 
 *     def extend(self, itemseq):             # <<<<<<<<<<<<<<
 *         """
 *         Add sequence of elements to end of ParseResults list of elements.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_43extend, 0, __pyx_n_s_ParseResults_extend, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__250)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_extend, __pyx_t_2) < 0) __PYX_ERR(0, 826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":845
 *             self.__toklist.extend(itemseq)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         """
 *         Clear all elements and results names.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_45clear, 0, __pyx_n_s_ParseResults_clear, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__251)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_clear, __pyx_t_2) < 0) __PYX_ERR(0, 845, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":852
 *         self.__tokdict.clear()
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_47__getattr__, 0, __pyx_n_s_ParseResults___getattr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__253)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_getattr, __pyx_t_2) < 0) __PYX_ERR(0, 852, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":858
 *             return ""
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         ret = self.copy()
 *         ret += other
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_49__add__, 0, __pyx_n_s_ParseResults___add, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__255)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_add, __pyx_t_2) < 0) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":863
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_51__iadd__, 0, __pyx_n_s_ParseResults___iadd, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__257)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_iadd, __pyx_t_2) < 0) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":879
 *         return self
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_53__radd__, 0, __pyx_n_s_ParseResults___radd, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__259)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_radd, __pyx_t_2) < 0) __PYX_ERR(0, 879, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":887
 *             return other + self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_55__repr__, 0, __pyx_n_s_ParseResults___repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__260)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_repr_2, __pyx_t_2) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":890
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_57__str__, 0, __pyx_n_s_ParseResults___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__261)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_str_2, __pyx_t_2) < 0) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":893
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 *     def _asStringList(self, sep=''):             # <<<<<<<<<<<<<<
 *         out = []
 *         for item in self.__toklist:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_59_asStringList, 0, __pyx_n_s_ParseResults__asStringList, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__263)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__264);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_asStringList, __pyx_t_2) < 0) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":904
 *         return out
 * 
 *     def asList(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the parse results as a nested list of matching tokens, all converted to strings.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_61asList, 0, __pyx_n_s_ParseResults_asList, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__266)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_asList, __pyx_t_2) < 0) __PYX_ERR(0, 904, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":921
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_63asDict, 0, __pyx_n_s_ParseResults_asDict, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__268)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_asDict, __pyx_t_2) < 0) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":957
 *         return dict((k, toItem(v)) for k, v in item_fn())
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a new copy of a :class:`ParseResults` object.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_65copy, 0, __pyx_n_s_ParseResults_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__270)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_copy, __pyx_t_2) < 0) __PYX_ERR(0, 957, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":969
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_67asXML, 0, __pyx_n_s_ParseResults_asXML, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__272)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__273);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_asXML, __pyx_t_2) < 0) __PYX_ERR(0, 969, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1030
 *         return "".join(out)
 * 
 *     def __lookup(self, sub):             # <<<<<<<<<<<<<<
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_69__lookup, 0, __pyx_n_s_ParseResults___lookup, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__275)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_ParseResults__lookup, __pyx_t_2) < 0) __PYX_ERR(0, 1030, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1037
 *         return None
 * 
 *     def getName(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Returns the results name for this token expression. Useful when several
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_71getName, 0, __pyx_n_s_ParseResults_getName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__277)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_getName, __pyx_t_2) < 0) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1077
 *             return None
 * 
 *     def dump(self, indent='', full=True, include_list=True, _depth=0):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_73dump, 0, __pyx_n_s_ParseResults_dump, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__279)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__280);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_dump, __pyx_t_2) < 0) __PYX_ERR(0, 1077, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1142
 *         return "".join(out)
 * 
 *     def pprint(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Pretty-printer for parsed results as a list, using the
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_75pprint, 0, __pyx_n_s_ParseResults_pprint, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__282)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_pprint, __pyx_t_2) < 0) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1170
 * 
 *     # add support for pickle protocol
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_77__getstate__, 0, __pyx_n_s_ParseResults___getstate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__283)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_getstate, __pyx_t_2) < 0) __PYX_ERR(0, 1170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1177
 *                  self.__name))
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.__toklist = state[0]
 *         self.__tokdict, par, inAccumNames, self.__name = state[1]
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_79__setstate__, 0, __pyx_n_s_ParseResults___setstate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__285)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_setstate, __pyx_t_2) < 0) __PYX_ERR(0, 1177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1187
 *             self.__parent = None
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_81__getnewargs__, 0, __pyx_n_s_ParseResults___getnewargs, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__286)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_getnewargs, __pyx_t_2) < 0) __PYX_ERR(0, 1187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1190
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return dir(type(self)) + list(self.keys())
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_83__dir__, 0, __pyx_n_s_ParseResults___dir, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__287)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_dir, __pyx_t_2) < 0) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1193
 *         return dir(type(self)) + list(self.keys())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_dict(cls, other, name=None):
 *         """
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12ParseResults_85from_dict, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_ParseResults_from_dict, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__289)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__57);
  __pyx_t_8 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_from_dict, __pyx_t_8) < 0) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":513
 *         self.tup = (self.tup[0], i)
 * 
 * class ParseResults(object):             # <<<<<<<<<<<<<<
 *     """Structured parse results, to provide multiple means of access to
 *     the parsed data:
 */
  __pyx_t_8 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_ParseResults, __pyx_t_14, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseResults, __pyx_t_8) < 0) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":1221
 *         return ret
 * 
 * MutableMapping.register(ParseResults)             # <<<<<<<<<<<<<<
 * 
 * def col (loc, strg):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_MutableMapping); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_register); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_ParseResults); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1223
 * MutableMapping.register(ParseResults)
 * 
 * def col (loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current column within a string, counting newlines as line separators.
 *    The first column is number 1.
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13col, 0, __pyx_n_s_col, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__291)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_col, __pyx_t_3) < 0) __PYX_ERR(0, 1223, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1237
 *     return 1 if 0 < loc < len(s) and s[loc-1] == '\n' else loc - s.rfind("\n", 0, loc)
 * 
 * def lineno(loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current line number within a string, counting newlines as line separators.
 *     The first line is number 1.
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15lineno, 0, __pyx_n_s_lineno, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__293)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_lineno, __pyx_t_3) < 0) __PYX_ERR(0, 1237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1249
 *     return strg.count("\n", 0, loc) + 1
 * 
 * def line(loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *        """
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_17line, 0, __pyx_n_s_line, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__295)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_line, __pyx_t_3) < 0) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1259
 *         return strg[lastCR + 1:]
 * 
 * def _defaultStartDebugAction(instring, loc, expr):             # <<<<<<<<<<<<<<
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_19_defaultStartDebugAction, 0, __pyx_n_s_defaultStartDebugAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__297)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_defaultStartDebugAction, __pyx_t_3) < 0) __PYX_ERR(0, 1259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1262
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):             # <<<<<<<<<<<<<<
 *     # [CPYPARSING] use custom list_str
 *     print("Matched " + _ustr(expr) + " -> " + list_str(toks.asList()))
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_21_defaultSuccessDebugAction, 0, __pyx_n_s_defaultSuccessDebugAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__299)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_defaultSuccessDebugAction, __pyx_t_3) < 0) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1266
 *     print("Matched " + _ustr(expr) + " -> " + list_str(toks.asList()))
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):             # <<<<<<<<<<<<<<
 *     print("Exception raised:" + _ustr(exc))
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23_defaultExceptionDebugAction, 0, __pyx_n_s_defaultExceptionDebugAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__301)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_defaultExceptionDebugAction, __pyx_t_3) < 0) __PYX_ERR(0, 1266, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1269
 *     print("Exception raised:" + _ustr(exc))
 * 
 * def nullDebugAction(*args):             # <<<<<<<<<<<<<<
 *     """'Do-nothing' debug action, to suppress debugging output during parsing."""
 *     pass
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_25nullDebugAction, 0, __pyx_n_s_nullDebugAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__303)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_nullDebugAction, __pyx_t_3) < 0) __PYX_ERR(0, 1269, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1296
 * # this version is Python 2.x-3.x cross-compatible
 * 'decorator to trim function calls to match the arity of the target'
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_27_trim_arity, 0, __pyx_n_s_trim_arity, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__305)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__306);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_trim_arity, __pyx_t_3) < 0) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1367
 * 
 * # [CPYPARSING] add _trim_arity.inspect_tracebacks
 * _trim_arity.inspect_tracebacks = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_trim_arity); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_3, __pyx_n_s_inspect_tracebacks, Py_False) < 0) __PYX_ERR(0, 1367, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1371
 * 
 * # [CPYPARSING] HIT, MISS are constants
 * HIT, MISS = 0, 1             # <<<<<<<<<<<<<<
 * # [CPYPARSING] TRY, MATCH, FAIL are constants
 * TRY, MATCH, FAIL = 0, 1, 2
 */
  __pyx_t_3 = __pyx_int_0;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_14 = __pyx_int_1;
  __Pyx_INCREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_HIT, __pyx_t_3) < 0) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MISS, __pyx_t_14) < 0) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":1373
 * HIT, MISS = 0, 1
 * # [CPYPARSING] TRY, MATCH, FAIL are constants
 * TRY, MATCH, FAIL = 0, 1, 2             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_14 = __pyx_int_0;
  __Pyx_INCREF(__pyx_t_14);
  __pyx_t_3 = __pyx_int_1;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_9 = __pyx_int_2;
  __Pyx_INCREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_TRY, __pyx_t_14) < 0) __PYX_ERR(0, 1373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MATCH, __pyx_t_3) < 0) __PYX_ERR(0, 1373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FAIL, __pyx_t_9) < 0) __PYX_ERR(0, 1373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":1377
 * 
 * # [CPYPARSING] caches are normal global classes
 * class _UnboundedCache(object):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         self.not_in_cache = object()
 */
  __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_tuple__308); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_9, __pyx_n_s_UnboundedCache, __pyx_n_s_UnboundedCache, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_9 != __pyx_tuple__308) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_tuple__308) < 0))) __PYX_ERR(0, 1377, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":1378
 * # [CPYPARSING] caches are normal global classes
 * class _UnboundedCache(object):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.not_in_cache = object()
 *         # [CPYPARSING] add self.cache
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15_UnboundedCache_1__init__, 0, __pyx_n_s_UnboundedCache___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__309)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_8) < 0) __PYX_ERR(0, 1378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1383
 *         self.cache = {}
 * 
 *     def get(self, key):             # <<<<<<<<<<<<<<
 *         return self.cache.get(key, self.not_in_cache)
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15_UnboundedCache_3get, 0, __pyx_n_s_UnboundedCache_get, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__311)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_get, __pyx_t_8) < 0) __PYX_ERR(0, 1383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1386
 *         return self.cache.get(key, self.not_in_cache)
 * 
 *     def set(self, key, value):             # <<<<<<<<<<<<<<
 *         self.cache[key] = value
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15_UnboundedCache_5set, 0, __pyx_n_s_UnboundedCache_set, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__313)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_set, __pyx_t_8) < 0) __PYX_ERR(0, 1386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1390
 * 
 *     # [CPYPARSING] add update
 *     def update(self, update_dict):             # <<<<<<<<<<<<<<
 *         self.cache.update(update_dict)
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15_UnboundedCache_7update, 0, __pyx_n_s_UnboundedCache_update, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__315)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_update, __pyx_t_8) < 0) __PYX_ERR(0, 1390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1393
 *         self.cache.update(update_dict)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         self.cache.clear()
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15_UnboundedCache_9clear, 0, __pyx_n_s_UnboundedCache_clear, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__316)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_clear, __pyx_t_8) < 0) __PYX_ERR(0, 1393, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1396
 *         self.cache.clear()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return len(self.cache)
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15_UnboundedCache_11__len__, 0, __pyx_n_s_UnboundedCache___len, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__317)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_len_3, __pyx_t_8) < 0) __PYX_ERR(0, 1396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1400
 * 
 *     # [CPYPARSING] add __reduce__
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         return (self.__class__, (), {"cache": self.cache})
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15_UnboundedCache_13__reduce__, 0, __pyx_n_s_UnboundedCache___reduce, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__318)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_reduce, __pyx_t_8) < 0) __PYX_ERR(0, 1400, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1377
 * 
 * # [CPYPARSING] caches are normal global classes
 * class _UnboundedCache(object):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         self.not_in_cache = object()
 */
  __pyx_t_8 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_UnboundedCache, __pyx_t_9, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UnboundedCache, __pyx_t_8) < 0) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":1403
 *         return (self.__class__, (), {"cache": self.cache})
 * 
 * if _OrderedDict is not None:             # <<<<<<<<<<<<<<
 *     class _FifoCache(object):
 *         def __init__(self, size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_4 = (__pyx_t_9 != Py_None);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":1404
 * 
 * if _OrderedDict is not None:
 *     class _FifoCache(object):             # <<<<<<<<<<<<<<
 *         def __init__(self, size):
 *             self.not_in_cache = object()
 */
    __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_tuple__320); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_9, __pyx_n_s_FifoCache, __pyx_n_s_FifoCache, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    if (__pyx_t_9 != __pyx_tuple__320) {
      if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_tuple__320) < 0))) __PYX_ERR(0, 1404, __pyx_L1_error)
    }

    /* "cPyparsing.pyx":1405
 * if _OrderedDict is not None:
 *     class _FifoCache(object):
 *         def __init__(self, size):             # <<<<<<<<<<<<<<
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_1__init__, 0, __pyx_n_s_FifoCache___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__322)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_8) < 0) __PYX_ERR(0, 1405, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1411
 *             self.cache = _OrderedDict()
 * 
 *         def get(self, key):             # <<<<<<<<<<<<<<
 *             return self.cache.get(key, self.not_in_cache)
 * 
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_3get, 0, __pyx_n_s_FifoCache_get, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__323)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_get, __pyx_t_8) < 0) __PYX_ERR(0, 1411, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1414
 *             return self.cache.get(key, self.not_in_cache)
 * 
 *         def set(self, key, value):             # <<<<<<<<<<<<<<
 *             self.cache[key] = value
 *             while len(self.cache) > self.size:
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_5set, 0, __pyx_n_s_FifoCache_set, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__324)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_set, __pyx_t_8) < 0) __PYX_ERR(0, 1414, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1423
 * 
 *         # [CPYPARSING] add update
 *         def update(self, update_dict):             # <<<<<<<<<<<<<<
 *             self.cache.update(update_dict)
 *             while len(self.cache) > self.size:
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_7update, 0, __pyx_n_s_FifoCache_update, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__325)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_update, __pyx_t_8) < 0) __PYX_ERR(0, 1423, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1431
 *                     pass
 * 
 *         def clear(self):             # <<<<<<<<<<<<<<
 *             self.cache.clear()
 * 
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_9clear, 0, __pyx_n_s_FifoCache_clear, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__326)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1431, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_clear, __pyx_t_8) < 0) __PYX_ERR(0, 1431, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1434
 *             self.cache.clear()
 * 
 *         def __len__(self):             # <<<<<<<<<<<<<<
 *             return len(self.cache)
 * 
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_11__len__, 0, __pyx_n_s_FifoCache___len, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__327)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1434, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_len_3, __pyx_t_8) < 0) __PYX_ERR(0, 1434, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1438
 * 
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):             # <<<<<<<<<<<<<<
 *             return (self.__class__, (self.size,), {"cache": self.cache})
 * 
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_13__reduce__, 0, __pyx_n_s_FifoCache___reduce, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__328)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_reduce, __pyx_t_8) < 0) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1404
 * 
 * if _OrderedDict is not None:
 *     class _FifoCache(object):             # <<<<<<<<<<<<<<
 *         def __init__(self, size):
 *             self.not_in_cache = object()
 */
    __pyx_t_8 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_FifoCache, __pyx_t_9, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_FifoCache, __pyx_t_8) < 0) __PYX_ERR(0, 1404, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":1403
 *         return (self.__class__, (), {"cache": self.cache})
 * 
 * if _OrderedDict is not None:             # <<<<<<<<<<<<<<
 *     class _FifoCache(object):
 *         def __init__(self, size):
 */
    goto __pyx_L78;
  }

  /* "cPyparsing.pyx":1442
 * 
 * else:
 *     class _FifoCache(object):             # <<<<<<<<<<<<<<
 *         def __init__(self, size):
 *             self.not_in_cache = object()
 */
  /*else*/ {
    __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_tuple__330); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_9, __pyx_n_s_FifoCache, __pyx_n_s_FifoCache, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    if (__pyx_t_9 != __pyx_tuple__330) {
      if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_tuple__330) < 0))) __PYX_ERR(0, 1442, __pyx_L1_error)
    }

    /* "cPyparsing.pyx":1443
 * else:
 *     class _FifoCache(object):
 *         def __init__(self, size):             # <<<<<<<<<<<<<<
 *             self.not_in_cache = object()
 *             # [CPYPARSING] add self.size, self.cache
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_15__init__, 0, __pyx_n_s_FifoCache___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__331)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_8) < 0) __PYX_ERR(0, 1443, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1450
 *             self.key_fifo = collections.deque([], self.size)
 * 
 *         def get(self, key):             # <<<<<<<<<<<<<<
 *             return self.cache.get(key, self.not_in_cache)
 * 
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_17get, 0, __pyx_n_s_FifoCache_get, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__332)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_get, __pyx_t_8) < 0) __PYX_ERR(0, 1450, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1453
 *             return self.cache.get(key, self.not_in_cache)
 * 
 *         def set(self, key, value):             # <<<<<<<<<<<<<<
 *             self.cache[key] = value
 *             while len(self.key_fifo) > self.size:
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_19set, 0, __pyx_n_s_FifoCache_set, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__333)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_set, __pyx_t_8) < 0) __PYX_ERR(0, 1453, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1459
 *             self.key_fifo.append(key)
 * 
 *         def clear(self):             # <<<<<<<<<<<<<<
 *             self.cache.clear()
 *             self.key_fifo.clear()
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_21clear, 0, __pyx_n_s_FifoCache_clear, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__334)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1459, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_clear, __pyx_t_8) < 0) __PYX_ERR(0, 1459, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1463
 *             self.key_fifo.clear()
 * 
 *         def __len__(self):             # <<<<<<<<<<<<<<
 *             return len(self.cache)
 * 
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_23__len__, 0, __pyx_n_s_FifoCache___len, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__335)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_len_3, __pyx_t_8) < 0) __PYX_ERR(0, 1463, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1467
 * 
 *         # [CPYPARSING] add __reduce__
 *         def __reduce__(self):             # <<<<<<<<<<<<<<
 *             return (self.__class__, (self.size,), {"cache": self.cache, "key_fifo": self.key_fifo})
 * 
 */
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_FifoCache_25__reduce__, 0, __pyx_n_s_FifoCache___reduce, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__336)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_reduce, __pyx_t_8) < 0) __PYX_ERR(0, 1467, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":1442
 * 
 * else:
 *     class _FifoCache(object):             # <<<<<<<<<<<<<<
 *         def __init__(self, size):
 *             self.not_in_cache = object()
 */
    __pyx_t_8 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_FifoCache, __pyx_t_9, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_FifoCache, __pyx_t_8) < 0) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_L78:;

  /* "cPyparsing.pyx":1471
 * 
 * 
 * class ParserElement(object):             # <<<<<<<<<<<<<<
 *     """Abstract base level parser element class."""
 *     DEFAULT_WHITE_CHARS = " \n\t\r"
 */
  __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_tuple__338); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_9, __pyx_n_s_ParserElement, __pyx_n_s_ParserElement, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_base_level_parser_eleme); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_9 != __pyx_tuple__338) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_tuple__338) < 0))) __PYX_ERR(0, 1471, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":1473
 * class ParserElement(object):
 *     """Abstract base level parser element class."""
 *     DEFAULT_WHITE_CHARS = " \n\t\r"             # <<<<<<<<<<<<<<
 *     verbose_stacktrace = False
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_DEFAULT_WHITE_CHARS, __pyx_kp_u__339) < 0) __PYX_ERR(0, 1473, __pyx_L1_error)

  /* "cPyparsing.pyx":1474
 *     """Abstract base level parser element class."""
 *     DEFAULT_WHITE_CHARS = " \n\t\r"
 *     verbose_stacktrace = False             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_verbose_stacktrace, Py_False) < 0) __PYX_ERR(0, 1474, __pyx_L1_error)

  /* "cPyparsing.pyx":1476
 *     verbose_stacktrace = False
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultWhitespaceChars(chars):
 *         r"""
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_setDefaultWhitespa, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__341)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setDefaultWhitespaceChars, __pyx_t_2) < 0) __PYX_ERR(0, 1476, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1492
 *         ParserElement.DEFAULT_WHITE_CHARS = chars
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def inlineLiteralsUsing(cls):
 *         """
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_3inlineLiteralsUsing, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_inlineLiteralsUsin, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__343)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_inlineLiteralsUsing, __pyx_t_8) < 0) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1514
 *         ParserElement._literalStringClass = cls
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _trim_traceback(cls, tb):
 *         while tb.tb_next:
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_5_trim_traceback, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_ParserElement__trim_traceback, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__345)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_trim_traceback, __pyx_t_2) < 0) __PYX_ERR(0, 1514, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1521
 * 
 *     # [CPYPARSING] add collectParseElements
 *     _all_parse_elements = None             # <<<<<<<<<<<<<<
 *     parse_element_index = None
 *     @staticmethod
 */
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_all_parse_elements, Py_None) < 0) __PYX_ERR(0, 1521, __pyx_L1_error)

  /* "cPyparsing.pyx":1522
 *     # [CPYPARSING] add collectParseElements
 *     _all_parse_elements = None
 *     parse_element_index = None             # <<<<<<<<<<<<<<
 *     @staticmethod
 *     def collectParseElements():
 */
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parse_element_index, Py_None) < 0) __PYX_ERR(0, 1522, __pyx_L1_error)

  /* "cPyparsing.pyx":1523
 *     _all_parse_elements = None
 *     parse_element_index = None
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def collectParseElements():
 *         ParserElement._all_parse_elements = []
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_7collectParseElements, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_collectParseElemen, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__346)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_collectParseElements, __pyx_t_8) < 0) __PYX_ERR(0, 1523, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1528
 *         return ParserElement._all_parse_elements
 * 
 *     def __init__(self, savelist=False):             # <<<<<<<<<<<<<<
 *         self.parseAction = list()
 *         self.failAction = None
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_9__init__, 0, __pyx_n_s_ParserElement___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__348)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_8) < 0) __PYX_ERR(0, 1528, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1555
 *             ParserElement._all_parse_elements.append(wkref(self))
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Make a copy of this :class:`ParserElement`.  Useful for defining
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_11copy, 0, __pyx_n_s_ParserElement_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__351)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_copy, __pyx_t_8) < 0) __PYX_ERR(0, 1555, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1588
 *         return cpy
 * 
 *     def setName(self, name):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for this expression, makes debugging and exception messages clearer.
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_13setName, 0, __pyx_n_s_ParserElement_setName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__352)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setName, __pyx_t_8) < 0) __PYX_ERR(0, 1588, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1603
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for referencing matching tokens as a nested attribute
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_15setResultsName, 0, __pyx_n_s_ParserElement_setResultsName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__354)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setResultsName_2, __pyx_t_8) < 0) __PYX_ERR(0, 1603, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1626
 *         return self._setResultsName(name, listAllMatches)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         newself = self.copy()
 *         if name.endswith("*"):
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_17_setResultsName, 0, __pyx_n_s_ParserElement__setResultsName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__356)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setResultsName, __pyx_t_8) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1635
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set ``breakFlag`` to True to enable, False to
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_19setBreak, 0, __pyx_n_s_ParserElement_setBreak, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__358)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setBreak, __pyx_t_8) < 0) __PYX_ERR(0, 1635, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1654
 *         return self
 * 
 *     def setParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Define one or more actions to perform when successfully matching parse element definition.
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_21setParseAction, 0, __pyx_n_s_ParserElement_setParseAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__360)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setParseAction, __pyx_t_8) < 0) __PYX_ERR(0, 1654, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1703
 *         return self
 * 
 *     def addParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Add one or more parse actions to expression's list of parse actions. See :class:`setParseAction`.
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_23addParseAction, 0, __pyx_n_s_ParserElement_addParseAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__362)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_addParseAction, __pyx_t_8) < 0) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1713
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         :class:`setParseAction` for function call signatures. Unlike ``setParseAction``,
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_25addCondition, 0, __pyx_n_s_ParserElement_addCondition, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__364)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_addCondition, __pyx_t_8) < 0) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1738
 *         return self
 * 
 *     def setFailAction(self, fn):             # <<<<<<<<<<<<<<
 *         """Define action to perform if parsing fails at this expression.
 *            Fail acton fn is a callable function that takes the arguments
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_27setFailAction, 0, __pyx_n_s_ParserElement_setFailAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__366)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setFailAction, __pyx_t_8) < 0) __PYX_ERR(0, 1738, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1770
 *     #                 exprsFound = True
 *     #     return loc
 *     def _skipIgnorables(self, instring, loc):             # <<<<<<<<<<<<<<
 *         exprsFound = True
 *         while exprsFound:
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_29_skipIgnorables, 0, __pyx_n_s_ParserElement__skipIgnorables, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__368)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_skipIgnorables, __pyx_t_8) < 0) __PYX_ERR(0, 1770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1783
 *         return loc
 * 
 *     def preParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_31preParse, 0, __pyx_n_s_ParserElement_preParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__370)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_preParse, __pyx_t_8) < 0) __PYX_ERR(0, 1783, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1795
 *         return loc
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_33parseImpl, 0, __pyx_n_s_ParserElement_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__371)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseImpl, __pyx_t_8) < 0) __PYX_ERR(0, 1795, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1798
 *         return loc, []
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return tokenlist
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_35postParse, 0, __pyx_n_s_ParserElement_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__373)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_postParse, __pyx_t_8) < 0) __PYX_ERR(0, 1798, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1899
 * 
 *     #     return loc, retTokens
 *     def _parseNoCache(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] TRY, MATCH, FAIL are constants
 *         debugging = (self.debug)  # and doActions)
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_37_parseNoCache, 0, __pyx_n_s_ParserElement__parseNoCache, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__375)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__50);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseNoCache, __pyx_t_8) < 0) __PYX_ERR(0, 1899, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2000
 *     #     else:
 *     #         return got[0]
 *     def tryParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_39tryParse, 0, __pyx_n_s_ParserElement_tryParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__377)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_tryParse, __pyx_t_8) < 0) __PYX_ERR(0, 2000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2006
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def canParseNext(self, instring, loc):             # <<<<<<<<<<<<<<
 *         try:
 *             self.tryParse(instring, loc)
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_41canParseNext, 0, __pyx_n_s_ParserElement_canParseNext, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__378)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_canParseNext, __pyx_t_8) < 0) __PYX_ERR(0, 2006, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2017
 * 
 *     # argument cache for optimizing repeated calls when backtracking through recursive expressions
 *     packrat_cache = {} # this is set later by enabledPackrat(); this is here so that resetCache() doesn't fail             # <<<<<<<<<<<<<<
 *     packrat_cache_lock = RLock()
 *     packrat_cache_stats = [0, 0]
 */
  __pyx_t_8 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_packrat_cache, __pyx_t_8) < 0) __PYX_ERR(0, 2017, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2018
 *     # argument cache for optimizing repeated calls when backtracking through recursive expressions
 *     packrat_cache = {} # this is set later by enabledPackrat(); this is here so that resetCache() doesn't fail
 *     packrat_cache_lock = RLock()             # <<<<<<<<<<<<<<
 *     packrat_cache_stats = [0, 0]
 *     # [CPYPARSING] add packrat_context
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_RLock); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_packrat_cache_lock, __pyx_t_8) < 0) __PYX_ERR(0, 2018, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2019
 *     packrat_cache = {} # this is set later by enabledPackrat(); this is here so that resetCache() doesn't fail
 *     packrat_cache_lock = RLock()
 *     packrat_cache_stats = [0, 0]             # <<<<<<<<<<<<<<
 *     # [CPYPARSING] add packrat_context
 *     packrat_context = None
 */
  __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_int_0)) __PYX_ERR(0, 2019, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 1, __pyx_int_0)) __PYX_ERR(0, 2019, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_packrat_cache_stats, __pyx_t_8) < 0) __PYX_ERR(0, 2019, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2021
 *     packrat_cache_stats = [0, 0]
 *     # [CPYPARSING] add packrat_context
 *     packrat_context = None             # <<<<<<<<<<<<<<
 * 
 *     # # [CPYPARSING] make safe
 */
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_packrat_context, Py_None) < 0) __PYX_ERR(0, 2021, __pyx_L1_error)

  /* "cPyparsing.pyx":2054
 *     #                 return value
 *     #             return value[0], value[1].copy()
 *     def _parseCache(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         # [CPYPARSING] HIT, MISS are constants
 *         # [CPYPARSING] include packrat_context, merge callPreParse and doActions
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_43_parseCache, 0, __pyx_n_s_ParserElement__parseCache, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__380)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__50);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseCache, __pyx_t_8) < 0) __PYX_ERR(0, 2054, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2169
 * 
 *     # [CPYPARSING] add _update_furthest_loc_for_regex
 *     def _update_furthest_loc_for_regex(self, instring, loc, flags=0):             # <<<<<<<<<<<<<<
 *         if ParserElement._incrementalEnabled:
 *             if flags & re.MULTILINE:
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_45_update_furthest_loc_for_regex, 0, __pyx_n_s_ParserElement__update_furthest_l, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__382)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__41);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_update_furthest_loc_for_regex, __pyx_t_8) < 0) __PYX_ERR(0, 2169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2182
 * 
 *     # [CPYPARSING] add _parseIncremental
 *     _incremental_parent_usefullness_obj = [False]  # caches at start loc can't be reused, so start usefullness at False             # <<<<<<<<<<<<<<
 *     def _parseIncremental(self, instring, loc, doActions=True, callPreParse=True):
 *         """Version of ParserElement._parseCache that can reuse caches from common prefix/suffix parses.
 */
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, Py_False)) __PYX_ERR(0, 2182, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_incremental_parent_usefullness, __pyx_t_8) < 0) __PYX_ERR(0, 2182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2183
 *     # [CPYPARSING] add _parseIncremental
 *     _incremental_parent_usefullness_obj = [False]  # caches at start loc can't be reused, so start usefullness at False
 *     def _parseIncremental(self, instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         """Version of ParserElement._parseCache that can reuse caches from common prefix/suffix parses.
 *         Note that unlike _parseCache, _parseIncremental is not thread-safe."""
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_47_parseIncremental, 0, __pyx_n_s_ParserElement__parseIncremental_2, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__384)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__50);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseIncremental, __pyx_t_8) < 0) __PYX_ERR(0, 2183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2396
 *             ParserElement._incremental_parent_usefullness_obj = outer_parent_usefullness_obj
 * 
 *     _parse = _parseNoCache             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __pyx_t_8 = PyObject_GetItem(__pyx_t_14, __pyx_n_s_parseNoCache);
  if (unlikely(!__pyx_t_8)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_parseNoCache);
  }
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parse, __pyx_t_8) < 0) __PYX_ERR(0, 2396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2398
 *     _parse = _parseNoCache
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def resetCache():
 *         # [CPYPARSING] don't reset in incremental mode
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_49resetCache, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_resetCache, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__385)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_resetCache, __pyx_t_2) < 0) __PYX_ERR(0, 2398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2411
 * 
 *     # [CPYPARSING] add enableIncremental
 *     _incrementalEnabled = False             # <<<<<<<<<<<<<<
 *     _incrementalWithResets = False
 *     @staticmethod
 */
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_incrementalEnabled, Py_False) < 0) __PYX_ERR(0, 2411, __pyx_L1_error)

  /* "cPyparsing.pyx":2412
 *     # [CPYPARSING] add enableIncremental
 *     _incrementalEnabled = False
 *     _incrementalWithResets = False             # <<<<<<<<<<<<<<
 *     @staticmethod
 *     def enableIncremental(
 */
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_incrementalWithResets, Py_False) < 0) __PYX_ERR(0, 2412, __pyx_L1_error)

  /* "cPyparsing.pyx":2413
 *     _incrementalEnabled = False
 *     _incrementalWithResets = False
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enableIncremental(
 *         cache_size_limit=None,
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_51enableIncremental, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_enableIncremental, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__387)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__388);
  __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_enableIncremental, __pyx_t_8) < 0) __PYX_ERR(0, 2413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2438
 *         ParserElement._should_cache_incremental_success = cache_successes
 * 
 *     _packratEnabled = False             # <<<<<<<<<<<<<<
 *     @staticmethod
 *     def enablePackrat(cache_size_limit=128):
 */
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_packratEnabled, Py_False) < 0) __PYX_ERR(0, 2438, __pyx_L1_error)

  /* "cPyparsing.pyx":2439
 * 
 *     _packratEnabled = False
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enablePackrat(cache_size_limit=128):
 *         """Enables "packrat" parsing, which adds memoizing to the parsing logic.
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_53enablePackrat, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_enablePackrat, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__390)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__391);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_enablePackrat, __pyx_t_2) < 0) __PYX_ERR(0, 2439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2474
 *             ParserElement._parse = ParserElement._parseCache
 * 
 *     def parseString(self, instring, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression with the given string.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_55parseString, 0, __pyx_n_s_ParserElement_parseString, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__393)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseString, __pyx_t_2) < 0) __PYX_ERR(0, 2474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2532
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_57scanString, 0, __pyx_n_s_ParserElement_scanString, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__52)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults2), 1)) __PYX_ERR(0, 2532, __pyx_L1_error)
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_t_2)->__pyx_arg_maxMatches = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_10cPyparsing_93__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_scanString, __pyx_t_2) < 0) __PYX_ERR(0, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2606
 *                 raise exc
 * 
 *     def transformString(self, instring):             # <<<<<<<<<<<<<<
 *         """
 *         Extension to :class:`scanString`, to modify matching text with modified tokens that may
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_60transformString, 0, __pyx_n_s_ParserElement_transformString, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__396)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_transformString, __pyx_t_2) < 0) __PYX_ERR(0, 2606, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2654
 *                 raise exc
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):             # <<<<<<<<<<<<<<
 *         """
 *         Another extension to :class:`scanString`, simplifying the access to the tokens found
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_62searchString, 0, __pyx_n_s_ParserElement_searchString, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__398)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults3), 1)) __PYX_ERR(0, 2654, __pyx_L1_error)
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_t_2)->__pyx_arg_maxMatches = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_10cPyparsing_95__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_searchString, __pyx_t_2) < 0) __PYX_ERR(0, 2654, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2686
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_64split, 0, __pyx_n_s_ParserElement_split, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__53)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults4), 1)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_t_2)->__pyx_arg_maxsplit = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_10cPyparsing_97__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_split, __pyx_t_2) < 0) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2711
 *         yield instring[last:]
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator - returns :class:`And`. Adding strings to a ParserElement
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_67__add__, 0, __pyx_n_s_ParserElement___add, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__400)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_add, __pyx_t_2) < 0) __PYX_ERR(0, 2711, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2749
 *         return And([self, other])
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator when left operand is not a :class:`ParserElement`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_69__radd__, 0, __pyx_n_s_ParserElement___radd, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__401)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_radd, __pyx_t_2) < 0) __PYX_ERR(0, 2749, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2764
 *         return other + self
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator, returns :class:`And` with error stop
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_71__sub__, 0, __pyx_n_s_ParserElement___sub, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__402)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_sub_2, __pyx_t_2) < 0) __PYX_ERR(0, 2764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2776
 *         return self + And._ErrorStop() + other
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator when left operand is not a :class:`ParserElement`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_73__rsub__, 0, __pyx_n_s_ParserElement___rsub, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__403)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_rsub, __pyx_t_2) < 0) __PYX_ERR(0, 2776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2788
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of ``expr * 3`` in place of
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_75__mul__, 0, __pyx_n_s_ParserElement___mul, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__405)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_mul, __pyx_t_2) < 0) __PYX_ERR(0, 2788, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2862
 *         return ret
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_77__rmul__, 0, __pyx_n_s_ParserElement___rmul, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__406)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_rmul, __pyx_t_2) < 0) __PYX_ERR(0, 2862, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2865
 *         return self.__mul__(other)
 * 
 *     def __or__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator - returns :class:`MatchFirst`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_79__or__, 0, __pyx_n_s_ParserElement___or, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__407)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_or, __pyx_t_2) < 0) __PYX_ERR(0, 2865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2880
 *         return MatchFirst([self, other])
 * 
 *     def __ror__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator when left operand is not a :class:`ParserElement`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_81__ror__, 0, __pyx_n_s_ParserElement___ror, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__408)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_ror, __pyx_t_2) < 0) __PYX_ERR(0, 2880, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2892
 *         return other | self
 * 
 *     def __xor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator - returns :class:`Or`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_83__xor__, 0, __pyx_n_s_ParserElement___xor, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__409)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_xor, __pyx_t_2) < 0) __PYX_ERR(0, 2892, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2904
 *         return Or([self, other])
 * 
 *     def __rxor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator when left operand is not a :class:`ParserElement`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_85__rxor__, 0, __pyx_n_s_ParserElement___rxor, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__410)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_rxor, __pyx_t_2) < 0) __PYX_ERR(0, 2904, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2916
 *         return other ^ self
 * 
 *     def __and__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator - returns :class:`Each`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_87__and__, 0, __pyx_n_s_ParserElement___and, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__411)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_and, __pyx_t_2) < 0) __PYX_ERR(0, 2916, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2928
 *         return Each([self, other])
 * 
 *     def __rand__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator when left operand is not a :class:`ParserElement`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_89__rand__, 0, __pyx_n_s_ParserElement___rand, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__412)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_rand, __pyx_t_2) < 0) __PYX_ERR(0, 2928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2940
 *         return other & self
 * 
 *     def __invert__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ~ operator - returns :class:`NotAny`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_91__invert__, 0, __pyx_n_s_ParserElement___invert, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__413)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_invert, __pyx_t_2) < 0) __PYX_ERR(0, 2940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2946
 *         return NotAny(self)
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         # must implement __iter__ to override legacy use of sequential access to __getitem__ to
 *         # iterate over a sequence
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_93__iter__, 0, __pyx_n_s_ParserElement___iter, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__414)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_iter, __pyx_t_2) < 0) __PYX_ERR(0, 2946, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2951
 *         raise TypeError('%r object is not iterable' % self.__class__.__name__)
 * 
 *     def __getitem__(self, key):             # <<<<<<<<<<<<<<
 *         """
 *         use ``[]`` indexing notation as a short form for expression repetition:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_95__getitem__, 0, __pyx_n_s_ParserElement___getitem, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__416)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_getitem, __pyx_t_2) < 0) __PYX_ERR(0, 2951, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2987
 *         return ret
 * 
 *     def __call__(self, name=None):             # <<<<<<<<<<<<<<
 *         """
 *         Shortcut for :class:`setResultsName`, with ``listAllMatches=False``.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_97__call__, 0, __pyx_n_s_ParserElement___call, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__417)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_call, __pyx_t_2) < 0) __PYX_ERR(0, 2987, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3007
 *             return self.copy()
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         """
 *         Suppresses the output of this :class:`ParserElement`; useful to keep punctuation from
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_99suppress, 0, __pyx_n_s_ParserElement_suppress, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__418)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_suppress, __pyx_t_2) < 0) __PYX_ERR(0, 3007, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3014
 *         return Suppress(self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """
 *         Disables the skipping of whitespace before matching the characters in the
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_101leaveWhitespace, 0, __pyx_n_s_ParserElement_leaveWhitespace, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__419)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_leaveWhitespace, __pyx_t_2) < 0) __PYX_ERR(0, 3014, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3023
 *         return self
 * 
 *     def setWhitespaceChars(self, chars):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides the default whitespace chars
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_103setWhitespaceChars, 0, __pyx_n_s_ParserElement_setWhitespaceChars, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__421)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setWhitespaceChars, __pyx_t_2) < 0) __PYX_ERR(0, 3023, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3032
 *         return self
 * 
 *     def parseWithTabs(self):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides default behavior to expand ``<TAB>``s to spaces before parsing the input string.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_105parseWithTabs, 0, __pyx_n_s_ParserElement_parseWithTabs, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__422)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseWithTabs, __pyx_t_2) < 0) __PYX_ERR(0, 3032, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3041
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Define expression to be ignored (e.g., comments) while doing pattern
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_107ignore, 0, __pyx_n_s_ParserElement_ignore, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__423)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_ignore, __pyx_t_2) < 0) __PYX_ERR(0, 3041, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3065
 *         return self
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_109setDebugActions, 0, __pyx_n_s_ParserElement_setDebugActions, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__425)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setDebugActions, __pyx_t_2) < 0) __PYX_ERR(0, 3065, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3075
 *         return self
 * 
 *     def setDebug(self, flag=True):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_111setDebug, 0, __pyx_n_s_ParserElement_setDebug, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__427)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_setDebug, __pyx_t_2) < 0) __PYX_ERR(0, 3075, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3118
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_113__str__, 0, __pyx_n_s_ParserElement___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__428)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_str_2, __pyx_t_2) < 0) __PYX_ERR(0, 3118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3121
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_115__repr__, 0, __pyx_n_s_ParserElement___repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__429)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_repr_2, __pyx_t_2) < 0) __PYX_ERR(0, 3121, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3124
 *         return _ustr(self)
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         self.streamlined = True
 *         self.strRepr = None
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_117streamline, 0, __pyx_n_s_ParserElement_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__430)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_streamline, __pyx_t_2) < 0) __PYX_ERR(0, 3124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3129
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_119checkRecursion, 0, __pyx_n_s_ParserElement_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_checkRecursion, __pyx_t_2) < 0) __PYX_ERR(0, 3129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3132
 *         pass
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         """
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_121validate, 0, __pyx_n_s_ParserElement_validate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__433)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_validate, __pyx_t_2) < 0) __PYX_ERR(0, 3132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3138
 *         self.checkRecursion([])
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on the given file or filename.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_123parseFile, 0, __pyx_n_s_ParserElement_parseFile, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__435)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseFile, __pyx_t_2) < 0) __PYX_ERR(0, 3138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3160
 *                 raise exc
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if self is other:
 *             return True
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_125__eq__, 0, __pyx_n_s_ParserElement___eq, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__436)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_eq, __pyx_t_2) < 0) __PYX_ERR(0, 3160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3169
 *         return False
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_127__ne__, 0, __pyx_n_s_ParserElement___ne, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__437)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_ne, __pyx_t_2) < 0) __PYX_ERR(0, 3169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3172
 *         return not (self == other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return id(self)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_129__hash__, 0, __pyx_n_s_ParserElement___hash, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__438)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_hash, __pyx_t_2) < 0) __PYX_ERR(0, 3172, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3175
 *         return id(self)
 * 
 *     def __req__(self, other):             # <<<<<<<<<<<<<<
 *         return self == other
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_131__req__, 0, __pyx_n_s_ParserElement___req, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__439)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_req, __pyx_t_2) < 0) __PYX_ERR(0, 3175, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3178
 *         return self == other
 * 
 *     def __rne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_133__rne__, 0, __pyx_n_s_ParserElement___rne, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__440)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_rne, __pyx_t_2) < 0) __PYX_ERR(0, 3178, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3181
 *         return not (self == other)
 * 
 *     def matches(self, testString, parseAll=True):             # <<<<<<<<<<<<<<
 *         """
 *         Method for quick testing of a parser against a test string. Good for simple
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_135matches, 0, __pyx_n_s_ParserElement_matches, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__442)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_matches, __pyx_t_2) < 0) __PYX_ERR(0, 3181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3201
 *             return False
 * 
 *     def runTests(self, tests, parseAll=True, comment='#',             # <<<<<<<<<<<<<<
 *                  fullDump=True, printResults=True, failureTests=False, postParse=None,
 *                  file=None):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_13ParserElement_137runTests, 0, __pyx_n_s_ParserElement_runTests, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__444)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__445);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_runTests, __pyx_t_2) < 0) __PYX_ERR(0, 3201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1471
 * 
 * 
 * class ParserElement(object):             # <<<<<<<<<<<<<<
 *     """Abstract base level parser element class."""
 *     DEFAULT_WHITE_CHARS = " \n\t\r"
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_ParserElement, __pyx_t_9, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParserElement, __pyx_t_2) < 0) __PYX_ERR(0, 1471, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3364
 * 
 * 
 * class _PendingSkip(ParserElement):             # <<<<<<<<<<<<<<
 *     # internal placeholder class to hold a place were '...' is added to a parser element,
 *     # once another ParserElement is added, this placeholder will be replaced with a SkipTo
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9)) __PYX_ERR(0, 3364, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_9, __pyx_n_s_PendingSkip, __pyx_n_s_PendingSkip, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_9 != __pyx_t_3) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_3) < 0))) __PYX_ERR(0, 3364, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3367
 *     # internal placeholder class to hold a place were '...' is added to a parser element,
 *     # once another ParserElement is added, this placeholder will be replaced with a SkipTo
 *     def __init__(self, expr, must_skip=False):             # <<<<<<<<<<<<<<
 *         super(_PendingSkip, self).__init__()
 *         self.strRepr = str(expr + Empty()).replace('Empty', '...')
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12_PendingSkip_1__init__, 0, __pyx_n_s_PendingSkip___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_3) < 0) __PYX_ERR(0, 3367, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3374
 *         self.must_skip = must_skip
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         skipper = SkipTo(other).setName("...")("_skipped*")
 *         if self.must_skip:
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12_PendingSkip_3__add__, 0, __pyx_n_s_PendingSkip___add, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__449)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_add, __pyx_t_3) < 0) __PYX_ERR(0, 3374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3390
 *         return self.anchor + skipper + other
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.strRepr
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12_PendingSkip_5__repr__, 0, __pyx_n_s_PendingSkip___repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__450)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_repr_2, __pyx_t_3) < 0) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3393
 *         return self.strRepr
 * 
 *     def parseImpl(self, *args):             # <<<<<<<<<<<<<<
 *         raise Exception("use of `...` expression without following SkipTo target expression")
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12_PendingSkip_7parseImpl, 0, __pyx_n_s_PendingSkip_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__452)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_3) < 0) __PYX_ERR(0, 3393, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3364
 * 
 * 
 * class _PendingSkip(ParserElement):             # <<<<<<<<<<<<<<
 *     # internal placeholder class to hold a place were '...' is added to a parser element,
 *     # once another ParserElement is added, this placeholder will be replaced with a SkipTo
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_PendingSkip, __pyx_t_9, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PendingSkip, __pyx_t_3) < 0) __PYX_ERR(0, 3364, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3397
 * 
 * 
 * class Token(ParserElement):             # <<<<<<<<<<<<<<
 *     """Abstract :class:`ParserElement` subclass, for defining atomic
 *     matching patterns.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_9)) __PYX_ERR(0, 3397, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_9, __pyx_n_s_Token, __pyx_n_s_Token, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_class_ParserElement_sub); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__pyx_t_9 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_3, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 3397, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3401
 *     matching patterns.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Token, self).__init__(savelist=False)
 * 
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Token_1__init__, 0, __pyx_n_s_Token___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__453)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 3401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3397
 * 
 * 
 * class Token(ParserElement):             # <<<<<<<<<<<<<<
 *     """Abstract :class:`ParserElement` subclass, for defining atomic
 *     matching patterns.
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Token, __pyx_t_9, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Token, __pyx_t_14) < 0) __PYX_ERR(0, 3397, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3405
 * 
 * 
 * class Empty(Token):             # <<<<<<<<<<<<<<
 *     """An empty token, will always match.
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Token); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_9)) __PYX_ERR(0, 3405, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_9, __pyx_n_s_Empty, __pyx_n_s_Empty, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_An_empty_token_will_always_match); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_9 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 3405, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3408
 *     """An empty token, will always match.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Empty_1__init__, 0, __pyx_n_s_Empty___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__454)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 3408, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3405
 * 
 * 
 * class Empty(Token):             # <<<<<<<<<<<<<<
 *     """An empty token, will always match.
 *     """
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_Empty, __pyx_t_9, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Empty, __pyx_t_2) < 0) __PYX_ERR(0, 3405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3415
 * 
 * 
 * class NoMatch(Token):             # <<<<<<<<<<<<<<
 *     """A token that will never match.
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Token); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9)) __PYX_ERR(0, 3415, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_9, __pyx_n_s_NoMatch, __pyx_n_s_NoMatch, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_A_token_that_will_never_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_9 != __pyx_t_3) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_3) < 0))) __PYX_ERR(0, 3415, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3418
 *     """A token that will never match.
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7NoMatch_1__init__, 0, __pyx_n_s_NoMatch___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__455)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_3) < 0) __PYX_ERR(0, 3418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3425
 *         self.errmsg = "Unmatchable token"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7NoMatch_3parseImpl, 0, __pyx_n_s_NoMatch_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__456)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_3) < 0) __PYX_ERR(0, 3425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3415
 * 
 * 
 * class NoMatch(Token):             # <<<<<<<<<<<<<<
 *     """A token that will never match.
 *     """
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_NoMatch, __pyx_t_9, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NoMatch, __pyx_t_3) < 0) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3429
 * 
 * 
 * class Literal(Token):             # <<<<<<<<<<<<<<
 *     """Token to exactly match a specified string.
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Token); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_9)) __PYX_ERR(0, 3429, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_9, __pyx_n_s_Literal, __pyx_n_s_Literal, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_to_exactly_match_a_specifi); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__pyx_t_9 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_3, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 3429, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3443
 *     use :class:`Keyword` or :class:`CaselessKeyword`.
 *     """
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(Literal, self).__init__()
 *         self.match = matchString
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Literal_1__init__, 0, __pyx_n_s_Literal___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__458)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 3443, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3472
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] == self.firstMatchChar and instring.startswith(self.match, loc):
 *             return loc + self.matchLen, self.match
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Literal_3parseImpl, 0, __pyx_n_s_Literal_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__459)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_parseImpl, __pyx_t_14) < 0) __PYX_ERR(0, 3472, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3429
 * 
 * 
 * class Literal(Token):             # <<<<<<<<<<<<<<
 *     """Token to exactly match a specified string.
 * 
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Literal, __pyx_t_9, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Literal, __pyx_t_14) < 0) __PYX_ERR(0, 3429, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3480
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class _SingleCharLiteral(Literal):             # <<<<<<<<<<<<<<
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] == self.firstMatchChar:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Literal); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_9)) __PYX_ERR(0, 3480, __pyx_L1_error);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_9, __pyx_n_s_SingleCharLiteral, __pyx_n_s_SingleCharLiteral, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_9 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 3480, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3481
 * 
 * class _SingleCharLiteral(Literal):
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] == self.firstMatchChar:
 *             return loc + 1, self.match
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18_SingleCharLiteral_1parseImpl, 0, __pyx_n_s_SingleCharLiteral_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__460)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 3481, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3480
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class _SingleCharLiteral(Literal):             # <<<<<<<<<<<<<<
 *     def parseImpl(self, instring, loc, doActions=True):
 *         if instring[loc] == self.firstMatchChar:
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_SingleCharLiteral, __pyx_t_9, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SingleCharLiteral, __pyx_t_2) < 0) __PYX_ERR(0, 3480, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3486
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 * _L = Literal             # <<<<<<<<<<<<<<
 * ParserElement._literalStringClass = Literal
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Literal); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_L_2, __pyx_t_9) < 0) __PYX_ERR(0, 3486, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3487
 * 
 * _L = Literal
 * ParserElement._literalStringClass = Literal             # <<<<<<<<<<<<<<
 * 
 * class Keyword(Token):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Literal); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_3, __pyx_n_s_literalStringClass, __pyx_t_9) < 0) __PYX_ERR(0, 3487, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3489
 * ParserElement._literalStringClass = Literal
 * 
 * class Keyword(Token):             # <<<<<<<<<<<<<<
 *     """Token to exactly match a specified string as a keyword, that is,
 *     it must be immediately followed by a non-keyword character.  Compare
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Token); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 3489, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_3, __pyx_n_s_Keyword, __pyx_n_s_Keyword, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_to_exactly_match_a_specifi_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 3489, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3514
 *     For case-insensitive matching, use :class:`CaselessKeyword`.
 *     """
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_alphanums); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = PyNumber_Add(__pyx_t_9, __pyx_kp_u__461); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_DEFAULT_KEYWORD_CHARS, __pyx_t_8) < 0) __PYX_ERR(0, 3514, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":3516
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):             # <<<<<<<<<<<<<<
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Keyword_1__init__, 0, __pyx_n_s_Keyword___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__463)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__183);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_8) < 0) __PYX_ERR(0, 3516, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":3560
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch)
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Keyword_3parseImpl, 0, __pyx_n_s_Keyword_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__464)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_8) < 0) __PYX_ERR(0, 3560, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":3582
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Keyword_5copy, 0, __pyx_n_s_Keyword_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__466)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_copy, __pyx_t_8) < 0) __PYX_ERR(0, 3582, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":3587
 *         return c
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultKeywordChars(chars):
 *         """Overrides the default Keyword chars
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Keyword_7setDefaultKeywordChars, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_Keyword_setDefaultKeywordChars, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__467)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_setDefaultKeywordChars, __pyx_t_9) < 0) __PYX_ERR(0, 3587, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3489
 * ParserElement._literalStringClass = Literal
 * 
 * class Keyword(Token):             # <<<<<<<<<<<<<<
 *     """Token to exactly match a specified string as a keyword, that is,
 *     it must be immediately followed by a non-keyword character.  Compare
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_Keyword, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Keyword, __pyx_t_9) < 0) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3593
 *         Keyword.DEFAULT_KEYWORD_CHARS = chars
 * 
 * class CaselessLiteral(Literal):             # <<<<<<<<<<<<<<
 *     """Token to match a specified string, ignoring case of letters.
 *     Note: the matched results will always be in the case of the given
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Literal); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_3)) __PYX_ERR(0, 3593, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_CaselessLiteral, __pyx_n_s_CaselessLiteral, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_to_match_a_specified_strin); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 3593, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3604
 *     (Contrast with example for :class:`CaselessKeyword`.)
 *     """
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15CaselessLiteral_1__init__, 0, __pyx_n_s_CaselessLiteral___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__468)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 3604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3620
 *     #         ParserElement._furthest_locs[instring] = max(ParserElement._furthest_locs[instring], loc + self.matchLen)
 *     #     return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15CaselessLiteral_3parseImpl, 0, __pyx_n_s_CaselessLiteral_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__469)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_14) < 0) __PYX_ERR(0, 3620, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3593
 *         Keyword.DEFAULT_KEYWORD_CHARS = chars
 * 
 * class CaselessLiteral(Literal):             # <<<<<<<<<<<<<<
 *     """Token to match a specified string, ignoring case of letters.
 *     Note: the matched results will always be in the case of the given
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_CaselessLiteral, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CaselessLiteral, __pyx_t_14) < 0) __PYX_ERR(0, 3593, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3628
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class CaselessKeyword(Keyword):             # <<<<<<<<<<<<<<
 *     """
 *     Caseless version of :class:`Keyword`.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Keyword); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 3628, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_CaselessKeyword, __pyx_n_s_CaselessKeyword, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Caseless_version_of_class_Keywo); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 3628, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3638
 *     (Contrast with example for :class:`CaselessLiteral`.)
 *     """
 *     def __init__(self, matchString, identChars=None):             # <<<<<<<<<<<<<<
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15CaselessKeyword_1__init__, 0, __pyx_n_s_CaselessKeyword___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__471)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 3638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3628
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class CaselessKeyword(Keyword):             # <<<<<<<<<<<<<<
 *     """
 *     Caseless version of :class:`Keyword`.
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_CaselessKeyword, __pyx_t_3, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CaselessKeyword, __pyx_t_2) < 0) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3641
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 * class CloseMatch(Token):             # <<<<<<<<<<<<<<
 *     """A variation on :class:`Literal` which matches "close" matches,
 *     that is, strings with at most 'n' mismatching characters.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Token); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 3641, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_3, __pyx_n_s_CloseMatch, __pyx_n_s_CloseMatch, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_A_variation_on_class_Literal_whi); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 3641, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3674
 *         patt.parseString("ATCAXCGAAXGGA") # -> (['ATCAXCGAAXGGA'], {'mismatches': [[4, 9]], 'original': ['ATCATCGAATGGA']})
 *     """
 *     def __init__(self, match_string, maxMismatches=1):             # <<<<<<<<<<<<<<
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10CloseMatch_1__init__, 0, __pyx_n_s_CloseMatch___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__473)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__177);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 3674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3683
 *         self.mayReturnEmpty = False
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         start = loc
 *         instrlen = len(instring)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10CloseMatch_3parseImpl, 0, __pyx_n_s_CloseMatch_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__475)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_9) < 0) __PYX_ERR(0, 3683, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3641
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 * class CloseMatch(Token):             # <<<<<<<<<<<<<<
 *     """A variation on :class:`Literal` which matches "close" matches,
 *     that is, strings with at most 'n' mismatching characters.
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_CloseMatch, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CloseMatch, __pyx_t_9) < 0) __PYX_ERR(0, 3641, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3710
 * 
 * 
 * class Word(Token):             # <<<<<<<<<<<<<<
 *     """Token for matching words composed of allowed character sets.
 *     Defined with string containing all allowed initial characters, an
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Token); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_3)) __PYX_ERR(0, 3710, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_Word, __pyx_n_s_Word, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_matching_words_compose); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 3710, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3763
 *         csv_value = Word(printables, excludeChars=",")
 *     """
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Word_1__init__, 0, __pyx_n_s_Word___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__478);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 3763, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3849
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] not in self.initChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Word_3parseImpl, 0, __pyx_n_s_Word_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__480)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_14) < 0) __PYX_ERR(0, 3849, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3877
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Word_5__str__, 0, __pyx_n_s_Word___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__482)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_14) < 0) __PYX_ERR(0, 3877, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3710
 * 
 * 
 * class Word(Token):             # <<<<<<<<<<<<<<
 *     """Token for matching words composed of allowed character sets.
 *     Defined with string containing all allowed initial characters, an
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Word, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Word, __pyx_t_14) < 0) __PYX_ERR(0, 3710, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3898
 *         return self.strRepr
 * 
 * class _WordRegex(Word):             # <<<<<<<<<<<<<<
 *     # # [CPYPARSING] make safe
 *     # @returns_excs
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Word); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 3898, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_WordRegex, __pyx_n_s_WordRegex, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 3898, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3912
 *     #     self._update_furthest_loc_for_regex(instring, loc)
 *     #     return loc, result.group()
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_WordRegex_1parseImpl, 0, __pyx_n_s_WordRegex_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__484)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 3912, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3898
 *         return self.strRepr
 * 
 * class _WordRegex(Word):             # <<<<<<<<<<<<<<
 *     # # [CPYPARSING] make safe
 *     # @returns_excs
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_WordRegex, __pyx_t_3, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_WordRegex, __pyx_t_2) < 0) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3925
 * 
 * 
 * class Char(_WordRegex):             # <<<<<<<<<<<<<<
 *     """A short-cut class for defining ``Word(characters, exact=1)``,
 *     when defining a match of any single character in a string of
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_WordRegex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 3925, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_3, __pyx_n_s_Char, __pyx_n_s_Char, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_A_short_cut_class_for_defining_W); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 3925, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3930
 *     characters.
 *     """
 *     def __init__(self, charset, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Char, self).__init__(charset, exact=1, asKeyword=asKeyword, excludeChars=excludeChars)
 *         self.reString = "[%s]" % _escapeRegexRangeChars(''.join(self.initChars))
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Char_1__init__, 0, __pyx_n_s_Char___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__486)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__487);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 3930, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3925
 * 
 * 
 * class Char(_WordRegex):             # <<<<<<<<<<<<<<
 *     """A short-cut class for defining ``Word(characters, exact=1)``,
 *     when defining a match of any single character in a string of
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_Char, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Char, __pyx_t_9) < 0) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3939
 * 
 * 
 * class Regex(Token):             # <<<<<<<<<<<<<<
 *     r"""Token for matching strings that match a given regular
 *     expression. Defined with string specifying the regular expression in
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Token); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_3)) __PYX_ERR(0, 3939, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_Regex, __pyx_n_s_Regex, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_matching_strings_that); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 3939, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3963
 * 
 *     """
 *     def __init__(self, pattern, flags=0, asGroupList=False, asMatch=False):             # <<<<<<<<<<<<<<
 *         """The parameters ``pattern`` and ``flags`` are passed
 *         to the ``re.compile()`` function as-is. See the Python
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Regex_1__init__, 0, __pyx_n_s_Regex___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__489)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__490);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 3963, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4026
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Regex_3parseImpl, 0, __pyx_n_s_Regex_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__492)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_14) < 0) __PYX_ERR(0, 4026, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4057
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImplAsGroupList(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Regex_5parseImplAsGroupList, 0, __pyx_n_s_Regex_parseImplAsGroupList, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__494)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImplAsGroupList, __pyx_t_14) < 0) __PYX_ERR(0, 4057, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4084
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImplAsMatch(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re_match(instring, loc)
 *         if not result:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Regex_7parseImplAsMatch, 0, __pyx_n_s_Regex_parseImplAsMatch, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__495)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImplAsMatch, __pyx_t_14) < 0) __PYX_ERR(0, 4084, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4097
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Regex, self).__str__()
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Regex_9__str__, 0, __pyx_n_s_Regex___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__496)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_14) < 0) __PYX_ERR(0, 4097, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4108
 *         return self.strRepr
 * 
 *     def sub(self, repl):             # <<<<<<<<<<<<<<
 *         r"""
 *         Return Regex with an attached parse action to transform the parsed
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Regex_11sub, 0, __pyx_n_s_Regex_sub, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__498)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_sub, __pyx_t_14) < 0) __PYX_ERR(0, 4108, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":3939
 * 
 * 
 * class Regex(Token):             # <<<<<<<<<<<<<<
 *     r"""Token for matching strings that match a given regular
 *     expression. Defined with string specifying the regular expression in
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Regex, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Regex, __pyx_t_14) < 0) __PYX_ERR(0, 3939, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4137
 *         return self.addParseAction(pa)
 * 
 * class QuotedString(Token):             # <<<<<<<<<<<<<<
 *     r"""
 *     Token for matching strings that are delimited by quoting characters.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Token); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 4137, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_QuotedString, __pyx_n_s_QuotedString, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_matching_strings_that_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 4137, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4176
 *         [['This is the quote with "embedded" quotes']]
 *     """
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False,             # <<<<<<<<<<<<<<
 *                  unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):
 *         super(QuotedString, self).__init__()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12QuotedString_1__init__, 0, __pyx_n_s_QuotedString___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__500)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__501);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 4176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4281
 *     #     self._update_furthest_loc_for_regex(instring, loc, self.flags)
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = instring[loc] == self.firstQuoteChar and self.re_match(instring, loc) or None
 *         if not result:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12QuotedString_3parseImpl, 0, __pyx_n_s_QuotedString_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__503)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 4281, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4320
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(QuotedString, self).__str__()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_12QuotedString_5__str__, 0, __pyx_n_s_QuotedString___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__504)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_str_2, __pyx_t_2) < 0) __PYX_ERR(0, 4320, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4137
 *         return self.addParseAction(pa)
 * 
 * class QuotedString(Token):             # <<<<<<<<<<<<<<
 *     r"""
 *     Token for matching strings that are delimited by quoting characters.
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_QuotedString, __pyx_t_3, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_QuotedString, __pyx_t_2) < 0) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4332
 * 
 * 
 * class CharsNotIn(Token):             # <<<<<<<<<<<<<<
 *     """Token for matching words composed of characters *not* in a given
 *     set (will include whitespace in matched characters if not listed in
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Token); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 4332, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_3, __pyx_n_s_CharsNotIn, __pyx_n_s_CharsNotIn, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_matching_words_compose_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 4332, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4352
 *         ['dkls', 'lsdkjf', 's12 34', '@!#', '213']
 *     """
 *     def __init__(self, notChars, min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10CharsNotIn_1__init__, 0, __pyx_n_s_CharsNotIn___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__506)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__507);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4394
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10CharsNotIn_3parseImpl, 0, __pyx_n_s_CharsNotIn_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__509)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_9) < 0) __PYX_ERR(0, 4394, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4410
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(CharsNotIn, self).__str__()
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10CharsNotIn_5__str__, 0, __pyx_n_s_CharsNotIn___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__510)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_str_2, __pyx_t_9) < 0) __PYX_ERR(0, 4410, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4332
 * 
 * 
 * class CharsNotIn(Token):             # <<<<<<<<<<<<<<
 *     """Token for matching words composed of characters *not* in a given
 *     set (will include whitespace in matched characters if not listed in
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_CharsNotIn, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CharsNotIn, __pyx_t_9) < 0) __PYX_ERR(0, 4332, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4424
 *         return self.strRepr
 * 
 * class White(Token):             # <<<<<<<<<<<<<<
 *     """Special matching class for matching whitespace.  Normally,
 *     whitespace is ignored by pyparsing grammars.  This class is included
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Token); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_3)) __PYX_ERR(0, 4424, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_White, __pyx_n_s_White, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Special_matching_class_for_match); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 4424, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4434
 *     """
 *     whiteStrs = {
 *         ' ' : '<SP>',             # <<<<<<<<<<<<<<
 *         '\t': '<TAB>',
 *         '\n': '<LF>',
 */
  __pyx_t_14 = __Pyx_PyDict_NewPresized(23); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__16, __pyx_kp_u_SP) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__98, __pyx_kp_u_TAB) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__19, __pyx_kp_u_LF) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__100, __pyx_kp_u_CR) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__99, __pyx_kp_u_FF) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__511, __pyx_kp_u_NBSP) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__512, __pyx_kp_u_OGHAM_SPACE_MARK) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__513, __pyx_kp_u_MONGOLIAN_VOWEL_SEPARATOR) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__514, __pyx_kp_u_EN_QUAD) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__515, __pyx_kp_u_EM_QUAD) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__516, __pyx_kp_u_EN_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__517, __pyx_kp_u_EM_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__518, __pyx_kp_u_THREE_PER_EM_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__519, __pyx_kp_u_FOUR_PER_EM_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__520, __pyx_kp_u_SIX_PER_EM_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__521, __pyx_kp_u_FIGURE_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__522, __pyx_kp_u_PUNCTUATION_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__523, __pyx_kp_u_THIN_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__524, __pyx_kp_u_HAIR_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__525, __pyx_kp_u_ZERO_WIDTH_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__526, __pyx_kp_u_NNBSP) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__527, __pyx_kp_u_MMSP) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_kp_u__528, __pyx_kp_u_IDEOGRAPHIC_SPACE) < 0) __PYX_ERR(0, 4434, __pyx_L1_error)
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_whiteStrs, __pyx_t_14) < 0) __PYX_ERR(0, 4433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4458
 *         u'\u3000': '<IDEOGRAPHIC_SPACE>',
 *         }
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5White_1__init__, 0, __pyx_n_s_White___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__530)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__531);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 4458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4494
 * 
 *     #     return loc, instring[start:loc]
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] not in self.matchWhite:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5White_3parseImpl, 0, __pyx_n_s_White_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__533)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_14) < 0) __PYX_ERR(0, 4494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4424
 *         return self.strRepr
 * 
 * class White(Token):             # <<<<<<<<<<<<<<
 *     """Special matching class for matching whitespace.  Normally,
 *     whitespace is ignored by pyparsing grammars.  This class is included
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_White, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_White, __pyx_t_14) < 0) __PYX_ERR(0, 4424, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4510
 * 
 * 
 * class _PositionToken(Token):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         super(_PositionToken, self).__init__()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Token); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 4510, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_PositionToken, __pyx_n_s_PositionToken, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 4510, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4511
 * 
 * class _PositionToken(Token):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_14_PositionToken_1__init__, 0, __pyx_n_s_PositionToken___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__534)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 4511, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4510
 * 
 * 
 * class _PositionToken(Token):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         super(_PositionToken, self).__init__()
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_PositionToken, __pyx_t_3, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PositionToken, __pyx_t_2) < 0) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4517
 *         self.mayIndexError = False
 * 
 * class GoToColumn(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Token to advance to a specific column of input text; useful for
 *     tabular report scraping.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PositionToken); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 4517, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_3, __pyx_n_s_GoToColumn, __pyx_n_s_GoToColumn, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_to_advance_to_a_specific_c); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 4517, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4521
 *     tabular report scraping.
 *     """
 *     def __init__(self, colno):             # <<<<<<<<<<<<<<
 *         super(GoToColumn, self).__init__()
 *         self.col = colno
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10GoToColumn_1__init__, 0, __pyx_n_s_GoToColumn___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__536)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 4521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4525
 *         self.col = colno
 * 
 *     def preParse(self, instring, loc):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10GoToColumn_3preParse, 0, __pyx_n_s_GoToColumn_preParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__538)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_preParse, __pyx_t_9) < 0) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4534
 *         return loc
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10GoToColumn_5parseImpl, 0, __pyx_n_s_GoToColumn_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__540)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_9) < 0) __PYX_ERR(0, 4534, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4517
 *         self.mayIndexError = False
 * 
 * class GoToColumn(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Token to advance to a specific column of input text; useful for
 *     tabular report scraping.
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_GoToColumn, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_GoToColumn, __pyx_t_9) < 0) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4543
 * 
 * 
 * class LineStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     r"""Matches if current position is at the beginning of a line within
 *     the parse string
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PositionToken); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_3)) __PYX_ERR(0, 4543, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_LineStart, __pyx_n_s_LineStart, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_current_position_is_a); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 4543, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4565
 * 
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9LineStart_1__init__, 0, __pyx_n_s_LineStart___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__541)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 4565, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4569
 *         self.errmsg = "Expected start of line"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) == 1:
 *             return loc, []
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9LineStart_3parseImpl, 0, __pyx_n_s_LineStart_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__542)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_14) < 0) __PYX_ERR(0, 4569, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4543
 * 
 * 
 * class LineStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     r"""Matches if current position is at the beginning of a line within
 *     the parse string
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_LineStart, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LineStart, __pyx_t_14) < 0) __PYX_ERR(0, 4543, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4574
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class LineEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if current position is at the end of a line within the
 *     parse string
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PositionToken); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 4574, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_LineEnd, __pyx_n_s_LineEnd, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_current_position_is_a_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 4574, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4578
 *     parse string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7LineEnd_1__init__, 0, __pyx_n_s_LineEnd___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__543)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 4578, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4583
 *         self.errmsg = "Expected end of line"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7LineEnd_3parseImpl, 0, __pyx_n_s_LineEnd_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__544)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 4583, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4574
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class LineEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if current position is at the end of a line within the
 *     parse string
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_LineEnd, __pyx_t_3, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LineEnd, __pyx_t_2) < 0) __PYX_ERR(0, 4574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4594
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class StringStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if current position is at the beginning of the parse
 *     string
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PositionToken); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 4594, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_3, __pyx_n_s_StringStart, __pyx_n_s_StringStart, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_current_position_is_a_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 4594, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4598
 *     string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11StringStart_1__init__, 0, __pyx_n_s_StringStart___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__545)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 4598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4610
 *     #             return ParseException(instring, loc, self.errmsg, self)
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11StringStart_3parseImpl, 0, __pyx_n_s_StringStart_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__546)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_9) < 0) __PYX_ERR(0, 4610, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4594
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class StringStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if current position is at the beginning of the parse
 *     string
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_StringStart, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_StringStart, __pyx_t_9) < 0) __PYX_ERR(0, 4594, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4617
 *         return loc, []
 * 
 * class StringEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if current position is at the end of the parse string
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PositionToken); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_3)) __PYX_ERR(0, 4617, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_StringEnd, __pyx_n_s_StringEnd, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_current_position_is_a_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 4617, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4620
 *     """Matches if current position is at the end of the parse string
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9StringEnd_1__init__, 0, __pyx_n_s_StringEnd___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__547)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 4620, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4635
 *     #     else:
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9StringEnd_3parseImpl, 0, __pyx_n_s_StringEnd_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__548)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_14) < 0) __PYX_ERR(0, 4635, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4617
 *         return loc, []
 * 
 * class StringEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if current position is at the end of the parse string
 *     """
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_StringEnd, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_StringEnd, __pyx_t_14) < 0) __PYX_ERR(0, 4617, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4645
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class WordStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if the current position is at the beginning of a Word,
 *     and is not preceded by any character in a given set of
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PositionToken); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 4645, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_WordStart, __pyx_n_s_WordStart, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_the_current_position); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 4645, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4654
 *     a line.
 *     """
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9WordStart_1__init__, 0, __pyx_n_s_WordStart___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__550)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults5), 1)) __PYX_ERR(0, 4654, __pyx_L1_error)
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_printables); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_t_2)->__pyx_arg_wordChars = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_10cPyparsing_99__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 4654, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4659
 *         self.errmsg = "Not at the start of a word"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9WordStart_3parseImpl, 0, __pyx_n_s_WordStart_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__551)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 4659, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4645
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 * class WordStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if the current position is at the beginning of a Word,
 *     and is not preceded by any character in a given set of
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_WordStart, __pyx_t_3, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_WordStart, __pyx_t_2) < 0) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4666
 *         return loc, []
 * 
 * class WordEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if the current position is at the end of a Word, and is
 *     not followed by any character in a given set of ``wordChars``
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PositionToken); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 4666, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_3, __pyx_n_s_WordEnd, __pyx_n_s_WordEnd, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_the_current_position_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 4666, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4674
 *     of a line.
 *     """
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7WordEnd_1__init__, 0, __pyx_n_s_WordEnd___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__552)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_9, sizeof(__pyx_defaults6), 1)) __PYX_ERR(0, 4674, __pyx_L1_error)
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_printables); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_t_9)->__pyx_arg_wordChars = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_9, __pyx_pf_10cPyparsing_101__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 4674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4680
 *         self.errmsg = "Not at the end of a word"
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7WordEnd_3parseImpl, 0, __pyx_n_s_WordEnd_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__554)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_9) < 0) __PYX_ERR(0, 4680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4666
 *         return loc, []
 * 
 * class WordEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """Matches if the current position is at the end of a Word, and is
 *     not followed by any character in a given set of ``wordChars``
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_WordEnd, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_WordEnd, __pyx_t_9) < 0) __PYX_ERR(0, 4666, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4689
 * 
 * 
 * class ParseExpression(ParserElement):             # <<<<<<<<<<<<<<
 *     """Abstract subclass of ParserElement, for combining and
 *     post-processing parsed tokens.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_3)) __PYX_ERR(0, 4689, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_ParseExpression, __pyx_n_s_ParseExpression, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_subclass_of_ParserEleme); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 4689, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4693
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_1__init__, 0, __pyx_n_s_ParseExpression___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__556)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 4693, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4717
 * 
 *     # [CPYPARSING] fix append
 *     def append(self, other):             # <<<<<<<<<<<<<<
 *         if (self.parseAction
 *                 or self.resultsName is not None
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_3append, 0, __pyx_n_s_ParseExpression_append, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__557)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_append, __pyx_t_14) < 0) __PYX_ERR(0, 4717, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4745
 *         return self
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """Extends ``leaveWhitespace`` defined in base class, and also invokes ``leaveWhitespace`` on
 *            all contained expressions."""
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_5leaveWhitespace, 0, __pyx_n_s_ParseExpression_leaveWhitespace, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__559)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_leaveWhitespace, __pyx_t_14) < 0) __PYX_ERR(0, 4745, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4754
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_7ignore, 0, __pyx_n_s_ParseExpression_ignore, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__561)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_ignore, __pyx_t_14) < 0) __PYX_ERR(0, 4754, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4766
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseExpression, self).__str__()
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_9__str__, 0, __pyx_n_s_ParseExpression___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__562)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_14) < 0) __PYX_ERR(0, 4766, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4776
 *         return self.strRepr
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).streamline()
 * 
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_11streamline, 0, __pyx_n_s_ParseExpression_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__564)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_streamline, __pyx_t_14) < 0) __PYX_ERR(0, 4776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4824
 *         return self
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         tmp = (validateTrace if validateTrace is not None else [])[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_13validate, 0, __pyx_n_s_ParseExpression_validate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__566)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_validate, __pyx_t_14) < 0) __PYX_ERR(0, 4824, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4830
 *         self.checkRecursion([])
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_15copy, 0, __pyx_n_s_ParseExpression_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__568)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_copy, __pyx_t_14) < 0) __PYX_ERR(0, 4830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4835
 *         return ret
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in self.exprs:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_15ParseExpression_17_setResultsName, 0, __pyx_n_s_ParseExpression__setResultsName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__570)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_setResultsName, __pyx_t_14) < 0) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":4689
 * 
 * 
 * class ParseExpression(ParserElement):             # <<<<<<<<<<<<<<
 *     """Abstract subclass of ParserElement, for combining and
 *     post-processing parsed tokens.
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_ParseExpression, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseExpression, __pyx_t_14) < 0) __PYX_ERR(0, 4689, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4849
 * 
 * 
 * class And(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires all given :class:`ParseExpression` s to be found in the given order.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 4849, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_And, __pyx_n_s_And, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Requires_all_given_class_ParseE); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 4849, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4867
 *     """
 * 
 *     class _ErrorStop(Empty):             # <<<<<<<<<<<<<<
 *         def __init__(self, *args, **kwargs):
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2)) __PYX_ERR(0, 4867, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_19 = __Pyx_Py3MetaclassPrepare(__pyx_t_10, __pyx_t_2, __pyx_n_s_ErrorStop, __pyx_n_s_And__ErrorStop, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 4867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (__pyx_t_2 != __pyx_t_8) {
    if (unlikely((PyDict_SetItemString(__pyx_t_19, "__orig_bases__", __pyx_t_8) < 0))) __PYX_ERR(0, 4867, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4868
 * 
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 */
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_ErrorStop_1__init__, 0, __pyx_n_s_And__ErrorStop___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__571)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_19, __pyx_n_s_init, __pyx_t_8) < 0) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4867
 *     """
 * 
 *     class _ErrorStop(Empty):             # <<<<<<<<<<<<<<
 *         def __init__(self, *args, **kwargs):
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 */
  __pyx_t_8 = __Pyx_Py3ClassCreate(__pyx_t_10, __pyx_n_s_ErrorStop, __pyx_t_2, __pyx_t_19, NULL, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_ErrorStop, __pyx_t_8) < 0) __PYX_ERR(0, 4867, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4873
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         exprs = list(exprs)
 *         if exprs and Ellipsis in exprs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_3And_1__init__, 0, __pyx_n_s_And___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__573)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 4873, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4893
 *         self.callPreparse = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         # collapse any _PendingSkip's
 *         if self.exprs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_3And_3streamline, 0, __pyx_n_s_And_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__575)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_streamline, __pyx_t_2) < 0) __PYX_ERR(0, 4893, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4944
 *     #             resultlist += exprtokens
 *     #     return loc, resultlist
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_3And_5parseImpl, 0, __pyx_n_s_And_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__577)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4969
 *         return loc, resultlist
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_3And_7__iadd__, 0, __pyx_n_s_And___iadd, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__578)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_iadd, __pyx_t_2) < 0) __PYX_ERR(0, 4969, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4974
 *         return self.append(other)  # And([self, other])
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_3And_9checkRecursion, 0, __pyx_n_s_And_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__580)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_checkRecursion, __pyx_t_2) < 0) __PYX_ERR(0, 4974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4981
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_3And_11__str__, 0, __pyx_n_s_And___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__581)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_str_2, __pyx_t_2) < 0) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4849
 * 
 * 
 * class And(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires all given :class:`ParseExpression` s to be found in the given order.
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_And, __pyx_t_3, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_And, __pyx_t_2) < 0) __PYX_ERR(0, 4849, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4991
 * 
 * 
 * class Or(ParseExpression):             # <<<<<<<<<<<<<<
 *     """Requires that at least one :class:`ParseExpression` is found. If
 *     two expressions match, the expression that matches the longest
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 4991, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_3, __pyx_n_s_Or, __pyx_n_s_Or, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Requires_that_at_least_one_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 4991, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5008
 *         [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_2Or_1__init__, 0, __pyx_n_s_Or___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__582)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 5008, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5015
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Or, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_2Or_3streamline, 0, __pyx_n_s_Or_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__583)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_streamline, __pyx_t_9) < 0) __PYX_ERR(0, 5015, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5021
 *         return self
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_2Or_5parseImpl, 0, __pyx_n_s_Or_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__585)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_9) < 0) __PYX_ERR(0, 5021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5082
 * 
 * 
 *     def __ixor__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_2Or_7__ixor__, 0, __pyx_n_s_Or___ixor, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__586)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_ixor, __pyx_t_9) < 0) __PYX_ERR(0, 5082, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5087
 *         return self.append(other)  # Or([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_2Or_9__str__, 0, __pyx_n_s_Or___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__587)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_str_2, __pyx_t_9) < 0) __PYX_ERR(0, 5087, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5096
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_2Or_11checkRecursion, 0, __pyx_n_s_Or_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__588)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_checkRecursion, __pyx_t_9) < 0) __PYX_ERR(0, 5096, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5101
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_2Or_13_setResultsName, 0, __pyx_n_s_Or__setResultsName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__590)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_setResultsName, __pyx_t_9) < 0) __PYX_ERR(0, 5101, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4991
 * 
 * 
 * class Or(ParseExpression):             # <<<<<<<<<<<<<<
 *     """Requires that at least one :class:`ParseExpression` is found. If
 *     two expressions match, the expression that matches the longest
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_Or, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Or, __pyx_t_9) < 0) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5114
 * 
 * 
 * class MatchFirst(ParseExpression):             # <<<<<<<<<<<<<<
 *     """Requires that at least one :class:`ParseExpression` is found. If
 *     two expressions match, the first one listed is the one that will
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_3)) __PYX_ERR(0, 5114, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_MatchFirst, __pyx_n_s_MatchFirst, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Requires_that_at_least_one_class_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 5114, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":5131
 *         print(number.searchString("123 3.1416 789")) #  Better -> [['123'], ['3.1416'], ['789']]
 *     """
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10MatchFirst_1__init__, 0, __pyx_n_s_MatchFirst___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__591)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_14) < 0) __PYX_ERR(0, 5131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":5138
 *             self.mayReturnEmpty = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).streamline()
 *         if __compat__.collect_all_And_tokens:
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10MatchFirst_3streamline, 0, __pyx_n_s_MatchFirst_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__592)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_streamline, __pyx_t_14) < 0) __PYX_ERR(0, 5138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":5145
 * 
 *     # [CPYPARSING] add adaptive mode constants
 *     adaptive_usage = None             # <<<<<<<<<<<<<<
 *     expr_order = None
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_adaptive_usage, Py_None) < 0) __PYX_ERR(0, 5145, __pyx_L1_error)

  /* "cPyparsing.pyx":5146
 *     # [CPYPARSING] add adaptive mode constants
 *     adaptive_usage = None
 *     expr_order = None             # <<<<<<<<<<<<<<
 * 
 *     # [CPYPARSING] add setAdaptiveMode
 */
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_expr_order, Py_None) < 0) __PYX_ERR(0, 5146, __pyx_L1_error)

  /* "cPyparsing.pyx":5149
 * 
 *     # [CPYPARSING] add setAdaptiveMode
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def setAdaptiveMode(
 *         cls,
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10MatchFirst_5setAdaptiveMode, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_MatchFirst_setAdaptiveMode, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__594)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__595);
  __pyx_t_10 = __Pyx_Method_ClassMethod(__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_setAdaptiveMode, __pyx_t_10) < 0) __PYX_ERR(0, 5149, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5165
 * 
 *     # [CPYPARSING] implement adaptive mode
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.adaptive_mode:
 *             if self.expr_order is None:
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10MatchFirst_7parseImpl, 0, __pyx_n_s_MatchFirst_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__597)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_10, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_10) < 0) __PYX_ERR(0, 5165, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5225
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ior__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10MatchFirst_9__ior__, 0, __pyx_n_s_MatchFirst___ior, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__598)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_ior, __pyx_t_10) < 0) __PYX_ERR(0, 5225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5230
 *         return self.append(other)  # MatchFirst([self, other])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10MatchFirst_11__str__, 0, __pyx_n_s_MatchFirst___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__599)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_10) < 0) __PYX_ERR(0, 5230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5239
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10MatchFirst_13checkRecursion, 0, __pyx_n_s_MatchFirst_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__600)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_checkRecursion, __pyx_t_10) < 0) __PYX_ERR(0, 5239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5244
 *             e.checkRecursion(subRecCheckList)
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if (not __compat__.collect_all_And_tokens
 *                 and __diag__.warn_multiple_tokens_in_named_alternation):
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10MatchFirst_15_setResultsName, 0, __pyx_n_s_MatchFirst__setResultsName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__601)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_10, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_setResultsName, __pyx_t_10) < 0) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5114
 * 
 * 
 * class MatchFirst(ParseExpression):             # <<<<<<<<<<<<<<
 *     """Requires that at least one :class:`ParseExpression` is found. If
 *     two expressions match, the first one listed is the one that will
 */
  __pyx_t_10 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_MatchFirst, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MatchFirst, __pyx_t_10) < 0) __PYX_ERR(0, 5114, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5257
 * 
 * # [CPYPARSING] initialize adaptive mode to off
 * MatchFirst.setAdaptiveMode(False)             # <<<<<<<<<<<<<<
 * 
 * class Each(ParseExpression):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_MatchFirst); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setAdaptiveMode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__349, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5259
 * MatchFirst.setAdaptiveMode(False)
 * 
 * class Each(ParseExpression):             # <<<<<<<<<<<<<<
 *     """Requires all given :class:`ParseExpression` s to be found, but in
 *     any order. Expressions may be separated by whitespace.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 5259, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_Each, __pyx_n_s_Each, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Requires_all_given_class_ParseEx); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_10, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 5259, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5316
 *         - size: 20
 *     """
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Each_1__init__, 0, __pyx_n_s_Each___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__602)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 5316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5323
 *         self.saveAsList = True
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(Each, self).streamline()
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Each_3streamline, 0, __pyx_n_s_Each_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__603)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_streamline, __pyx_t_2) < 0) __PYX_ERR(0, 5323, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5328
 *         return self
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Each_5parseImpl, 0, __pyx_n_s_Each_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__605)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 5328, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5377
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Each_7__str__, 0, __pyx_n_s_Each___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__606)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_str_2, __pyx_t_2) < 0) __PYX_ERR(0, 5377, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5386
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Each_9checkRecursion, 0, __pyx_n_s_Each_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__607)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_checkRecursion, __pyx_t_2) < 0) __PYX_ERR(0, 5386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5259
 * MatchFirst.setAdaptiveMode(False)
 * 
 * class Each(ParseExpression):             # <<<<<<<<<<<<<<
 *     """Requires all given :class:`ParseExpression` s to be found, but in
 *     any order. Expressions may be separated by whitespace.
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_Each, __pyx_t_3, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Each, __pyx_t_2) < 0) __PYX_ERR(0, 5259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5392
 * 
 * 
 * class ParseElementEnhance(ParserElement):             # <<<<<<<<<<<<<<
 *     """Abstract subclass of :class:`ParserElement`, for combining and
 *     post-processing parsed tokens.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 5392, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_10, __pyx_t_3, __pyx_n_s_ParseElementEnhance, __pyx_n_s_ParseElementEnhance, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_subclass_of_class_Parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 5392, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5396
 *     post-processing parsed tokens.
 *     """
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_1__init__, 0, __pyx_n_s_ParseElementEnhance___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__609)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 5396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5421
 *     #     else:
 *     #         return ParseException("", loc, self.errmsg, self)
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_3parseImpl, 0, __pyx_n_s_ParseElementEnhance_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__610)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_9) < 0) __PYX_ERR(0, 5421, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5428
 * 
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_5leaveWhitespace, 0, __pyx_n_s_ParseElementEnhance_leaveWhitesp, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__611)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_leaveWhitespace, __pyx_t_9) < 0) __PYX_ERR(0, 5428, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5435
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_7ignore, 0, __pyx_n_s_ParseElementEnhance_ignore, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__612)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_ignore, __pyx_t_9) < 0) __PYX_ERR(0, 5435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5447
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_9streamline, 0, __pyx_n_s_ParseElementEnhance_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__613)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_streamline, __pyx_t_9) < 0) __PYX_ERR(0, 5447, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5453
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_11checkRecursion, 0, __pyx_n_s_ParseElementEnhance_checkRecursi, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__615)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_checkRecursion, __pyx_t_9) < 0) __PYX_ERR(0, 5453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5460
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         if validateTrace is None:
 *             validateTrace = []
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_13validate, 0, __pyx_n_s_ParseElementEnhance_validate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__617)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_validate, __pyx_t_9) < 0) __PYX_ERR(0, 5460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5468
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_15__str__, 0, __pyx_n_s_ParseElementEnhance___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__618)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_str_2, __pyx_t_9) < 0) __PYX_ERR(0, 5468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5392
 * 
 * 
 * class ParseElementEnhance(ParserElement):             # <<<<<<<<<<<<<<
 *     """Abstract subclass of :class:`ParserElement`, for combining and
 *     post-processing parsed tokens.
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_10, __pyx_n_s_ParseElementEnhance, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseElementEnhance, __pyx_t_9) < 0) __PYX_ERR(0, 5392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5479
 * 
 * 
 * class FollowedBy(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Lookahead matching of the given parse expression.
 *     ``FollowedBy`` does *not* advance the parsing position within
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3)) __PYX_ERR(0, 5479, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_FollowedBy, __pyx_n_s_FollowedBy, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Lookahead_matching_of_the_given); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_10) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_10) < 0))) __PYX_ERR(0, 5479, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5501
 *         [['shape', 'SQUARE'], ['color', 'BLACK'], ['posn', 'upper left']]
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10FollowedBy_1__init__, 0, __pyx_n_s_FollowedBy___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__620)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_10) < 0) __PYX_ERR(0, 5501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5518
 * 
 *     #     return loc, ret
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # by using self._expr.parse and deleting the contents of the returned ParseResults list
 *         # we keep any named results that were defined in the FollowedBy expression
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10FollowedBy_3parseImpl, 0, __pyx_n_s_FollowedBy_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__623)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_10, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_10) < 0) __PYX_ERR(0, 5518, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5479
 * 
 * 
 * class FollowedBy(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Lookahead matching of the given parse expression.
 *     ``FollowedBy`` does *not* advance the parsing position within
 */
  __pyx_t_10 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_FollowedBy, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FollowedBy, __pyx_t_10) < 0) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5527
 * 
 * 
 * class PrecededBy(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Lookbehind matching of the given parse expression.
 *     ``PrecededBy`` does not advance the parsing position within the
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 5527, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_PrecededBy, __pyx_n_s_PrecededBy, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Lookbehind_matching_of_the_given); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_10, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 5527, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5555
 * 
 *     """
 *     def __init__(self, expr, retreat=None):             # <<<<<<<<<<<<<<
 *         super(PrecededBy, self).__init__(expr)
 *         self.expr = self.expr().leaveWhitespace()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10PrecededBy_1__init__, 0, __pyx_n_s_PrecededBy___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__625)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 5555, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5578
 *         self.parseAction.append(lambda s, l, t: t.__delitem__(slice(None, None)))
 * 
 *     def parseImpl(self, instring, loc=0, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.exact:
 *             if loc < self.retreat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10PrecededBy_3parseImpl, 0, __pyx_n_s_PrecededBy_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__627)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__628);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 5578, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5527
 * 
 * 
 * class PrecededBy(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Lookbehind matching of the given parse expression.
 *     ``PrecededBy`` does not advance the parsing position within the
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_PrecededBy, __pyx_t_3, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PrecededBy, __pyx_t_2) < 0) __PYX_ERR(0, 5527, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5602
 * 
 * 
 * class NotAny(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Lookahead to disallow matching with the given parse expression.
 *     ``NotAny`` does *not* advance the parsing position within the
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 5602, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_10, __pyx_t_3, __pyx_n_s_NotAny, __pyx_n_s_NotAny, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Lookahead_to_disallow_matching_w); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 5602, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5625
 *         integer = Word(nums) + ~Char(".")
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(NotAny, self).__init__(expr)
 *         # ~ self.leaveWhitespace()
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_6NotAny_1__init__, 0, __pyx_n_s_NotAny___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__629)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 5625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5638
 *     #         return ParseException(instring, loc, self.errmsg, self)
 *     #     return loc, []
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_6NotAny_3parseImpl, 0, __pyx_n_s_NotAny_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__630)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_9) < 0) __PYX_ERR(0, 5638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5643
 *         return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_6NotAny_5__str__, 0, __pyx_n_s_NotAny___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__631)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_str_2, __pyx_t_9) < 0) __PYX_ERR(0, 5643, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5602
 * 
 * 
 * class NotAny(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Lookahead to disallow matching with the given parse expression.
 *     ``NotAny`` does *not* advance the parsing position within the
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_10, __pyx_n_s_NotAny, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NotAny, __pyx_t_9) < 0) __PYX_ERR(0, 5602, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5652
 *         return self.strRepr
 * 
 * class _MultipleMatch(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     def __init__(self, expr, stopOn=None):
 *         super(_MultipleMatch, self).__init__(expr)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3)) __PYX_ERR(0, 5652, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_MultipleMatch, __pyx_n_s_MultipleMatch, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_10) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_10) < 0))) __PYX_ERR(0, 5652, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5653
 * 
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_14_MultipleMatch_1__init__, 0, __pyx_n_s_MultipleMatch___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__633)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_10, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_10) < 0) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5661
 *         self.stopOn(ender)
 * 
 *     def stopOn(self, ender):             # <<<<<<<<<<<<<<
 *         if isinstance(ender, basestring):
 *             ender = self._literalStringClass(ender)
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_14_MultipleMatch_3stopOn, 0, __pyx_n_s_MultipleMatch_stopOn, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__635)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_stopOn, __pyx_t_10) < 0) __PYX_ERR(0, 5661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5720
 * 
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_14_MultipleMatch_5parseImpl, 0, __pyx_n_s_MultipleMatch_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__637)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_10, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_10) < 0) __PYX_ERR(0, 5720, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5749
 *         return loc, tokens
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_ungrouped_named_tokens_in_collection:
 *             for e in [self.expr] + getattr(self.expr, 'exprs', []):
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_14_MultipleMatch_7_setResultsName, 0, __pyx_n_s_MultipleMatch__setResultsName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__638)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_10, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_setResultsName, __pyx_t_10) < 0) __PYX_ERR(0, 5749, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5652
 *         return self.strRepr
 * 
 * class _MultipleMatch(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     def __init__(self, expr, stopOn=None):
 *         super(_MultipleMatch, self).__init__(expr)
 */
  __pyx_t_10 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_MultipleMatch, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MultipleMatch, __pyx_t_10) < 0) __PYX_ERR(0, 5652, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5763
 * 
 * 
 * class OneOrMore(_MultipleMatch):             # <<<<<<<<<<<<<<
 *     """Repetition of one or more of the given expression.
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_MultipleMatch); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 5763, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_OneOrMore, __pyx_n_s_OneOrMore, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Repetition_of_one_or_more_of_the); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_10, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 5763, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5789
 *     """
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_9OneOrMore_1__str__, 0, __pyx_n_s_OneOrMore___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__639)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_str_2, __pyx_t_2) < 0) __PYX_ERR(0, 5789, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5763
 * 
 * 
 * class OneOrMore(_MultipleMatch):             # <<<<<<<<<<<<<<
 *     """Repetition of one or more of the given expression.
 * 
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_OneOrMore, __pyx_t_3, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OneOrMore, __pyx_t_2) < 0) __PYX_ERR(0, 5763, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5798
 *         return self.strRepr
 * 
 * class ZeroOrMore(_MultipleMatch):             # <<<<<<<<<<<<<<
 *     """Optional repetition of zero or more of the given expression.
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_MultipleMatch); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 5798, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_10, __pyx_t_3, __pyx_n_s_ZeroOrMore, __pyx_n_s_ZeroOrMore, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Optional_repetition_of_zero_or_m); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 5798, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5809
 *     Example: similar to :class:`OneOrMore`
 *     """
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10ZeroOrMore_1__init__, 0, __pyx_n_s_ZeroOrMore___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__641)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 5809, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5823
 *     #         return loc, []
 *     #     return got
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10ZeroOrMore_3parseImpl, 0, __pyx_n_s_ZeroOrMore_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__642)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_parseImpl, __pyx_t_9) < 0) __PYX_ERR(0, 5823, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5829
 *             return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10ZeroOrMore_5__str__, 0, __pyx_n_s_ZeroOrMore___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__643)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_str_2, __pyx_t_9) < 0) __PYX_ERR(0, 5829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5798
 *         return self.strRepr
 * 
 * class ZeroOrMore(_MultipleMatch):             # <<<<<<<<<<<<<<
 *     """Optional repetition of zero or more of the given expression.
 * 
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_10, __pyx_n_s_ZeroOrMore, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ZeroOrMore, __pyx_t_9) < 0) __PYX_ERR(0, 5798, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5839
 * 
 * 
 * class _NullToken(object):             # <<<<<<<<<<<<<<
 *     def __bool__(self):
 *         return False
 */
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_tuple__645); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_10, __pyx_t_3, __pyx_n_s_NullToken, __pyx_n_s_NullToken, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_tuple__645) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_tuple__645) < 0))) __PYX_ERR(0, 5839, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":5840
 * 
 * class _NullToken(object):
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 *     __nonzero__ = __bool__
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_NullToken_1__bool__, 0, __pyx_n_s_NullToken___bool, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__646)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_bool, __pyx_t_9) < 0) __PYX_ERR(0, 5840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5842
 *     def __bool__(self):
 *         return False
 *     __nonzero__ = __bool__             # <<<<<<<<<<<<<<
 *     def __str__(self):
 *         return ""
 */
  __pyx_t_9 = PyObject_GetItem(__pyx_t_2, __pyx_n_s_bool);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_bool);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_nonzero, __pyx_t_9) < 0) __PYX_ERR(0, 5842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5843
 *         return False
 *     __nonzero__ = __bool__
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_10_NullToken_3__str__, 0, __pyx_n_s_NullToken___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__647)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_str_2, __pyx_t_9) < 0) __PYX_ERR(0, 5843, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5839
 * 
 * 
 * class _NullToken(object):             # <<<<<<<<<<<<<<
 *     def __bool__(self):
 *         return False
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_10, __pyx_n_s_NullToken, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NullToken, __pyx_t_9) < 0) __PYX_ERR(0, 5839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5846
 *         return ""
 * 
 * class Optional(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Optional matching of the given expression.
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3)) __PYX_ERR(0, 5846, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_Optional, __pyx_n_s_Optional, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Optional_matching_of_the_given_e); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_10) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_10) < 0))) __PYX_ERR(0, 5846, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5883
 *         FAIL: Expected end of text (at char 5), (line:1, col:6)
 *     """
 *     __optionalNotMatched = _NullToken()             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, expr, default=__optionalNotMatched):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_NullToken); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, NULL};
    __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_Optional__optionalNotMatched, __pyx_t_10) < 0) __PYX_ERR(0, 5883, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5885
 *     __optionalNotMatched = _NullToken()
 * 
 *     def __init__(self, expr, default=__optionalNotMatched):             # <<<<<<<<<<<<<<
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_8Optional_1__init__, 0, __pyx_n_s_Optional___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__649)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_10, sizeof(__pyx_defaults7), 1)) __PYX_ERR(0, 5885, __pyx_L1_error)
  __pyx_t_14 = PyObject_GetItem(__pyx_t_9, __pyx_n_s_Optional__optionalNotMatched);
  if (unlikely(!__pyx_t_14)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Optional__optionalNotMatched);
  }
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_t_10)->__pyx_arg_default = __pyx_t_14;
  __Pyx_GIVEREF(__pyx_t_14);
  __pyx_t_14 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_10, __pyx_pf_10cPyparsing_103__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_10) < 0) __PYX_ERR(0, 5885, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5912
 *     #         loc, tokens = got
 *     #     return loc, tokens
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_8Optional_3parseImpl, 0, __pyx_n_s_Optional_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__651)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_10, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_10) < 0) __PYX_ERR(0, 5912, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5926
 *         return loc, tokens
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_8Optional_5__str__, 0, __pyx_n_s_Optional___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__652)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_10) < 0) __PYX_ERR(0, 5926, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":5846
 *         return ""
 * 
 * class Optional(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Optional matching of the given expression.
 * 
 */
  __pyx_t_10 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Optional, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Optional, __pyx_t_10) < 0) __PYX_ERR(0, 5846, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5935
 *         return self.strRepr
 * 
 * class SkipTo(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Token for skipping over all undefined text until the matched
 *     expression is found.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 5935, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_SkipTo, __pyx_n_s_SkipTo, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_skipping_over_all_unde); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_10, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 5935, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5994
 *     """
 *     # [CPYPARSING] use kwargs to detect include
 *     def __init__(self, other, ignore=None, failOn=None, **kwargs):             # <<<<<<<<<<<<<<
 *         include_ = kwargs.get("include", False)  # include=False
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_6SkipTo_1__init__, 0, __pyx_n_s_SkipTo___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__654)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__58);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 5994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6010
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, loc, doActions=True):             # <<<<<<<<<<<<<<
 *         startloc = loc
 *         instrlen = len(instring)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_6SkipTo_3parseImpl, 0, __pyx_n_s_SkipTo_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__656)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__155);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_parseImpl, __pyx_t_2) < 0) __PYX_ERR(0, 6010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5935
 *         return self.strRepr
 * 
 * class SkipTo(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Token for skipping over all undefined text until the matched
 *     expression is found.
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_SkipTo, __pyx_t_3, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SkipTo, __pyx_t_2) < 0) __PYX_ERR(0, 5935, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6057
 *         return loc, skipresult
 * 
 * class Forward(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Forward declaration of an expression to be defined later -
 *     used for recursive grammars, such as algebraic infix notation.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 6057, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_10, __pyx_t_3, __pyx_n_s_Forward, __pyx_n_s_Forward, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Forward_declaration_of_an_expres); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 6057, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6084
 *     parser created using ``Forward``.
 *     """
 *     def __init__(self, other=None):             # <<<<<<<<<<<<<<
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Forward_1__init__, 0, __pyx_n_s_Forward___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__657)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 6084, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6087
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 *     def __lshift__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = self._literalStringClass(other)
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Forward_3__lshift__, 0, __pyx_n_s_Forward___lshift, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__658)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_lshift, __pyx_t_9) < 0) __PYX_ERR(0, 6087, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6100
 *         return self
 * 
 *     def __ilshift__(self, other):             # <<<<<<<<<<<<<<
 *         return self << other
 * 
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Forward_5__ilshift__, 0, __pyx_n_s_Forward___ilshift, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__659)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_ilshift, __pyx_t_9) < 0) __PYX_ERR(0, 6100, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6103
 *         return self << other
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         return self
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Forward_7leaveWhitespace, 0, __pyx_n_s_Forward_leaveWhitespace, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__660)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_leaveWhitespace, __pyx_t_9) < 0) __PYX_ERR(0, 6103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6107
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamlined = True
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Forward_9streamline, 0, __pyx_n_s_Forward_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__661)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_streamline, __pyx_t_9) < 0) __PYX_ERR(0, 6107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6114
 *         return self
 * 
 *     def validate(self, validateTrace=None):             # <<<<<<<<<<<<<<
 *         if validateTrace is None:
 *             validateTrace = []
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Forward_11validate, 0, __pyx_n_s_Forward_validate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__662)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__57);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_validate, __pyx_t_9) < 0) __PYX_ERR(0, 6114, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6124
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Forward_13__str__, 0, __pyx_n_s_Forward___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__663)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_str_2, __pyx_t_9) < 0) __PYX_ERR(0, 6124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6134
 *         return self.strRepr
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return super(Forward, self).copy()
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Forward_15copy, 0, __pyx_n_s_Forward_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__664)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_copy, __pyx_t_9) < 0) __PYX_ERR(0, 6134, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6142
 *             return ret
 * 
 *     def _setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         if __diag__.warn_name_set_on_empty_Forward:
 *             if self.expr is None:
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Forward_17_setResultsName, 0, __pyx_n_s_Forward__setResultsName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__665)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_setResultsName, __pyx_t_9) < 0) __PYX_ERR(0, 6142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6057
 *         return loc, skipresult
 * 
 * class Forward(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """Forward declaration of an expression to be defined later -
 *     used for recursive grammars, such as algebraic infix notation.
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_10, __pyx_n_s_Forward, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Forward, __pyx_t_9) < 0) __PYX_ERR(0, 6057, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6153
 *         return super(Forward, self)._setResultsName(name, listAllMatches)
 * 
 * class TokenConverter(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract subclass of :class:`ParseExpression`, for converting parsed results.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3)) __PYX_ERR(0, 6153, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_TokenConverter, __pyx_n_s_TokenConverter, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_subclass_of_class_Pars); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_10) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_10) < 0))) __PYX_ERR(0, 6153, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":6157
 *     Abstract subclass of :class:`ParseExpression`, for converting parsed results.
 *     """
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(TokenConverter, self).__init__(expr)  # , savelist)
 *         self.saveAsList = False
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_14TokenConverter_1__init__, 0, __pyx_n_s_TokenConverter___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__666)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_10, __pyx_tuple__349);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_10) < 0) __PYX_ERR(0, 6157, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":6153
 *         return super(Forward, self)._setResultsName(name, listAllMatches)
 * 
 * class TokenConverter(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract subclass of :class:`ParseExpression`, for converting parsed results.
 */
  __pyx_t_10 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_TokenConverter, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_TokenConverter, __pyx_t_10) < 0) __PYX_ERR(0, 6153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6161
 *         self.saveAsList = False
 * 
 * class Combine(TokenConverter):             # <<<<<<<<<<<<<<
 *     """Converter to concatenate all matching tokens to a single string.
 *     By default, the matching patterns must also be contiguous in the
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 6161, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_Combine, __pyx_n_s_Combine, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Converter_to_concatenate_all_mat); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_10, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 6161, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6179
 *         print(real.parseString('3. 1416')) # -> Exception: Expected W:(0123...)
 *     """
 *     def __init__(self, expr, joinString="", adjacent=True):             # <<<<<<<<<<<<<<
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Combine_1__init__, 0, __pyx_n_s_Combine___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__668)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__669);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 6179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6189
 *         self.callPreparse = True
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Combine_3ignore, 0, __pyx_n_s_Combine_ignore, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__670)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_ignore, __pyx_t_2) < 0) __PYX_ERR(0, 6189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6196
 *         return self
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_7Combine_5postParse, 0, __pyx_n_s_Combine_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__672)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_postParse, __pyx_t_2) < 0) __PYX_ERR(0, 6196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6161
 *         self.saveAsList = False
 * 
 * class Combine(TokenConverter):             # <<<<<<<<<<<<<<
 *     """Converter to concatenate all matching tokens to a single string.
 *     By default, the matching patterns must also be contiguous in the
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_Combine, __pyx_t_3, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Combine, __pyx_t_2) < 0) __PYX_ERR(0, 6161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6206
 *             return retToks
 * 
 * class Group(TokenConverter):             # <<<<<<<<<<<<<<
 *     """Converter to return the matched tokens as a list - useful for
 *     returning tokens of :class:`ZeroOrMore` and :class:`OneOrMore` expressions.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 6206, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_10, __pyx_t_3, __pyx_n_s_Group, __pyx_n_s_Group, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Converter_to_return_the_matched); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_3 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 6206, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6221
 *         print(func.parseString("fn a, b, 100"))  # -> ['fn', ['a', 'b', '100']]
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Group_1__init__, 0, __pyx_n_s_Group___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__673)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 6221, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6225
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return [tokenlist]
 * 
 */
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_5Group_3postParse, 0, __pyx_n_s_Group_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__674)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_postParse, __pyx_t_9) < 0) __PYX_ERR(0, 6225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6206
 *             return retToks
 * 
 * class Group(TokenConverter):             # <<<<<<<<<<<<<<
 *     """Converter to return the matched tokens as a list - useful for
 *     returning tokens of :class:`ZeroOrMore` and :class:`OneOrMore` expressions.
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_10, __pyx_n_s_Group, __pyx_t_3, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Group, __pyx_t_9) < 0) __PYX_ERR(0, 6206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6228
 *         return [tokenlist]
 * 
 * class Dict(TokenConverter):             # <<<<<<<<<<<<<<
 *     """Converter to return a repetitive expression as a list, but also
 *     as a dictionary. Each element can also be referenced using the first
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3)) __PYX_ERR(0, 6228, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_Dict, __pyx_n_s_Dict, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Converter_to_return_a_repetitive); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_3 != __pyx_t_10) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_10) < 0))) __PYX_ERR(0, 6228, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":6267
 *     See more examples at :class:`ParseResults` of accessing fields by results name.
 *     """
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Dict_1__init__, 0, __pyx_n_s_Dict___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__675)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_init, __pyx_t_10) < 0) __PYX_ERR(0, 6267, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":6271
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 */
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_4Dict_3postParse, 0, __pyx_n_s_Dict_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__677)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_postParse, __pyx_t_10) < 0) __PYX_ERR(0, 6271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":6228
 *         return [tokenlist]
 * 
 * class Dict(TokenConverter):             # <<<<<<<<<<<<<<
 *     """Converter to return a repetitive expression as a list, but also
 *     as a dictionary. Each element can also be referenced using the first
 */
  __pyx_t_10 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Dict, __pyx_t_3, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Dict, __pyx_t_10) < 0) __PYX_ERR(0, 6228, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6296
 * 
 * 
 * class Suppress(TokenConverter):             # <<<<<<<<<<<<<<
 *     """Converter for ignoring the results of a parsed expression.
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 6296, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_Suppress, __pyx_n_s_Suppress, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Converter_for_ignoring_the_resul); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_10, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 6296, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6318
 *     (See also :class:`delimitedList`.)
 *     """
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return []
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_8Suppress_1postParse, 0, __pyx_n_s_Suppress_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__678)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_postParse, __pyx_t_2) < 0) __PYX_ERR(0, 6318, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6321
 *         return []
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_8Suppress_3suppress, 0, __pyx_n_s_Suppress_suppress, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__679)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_suppress, __pyx_t_2) < 0) __PYX_ERR(0, 6321, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6296
 * 
 * 
 * class Suppress(TokenConverter):             # <<<<<<<<<<<<<<
 *     """Converter for ignoring the results of a parsed expression.
 * 
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_Suppress, __pyx_t_3, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Suppress, __pyx_t_2) < 0) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6325
 * 
 * 
 * class OnlyOnce(object):             # <<<<<<<<<<<<<<
 *     """Wrapper for parse actions, to ensure they are only called once.
 *     """
 */
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_tuple__681); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_3, __pyx_n_s_OnlyOnce, __pyx_n_s_OnlyOnce, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Wrapper_for_parse_actions_to_ens); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__pyx_t_3 != __pyx_tuple__681) {
    if (unlikely((PyDict_SetItemString(__pyx_t_10, "__orig_bases__", __pyx_tuple__681) < 0))) __PYX_ERR(0, 6325, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":6328
 *     """Wrapper for parse actions, to ensure they are only called once.
 *     """
 *     def __init__(self, methodCall):             # <<<<<<<<<<<<<<
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_8OnlyOnce_1__init__, 0, __pyx_n_s_OnlyOnce___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__683)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 6328, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6331
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 *     def __call__(self, s, l, t):             # <<<<<<<<<<<<<<
 *         if not self.called:
 *             results = self.callable(s, l, t)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_8OnlyOnce_3__call__, 0, __pyx_n_s_OnlyOnce___call, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__685)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_call, __pyx_t_2) < 0) __PYX_ERR(0, 6331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6337
 *             return results
 *         raise ParseException(s, l, "")
 *     def reset(self):             # <<<<<<<<<<<<<<
 *         self.called = False
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_8OnlyOnce_5reset, 0, __pyx_n_s_OnlyOnce_reset, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__686)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_reset, __pyx_t_2) < 0) __PYX_ERR(0, 6337, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6325
 * 
 * 
 * class OnlyOnce(object):             # <<<<<<<<<<<<<<
 *     """Wrapper for parse actions, to ensure they are only called once.
 *     """
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_OnlyOnce, __pyx_t_3, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OnlyOnce, __pyx_t_2) < 0) __PYX_ERR(0, 6325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6340
 *         self.called = False
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """Decorator for debugging parse actions.
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_29traceParseAction, 0, __pyx_n_s_traceParseAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__688)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_traceParseAction, __pyx_t_3) < 0) __PYX_ERR(0, 6340, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6388
 * # global helpers
 * #
 * def delimitedList(expr, delim=",", combine=False):             # <<<<<<<<<<<<<<
 *     """Helper to define a delimited list of expressions - the delimiter
 *     defaults to ','. By default, the list elements and delimiters can
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_31delimitedList, 0, __pyx_n_s_delimitedList, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__690)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__691);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_delimitedList, __pyx_t_3) < 0) __PYX_ERR(0, 6388, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6409
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """Helper to define a counted list of expressions.
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_33countedArray, 0, __pyx_n_s_countedArray, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__693)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__57);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_countedArray, __pyx_t_3) < 0) __PYX_ERR(0, 6409, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6445
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')
 * 
 * def _flatten(L):             # <<<<<<<<<<<<<<
 *     ret = []
 *     for i in L:
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_35_flatten, 0, __pyx_n_s_flatten, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__695)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_flatten, __pyx_t_3) < 0) __PYX_ERR(0, 6445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6454
 *     return ret
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_37matchPreviousLiteral, 0, __pyx_n_s_matchPreviousLiteral, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__697)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_matchPreviousLiteral, __pyx_t_3) < 0) __PYX_ERR(0, 6454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6484
 *     return rep
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to define an expression that is indirectly defined from
 *     the tokens matched in a previous expression, that is, it looks for
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_39matchPreviousExpr, 0, __pyx_n_s_matchPreviousExpr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__699)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_matchPreviousExpr, __pyx_t_3) < 0) __PYX_ERR(0, 6484, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6513
 *     return rep
 * 
 * def _escapeRegexRangeChars(s):             # <<<<<<<<<<<<<<
 *     # ~  escape these chars: ^-[]
 *     for c in r"\^-[]":
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_41_escapeRegexRangeChars, 0, __pyx_n_s_escapeRegexRangeChars, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__701)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_escapeRegexRangeChars, __pyx_t_3) < 0) __PYX_ERR(0, 6513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6521
 *     return _ustr(s)
 * 
 * def oneOf(strs, caseless=False, useRegex=True, asKeyword=False):             # <<<<<<<<<<<<<<
 *     """Helper to quickly define a set of alternative Literals, and makes
 *     sure to do longest-first testing when there is a conflict,
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_43oneOf, 0, __pyx_n_s_oneOf, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__703)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__704);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_oneOf, __pyx_t_3) < 0) __PYX_ERR(0, 6521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6608
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))
 * 
 * def dictOf(key, value):             # <<<<<<<<<<<<<<
 *     """Helper to easily and clearly define a dictionary by specifying
 *     the respective patterns for the key and value.  Takes care of
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_45dictOf, 0, __pyx_n_s_dictOf, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__706)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dictOf, __pyx_t_3) < 0) __PYX_ERR(0, 6608, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6647
 *     return Dict(OneOrMore(Group(key + value)))
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """Helper to return the original, untokenized text for a given
 *     expression.  Useful to restore the parsed fields of an HTML start
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_47originalTextFor, 0, __pyx_n_s_originalTextFor, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__708)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__155);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_originalTextFor, __pyx_t_3) < 0) __PYX_ERR(0, 6647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6689
 *     return matchExpr
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """Helper to undo pyparsing's default grouping of And expressions,
 *     even if all but one are non-empty.
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_49ungroup, 0, __pyx_n_s_ungroup, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__710)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ungroup, __pyx_t_3) < 0) __PYX_ERR(0, 6689, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6695
 *     return TokenConverter(expr).addParseAction(lambda t: t[0])
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """Helper to decorate a returned token with its starting and ending
 *     locations in the input string.
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_51locatedExpr, 0, __pyx_n_s_locatedExpr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__712)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_locatedExpr, __pyx_t_3) < 0) __PYX_ERR(0, 6695, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6725
 * 
 * # convenience constants for positional expressions
 * empty       = Empty().setName("empty")             # <<<<<<<<<<<<<<
 * lineStart   = LineStart().setName("lineStart")
 * lineEnd     = LineEnd().setName("lineEnd")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__713, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_empty, __pyx_t_9) < 0) __PYX_ERR(0, 6725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6726
 * # convenience constants for positional expressions
 * empty       = Empty().setName("empty")
 * lineStart   = LineStart().setName("lineStart")             # <<<<<<<<<<<<<<
 * lineEnd     = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_LineStart); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__714, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_lineStart, __pyx_t_3) < 0) __PYX_ERR(0, 6726, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6727
 * empty       = Empty().setName("empty")
 * lineStart   = LineStart().setName("lineStart")
 * lineEnd     = LineEnd().setName("lineEnd")             # <<<<<<<<<<<<<<
 * stringStart = StringStart().setName("stringStart")
 * stringEnd   = StringEnd().setName("stringEnd")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_LineEnd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__715, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_lineEnd, __pyx_t_9) < 0) __PYX_ERR(0, 6727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6728
 * lineStart   = LineStart().setName("lineStart")
 * lineEnd     = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")             # <<<<<<<<<<<<<<
 * stringEnd   = StringEnd().setName("stringEnd")
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_StringStart); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__716, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stringStart, __pyx_t_3) < 0) __PYX_ERR(0, 6728, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6729
 * lineEnd     = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")
 * stringEnd   = StringEnd().setName("stringEnd")             # <<<<<<<<<<<<<<
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_StringEnd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__717, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stringEnd, __pyx_t_9) < 0) __PYX_ERR(0, 6729, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":6731
 * stringEnd   = StringEnd().setName("stringEnd")
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])             # <<<<<<<<<<<<<<
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Word); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_bslash); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3)) __PYX_ERR(0, 6731, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_u__718);
  __Pyx_GIVEREF(__pyx_kp_u__718);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_kp_u__718)) __PYX_ERR(0, 6731, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_exact, __pyx_int_2) < 0) __PYX_ERR(0, 6731, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_84lambda54, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_escapedPunc, __pyx_t_10) < 0) __PYX_ERR(0, 6731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":6732
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))             # <<<<<<<<<<<<<<
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_Regex); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__719, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_85lambda55, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_escapedHexChar, __pyx_t_3) < 0) __PYX_ERR(0, 6732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6733
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))             # <<<<<<<<<<<<<<
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Regex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__720, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_86lambda56, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_escapedOctChar, __pyx_t_10) < 0) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":6734
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)             # <<<<<<<<<<<<<<
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_escapedPunc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_escapedHexChar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Or(__pyx_t_10, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_escapedOctChar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = PyNumber_Or(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_exact, __pyx_int_1) < 0) __PYX_ERR(0, 6734, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__722, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Or(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_singleChar, __pyx_t_3) < 0) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6735
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)             # <<<<<<<<<<<<<<
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Group); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_singleChar); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__723, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyNumber_Add(__pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_singleChar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyNumber_Add(__pyx_t_10, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_charRange, __pyx_t_2) < 0) __PYX_ERR(0, 6735, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6736
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | CharsNotIn(r'\]', exact=1)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"             # <<<<<<<<<<<<<<
 * 
 * def srange(s):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__724, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__725, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setResultsName_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__726, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_9, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Group); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_charRange); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_singleChar); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_19 = PyNumber_Or(__pyx_t_10, __pyx_t_14); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_14); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setResultsName_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__727, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyNumber_Add(__pyx_t_2, __pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyNumber_Add(__pyx_t_14, __pyx_kp_u__4); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reBracketExpr, __pyx_t_19) < 0) __PYX_ERR(0, 6736, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6738
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""Helper to easily define string ranges for use in Word
 *     construction. Borrows syntax from regexp '[]' string range
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_53srange, 0, __pyx_n_s_srange, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__729)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_srange, __pyx_t_19) < 0) __PYX_ERR(0, 6738, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6770
 *         return ""
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """Helper method for defining parse actions that require matching at
 *     a specific column in the input text.
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_55matchOnlyAtCol, 0, __pyx_n_s_matchOnlyAtCol, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__731)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_matchOnlyAtCol, __pyx_t_19) < 0) __PYX_ERR(0, 6770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6779
 *     return verifyCol
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """Helper method for common parse actions that simply return
 *     a literal value.  Especially useful when used with
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_57replaceWith, 0, __pyx_n_s_replaceWith, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__733)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_replaceWith, __pyx_t_19) < 0) __PYX_ERR(0, 6779, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6794
 *     return lambda s, l, t: [replStr]
 * 
 * def removeQuotes(s, l, t):             # <<<<<<<<<<<<<<
 *     """Helper parse action for removing quotation marks from parsed
 *     quoted strings.
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_59removeQuotes, 0, __pyx_n_s_removeQuotes, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__734)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_removeQuotes, __pyx_t_19) < 0) __PYX_ERR(0, 6794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6809
 *     return t[0][1:-1]
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """Helper to define a parse action by mapping a function to all
 *     elements of a ParseResults list. If any additional args are passed,
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_61tokenMap, 0, __pyx_n_s_tokenMap, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__736)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_tokenMap, __pyx_t_19) < 0) __PYX_ERR(0, 6809, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6857
 *     return pa
 * 
 * upcaseTokens = tokenMap(lambda t: _ustr(t).upper())             # <<<<<<<<<<<<<<
 * """(Deprecated) Helper parse action to convert tokens to upper case.
 * Deprecated in favor of :class:`pyparsing_common.upcaseTokens`"""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_tokenMap); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_87lambda61, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_upcaseTokens, __pyx_t_2) < 0) __PYX_ERR(0, 6857, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6861
 * Deprecated in favor of :class:`pyparsing_common.upcaseTokens`"""
 * 
 * downcaseTokens = tokenMap(lambda t: _ustr(t).lower())             # <<<<<<<<<<<<<<
 * """(Deprecated) Helper parse action to convert tokens to lower case.
 * Deprecated in favor of :class:`pyparsing_common.downcaseTokens`"""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_tokenMap); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_88lambda62, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_14); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_downcaseTokens, __pyx_t_19) < 0) __PYX_ERR(0, 6861, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6865
 * Deprecated in favor of :class:`pyparsing_common.downcaseTokens`"""
 * 
 * def _makeTags(tagStr, xml,             # <<<<<<<<<<<<<<
 *               suppress_LT=Suppress("<"),
 *               suppress_GT=Suppress(">")):
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_63_makeTags, 0, __pyx_n_s_makeTags, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__738)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_19, sizeof(__pyx_defaults8), 2)) __PYX_ERR(0, 6865, __pyx_L1_error)

  /* "cPyparsing.pyx":6866
 * 
 * def _makeTags(tagStr, xml,
 *               suppress_LT=Suppress("<"),             # <<<<<<<<<<<<<<
 *               suppress_GT=Suppress(">")):
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__739, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_t_19)->__pyx_arg_suppress_LT = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":6867
 * def _makeTags(tagStr, xml,
 *               suppress_LT=Suppress("<"),
 *               suppress_GT=Suppress(">")):             # <<<<<<<<<<<<<<
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__740, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_t_19)->__pyx_arg_suppress_GT = __pyx_t_14;
  __Pyx_GIVEREF(__pyx_t_14);
  __pyx_t_14 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_19, __pyx_pf_10cPyparsing_105__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_makeTags, __pyx_t_19) < 0) __PYX_ERR(0, 6865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6902
 *     return openTag, closeTag
 * 
 * def makeHTMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """Helper to construct opening and closing tag expressions for HTML,
 *     given a tag name. Matches tags in either upper or lower case,
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_65makeHTMLTags, 0, __pyx_n_s_makeHTMLTags, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__742)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_makeHTMLTags, __pyx_t_19) < 0) __PYX_ERR(0, 6902, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6926
 *     return _makeTags(tagStr, False)
 * 
 * def makeXMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """Helper to construct opening and closing tag expressions for XML,
 *     given a tag name. Matches tags only in the given upper/lower case.
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_67makeXMLTags, 0, __pyx_n_s_makeXMLTags, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__743)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_makeXMLTags, __pyx_t_19) < 0) __PYX_ERR(0, 6926, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":6935
 * 
 * # [CPYPARSING] withAttribute must be a class
 * class BaseWithAttribute(object):             # <<<<<<<<<<<<<<
 *     ANY_VALUE = object()
 * 
 */
  __pyx_t_19 = __Pyx_PEP560_update_bases(__pyx_tuple__745); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 6935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 6935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_19, __pyx_n_s_BaseWithAttribute, __pyx_n_s_BaseWithAttribute, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_19 != __pyx_tuple__745) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_tuple__745) < 0))) __PYX_ERR(0, 6935, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":6936
 * # [CPYPARSING] withAttribute must be a class
 * class BaseWithAttribute(object):
 *     ANY_VALUE = object()             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, *args, **attrDict):
 */
  __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_ANY_VALUE, __pyx_t_3) < 0) __PYX_ERR(0, 6936, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6938
 *     ANY_VALUE = object()
 * 
 *     def __call__(self, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         """Helper to create a validating parse action to be used with start
 *         tags created with :class:`makeXMLTags` or
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_17BaseWithAttribute_1__call__, 0, __pyx_n_s_BaseWithAttribute___call, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__747)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_call, __pyx_t_3) < 0) __PYX_ERR(0, 6938, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":6935
 * 
 * # [CPYPARSING] withAttribute must be a class
 * class BaseWithAttribute(object):             # <<<<<<<<<<<<<<
 *     ANY_VALUE = object()
 * 
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_BaseWithAttribute, __pyx_t_19, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BaseWithAttribute, __pyx_t_3) < 0) __PYX_ERR(0, 6935, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7009
 * 
 * # [CPYPARSING] set withAttribute
 * withAttribute = BaseWithAttribute()             # <<<<<<<<<<<<<<
 * 
 * def withClass(classname, namespace=''):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_BaseWithAttribute); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_14 = __Pyx_PyObject_CallNoArg(__pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_withAttribute, __pyx_t_14) < 0) __PYX_ERR(0, 7009, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7011
 * withAttribute = BaseWithAttribute()
 * 
 * def withClass(classname, namespace=''):             # <<<<<<<<<<<<<<
 *     """Simplified version of :class:`withAttribute` when
 *     matching on a div class - made difficult because ``class`` is
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_69withClass, 0, __pyx_n_s_withClass, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__749)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__264);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_withClass, __pyx_t_14) < 0) __PYX_ERR(0, 7011, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7049
 *     return withAttribute(**{classattr: classname})
 * 
 * opAssoc = SimpleNamespace()             # <<<<<<<<<<<<<<
 * opAssoc.LEFT = object()
 * opAssoc.RIGHT = object()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_SimpleNamespace); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_19 = __Pyx_PyObject_CallNoArg(__pyx_t_14); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_opAssoc, __pyx_t_19) < 0) __PYX_ERR(0, 7049, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7050
 * 
 * opAssoc = SimpleNamespace()
 * opAssoc.LEFT = object()             # <<<<<<<<<<<<<<
 * opAssoc.RIGHT = object()
 * 
 */
  __pyx_t_19 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_opAssoc); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_14, __pyx_n_s_LEFT, __pyx_t_19) < 0) __PYX_ERR(0, 7050, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7051
 * opAssoc = SimpleNamespace()
 * opAssoc.LEFT = object()
 * opAssoc.RIGHT = object()             # <<<<<<<<<<<<<<
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):
 */
  __pyx_t_14 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_opAssoc); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_19, __pyx_n_s_RIGHT, __pyx_t_14) < 0) __PYX_ERR(0, 7051, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7053
 * opAssoc.RIGHT = object()
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):             # <<<<<<<<<<<<<<
 *     """Helper method for constructing grammars of expressions made up of
 *     operators working in a precedence hierarchy.  Operators may be unary
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_71infixNotation, 0, __pyx_n_s_infixNotation, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__751)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_19, sizeof(__pyx_defaults9), 2)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__752, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_t_19)->__pyx_arg_lpar = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Suppress); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__753, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_t_19)->__pyx_arg_rpar = __pyx_t_14;
  __Pyx_GIVEREF(__pyx_t_14);
  __pyx_t_14 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_19, __pyx_pf_10cPyparsing_107__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_infixNotation, __pyx_t_19) < 0) __PYX_ERR(0, 7053, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7182
 *     return ret
 * 
 * operatorPrecedence = infixNotation             # <<<<<<<<<<<<<<
 * """(Deprecated) Former name of :class:`infixNotation`, will be
 * dropped in a future release."""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_infixNotation); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_operatorPrecedence, __pyx_t_19) < 0) __PYX_ERR(0, 7182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7186
 * dropped in a future release."""
 * 
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")             # <<<<<<<<<<<<<<
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Combine); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Regex); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__754, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__755); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__756, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dblQuotedString, __pyx_t_2) < 0) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7187
 * 
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")             # <<<<<<<<<<<<<<
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'
 *                        | Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Combine); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Regex); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__757, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyNumber_Add(__pyx_t_19, __pyx_kp_u__150); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_14); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__758, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sglQuotedString, __pyx_t_19) < 0) __PYX_ERR(0, 7187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7188
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'             # <<<<<<<<<<<<<<
 *                        | Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Combine); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Regex); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__754, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__755); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7189
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'
 *                        | Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")             # <<<<<<<<<<<<<<
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__757, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__150); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Or(__pyx_t_14, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7188
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'             # <<<<<<<<<<<<<<
 *                        | Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7189
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'
 *                        | Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")             # <<<<<<<<<<<<<<
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__759, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_quotedString, __pyx_t_2) < 0) __PYX_ERR(0, 7188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7190
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"'
 *                        | Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")             # <<<<<<<<<<<<<<
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Combine); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_L_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__760, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_quotedString); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_copy); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyNumber_Add(__pyx_t_19, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__761, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_unicodeString, __pyx_t_3) < 0) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7192
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """Helper method for defining nested lists enclosed in opening and
 *     closing delimiters ("(" and ")" are the default).
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_73nestedExpr, 0, __pyx_n_s_nestedExpr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__763)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_3, sizeof(__pyx_defaults10), 1)) __PYX_ERR(0, 7192, __pyx_L1_error)
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_quotedString); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_t_3)->__pyx_arg_ignoreExpr = __pyx_t_14;
  __Pyx_GIVEREF(__pyx_t_14);
  __pyx_t_14 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_3, __pyx_pf_10cPyparsing_109__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_nestedExpr, __pyx_t_3) < 0) __PYX_ERR(0, 7192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7296
 *     return ret
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """Helper method for defining space-delimited indentation blocks,
 *     such as those used to define block statements in Python source code.
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_75indentedBlock, 0, __pyx_n_s_indentedBlock, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__765)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__155);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_indentedBlock, __pyx_t_3) < 0) __PYX_ERR(0, 7296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7422
 *     return smExpr.setName('indented block')
 * 
 * alphas8bit = srange(r"[\0xc0-\0xd6\0xd8-\0xf6\0xf8-\0xff]")             # <<<<<<<<<<<<<<
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_srange); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__766, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_alphas8bit, __pyx_t_14) < 0) __PYX_ERR(0, 7422, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7423
 * 
 * alphas8bit = srange(r"[\0xc0-\0xd6\0xd8-\0xf6\0xf8-\0xff]")
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")             # <<<<<<<<<<<<<<
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_srange); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__767, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_punc8bit, __pyx_t_3) < 0) __PYX_ERR(0, 7423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7425
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))             # <<<<<<<<<<<<<<
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) +");").setName("common HTML entity")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_makeHTMLTags); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Word); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_alphas); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_alphanums); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_9 = PyNumber_Add(__pyx_t_19, __pyx_kp_u__768); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyTuple_New(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_2)) __PYX_ERR(0, 7425, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_t_9)) __PYX_ERR(0, 7425, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_19, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_tuple__769, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_19))) || (PyList_CheckExact(__pyx_t_19))) {
    PyObject* sequence = __pyx_t_19;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 7425, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_14 = PyObject_GetIter(__pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __pyx_t_20 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_14);
    index = 0; __pyx_t_9 = __pyx_t_20(__pyx_t_14); if (unlikely(!__pyx_t_9)) goto __pyx_L79_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_9);
    index = 1; __pyx_t_3 = __pyx_t_20(__pyx_t_14); if (unlikely(!__pyx_t_3)) goto __pyx_L79_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_20(__pyx_t_14), 2) < 0) __PYX_ERR(0, 7425, __pyx_L1_error)
    __pyx_t_20 = NULL;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    goto __pyx_L80_unpacking_done;
    __pyx_L79_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_20 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 7425, __pyx_L1_error)
    __pyx_L80_unpacking_done:;
  }
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_anyOpenTag, __pyx_t_9) < 0) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_anyCloseTag, __pyx_t_3) < 0) __PYX_ERR(0, 7425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7426
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))             # <<<<<<<<<<<<<<
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) +");").setName("common HTML entity")
 * def replaceHTMLEntity(t):
 */
  __pyx_t_19 = PyUnicode_Split(__pyx_kp_u_gt_lt_amp_nbsp_quot_apos, ((PyObject *)NULL), -1L); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_19)) __PYX_ERR(0, 7426, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_u__770);
  __Pyx_GIVEREF(__pyx_kp_u__770);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_kp_u__770)) __PYX_ERR(0, 7426, __pyx_L1_error);
  __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_3, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyDict_Type)), __pyx_t_19); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_htmlEntityMap, __pyx_t_3) < 0) __PYX_ERR(0, 7426, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7427
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) +");").setName("common HTML entity")             # <<<<<<<<<<<<<<
 * def replaceHTMLEntity(t):
 *     """Helper parser action to replace common HTML entities with their special characters"""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Regex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_htmlEntityMap); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_keys); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__136, __pyx_t_19); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyUnicode_Concat(__pyx_kp_u_P_entity, __pyx_t_9); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_19, __pyx_kp_u__771); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__772, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_commonHTMLEntity, __pyx_t_19) < 0) __PYX_ERR(0, 7427, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7428
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) +");").setName("common HTML entity")
 * def replaceHTMLEntity(t):             # <<<<<<<<<<<<<<
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_77replaceHTMLEntity, 0, __pyx_n_s_replaceHTMLEntity, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__773)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_replaceHTMLEntity, __pyx_t_19) < 0) __PYX_ERR(0, 7428, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7433
 * 
 * # it's easy to get these comment structures wrong - they're very common, so may as well make them available
 * cStyleComment = Combine(Regex(r"/\*(?:[^*]|\*(?!/))*") + '*[inserted by cython to avoid comment closer]/').setName("C style comment")             # <<<<<<<<<<<<<<
 * "Comment of the form ``/[inserted by cython to avoid comment start]* ... *[inserted by cython to avoid comment closer]/``"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Combine); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Regex); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__775, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__776); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__777, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cStyleComment, __pyx_t_3) < 0) __PYX_ERR(0, 7433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7436
 * "Comment of the form ``/[inserted by cython to avoid comment start]* ... *[inserted by cython to avoid comment closer]/``"
 * 
 * htmlComment = Regex(r"<!--[\s\S]*?-->").setName("HTML comment")             # <<<<<<<<<<<<<<
 * "Comment of the form ``<!-- ... -->``"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Regex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__778, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__779, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_htmlComment, __pyx_t_9) < 0) __PYX_ERR(0, 7436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7439
 * "Comment of the form ``<!-- ... -->``"
 * 
 * restOfLine = Regex(r".*").leaveWhitespace().setName("rest of line")             # <<<<<<<<<<<<<<
 * dblSlashComment = Regex(r"//(?:\\\n|[^\n])*").setName("// comment")
 * "Comment of the form ``// ... (to end of line)``"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Regex); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__781, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__782, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_restOfLine, __pyx_t_3) < 0) __PYX_ERR(0, 7439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7440
 * 
 * restOfLine = Regex(r".*").leaveWhitespace().setName("rest of line")
 * dblSlashComment = Regex(r"//(?:\\\n|[^\n])*").setName("// comment")             # <<<<<<<<<<<<<<
 * "Comment of the form ``// ... (to end of line)``"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Regex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__783, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__784, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dblSlashComment, __pyx_t_9) < 0) __PYX_ERR(0, 7440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7443
 * "Comment of the form ``// ... (to end of line)``"
 * 
 * cppStyleComment = Combine(Regex(r"/\*(?:[^*]|\*(?!/))*") + '*[inserted by cython to avoid comment closer]/' | dblSlashComment).setName("C++ style comment")             # <<<<<<<<<<<<<<
 * "Comment of either form :class:`cStyleComment` or :class:`dblSlashComment`"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Combine); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Regex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__775, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_19, __pyx_kp_u__776); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_dblSlashComment); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_14 = PyNumber_Or(__pyx_t_3, __pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_14); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__785, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cppStyleComment, __pyx_t_19) < 0) __PYX_ERR(0, 7443, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7446
 * "Comment of either form :class:`cStyleComment` or :class:`dblSlashComment`"
 * 
 * javaStyleComment = cppStyleComment             # <<<<<<<<<<<<<<
 * "Same as :class:`cppStyleComment`"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_cppStyleComment); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_javaStyleComment, __pyx_t_19) < 0) __PYX_ERR(0, 7446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7449
 * "Same as :class:`cppStyleComment`"
 * 
 * pythonStyleComment = Regex(r"#.*").setName("Python style comment")             # <<<<<<<<<<<<<<
 * "Comment of the form ``# ... (to end of line)``"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Regex); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_tuple__787, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_tuple__788, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pythonStyleComment, __pyx_t_14) < 0) __PYX_ERR(0, 7449, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7452
 * "Comment of the form ``# ... (to end of line)``"
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',')             # <<<<<<<<<<<<<<
 *                                   + Optional(Word(" \t")
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Combine); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Word); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_printables); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 7452, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_excludeChars, __pyx_kp_u__34) < 0) __PYX_ERR(0, 7452, __pyx_L1_error)
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7453
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',')
 *                                   + Optional(Word(" \t")             # <<<<<<<<<<<<<<
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Optional); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Word); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__790, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7454
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',')
 *                                   + Optional(Word(" \t")
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 * """(Deprecated) Predefined expression of 1 or more printable words or
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__791, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Invert(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_Add(__pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_LineEnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Invert(__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_Add(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7453
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',')
 *                                   + Optional(Word(" \t")             # <<<<<<<<<<<<<<
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_Add(__pyx_t_10, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7452
 * "Comment of the form ``# ... (to end of line)``"
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',')             # <<<<<<<<<<<<<<
 *                                   + Optional(Word(" \t")
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7454
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',')
 *                                   + Optional(Word(" \t")
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 * """(Deprecated) Predefined expression of 1 or more printable words or
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_streamline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__792, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_commasepitem, __pyx_t_9) < 0) __PYX_ERR(0, 7452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7455
 *                                   + Optional(Word(" \t")
 *                                              + ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")             # <<<<<<<<<<<<<<
 * """(Deprecated) Predefined expression of 1 or more printable words or
 * quoted strings, separated by commas.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_delimitedList); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_quotedString); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_copy); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_CallNoArg(__pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_commasepitem); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_10 = PyNumber_Or(__pyx_t_14, __pyx_t_19); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyTuple_New(1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_10)) __PYX_ERR(0, 7455, __pyx_L1_error);
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_default, __pyx_kp_u__10) < 0) __PYX_ERR(0, 7455, __pyx_L1_error)
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_19, __pyx_t_10); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_setName); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__793, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_commaSeparatedList, __pyx_t_10) < 0) __PYX_ERR(0, 7455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":7463
 * 
 * # some other useful expressions - using lower-case class name since we are really using this as a namespace
 * class pyparsing_common:             # <<<<<<<<<<<<<<
 *     """Here are some common low-level expressions that may be useful in
 *     jump-starting parser development:
 */
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_pyparsing_common, __pyx_n_s_pyparsing_common, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Here_are_some_common_low_level_e); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);

  /* "cPyparsing.pyx":7608
 *     """
 * 
 *     convertToInteger = tokenMap(int)             # <<<<<<<<<<<<<<
 *     """
 *     Parse action for converting parsed integers to Python int
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_tokenMap); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, ((PyObject *)(&PyInt_Type))};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7608, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_convertToInteger, __pyx_t_14) < 0) __PYX_ERR(0, 7608, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7613
 *     """
 * 
 *     convertToFloat = tokenMap(float)             # <<<<<<<<<<<<<<
 *     """
 *     Parse action for converting parsed numbers to Python float
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_tokenMap); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, ((PyObject *)(&PyFloat_Type))};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7613, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_convertToFloat, __pyx_t_14) < 0) __PYX_ERR(0, 7613, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7618
 *     """
 * 
 *     integer = Word(nums).setName("integer").setParseAction(convertToInteger)             # <<<<<<<<<<<<<<
 *     """expression that parses an unsigned integer, returns an int"""
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Word); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_nums); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_3};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_n_u_integer};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_convertToInteger);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_convertToInteger);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_t_9};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_integer, __pyx_t_14) < 0) __PYX_ERR(0, 7618, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7621
 *     """expression that parses an unsigned integer, returns an int"""
 * 
 *     hex_integer = Word(hexnums).setName("hex integer").setParseAction(tokenMap(int, 16))             # <<<<<<<<<<<<<<
 *     """expression that parses a hexadecimal integer, returns an int"""
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Word); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_hexnums); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_3};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_kp_u_hex_integer};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_tokenMap); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, ((PyObject *)(&PyInt_Type)), __pyx_int_16};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_2};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_hex_integer_2, __pyx_t_14) < 0) __PYX_ERR(0, 7621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7624
 *     """expression that parses a hexadecimal integer, returns an int"""
 * 
 *     signed_integer = Regex(r'[+-]?\d+').setName("signed integer").setParseAction(convertToInteger)             # <<<<<<<<<<<<<<
 *     """expression that parses an integer with optional leading sign, returns an int"""
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Regex); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_d_2};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7624, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_u_signed_integer};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7624, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_convertToInteger);
  if (unlikely(!__pyx_t_19)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_convertToInteger);
  }
  if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_19};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7624, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_signed_integer_2, __pyx_t_14) < 0) __PYX_ERR(0, 7624, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7627
 *     """expression that parses an integer with optional leading sign, returns an int"""
 * 
 *     fraction = (signed_integer().setParseAction(convertToFloat) + '/' + signed_integer().setParseAction(convertToFloat)).setName("fraction")             # <<<<<<<<<<<<<<
 *     """fractional expression of an integer divided by an integer, returns a float"""
 *     fraction.addParseAction(lambda t: t[0]/t[-1])
 */
  __pyx_t_2 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_signed_integer_2);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_signed_integer_2);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_19)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_19};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyNumber_Add(__pyx_t_9, __pyx_kp_u__144); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_signed_integer_2);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_signed_integer_2);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_19)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_19};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_fraction};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_fraction, __pyx_t_14) < 0) __PYX_ERR(0, 7627, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7629
 *     fraction = (signed_integer().setParseAction(convertToFloat) + '/' + signed_integer().setParseAction(convertToFloat)).setName("fraction")
 *     """fractional expression of an integer divided by an integer, returns a float"""
 *     fraction.addParseAction(lambda t: t[0]/t[-1])             # <<<<<<<<<<<<<<
 * 
 *     mixed_integer = (fraction | signed_integer + Optional(Optional('-').suppress() + fraction)).setName("fraction or mixed integer-fraction")
 */
  __pyx_t_9 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_fraction);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_fraction);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16pyparsing_common_6lambda71, 0, __pyx_n_s_pyparsing_common_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_9};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7631
 *     fraction.addParseAction(lambda t: t[0]/t[-1])
 * 
 *     mixed_integer = (fraction | signed_integer + Optional(Optional('-').suppress() + fraction)).setName("fraction or mixed integer-fraction")             # <<<<<<<<<<<<<<
 *     """mixed integer of the form 'integer - fraction', with optional leading integer, returns float"""
 *     mixed_integer.addParseAction(sum)
 */
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_fraction);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_fraction);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_signed_integer_2);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_signed_integer_2);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Optional); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GetModuleGlobalName(__pyx_t_22, __pyx_n_s_Optional); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_23 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_22))) {
    __pyx_t_23 = PyMethod_GET_SELF(__pyx_t_22);
    if (likely(__pyx_t_23)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_22);
      __Pyx_INCREF(__pyx_t_23);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_22, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_23, __pyx_kp_u__105};
    __pyx_t_21 = __Pyx_PyObject_FastCall(__pyx_t_22, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
    if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  }
  __pyx_t_22 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_suppress); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_22))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_22);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_22);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_22, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, NULL};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_22, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  }
  __pyx_t_22 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_fraction);
  if (unlikely(!__pyx_t_22)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_22, __pyx_n_s_fraction);
  }
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_21 = PyNumber_Add(__pyx_t_8, __pyx_t_22); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_22, __pyx_t_21};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __pyx_t_19 = PyNumber_Add(__pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Or(__pyx_t_3, __pyx_t_19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_u_fraction_or_mixed_integer_fracti};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_mixed_integer, __pyx_t_14) < 0) __PYX_ERR(0, 7631, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7633
 *     mixed_integer = (fraction | signed_integer + Optional(Optional('-').suppress() + fraction)).setName("fraction or mixed integer-fraction")
 *     """mixed integer of the form 'integer - fraction', with optional leading integer, returns float"""
 *     mixed_integer.addParseAction(sum)             # <<<<<<<<<<<<<<
 * 
 *     real = Regex(r'[+-]?(?:\d+\.\d*|\.\d+)').setName("real number").setParseAction(convertToFloat)
 */
  __pyx_t_19 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_mixed_integer);
  if (unlikely(!__pyx_t_19)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_mixed_integer);
  }
  if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_builtin_sum};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7635
 *     mixed_integer.addParseAction(sum)
 * 
 *     real = Regex(r'[+-]?(?:\d+\.\d*|\.\d+)').setName("real number").setParseAction(convertToFloat)             # <<<<<<<<<<<<<<
 *     """expression that parses a floating point number and returns a float"""
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Regex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_kp_u_d_d_d};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_kp_u_real_number};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_t_2};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_real, __pyx_t_14) < 0) __PYX_ERR(0, 7635, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7638
 *     """expression that parses a floating point number and returns a float"""
 * 
 *     sci_real = Regex(r'[+-]?(?:\d+(?:[eE][+-]?\d+)|(?:\d+\.\d*|\.\d+)(?:[eE][+-]?\d+)?)').setName("real number with scientific notation").setParseAction(convertToFloat)             # <<<<<<<<<<<<<<
 *     """expression that parses a floating point number with optional
 *     scientific notation and returns a float"""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Regex); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_kp_u_d_eE_d_d_d_d_eE_d};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_u_real_number_with_scientific_nota};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_sci_real, __pyx_t_14) < 0) __PYX_ERR(0, 7638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7643
 * 
 *     # streamlining this expression makes the docs nicer-looking
 *     number = (sci_real | real | signed_integer).streamline()             # <<<<<<<<<<<<<<
 *     """any numeric expression, returns the corresponding Python type"""
 * 
 */
  __pyx_t_19 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_sci_real);
  if (unlikely(!__pyx_t_19)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_sci_real);
  }
  if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_real);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_real);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Or(__pyx_t_19, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_signed_integer_2);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_signed_integer_2);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_19 = PyNumber_Or(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, NULL};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_number, __pyx_t_14) < 0) __PYX_ERR(0, 7643, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7646
 *     """any numeric expression, returns the corresponding Python type"""
 * 
 *     fnumber = Regex(r'[+-]?\d+\.?\d*([eE][+-]?\d+)?').setName("fnumber").setParseAction(convertToFloat)             # <<<<<<<<<<<<<<
 *     """any int or real number, returned as float"""
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_kp_u_d_d_eE_d};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_n_u_fnumber};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_t_3};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_fnumber, __pyx_t_14) < 0) __PYX_ERR(0, 7646, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7649
 *     """any int or real number, returned as float"""
 * 
 *     identifier = Word(alphas + '_', alphanums + '_').setName("identifier")             # <<<<<<<<<<<<<<
 *     """typical code identifier (leading alpha or '_', followed by 0 or more alphas, nums, or '_')"""
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Word); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_alphas); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_9 = PyNumber_Add(__pyx_t_19, __pyx_n_u__621); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_alphanums); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_21 = PyNumber_Add(__pyx_t_19, __pyx_n_u__621); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_19, __pyx_t_9, __pyx_t_21};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7649, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_identifier};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7649, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_identifier, __pyx_t_14) < 0) __PYX_ERR(0, 7649, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7652
 *     """typical code identifier (leading alpha or '_', followed by 0 or more alphas, nums, or '_')"""
 * 
 *     ipv4_address = Regex(r'(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})(\.(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})){3}').setName("IPv4 address")             # <<<<<<<<<<<<<<
 *     "IPv4 address (``0.0.0.0 - 255.255.255.255``)"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7652, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_IPv4_address};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7652, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_ipv4_address, __pyx_t_14) < 0) __PYX_ERR(0, 7652, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7655
 *     "IPv4 address (``0.0.0.0 - 255.255.255.255``)"
 * 
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")             # <<<<<<<<<<<<<<
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Regex); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_kp_u_0_9a_fA_F_1_4};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_hex_integer_2};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_ipv6_part, __pyx_t_14) < 0) __PYX_ERR(0, 7655, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7656
 * 
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")             # <<<<<<<<<<<<<<
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 *                            + "::"
 */
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_21 = PyNumber_Add(__pyx_kp_u__145, __pyx_t_2); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_MultiplyObjC(__pyx_t_21, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = PyNumber_Add(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_kp_u_full_IPv6_address};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_full_ipv6_address, __pyx_t_14) < 0) __PYX_ERR(0, 7656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7657
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))             # <<<<<<<<<<<<<<
 *                            + "::"
 *                            + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_Optional); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_19 = PyNumber_Add(__pyx_kp_u__145, __pyx_t_9); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_Multiply(__pyx_t_19, __pyx_tuple__794); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyNumber_Add(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_19};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_21, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  }

  /* "cPyparsing.pyx":7658
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 *                            + "::"             # <<<<<<<<<<<<<<
 *                            + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 *                            ).setName("short IPv6 address")
 */
  __pyx_t_21 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__795); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7659
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 *                            + "::"
 *                            + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))             # <<<<<<<<<<<<<<
 *                            ).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Optional); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_9 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_22 = PyNumber_Add(__pyx_kp_u__145, __pyx_t_3); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_22, __pyx_tuple__794); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = PyNumber_Add(__pyx_t_9, __pyx_t_3); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_22};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __pyx_t_19 = PyNumber_Add(__pyx_t_21, __pyx_t_2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7660
 *                            + "::"
 *                            + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 *                            ).setName("short IPv6 address")             # <<<<<<<<<<<<<<
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_kp_u_short_IPv6_address};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_short_ipv6_address, __pyx_t_14) < 0) __PYX_ERR(0, 7657, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7661
 *                            + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))
 *                            ).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)             # <<<<<<<<<<<<<<
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")
 */
  __pyx_t_2 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_short_ipv6_address);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_short_ipv6_address);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_addCondition); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16pyparsing_common_7lambda72, 0, __pyx_n_s_pyparsing_common_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_t_2};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7662
 *                            ).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")             # <<<<<<<<<<<<<<
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")
 *     "IPv6 address (long, short, or mixed form)"
 */
  __pyx_t_19 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_ipv4_address);
  if (unlikely(!__pyx_t_19)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_ipv4_address);
  }
  if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_ffff, __pyx_t_19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_u_mixed_IPv6_address};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_mixed_ipv6_address, __pyx_t_14) < 0) __PYX_ERR(0, 7662, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7663
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")             # <<<<<<<<<<<<<<
 *     "IPv6 address (long, short, or mixed form)"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Combine); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_full_ipv6_address);
  if (unlikely(!__pyx_t_22)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_22, __pyx_n_s_full_ipv6_address);
  }
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_mixed_ipv6_address);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_mixed_ipv6_address);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = PyNumber_Or(__pyx_t_22, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_short_ipv6_address);
  if (unlikely(!__pyx_t_3)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_short_ipv6_address);
  }
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_22 = PyNumber_Or(__pyx_t_9, __pyx_t_3); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_22, __pyx_kp_u_IPv6_address};
    __pyx_t_21 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
    if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7663, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_21};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7663, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_kp_u_IPv6_address};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7663, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_ipv6_address, __pyx_t_14) < 0) __PYX_ERR(0, 7663, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7666
 *     "IPv6 address (long, short, or mixed form)"
 * 
 *     mac_address = Regex(r'[0-9a-fA-F]{2}([:.-])[0-9a-fA-F]{2}(?:\1[0-9a-fA-F]{2}){4}').setName("MAC address")             # <<<<<<<<<<<<<<
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Regex); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_u_MAC_address};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_mac_address, __pyx_t_14) < 0) __PYX_ERR(0, 7666, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7669
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDate(fmt="%Y-%m-%d"):
 *         """
 */
  __pyx_t_14 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16pyparsing_common_1convertToDate, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_pyparsing_common_convertToDate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__797)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_14, __pyx_tuple__798);
  __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_14); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_convertToDate, __pyx_t_19) < 0) __PYX_ERR(0, 7669, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7694
 *         return cvt_fn
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):
 *         """Helper to create a parse action for converting parsed
 */
  __pyx_t_19 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16pyparsing_common_3convertToDatetime, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_pyparsing_common_convertToDateti_2, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__799)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_19, __pyx_tuple__800);
  __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_convertToDatetime, __pyx_t_14) < 0) __PYX_ERR(0, 7694, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7719
 *         return cvt_fn
 * 
 *     iso8601_date = Regex(r'(?P<year>\d{4})(?:-(?P<month>\d\d)(?:-(?P<day>\d\d))?)?').setName("ISO8601 date")             # <<<<<<<<<<<<<<
 *     "ISO8601 date (``yyyy-mm-dd``)"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7719, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_kp_u_ISO8601_date};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7719, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_iso8601_date, __pyx_t_14) < 0) __PYX_ERR(0, 7719, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7722
 *     "ISO8601 date (``yyyy-mm-dd``)"
 * 
 *     iso8601_datetime = Regex(r'(?P<year>\d{4})-(?P<month>\d\d)-(?P<day>\d\d)[T ](?P<hour>\d\d):(?P<minute>\d\d)(:(?P<second>\d\d(\.\d*)?)?)?(?P<tz>Z|[+-]\d\d:?\d\d)?').setName("ISO8601 datetime")             # <<<<<<<<<<<<<<
 *     "ISO8601 datetime (``yyyy-mm-ddThh:mm:ss.s(Z|+-00:00)``) - trailing seconds, milliseconds, and timezone optional; accepts separating ``'T'`` or ``' '``"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Regex); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7722, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_u_ISO8601_datetime};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7722, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_iso8601_datetime, __pyx_t_14) < 0) __PYX_ERR(0, 7722, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7725
 *     "ISO8601 datetime (``yyyy-mm-ddThh:mm:ss.s(Z|+-00:00)``) - trailing seconds, milliseconds, and timezone optional; accepts separating ``'T'`` or ``' '``"
 * 
 *     uuid = Regex(r'[0-9a-fA-F]{8}(-[0-9a-fA-F]{4}){3}-[0-9a-fA-F]{12}').setName("UUID")             # <<<<<<<<<<<<<<
 *     "UUID (``xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx``)"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7725, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_n_u_UUID};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7725, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_uuid, __pyx_t_14) < 0) __PYX_ERR(0, 7725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7728
 *     "UUID (``xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx``)"
 * 
 *     _html_stripper = anyOpenTag.suppress() | anyCloseTag.suppress()             # <<<<<<<<<<<<<<
 *     @staticmethod
 *     def stripHTMLTags(s, l, tokens):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_anyOpenTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_suppress); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7728, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_anyCloseTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_suppress); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_21, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7728, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  }
  __pyx_t_21 = PyNumber_Or(__pyx_t_14, __pyx_t_19); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_html_stripper, __pyx_t_21) < 0) __PYX_ERR(0, 7728, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":7729
 * 
 *     _html_stripper = anyOpenTag.suppress() | anyCloseTag.suppress()
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def stripHTMLTags(s, l, tokens):
 *         """Parse action to remove HTML tags from web page HTML source
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16pyparsing_common_5stripHTMLTags, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_pyparsing_common_stripHTMLTags, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__802)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_21); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_stripHTMLTags, __pyx_t_19) < 0) __PYX_ERR(0, 7729, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7747
 *         return pyparsing_common._html_stripper.transformString(tokens[0])
 * 
 *     _commasepitem = Combine(OneOrMore(~Literal(",")             # <<<<<<<<<<<<<<
 *                                       + ~LineEnd()
 *                                       + Word(printables, excludeChars=',')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Combine); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_22, __pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_Literal); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_23 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_23 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_23)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_23);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_23, __pyx_kp_u__34};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_t_8 = PyNumber_Invert(__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7748
 * 
 *     _commasepitem = Combine(OneOrMore(~Literal(",")
 *                                       + ~LineEnd()             # <<<<<<<<<<<<<<
 *                                       + Word(printables, excludeChars=',')
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_23, __pyx_n_s_LineEnd); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 7748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __pyx_t_24 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_23))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_23);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_23);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_23, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_24, NULL};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_23, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  }
  __pyx_t_23 = PyNumber_Invert(__pyx_t_9); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 7748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_Add(__pyx_t_8, __pyx_t_23); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;

  /* "cPyparsing.pyx":7749
 *     _commasepitem = Combine(OneOrMore(~Literal(",")
 *                                       + ~LineEnd()
 *                                       + Word(printables, excludeChars=',')             # <<<<<<<<<<<<<<
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_23, __pyx_n_s_Word); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 7749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_printables); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_24 = PyTuple_New(1); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 7749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_24, 0, __pyx_t_8)) __PYX_ERR(0, 7749, __pyx_L1_error);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_excludeChars, __pyx_kp_u__34) < 0) __PYX_ERR(0, 7749, __pyx_L1_error)
  __pyx_t_25 = __Pyx_PyObject_Call(__pyx_t_23, __pyx_t_24, __pyx_t_8); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 7749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_Add(__pyx_t_9, __pyx_t_25); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;

  /* "cPyparsing.pyx":7750
 *                                       + ~LineEnd()
 *                                       + Word(printables, excludeChars=',')
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 *     comma_separated_list = delimitedList(Optional(quotedString.copy()
 *                                                   | _commasepitem, default='')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Optional); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GetModuleGlobalName(__pyx_t_23, __pyx_n_s_White); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 7750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __pyx_t_26 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_23))) {
    __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_23);
    if (likely(__pyx_t_26)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_23);
      __Pyx_INCREF(__pyx_t_26);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_23, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_26, __pyx_kp_u__789};
    __pyx_t_24 = __Pyx_PyObject_FastCall(__pyx_t_23, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
    if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 7750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_24);
    __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  }
  __pyx_t_23 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_23 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_23)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_23);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_23, __pyx_t_24};
    __pyx_t_25 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
    __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
    if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 7750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_25);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = PyNumber_Add(__pyx_t_8, __pyx_t_25); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __pyx_t_25 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_22))) {
    __pyx_t_25 = PyMethod_GET_SELF(__pyx_t_22);
    if (likely(__pyx_t_25)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_22);
      __Pyx_INCREF(__pyx_t_25);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_22, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_25, __pyx_t_9};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_22, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  }
  __pyx_t_22 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_22, __pyx_t_3};
    __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_streamline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_14, NULL};
    __pyx_t_21 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_n_u_commaItem};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_commasepitem, __pyx_t_19) < 0) __PYX_ERR(0, 7747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7751
 *                                       + Word(printables, excludeChars=',')
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy()             # <<<<<<<<<<<<<<
 *                                                   | _commasepitem, default='')
 *                                          ).setName("comma separated list")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_delimitedList); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_Optional); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GetModuleGlobalName(__pyx_t_22, __pyx_n_s_quotedString); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_copy); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_22, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }

  /* "cPyparsing.pyx":7752
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy()
 *                                                   | _commasepitem, default='')             # <<<<<<<<<<<<<<
 *                                          ).setName("comma separated list")
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 */
  __pyx_t_9 = PyObject_GetItem(__pyx_t_10, __pyx_n_s_commasepitem);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_commasepitem);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_22 = PyNumber_Or(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7751
 *                                       + Word(printables, excludeChars=',')
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy()             # <<<<<<<<<<<<<<
 *                                                   | _commasepitem, default='')
 *                                          ).setName("comma separated list")
 */
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_22);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_22)) __PYX_ERR(0, 7751, __pyx_L1_error);
  __pyx_t_22 = 0;

  /* "cPyparsing.pyx":7752
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy()
 *                                                   | _commasepitem, default='')             # <<<<<<<<<<<<<<
 *                                          ).setName("comma separated list")
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 */
  __pyx_t_22 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (PyDict_SetItem(__pyx_t_22, __pyx_n_s_default, __pyx_kp_u__10) < 0) __PYX_ERR(0, 7752, __pyx_L1_error)

  /* "cPyparsing.pyx":7751
 *                                       + Word(printables, excludeChars=',')
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy()             # <<<<<<<<<<<<<<
 *                                                   | _commasepitem, default='')
 *                                          ).setName("comma separated list")
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_9, __pyx_t_22); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_22, __pyx_t_3};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_21, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  }

  /* "cPyparsing.pyx":7753
 *     comma_separated_list = delimitedList(Optional(quotedString.copy()
 *                                                   | _commasepitem, default='')
 *                                          ).setName("comma separated list")             # <<<<<<<<<<<<<<
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 * 
 */
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_u_comma_separated_list};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_21, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_comma_separated_list_2, __pyx_t_19) < 0) __PYX_ERR(0, 7751, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7756
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 * 
 *     upcaseTokens = staticmethod(tokenMap(lambda t: _ustr(t).upper()))             # <<<<<<<<<<<<<<
 *     """Parse action to convert tokens to upper case."""
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_tokenMap); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16pyparsing_common_8lambda74, 0, __pyx_n_s_pyparsing_common_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_19 = __Pyx_PyObject_FastCall(__pyx_t_21, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  }
  __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_19); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_upcaseTokens, __pyx_t_21) < 0) __PYX_ERR(0, 7756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":7759
 *     """Parse action to convert tokens to upper case."""
 * 
 *     downcaseTokens = staticmethod(tokenMap(lambda t: _ustr(t).lower()))             # <<<<<<<<<<<<<<
 *     """Parse action to convert tokens to lower case."""
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_tokenMap); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_16pyparsing_common_9lambda75, 0, __pyx_n_s_pyparsing_common_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_21 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_21); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_downcaseTokens, __pyx_t_19) < 0) __PYX_ERR(0, 7759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7463
 * 
 * # some other useful expressions - using lower-case class name since we are really using this as a namespace
 * class pyparsing_common:             # <<<<<<<<<<<<<<
 *     """Here are some common low-level expressions that may be useful in
 *     jump-starting parser development:
 */
  __pyx_t_19 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_n_s_pyparsing_common, __pyx_empty_tuple, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyparsing_common, __pyx_t_19) < 0) __PYX_ERR(0, 7463, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":7763
 * 
 * 
 * class _lazyclassproperty(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, fn):
 *         self.fn = fn
 */
  __pyx_t_10 = __Pyx_PEP560_update_bases(__pyx_tuple__804); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_19 = __Pyx_CalculateMetaclass(NULL, __pyx_t_10); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_21 = __Pyx_Py3MetaclassPrepare(__pyx_t_19, __pyx_t_10, __pyx_n_s_lazyclassproperty, __pyx_n_s_lazyclassproperty, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (__pyx_t_10 != __pyx_tuple__804) {
    if (unlikely((PyDict_SetItemString(__pyx_t_21, "__orig_bases__", __pyx_tuple__804) < 0))) __PYX_ERR(0, 7763, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":7764
 * 
 * class _lazyclassproperty(object):
 *     def __init__(self, fn):             # <<<<<<<<<<<<<<
 *         self.fn = fn
 *         self.__doc__ = fn.__doc__
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18_lazyclassproperty_1__init__, 0, __pyx_n_s_lazyclassproperty___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__805)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_21, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 7764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7769
 *         self.__name__ = fn.__name__
 * 
 *     def __get__(self, obj, cls):             # <<<<<<<<<<<<<<
 *         if cls is None:
 *             cls = type(obj)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_18_lazyclassproperty_3__get__, 0, __pyx_n_s_lazyclassproperty___get, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__807)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_21, __pyx_n_s_get_2, __pyx_t_2) < 0) __PYX_ERR(0, 7769, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7763
 * 
 * 
 * class _lazyclassproperty(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, fn):
 *         self.fn = fn
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_19, __pyx_n_s_lazyclassproperty, __pyx_t_10, __pyx_t_21, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_lazyclassproperty, __pyx_t_2) < 0) __PYX_ERR(0, 7763, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":7781
 * 
 * 
 * class unicode_set(object):             # <<<<<<<<<<<<<<
 *     """
 *     A set of Unicode characters, for language-specific strings for
 */
  __pyx_t_10 = __Pyx_PEP560_update_bases(__pyx_tuple__809); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_19 = __Pyx_CalculateMetaclass(NULL, __pyx_t_10); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_21 = __Pyx_Py3MetaclassPrepare(__pyx_t_19, __pyx_t_10, __pyx_n_s_unicode_set, __pyx_n_s_unicode_set, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_A_set_of_Unicode_characters_for); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (__pyx_t_10 != __pyx_tuple__809) {
    if (unlikely((PyDict_SetItemString(__pyx_t_21, "__orig_bases__", __pyx_tuple__809) < 0))) __PYX_ERR(0, 7781, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":7795
 *             pass
 *     """
 *     _ranges = []             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_21, __pyx_n_s_ranges, __pyx_t_2) < 0) __PYX_ERR(0, 7795, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7797
 *     _ranges = []
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _get_chars_for_ranges(cls):
 *         ret = []
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11unicode_set_1_get_chars_for_ranges, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_unicode_set__get_chars_for_range, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__811)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_21, __pyx_n_s_get_chars_for_ranges, __pyx_t_3) < 0) __PYX_ERR(0, 7797, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7807
 *         return [unichr(c) for c in sorted(set(ret))]
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def printables(cls):
 *         "all non-whitespace characters in this range"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_lazyclassproperty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11unicode_set_3printables, 0, __pyx_n_s_unicode_set_printables, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__812)); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_22};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7807, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_21, __pyx_n_s_printables, __pyx_t_3) < 0) __PYX_ERR(0, 7807, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7812
 *         return u''.join(filterfalse(unicode.isspace, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def alphas(cls):
 *         "all alphabetic characters in this range"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_lazyclassproperty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11unicode_set_5alphas, 0, __pyx_n_s_unicode_set_alphas, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__813)); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_22};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7812, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_21, __pyx_n_s_alphas, __pyx_t_3) < 0) __PYX_ERR(0, 7812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7817
 *         return u''.join(filter(unicode.isalpha, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def nums(cls):
 *         "all numeric digit characters in this range"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_lazyclassproperty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11unicode_set_7nums, 0, __pyx_n_s_unicode_set_nums, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__814)); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_22};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_21, __pyx_n_s_nums, __pyx_t_3) < 0) __PYX_ERR(0, 7817, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7822
 *         return u''.join(filter(unicode.isdigit, cls._get_chars_for_ranges()))
 * 
 *     @_lazyclassproperty             # <<<<<<<<<<<<<<
 *     def alphanums(cls):
 *         "all alphanumeric characters in this range"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_lazyclassproperty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_11unicode_set_9alphanums, 0, __pyx_n_s_unicode_set_alphanums, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__815)); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_22};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_21, __pyx_n_s_alphanums, __pyx_t_3) < 0) __PYX_ERR(0, 7822, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7781
 * 
 * 
 * class unicode_set(object):             # <<<<<<<<<<<<<<
 *     """
 *     A set of Unicode characters, for language-specific strings for
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(__pyx_t_19, __pyx_n_s_unicode_set, __pyx_t_10, __pyx_t_21, NULL, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_unicode_set, __pyx_t_3) < 0) __PYX_ERR(0, 7781, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":7828
 * 
 * 
 * class pyparsing_unicode(unicode_set):             # <<<<<<<<<<<<<<
 *     """
 *     A namespace class for defining common language unicode_sets.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_19 = PyTuple_New(1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_10)) __PYX_ERR(0, 7828, __pyx_L1_error);
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PEP560_update_bases(__pyx_t_19); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_21 = __Pyx_CalculateMetaclass(NULL, __pyx_t_10); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_21, __pyx_t_10, __pyx_n_s_pyparsing_unicode, __pyx_n_s_pyparsing_unicode, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_A_namespace_class_for_defining); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__pyx_t_10 != __pyx_t_19) {
    if (unlikely((PyDict_SetItemString(__pyx_t_3, "__orig_bases__", __pyx_t_19) < 0))) __PYX_ERR(0, 7828, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7832
 *     A namespace class for defining common language unicode_sets.
 *     """
 *     _ranges = [(32, sys.maxunicode)]             # <<<<<<<<<<<<<<
 * 
 *     class Latin1(unicode_set):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_sys); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_maxunicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyTuple_New(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_INCREF(__pyx_int_32);
  __Pyx_GIVEREF(__pyx_int_32);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_int_32)) __PYX_ERR(0, 7832, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_t_2)) __PYX_ERR(0, 7832, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_19)) __PYX_ERR(0, 7832, __pyx_L1_error);
  __pyx_t_19 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_ranges, __pyx_t_2) < 0) __PYX_ERR(0, 7832, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7834
 *     _ranges = [(32, sys.maxunicode)]
 * 
 *     class Latin1(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Latin-1 Unicode Character Range"
 *         _ranges = [(0x0020, 0x007e), (0x00a0, 0x00ff),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = PyTuple_New(1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_2)) __PYX_ERR(0, 7834, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_22, __pyx_t_2, __pyx_n_s_Latin1, __pyx_n_s_pyparsing_unicode_Latin1, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Latin_1_Unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_2 != __pyx_t_19) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_19) < 0))) __PYX_ERR(0, 7834, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7836
 *     class Latin1(unicode_set):
 *         "Unicode set for Latin-1 Unicode Character Range"
 *         _ranges = [(0x0020, 0x007e), (0x00a0, 0x00ff),]             # <<<<<<<<<<<<<<
 * 
 *     class LatinA(unicode_set):
 */
  __pyx_t_19 = PyList_New(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_INCREF(__pyx_tuple__816);
  __Pyx_GIVEREF(__pyx_tuple__816);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 0, __pyx_tuple__816)) __PYX_ERR(0, 7836, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__817);
  __Pyx_GIVEREF(__pyx_tuple__817);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 1, __pyx_tuple__817)) __PYX_ERR(0, 7836, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_ranges, __pyx_t_19) < 0) __PYX_ERR(0, 7836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7834
 *     _ranges = [(32, sys.maxunicode)]
 * 
 *     class Latin1(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Latin-1 Unicode Character Range"
 *         _ranges = [(0x0020, 0x007e), (0x00a0, 0x00ff),]
 */
  __pyx_t_19 = __Pyx_Py3ClassCreate(__pyx_t_22, __pyx_n_s_Latin1, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Latin1, __pyx_t_19) < 0) __PYX_ERR(0, 7834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7838
 *         _ranges = [(0x0020, 0x007e), (0x00a0, 0x00ff),]
 * 
 *     class LatinA(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Latin-A Unicode Character Range"
 *         _ranges = [(0x0100, 0x017f),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = PyTuple_New(1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_22, 0, __pyx_t_2)) __PYX_ERR(0, 7838, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_22); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_19 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_2, __pyx_n_s_LatinA, __pyx_n_s_pyparsing_unicode_LatinA, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Latin_A_Unicode); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (__pyx_t_2 != __pyx_t_22) {
    if (unlikely((PyDict_SetItemString(__pyx_t_19, "__orig_bases__", __pyx_t_22) < 0))) __PYX_ERR(0, 7838, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "cPyparsing.pyx":7840
 *     class LatinA(unicode_set):
 *         "Unicode set for Latin-A Unicode Character Range"
 *         _ranges = [(0x0100, 0x017f),]             # <<<<<<<<<<<<<<
 * 
 *     class LatinB(unicode_set):
 */
  __pyx_t_22 = PyList_New(1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_INCREF(__pyx_tuple__818);
  __Pyx_GIVEREF(__pyx_tuple__818);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_22, 0, __pyx_tuple__818)) __PYX_ERR(0, 7840, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_19, __pyx_n_s_ranges, __pyx_t_22) < 0) __PYX_ERR(0, 7840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "cPyparsing.pyx":7838
 *         _ranges = [(0x0020, 0x007e), (0x00a0, 0x00ff),]
 * 
 *     class LatinA(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Latin-A Unicode Character Range"
 *         _ranges = [(0x0100, 0x017f),]
 */
  __pyx_t_22 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_LatinA, __pyx_t_2, __pyx_t_19, NULL, 0, 0); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_LatinA, __pyx_t_22) < 0) __PYX_ERR(0, 7838, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7842
 *         _ranges = [(0x0100, 0x017f),]
 * 
 *     class LatinB(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Latin-B Unicode Character Range"
 *         _ranges = [(0x0180, 0x024f),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_2)) __PYX_ERR(0, 7842, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_22 = __Pyx_Py3MetaclassPrepare(__pyx_t_19, __pyx_t_2, __pyx_n_s_LatinB, __pyx_n_s_pyparsing_unicode_LatinB, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Latin_B_Unicode); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (__pyx_t_2 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_22, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 7842, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7844
 *     class LatinB(unicode_set):
 *         "Unicode set for Latin-B Unicode Character Range"
 *         _ranges = [(0x0180, 0x024f),]             # <<<<<<<<<<<<<<
 * 
 *     class Greek(unicode_set):
 */
  __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_tuple__819);
  __Pyx_GIVEREF(__pyx_tuple__819);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_tuple__819)) __PYX_ERR(0, 7844, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_22, __pyx_n_s_ranges, __pyx_t_9) < 0) __PYX_ERR(0, 7844, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7842
 *         _ranges = [(0x0100, 0x017f),]
 * 
 *     class LatinB(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Latin-B Unicode Character Range"
 *         _ranges = [(0x0180, 0x024f),]
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_19, __pyx_n_s_LatinB, __pyx_t_2, __pyx_t_22, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_LatinB, __pyx_t_9) < 0) __PYX_ERR(0, 7842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7846
 *         _ranges = [(0x0180, 0x024f),]
 * 
 *     class Greek(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Greek Unicode Character Ranges"
 *         _ranges = [
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = PyTuple_New(1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_2)) __PYX_ERR(0, 7846, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_22, __pyx_t_2, __pyx_n_s_Greek, __pyx_n_s_pyparsing_unicode_Greek, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Greek_Unicode_Ch); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_2 != __pyx_t_19) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_19) < 0))) __PYX_ERR(0, 7846, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7848
 *     class Greek(unicode_set):
 *         "Unicode set for Greek Unicode Character Ranges"
 *         _ranges = [             # <<<<<<<<<<<<<<
 *             (0x0370, 0x03ff), (0x1f00, 0x1f15), (0x1f18, 0x1f1d), (0x1f20, 0x1f45), (0x1f48, 0x1f4d),
 *             (0x1f50, 0x1f57), (0x1f59,), (0x1f5b,), (0x1f5d,), (0x1f5f, 0x1f7d), (0x1f80, 0x1fb4), (0x1fb6, 0x1fc4),
 */
  __pyx_t_19 = PyList_New(17); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_INCREF(__pyx_tuple__820);
  __Pyx_GIVEREF(__pyx_tuple__820);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 0, __pyx_tuple__820)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__821);
  __Pyx_GIVEREF(__pyx_tuple__821);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 1, __pyx_tuple__821)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__822);
  __Pyx_GIVEREF(__pyx_tuple__822);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 2, __pyx_tuple__822)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__823);
  __Pyx_GIVEREF(__pyx_tuple__823);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 3, __pyx_tuple__823)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__824);
  __Pyx_GIVEREF(__pyx_tuple__824);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 4, __pyx_tuple__824)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__825);
  __Pyx_GIVEREF(__pyx_tuple__825);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 5, __pyx_tuple__825)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__826);
  __Pyx_GIVEREF(__pyx_tuple__826);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 6, __pyx_tuple__826)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__827);
  __Pyx_GIVEREF(__pyx_tuple__827);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 7, __pyx_tuple__827)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__828);
  __Pyx_GIVEREF(__pyx_tuple__828);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 8, __pyx_tuple__828)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__829);
  __Pyx_GIVEREF(__pyx_tuple__829);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 9, __pyx_tuple__829)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__830);
  __Pyx_GIVEREF(__pyx_tuple__830);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 10, __pyx_tuple__830)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__831);
  __Pyx_GIVEREF(__pyx_tuple__831);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 11, __pyx_tuple__831)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__832);
  __Pyx_GIVEREF(__pyx_tuple__832);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 12, __pyx_tuple__832)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__833);
  __Pyx_GIVEREF(__pyx_tuple__833);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 13, __pyx_tuple__833)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__834);
  __Pyx_GIVEREF(__pyx_tuple__834);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 14, __pyx_tuple__834)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__835);
  __Pyx_GIVEREF(__pyx_tuple__835);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 15, __pyx_tuple__835)) __PYX_ERR(0, 7848, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__836);
  __Pyx_GIVEREF(__pyx_tuple__836);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_19, 16, __pyx_tuple__836)) __PYX_ERR(0, 7848, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_ranges, __pyx_t_19) < 0) __PYX_ERR(0, 7848, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7846
 *         _ranges = [(0x0180, 0x024f),]
 * 
 *     class Greek(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Greek Unicode Character Ranges"
 *         _ranges = [
 */
  __pyx_t_19 = __Pyx_Py3ClassCreate(__pyx_t_22, __pyx_n_s_Greek, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Greek, __pyx_t_19) < 0) __PYX_ERR(0, 7846, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7854
 *         ]
 * 
 *     class Cyrillic(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Cyrillic Unicode Character Range"
 *         _ranges = [(0x0400, 0x04ff)]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = PyTuple_New(1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_22, 0, __pyx_t_2)) __PYX_ERR(0, 7854, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_22); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_19 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_2, __pyx_n_s_Cyrillic, __pyx_n_s_pyparsing_unicode_Cyrillic, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Cyrillic_Unicode); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (__pyx_t_2 != __pyx_t_22) {
    if (unlikely((PyDict_SetItemString(__pyx_t_19, "__orig_bases__", __pyx_t_22) < 0))) __PYX_ERR(0, 7854, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "cPyparsing.pyx":7856
 *     class Cyrillic(unicode_set):
 *         "Unicode set for Cyrillic Unicode Character Range"
 *         _ranges = [(0x0400, 0x04ff)]             # <<<<<<<<<<<<<<
 * 
 *     class Chinese(unicode_set):
 */
  __pyx_t_22 = PyList_New(1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_INCREF(__pyx_tuple__837);
  __Pyx_GIVEREF(__pyx_tuple__837);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_22, 0, __pyx_tuple__837)) __PYX_ERR(0, 7856, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_19, __pyx_n_s_ranges, __pyx_t_22) < 0) __PYX_ERR(0, 7856, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "cPyparsing.pyx":7854
 *         ]
 * 
 *     class Cyrillic(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Cyrillic Unicode Character Range"
 *         _ranges = [(0x0400, 0x04ff)]
 */
  __pyx_t_22 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_Cyrillic, __pyx_t_2, __pyx_t_19, NULL, 0, 0); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Cyrillic, __pyx_t_22) < 0) __PYX_ERR(0, 7854, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7858
 *         _ranges = [(0x0400, 0x04ff)]
 * 
 *     class Chinese(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Chinese Unicode Character Range"
 *         _ranges = [(0x4e00, 0x9fff), (0x3000, 0x303f),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_2)) __PYX_ERR(0, 7858, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_22 = __Pyx_Py3MetaclassPrepare(__pyx_t_19, __pyx_t_2, __pyx_n_s_Chinese, __pyx_n_s_pyparsing_unicode_Chinese, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Chinese_Unicode); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (__pyx_t_2 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_22, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 7858, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7860
 *     class Chinese(unicode_set):
 *         "Unicode set for Chinese Unicode Character Range"
 *         _ranges = [(0x4e00, 0x9fff), (0x3000, 0x303f),]             # <<<<<<<<<<<<<<
 * 
 *     class Japanese(unicode_set):
 */
  __pyx_t_9 = PyList_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_tuple__838);
  __Pyx_GIVEREF(__pyx_tuple__838);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_tuple__838)) __PYX_ERR(0, 7860, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__839);
  __Pyx_GIVEREF(__pyx_tuple__839);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 1, __pyx_tuple__839)) __PYX_ERR(0, 7860, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_22, __pyx_n_s_ranges, __pyx_t_9) < 0) __PYX_ERR(0, 7860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7858
 *         _ranges = [(0x0400, 0x04ff)]
 * 
 *     class Chinese(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Chinese Unicode Character Range"
 *         _ranges = [(0x4e00, 0x9fff), (0x3000, 0x303f),]
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_19, __pyx_n_s_Chinese, __pyx_t_2, __pyx_t_22, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Chinese, __pyx_t_9) < 0) __PYX_ERR(0, 7858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7862
 *         _ranges = [(0x4e00, 0x9fff), (0x3000, 0x303f),]
 * 
 *     class Japanese(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Japanese Unicode Character Range, combining Kanji, Hiragana, and Katakana ranges"
 *         _ranges = []
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = PyTuple_New(1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_2)) __PYX_ERR(0, 7862, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_22, __pyx_t_2, __pyx_n_s_Japanese, __pyx_n_s_pyparsing_unicode_Japanese, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Japanese_Unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_2 != __pyx_t_19) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_19) < 0))) __PYX_ERR(0, 7862, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7864
 *     class Japanese(unicode_set):
 *         "Unicode set for Japanese Unicode Character Range, combining Kanji, Hiragana, and Katakana ranges"
 *         _ranges = []             # <<<<<<<<<<<<<<
 * 
 *         class Kanji(unicode_set):
 */
  __pyx_t_19 = PyList_New(0); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_ranges, __pyx_t_19) < 0) __PYX_ERR(0, 7864, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7866
 *         _ranges = []
 * 
 *         class Kanji(unicode_set):             # <<<<<<<<<<<<<<
 *             "Unicode set for Kanji Unicode Character Range"
 *             _ranges = [(0x4E00, 0x9Fbf), (0x3000, 0x303f),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_19)) __PYX_ERR(0, 7866, __pyx_L1_error);
  __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PEP560_update_bases(__pyx_t_14); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_25 = __Pyx_CalculateMetaclass(NULL, __pyx_t_19); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 7866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __pyx_t_8 = __Pyx_Py3MetaclassPrepare(__pyx_t_25, __pyx_t_19, __pyx_n_s_Kanji, __pyx_n_s_pyparsing_unicode_Japanese_Kanji, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Kanji_Unicode_Ch); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__pyx_t_19 != __pyx_t_14) {
    if (unlikely((PyDict_SetItemString(__pyx_t_8, "__orig_bases__", __pyx_t_14) < 0))) __PYX_ERR(0, 7866, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7868
 *         class Kanji(unicode_set):
 *             "Unicode set for Kanji Unicode Character Range"
 *             _ranges = [(0x4E00, 0x9Fbf), (0x3000, 0x303f),]             # <<<<<<<<<<<<<<
 * 
 *         class Hiragana(unicode_set):
 */
  __pyx_t_14 = PyList_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_INCREF(__pyx_tuple__840);
  __Pyx_GIVEREF(__pyx_tuple__840);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_14, 0, __pyx_tuple__840)) __PYX_ERR(0, 7868, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__839);
  __Pyx_GIVEREF(__pyx_tuple__839);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_14, 1, __pyx_tuple__839)) __PYX_ERR(0, 7868, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_8, __pyx_n_s_ranges, __pyx_t_14) < 0) __PYX_ERR(0, 7868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "cPyparsing.pyx":7866
 *         _ranges = []
 * 
 *         class Kanji(unicode_set):             # <<<<<<<<<<<<<<
 *             "Unicode set for Kanji Unicode Character Range"
 *             _ranges = [(0x4E00, 0x9Fbf), (0x3000, 0x303f),]
 */
  __pyx_t_14 = __Pyx_Py3ClassCreate(__pyx_t_25, __pyx_n_s_Kanji, __pyx_t_19, __pyx_t_8, NULL, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_Kanji, __pyx_t_14) < 0) __PYX_ERR(0, 7866, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7870
 *             _ranges = [(0x4E00, 0x9Fbf), (0x3000, 0x303f),]
 * 
 *         class Hiragana(unicode_set):             # <<<<<<<<<<<<<<
 *             "Unicode set for Hiragana Unicode Character Range"
 *             _ranges = [(0x3040, 0x309f),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_25 = PyTuple_New(1); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 7870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_25, 0, __pyx_t_19)) __PYX_ERR(0, 7870, __pyx_L1_error);
  __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PEP560_update_bases(__pyx_t_25); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_8 = __Pyx_CalculateMetaclass(NULL, __pyx_t_19); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_8, __pyx_t_19, __pyx_n_s_Hiragana, __pyx_n_s_pyparsing_unicode_Japanese_Hirag, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Hiragana_Unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (__pyx_t_19 != __pyx_t_25) {
    if (unlikely((PyDict_SetItemString(__pyx_t_14, "__orig_bases__", __pyx_t_25) < 0))) __PYX_ERR(0, 7870, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;

  /* "cPyparsing.pyx":7872
 *         class Hiragana(unicode_set):
 *             "Unicode set for Hiragana Unicode Character Range"
 *             _ranges = [(0x3040, 0x309f),]             # <<<<<<<<<<<<<<
 * 
 *         class Katakana(unicode_set):
 */
  __pyx_t_25 = PyList_New(1); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 7872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_INCREF(__pyx_tuple__841);
  __Pyx_GIVEREF(__pyx_tuple__841);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_25, 0, __pyx_tuple__841)) __PYX_ERR(0, 7872, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_14, __pyx_n_s_ranges, __pyx_t_25) < 0) __PYX_ERR(0, 7872, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;

  /* "cPyparsing.pyx":7870
 *             _ranges = [(0x4E00, 0x9Fbf), (0x3000, 0x303f),]
 * 
 *         class Hiragana(unicode_set):             # <<<<<<<<<<<<<<
 *             "Unicode set for Hiragana Unicode Character Range"
 *             _ranges = [(0x3040, 0x309f),]
 */
  __pyx_t_25 = __Pyx_Py3ClassCreate(__pyx_t_8, __pyx_n_s_Hiragana, __pyx_t_19, __pyx_t_14, NULL, 0, 0); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 7870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_Hiragana, __pyx_t_25) < 0) __PYX_ERR(0, 7870, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7874
 *             _ranges = [(0x3040, 0x309f),]
 * 
 *         class Katakana(unicode_set):             # <<<<<<<<<<<<<<
 *             "Unicode set for Katakana  Unicode Character Range"
 *             _ranges = [(0x30a0, 0x30ff),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_19)) __PYX_ERR(0, 7874, __pyx_L1_error);
  __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PEP560_update_bases(__pyx_t_8); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_14 = __Pyx_CalculateMetaclass(NULL, __pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 7874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_25 = __Pyx_Py3MetaclassPrepare(__pyx_t_14, __pyx_t_19, __pyx_n_s_Katakana, __pyx_n_s_pyparsing_unicode_Japanese_Katak, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Katakana_Unicode); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 7874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  if (__pyx_t_19 != __pyx_t_8) {
    if (unlikely((PyDict_SetItemString(__pyx_t_25, "__orig_bases__", __pyx_t_8) < 0))) __PYX_ERR(0, 7874, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":7876
 *         class Katakana(unicode_set):
 *             "Unicode set for Katakana  Unicode Character Range"
 *             _ranges = [(0x30a0, 0x30ff),]             # <<<<<<<<<<<<<<
 * 
 *     class Korean(unicode_set):
 */
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_tuple__842);
  __Pyx_GIVEREF(__pyx_tuple__842);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_tuple__842)) __PYX_ERR(0, 7876, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_25, __pyx_n_s_ranges, __pyx_t_8) < 0) __PYX_ERR(0, 7876, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":7874
 *             _ranges = [(0x3040, 0x309f),]
 * 
 *         class Katakana(unicode_set):             # <<<<<<<<<<<<<<
 *             "Unicode set for Katakana  Unicode Character Range"
 *             _ranges = [(0x30a0, 0x30ff),]
 */
  __pyx_t_8 = __Pyx_Py3ClassCreate(__pyx_t_14, __pyx_n_s_Katakana, __pyx_t_19, __pyx_t_25, NULL, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 7874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_Katakana, __pyx_t_8) < 0) __PYX_ERR(0, 7874, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7862
 *         _ranges = [(0x4e00, 0x9fff), (0x3000, 0x303f),]
 * 
 *     class Japanese(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Japanese Unicode Character Range, combining Kanji, Hiragana, and Katakana ranges"
 *         _ranges = []
 */
  __pyx_t_19 = __Pyx_Py3ClassCreate(__pyx_t_22, __pyx_n_s_Japanese, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Japanese, __pyx_t_19) < 0) __PYX_ERR(0, 7862, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7878
 *             _ranges = [(0x30a0, 0x30ff),]
 * 
 *     class Korean(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Korean Unicode Character Range"
 *         _ranges = [(0xac00, 0xd7af), (0x1100, 0x11ff), (0x3130, 0x318f), (0xa960, 0xa97f), (0xd7b0, 0xd7ff), (0x3000, 0x303f),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = PyTuple_New(1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_22, 0, __pyx_t_2)) __PYX_ERR(0, 7878, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_22); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_19 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_2, __pyx_n_s_Korean, __pyx_n_s_pyparsing_unicode_Korean, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Korean_Unicode_C); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (__pyx_t_2 != __pyx_t_22) {
    if (unlikely((PyDict_SetItemString(__pyx_t_19, "__orig_bases__", __pyx_t_22) < 0))) __PYX_ERR(0, 7878, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "cPyparsing.pyx":7880
 *     class Korean(unicode_set):
 *         "Unicode set for Korean Unicode Character Range"
 *         _ranges = [(0xac00, 0xd7af), (0x1100, 0x11ff), (0x3130, 0x318f), (0xa960, 0xa97f), (0xd7b0, 0xd7ff), (0x3000, 0x303f),]             # <<<<<<<<<<<<<<
 * 
 *     class CJK(Chinese, Japanese, Korean):
 */
  __pyx_t_22 = PyList_New(6); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_INCREF(__pyx_tuple__843);
  __Pyx_GIVEREF(__pyx_tuple__843);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_22, 0, __pyx_tuple__843)) __PYX_ERR(0, 7880, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__844);
  __Pyx_GIVEREF(__pyx_tuple__844);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_22, 1, __pyx_tuple__844)) __PYX_ERR(0, 7880, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__845);
  __Pyx_GIVEREF(__pyx_tuple__845);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_22, 2, __pyx_tuple__845)) __PYX_ERR(0, 7880, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__846);
  __Pyx_GIVEREF(__pyx_tuple__846);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_22, 3, __pyx_tuple__846)) __PYX_ERR(0, 7880, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__847);
  __Pyx_GIVEREF(__pyx_tuple__847);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_22, 4, __pyx_tuple__847)) __PYX_ERR(0, 7880, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__839);
  __Pyx_GIVEREF(__pyx_tuple__839);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_22, 5, __pyx_tuple__839)) __PYX_ERR(0, 7880, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_19, __pyx_n_s_ranges, __pyx_t_22) < 0) __PYX_ERR(0, 7880, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "cPyparsing.pyx":7878
 *             _ranges = [(0x30a0, 0x30ff),]
 * 
 *     class Korean(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Korean Unicode Character Range"
 *         _ranges = [(0xac00, 0xd7af), (0x1100, 0x11ff), (0x3130, 0x318f), (0xa960, 0xa97f), (0xd7b0, 0xd7ff), (0x3000, 0x303f),]
 */
  __pyx_t_22 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_Korean, __pyx_t_2, __pyx_t_19, NULL, 0, 0); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Korean, __pyx_t_22) < 0) __PYX_ERR(0, 7878, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7882
 *         _ranges = [(0xac00, 0xd7af), (0x1100, 0x11ff), (0x3130, 0x318f), (0xa960, 0xa97f), (0xd7b0, 0xd7ff), (0x3000, 0x303f),]
 * 
 *     class CJK(Chinese, Japanese, Korean):             # <<<<<<<<<<<<<<
 *         "Unicode set for combined Chinese, Japanese, and Korean (CJK) Unicode Character Range"
 *         pass
 */
  __pyx_t_2 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_Chinese);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Chinese);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_Japanese);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_Japanese);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_19 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_Korean);
  if (unlikely(!__pyx_t_19)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_Korean);
  }
  if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_22 = PyTuple_New(3); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_22, 0, __pyx_t_2)) __PYX_ERR(0, 7882, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_22, 1, __pyx_t_9)) __PYX_ERR(0, 7882, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_22, 2, __pyx_t_19)) __PYX_ERR(0, 7882, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_9 = 0;
  __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PEP560_update_bases(__pyx_t_22); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_19); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_19, __pyx_n_s_CJK, __pyx_n_s_pyparsing_unicode_CJK, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_combined_Chinese); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_19 != __pyx_t_22) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_22) < 0))) __PYX_ERR(0, 7882, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_CJK, __pyx_t_19, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_CJK, __pyx_t_22) < 0) __PYX_ERR(0, 7882, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7886
 *         pass
 * 
 *     class Thai(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Thai Unicode Character Range"
 *         _ranges = [(0x0e01, 0x0e3a), (0x0e3f, 0x0e5b),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_19)) __PYX_ERR(0, 7886, __pyx_L1_error);
  __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_19, __pyx_n_s_Thai, __pyx_n_s_pyparsing_unicode_Thai, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Thai_Unicode_Cha); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (__pyx_t_19 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_22, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 7886, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7888
 *     class Thai(unicode_set):
 *         "Unicode set for Thai Unicode Character Range"
 *         _ranges = [(0x0e01, 0x0e3a), (0x0e3f, 0x0e5b),]             # <<<<<<<<<<<<<<
 * 
 *     class Arabic(unicode_set):
 */
  __pyx_t_9 = PyList_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_tuple__848);
  __Pyx_GIVEREF(__pyx_tuple__848);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_tuple__848)) __PYX_ERR(0, 7888, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__849);
  __Pyx_GIVEREF(__pyx_tuple__849);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 1, __pyx_tuple__849)) __PYX_ERR(0, 7888, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_22, __pyx_n_s_ranges, __pyx_t_9) < 0) __PYX_ERR(0, 7888, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7886
 *         pass
 * 
 *     class Thai(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Thai Unicode Character Range"
 *         _ranges = [(0x0e01, 0x0e3a), (0x0e3f, 0x0e5b),]
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Thai, __pyx_t_19, __pyx_t_22, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Thai, __pyx_t_9) < 0) __PYX_ERR(0, 7886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7890
 *         _ranges = [(0x0e01, 0x0e3a), (0x0e3f, 0x0e5b),]
 * 
 *     class Arabic(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Arabic Unicode Character Range"
 *         _ranges = [(0x0600, 0x061b), (0x061e, 0x06ff), (0x0700, 0x077f),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_19)) __PYX_ERR(0, 7890, __pyx_L1_error);
  __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_22 = __Pyx_CalculateMetaclass(NULL, __pyx_t_19); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_22, __pyx_t_19, __pyx_n_s_Arabic, __pyx_n_s_pyparsing_unicode_Arabic, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Arabic_Unicode_C); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__pyx_t_19 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_9, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 7890, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7892
 *     class Arabic(unicode_set):
 *         "Unicode set for Arabic Unicode Character Range"
 *         _ranges = [(0x0600, 0x061b), (0x061e, 0x06ff), (0x0700, 0x077f),]             # <<<<<<<<<<<<<<
 * 
 *     class Hebrew(unicode_set):
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_tuple__850);
  __Pyx_GIVEREF(__pyx_tuple__850);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_tuple__850)) __PYX_ERR(0, 7892, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__851);
  __Pyx_GIVEREF(__pyx_tuple__851);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_tuple__851)) __PYX_ERR(0, 7892, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__852);
  __Pyx_GIVEREF(__pyx_tuple__852);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_tuple__852)) __PYX_ERR(0, 7892, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_9, __pyx_n_s_ranges, __pyx_t_2) < 0) __PYX_ERR(0, 7892, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":7890
 *         _ranges = [(0x0e01, 0x0e3a), (0x0e3f, 0x0e5b),]
 * 
 *     class Arabic(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Arabic Unicode Character Range"
 *         _ranges = [(0x0600, 0x061b), (0x061e, 0x06ff), (0x0700, 0x077f),]
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_22, __pyx_n_s_Arabic, __pyx_t_19, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Arabic, __pyx_t_2) < 0) __PYX_ERR(0, 7890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7894
 *         _ranges = [(0x0600, 0x061b), (0x061e, 0x06ff), (0x0700, 0x077f),]
 * 
 *     class Hebrew(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Hebrew Unicode Character Range"
 *         _ranges = [(0x0590, 0x05ff),]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_22 = PyTuple_New(1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_22, 0, __pyx_t_19)) __PYX_ERR(0, 7894, __pyx_L1_error);
  __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PEP560_update_bases(__pyx_t_22); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_9 = __Pyx_CalculateMetaclass(NULL, __pyx_t_19); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_9, __pyx_t_19, __pyx_n_s_Hebrew, __pyx_n_s_pyparsing_unicode_Hebrew, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Hebrew_Unicode_C); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_19 != __pyx_t_22) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_22) < 0))) __PYX_ERR(0, 7894, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "cPyparsing.pyx":7896
 *     class Hebrew(unicode_set):
 *         "Unicode set for Hebrew Unicode Character Range"
 *         _ranges = [(0x0590, 0x05ff),]             # <<<<<<<<<<<<<<
 * 
 *     class Devanagari(unicode_set):
 */
  __pyx_t_22 = PyList_New(1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_INCREF(__pyx_tuple__853);
  __Pyx_GIVEREF(__pyx_tuple__853);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_22, 0, __pyx_tuple__853)) __PYX_ERR(0, 7896, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_ranges, __pyx_t_22) < 0) __PYX_ERR(0, 7896, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "cPyparsing.pyx":7894
 *         _ranges = [(0x0600, 0x061b), (0x061e, 0x06ff), (0x0700, 0x077f),]
 * 
 *     class Hebrew(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Hebrew Unicode Character Range"
 *         _ranges = [(0x0590, 0x05ff),]
 */
  __pyx_t_22 = __Pyx_Py3ClassCreate(__pyx_t_9, __pyx_n_s_Hebrew, __pyx_t_19, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Hebrew, __pyx_t_22) < 0) __PYX_ERR(0, 7894, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7898
 *         _ranges = [(0x0590, 0x05ff),]
 * 
 *     class Devanagari(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Devanagari Unicode Character Range"
 *         _ranges = [(0x0900, 0x097f), (0xa8e0, 0xa8ff)]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_unicode_set); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_19);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_19)) __PYX_ERR(0, 7898, __pyx_L1_error);
  __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PEP560_update_bases(__pyx_t_9); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_22 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_19, __pyx_n_s_Devanagari, __pyx_n_s_pyparsing_unicode_Devanagari, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Unicode_set_for_Devanagari_Unico); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 7898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  if (__pyx_t_19 != __pyx_t_9) {
    if (unlikely((PyDict_SetItemString(__pyx_t_22, "__orig_bases__", __pyx_t_9) < 0))) __PYX_ERR(0, 7898, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7900
 *     class Devanagari(unicode_set):
 *         "Unicode set for Devanagari Unicode Character Range"
 *         _ranges = [(0x0900, 0x097f), (0xa8e0, 0xa8ff)]             # <<<<<<<<<<<<<<
 * 
 * pyparsing_unicode.Japanese._ranges = (pyparsing_unicode.Japanese.Kanji._ranges
 */
  __pyx_t_9 = PyList_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_tuple__854);
  __Pyx_GIVEREF(__pyx_tuple__854);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 0, __pyx_tuple__854)) __PYX_ERR(0, 7900, __pyx_L1_error);
  __Pyx_INCREF(__pyx_tuple__855);
  __Pyx_GIVEREF(__pyx_tuple__855);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_9, 1, __pyx_tuple__855)) __PYX_ERR(0, 7900, __pyx_L1_error);
  if (__Pyx_SetNameInClass(__pyx_t_22, __pyx_n_s_ranges, __pyx_t_9) < 0) __PYX_ERR(0, 7900, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":7898
 *         _ranges = [(0x0590, 0x05ff),]
 * 
 *     class Devanagari(unicode_set):             # <<<<<<<<<<<<<<
 *         "Unicode set for Devanagari Unicode Character Range"
 *         _ranges = [(0x0900, 0x097f), (0xa8e0, 0xa8ff)]
 */
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Devanagari, __pyx_t_19, __pyx_t_22, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 7898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_Devanagari, __pyx_t_9) < 0) __PYX_ERR(0, 7898, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":7828
 * 
 * 
 * class pyparsing_unicode(unicode_set):             # <<<<<<<<<<<<<<
 *     """
 *     A namespace class for defining common language unicode_sets.
 */
  __pyx_t_19 = __Pyx_Py3ClassCreate(__pyx_t_21, __pyx_n_s_pyparsing_unicode, __pyx_t_10, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 7828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyparsing_unicode, __pyx_t_19) < 0) __PYX_ERR(0, 7828, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":7902
 *         _ranges = [(0x0900, 0x097f), (0xa8e0, 0xa8ff)]
 * 
 * pyparsing_unicode.Japanese._ranges = (pyparsing_unicode.Japanese.Kanji._ranges             # <<<<<<<<<<<<<<
 *                                       + pyparsing_unicode.Japanese.Hiragana._ranges
 *                                       + pyparsing_unicode.Japanese.Katakana._ranges)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Kanji); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_ranges); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":7903
 * 
 * pyparsing_unicode.Japanese._ranges = (pyparsing_unicode.Japanese.Kanji._ranges
 *                                       + pyparsing_unicode.Japanese.Hiragana._ranges             # <<<<<<<<<<<<<<
 *                                       + pyparsing_unicode.Japanese.Katakana._ranges)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Hiragana); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_ranges); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyNumber_Add(__pyx_t_21, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7904
 * pyparsing_unicode.Japanese._ranges = (pyparsing_unicode.Japanese.Kanji._ranges
 *                                       + pyparsing_unicode.Japanese.Hiragana._ranges
 *                                       + pyparsing_unicode.Japanese.Katakana._ranges)             # <<<<<<<<<<<<<<
 * 
 * # define ranges in language character sets
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Katakana); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ranges); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_10, __pyx_t_21); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":7902
 *         _ranges = [(0x0900, 0x097f), (0xa8e0, 0xa8ff)]
 * 
 * pyparsing_unicode.Japanese._ranges = (pyparsing_unicode.Japanese.Kanji._ranges             # <<<<<<<<<<<<<<
 *                                       + pyparsing_unicode.Japanese.Hiragana._ranges
 *                                       + pyparsing_unicode.Japanese.Katakana._ranges)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_10, __pyx_n_s_ranges, __pyx_t_3) < 0) __PYX_ERR(0, 7902, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":7907
 * 
 * # define ranges in language character sets
 * if PY_3:             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Arabic)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Chinese)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_PY_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 7907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":7908
 * # define ranges in language character sets
 * if PY_3:
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Arabic)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Chinese)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Cyrillic)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Arabic); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_10, __pyx_n_u__856, __pyx_t_21); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7908, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

    /* "cPyparsing.pyx":7909
 * if PY_3:
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Arabic)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Chinese)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Cyrillic)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Greek)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Chinese); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_21, __pyx_n_u__857, __pyx_t_3); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7909, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":7910
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Arabic)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Chinese)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Cyrillic)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Greek)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Hebrew)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Cyrillic); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_3, __pyx_n_u__858, __pyx_t_10); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7910, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":7911
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Chinese)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Cyrillic)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Greek)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Hebrew)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Japanese)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Greek); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_10, __pyx_n_u__859, __pyx_t_21); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7911, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

    /* "cPyparsing.pyx":7912
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Cyrillic)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Greek)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Hebrew)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Japanese)
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Kanji)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Hebrew); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_21, __pyx_kp_u__860, __pyx_t_3); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7912, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":7913
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Greek)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Hebrew)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Japanese)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Kanji)
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Katakana)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_3, __pyx_n_u__861, __pyx_t_10); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7913, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":7914
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Hebrew)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Japanese)
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Kanji)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Katakana)
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Hiragana)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Kanji); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_3, __pyx_n_u__862, __pyx_t_10); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7914, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":7915
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Japanese)
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Kanji)
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Katakana)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Hiragana)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Korean)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Katakana); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_3, __pyx_n_u__863, __pyx_t_10); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7915, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":7916
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Kanji)
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Katakana)
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Hiragana)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Korean)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Thai)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Japanese); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Hiragana); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_3, __pyx_n_u__864, __pyx_t_10); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7916, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":7917
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Katakana)
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Hiragana)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Korean)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Thai)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Devanagari)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Korean); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_10, __pyx_n_u__865, __pyx_t_21); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7917, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

    /* "cPyparsing.pyx":7918
 *     setattr(pyparsing_unicode.Japanese, u"", pyparsing_unicode.Japanese.Hiragana)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Korean)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Thai)             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Devanagari)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_Thai); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_21, __pyx_n_u__866, __pyx_t_3); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7918, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":7919
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Korean)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Thai)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Devanagari)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pyparsing_unicode); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Devanagari); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_18 = PyObject_SetAttr(__pyx_t_3, __pyx_kp_u__867, __pyx_t_10); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 7919, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":7907
 * 
 * # define ranges in language character sets
 * if PY_3:             # <<<<<<<<<<<<<<
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Arabic)
 *     setattr(pyparsing_unicode, u"", pyparsing_unicode.Chinese)
 */
  }

  /* "cPyparsing.pyx":7922
 * 
 * 
 * class pyparsing_test:             # <<<<<<<<<<<<<<
 *     """
 *     namespace class for classes useful in writing unit tests
 */
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_pyparsing_test, __pyx_n_s_pyparsing_test, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_namespace_class_for_classes_use); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 7922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);

  /* "cPyparsing.pyx":7927
 *     """
 * 
 *     class reset_pyparsing_context:             # <<<<<<<<<<<<<<
 *         """
 *         Context manager to be used when writing unit tests that modify pyparsing config values:
 */
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_reset_pyparsing_context, __pyx_n_s_pyparsing_test_reset_pyparsing_c, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Context_manager_to_be_used_when); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "cPyparsing.pyx":7950
 *         """
 * 
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             self._save_context = {}
 * 
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23reset_pyparsing_context_1__init__, 0, __pyx_n_s_pyparsing_test_reset_pyparsing_c_2, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__868)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_init, __pyx_t_21) < 0) __PYX_ERR(0, 7950, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":7953
 *             self._save_context = {}
 * 
 *         def save(self):             # <<<<<<<<<<<<<<
 *             self._save_context["default_whitespace"] = ParserElement.DEFAULT_WHITE_CHARS
 *             self._save_context["default_keyword_chars"] = Keyword.DEFAULT_KEYWORD_CHARS
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23reset_pyparsing_context_3save, 0, __pyx_n_s_pyparsing_test_reset_pyparsing_c_3, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__869)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_save, __pyx_t_21) < 0) __PYX_ERR(0, 7953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":7969
 *             return self
 * 
 *         def restore(self):             # <<<<<<<<<<<<<<
 *             # reset pyparsing global state
 *             if (
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23reset_pyparsing_context_5restore, 0, __pyx_n_s_pyparsing_test_reset_pyparsing_c_4, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__871)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_restore, __pyx_t_21) < 0) __PYX_ERR(0, 7969, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":7988
 *             __compat__.collect_all_And_tokens = self._save_context["__compat__"]
 * 
 *         def __enter__(self):             # <<<<<<<<<<<<<<
 *             return self.save()
 * 
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23reset_pyparsing_context_7__enter__, 0, __pyx_n_s_pyparsing_test_reset_pyparsing_c_5, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__872)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_enter, __pyx_t_21) < 0) __PYX_ERR(0, 7988, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":7991
 *             return self.save()
 * 
 *         def __exit__(self, *args):             # <<<<<<<<<<<<<<
 *             return self.restore()
 * 
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23reset_pyparsing_context_9__exit__, 0, __pyx_n_s_pyparsing_test_reset_pyparsing_c_6, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__873)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_exit, __pyx_t_21) < 0) __PYX_ERR(0, 7991, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":7927
 *     """
 * 
 *     class reset_pyparsing_context:             # <<<<<<<<<<<<<<
 *         """
 *         Context manager to be used when writing unit tests that modify pyparsing config values:
 */
  __pyx_t_21 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_n_s_reset_pyparsing_context, __pyx_empty_tuple, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_reset_pyparsing_context, __pyx_t_21) < 0) __PYX_ERR(0, 7927, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7994
 *             return self.restore()
 * 
 *     class TestParseResultsAsserts:             # <<<<<<<<<<<<<<
 *         """
 *         A mixin class to add parse results assertion methods to normal unittest.TestCase classes.
 */
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_TestParseResultsAsserts, __pyx_n_s_pyparsing_test_TestParseResultsA_3, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_A_mixin_class_to_add_parse_resu); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "cPyparsing.pyx":7998
 *         A mixin class to add parse results assertion methods to normal unittest.TestCase classes.
 *         """
 *         def assertParseResultsEquals(             # <<<<<<<<<<<<<<
 *             self, result, expected_list=None, expected_dict=None, msg=None
 *         ):
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23TestParseResultsAsserts_1assertParseResultsEquals, 0, __pyx_n_s_pyparsing_test_TestParseResultsA_4, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__875)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_21, __pyx_tuple__46);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_assertParseResultsEquals, __pyx_t_21) < 0) __PYX_ERR(0, 7998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":8010
 *                 self.assertEqual(expected_dict, result.asDict(), msg=msg)
 * 
 *         def assertParseAndCheckList(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_list, msg=None, verbose=True
 *         ):
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23TestParseResultsAsserts_3assertParseAndCheckList, 0, __pyx_n_s_pyparsing_test_TestParseResultsA_5, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__877)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_21, __pyx_tuple__878);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_assertParseAndCheckList, __pyx_t_21) < 0) __PYX_ERR(0, 8010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":8022
 *             self.assertParseResultsEquals(result, expected_list=expected_list, msg=msg)
 * 
 *         def assertParseAndCheckDict(             # <<<<<<<<<<<<<<
 *             self, expr, test_string, expected_dict, msg=None, verbose=True
 *         ):
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23TestParseResultsAsserts_5assertParseAndCheckDict, 0, __pyx_n_s_pyparsing_test_TestParseResultsA_6, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__880)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_21, __pyx_tuple__878);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_assertParseAndCheckDict, __pyx_t_21) < 0) __PYX_ERR(0, 8022, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":8034
 *             self.assertParseResultsEquals(result, expected_dict=expected_dict, msg=msg)
 * 
 *         def assertRunTestResults(             # <<<<<<<<<<<<<<
 *             self, run_tests_report, expected_parse_results=None, msg=None
 *         ):
 */
  __pyx_t_21 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23TestParseResultsAsserts_7assertRunTestResults, 0, __pyx_n_s_pyparsing_test_TestParseResultsA_7, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__882)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_21, __pyx_tuple__58);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_assertRunTestResults, __pyx_t_21) < 0) __PYX_ERR(0, 8034, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":8097
 *             )
 * 
 *         @contextmanager             # <<<<<<<<<<<<<<
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):
 *             with self.assertRaises(exc_type, msg=msg):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_contextmanager); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_10cPyparsing_23TestParseResultsAsserts_9assertRaisesParseException, 0, __pyx_n_s_pyparsing_test_TestParseResultsA_2, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__170)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults11), 1)) __PYX_ERR(0, 8097, __pyx_L1_error)

  /* "cPyparsing.pyx":8098
 * 
 *         @contextmanager
 *         def assertRaisesParseException(self, exc_type=ParseException, msg=None):             # <<<<<<<<<<<<<<
 *             with self.assertRaises(exc_type, msg=msg):
 *                 yield
 */
  __Pyx_GetModuleGlobalName(__pyx_t_22, __pyx_n_s_ParseException); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 8098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_t_2)->__pyx_arg_exc_type = __pyx_t_22;
  __Pyx_GIVEREF(__pyx_t_22);
  __pyx_t_22 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_10cPyparsing_111__defaults__);
  __pyx_t_22 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_22, __pyx_t_2};
    __pyx_t_21 = __Pyx_PyObject_FastCall(__pyx_t_19, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  }
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_assertRaisesParseException, __pyx_t_21) < 0) __PYX_ERR(0, 8097, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":7994
 *             return self.restore()
 * 
 *     class TestParseResultsAsserts:             # <<<<<<<<<<<<<<
 *         """
 *         A mixin class to add parse results assertion methods to normal unittest.TestCase classes.
 */
  __pyx_t_21 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_n_s_TestParseResultsAsserts, __pyx_empty_tuple, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 7994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_TestParseResultsAsserts, __pyx_t_21) < 0) __PYX_ERR(0, 7994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":7922
 * 
 * 
 * class pyparsing_test:             # <<<<<<<<<<<<<<
 *     """
 *     namespace class for classes useful in writing unit tests
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_n_s_pyparsing_test, __pyx_empty_tuple, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyparsing_test, __pyx_t_3) < 0) __PYX_ERR(0, 7922, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "cPyparsing.pyx":8103
 * 
 * 
 * if __name__ == "__main__":             # <<<<<<<<<<<<<<
 * 
 *     selectToken    = CaselessLiteral("select")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_name); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_10, __pyx_n_u_main, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 8103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":8105
 * if __name__ == "__main__":
 * 
 *     selectToken    = CaselessLiteral("select")             # <<<<<<<<<<<<<<
 *     fromToken      = CaselessLiteral("from")
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_CaselessLiteral); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__884, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_selectToken, __pyx_t_3) < 0) __PYX_ERR(0, 8105, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":8106
 * 
 *     selectToken    = CaselessLiteral("select")
 *     fromToken      = CaselessLiteral("from")             # <<<<<<<<<<<<<<
 * 
 *     ident          = Word(alphas, alphanums + "_$")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CaselessLiteral); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__885, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_fromToken, __pyx_t_10) < 0) __PYX_ERR(0, 8106, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":8108
 *     fromToken      = CaselessLiteral("from")
 * 
 *     ident          = Word(alphas, alphanums + "_$")             # <<<<<<<<<<<<<<
 * 
 *     columnName     = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_Word); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_alphas); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_alphanums); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_19 = PyNumber_Add(__pyx_t_21, __pyx_kp_u__461); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = PyTuple_New(2); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_3)) __PYX_ERR(0, 8108, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_19);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_21, 1, __pyx_t_19)) __PYX_ERR(0, 8108, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_19 = 0;
    __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_21, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_ident, __pyx_t_19) < 0) __PYX_ERR(0, 8108, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

    /* "cPyparsing.pyx":8110
 *     ident          = Word(alphas, alphanums + "_$")
 * 
 *     columnName     = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)             # <<<<<<<<<<<<<<
 *     columnNameList = Group(delimitedList(columnName)).setName("columns")
 *     columnSpec     = ('*' | columnNameList)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_delimitedList); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_ident); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_21);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_21)) __PYX_ERR(0, 8110, __pyx_L1_error);
    __Pyx_INCREF(__pyx_kp_u__117);
    __Pyx_GIVEREF(__pyx_kp_u__117);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_kp_u__117)) __PYX_ERR(0, 8110, __pyx_L1_error);
    __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_combine, Py_True) < 0) __PYX_ERR(0, 8110, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_t_10, __pyx_t_21); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_upcaseTokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_columnName, __pyx_t_10) < 0) __PYX_ERR(0, 8110, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":8111
 * 
 *     columnName     = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     columnNameList = Group(delimitedList(columnName)).setName("columns")             # <<<<<<<<<<<<<<
 *     columnSpec     = ('*' | columnNameList)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_Group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_delimitedList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_columnName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_21); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_19); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_tuple__886, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_columnNameList, __pyx_t_21) < 0) __PYX_ERR(0, 8111, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

    /* "cPyparsing.pyx":8112
 *     columnName     = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     columnNameList = Group(delimitedList(columnName)).setName("columns")
 *     columnSpec     = ('*' | columnNameList)             # <<<<<<<<<<<<<<
 * 
 *     tableName      = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_columnNameList); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_19 = PyNumber_Or(__pyx_kp_u__15, __pyx_t_21); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_columnSpec, __pyx_t_19) < 0) __PYX_ERR(0, 8112, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

    /* "cPyparsing.pyx":8114
 *     columnSpec     = ('*' | columnNameList)
 * 
 *     tableName      = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)             # <<<<<<<<<<<<<<
 *     tableNameList  = Group(delimitedList(tableName)).setName("tables")
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_delimitedList); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_ident); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_21);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_21)) __PYX_ERR(0, 8114, __pyx_L1_error);
    __Pyx_INCREF(__pyx_kp_u__117);
    __Pyx_GIVEREF(__pyx_kp_u__117);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_kp_u__117)) __PYX_ERR(0, 8114, __pyx_L1_error);
    __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_combine, Py_True) < 0) __PYX_ERR(0, 8114, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_t_10, __pyx_t_21); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_upcaseTokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_tableName, __pyx_t_10) < 0) __PYX_ERR(0, 8114, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":8115
 * 
 *     tableName      = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     tableNameList  = Group(delimitedList(tableName)).setName("tables")             # <<<<<<<<<<<<<<
 * 
 *     simpleSQL      = selectToken("command") + columnSpec("columns") + fromToken + tableNameList("tables")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_Group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_delimitedList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_tableName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_21); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_19); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_tuple__887, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_tableNameList, __pyx_t_21) < 0) __PYX_ERR(0, 8115, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

    /* "cPyparsing.pyx":8117
 *     tableNameList  = Group(delimitedList(tableName)).setName("tables")
 * 
 *     simpleSQL      = selectToken("command") + columnSpec("columns") + fromToken + tableNameList("tables")             # <<<<<<<<<<<<<<
 * 
 *     # demo runTests method, including embedded comments in test string
 */
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_selectToken); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__888, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_columnSpec); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__886, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = PyNumber_Add(__pyx_t_19, __pyx_t_10); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_fromToken); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_19 = PyNumber_Add(__pyx_t_21, __pyx_t_10); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_tableNameList); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__887, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_Add(__pyx_t_19, __pyx_t_21); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_simpleSQL, __pyx_t_10) < 0) __PYX_ERR(0, 8117, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":8120
 * 
 *     # demo runTests method, including embedded comments in test string
 *     simpleSQL.runTests("""             # <<<<<<<<<<<<<<
 *         # '*' as column list and dotted table name
 *         select * from SYS.XYZZY
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_simpleSQL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_runTests); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__889, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":8144
 *         """)
 * 
 *     pyparsing_common.number.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         -100
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_number); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_runTests); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__890, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

    /* "cPyparsing.pyx":8154
 * 
 *     # any int or real number, returned as float
 *     pyparsing_common.fnumber.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         -100
 */
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_fnumber); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_runTests); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__890, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":8163
 *         """)
 * 
 *     pyparsing_common.hex_integer.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         FF
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_hex_integer_2); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_runTests); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__891, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

    /* "cPyparsing.pyx":8168
 *         """)
 * 
 *     import uuid             # <<<<<<<<<<<<<<
 *     pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))
 *     pyparsing_common.uuid.runTests("""
 */
    __pyx_t_21 = __Pyx_ImportDottedModule(__pyx_n_s_uuid, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_uuid, __pyx_t_21) < 0) __PYX_ERR(0, 8168, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

    /* "cPyparsing.pyx":8169
 * 
 *     import uuid
 *     pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))             # <<<<<<<<<<<<<<
 *     pyparsing_common.uuid.runTests("""
 *         12345678-1234-5678-1234-567812345678
 */
    __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_uuid); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 8169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_tokenMap); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 8169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_uuid); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_UUID); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_3); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_t_19); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":8170
 *     import uuid
 *     pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))
 *     pyparsing_common.uuid.runTests("""             # <<<<<<<<<<<<<<
 *         12345678-1234-5678-1234-567812345678
 *         """)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_uuid); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_runTests); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 8170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__892, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 8170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

    /* "cPyparsing.pyx":8103
 * 
 * 
 * if __name__ == "__main__":             # <<<<<<<<<<<<<<
 * 
 *     selectToken    = CaselessLiteral("select")
 */
  }

  /* "cPyparsing.pyx":1
 * # -*- coding: utf-8 -*-             # <<<<<<<<<<<<<<
 * 
 * #-----------------------------------------------------------------------------------------------------------------------
 */
  __pyx_t_19 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_19) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init cPyparsing");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc;
    __Pyx_PyThreadState_declare
    #ifdef __Pyx_StopAsyncIteration_USED
    int is_async_stopiteration = 0;
    #endif
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    cur_exc = PyErr_Occurred();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        #ifdef __Pyx_StopAsyncIteration_USED
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, __Pyx_PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else
        #endif
            return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(val);
    Py_XDECREF(tb);
    PyErr_SetString(PyExc_RuntimeError,
        #ifdef __Pyx_StopAsyncIteration_USED
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        #endif
        "generator raised StopIteration");
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;  // error
            return kwvalues[i];
        }
    }
    return NULL;  // not found (no exception set)
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
static CYTHON_UNUSED PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value); // transfer ownership of value to values
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;  // ownership transferred to values
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL; // ownership transferred to values
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
static int
__Pyx_unicode_modifiable(PyObject *unicode)
{
    if (Py_REFCNT(unicode) != 1)
        return 0;
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    PyObject* exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseClosureNameError */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a + (unsigned long)b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op2);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyString_CheckExact(s))) {
        PyObject *result = PyUnicode_FromEncodedObject(s, NULL, "strict");
        Py_DECREF(s);
        return result;
    }
    #endif
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a - (unsigned long)b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return PyLong_FromLong(-intval);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__15;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchInspect */
static PyObject* __Pyx_patch_inspect(PyObject* module) {
#if defined(__Pyx_Generator_USED) && (!defined(CYTHON_PATCH_INSPECT) || CYTHON_PATCH_INSPECT)
    static int inspect_patched = 0;
    if (unlikely((!inspect_patched) && module)) {
        module = __Pyx_Coroutine_patch_module(
            module, ""
"old_types = getattr(_module.isgenerator, '_cython_generator_types', None)\n"
"if old_types is None or not isinstance(old_types, set):\n"
"    old_types = set()\n"
"    def cy_wrap(orig_func, type=type, cython_generator_types=old_types):\n"
"        def cy_isgenerator(obj): return type(obj) in cython_generator_types or orig_func(obj)\n"
"        cy_isgenerator._cython_generator_types = cython_generator_types\n"
"        return cy_isgenerator\n"
"    _module.isgenerator = cy_wrap(_module.isgenerator)\n"
"old_types.add(_cython_generator_type)\n"
        );
        inspect_patched = 1;
    }
#else
    if ((0)) return __Pyx_Coroutine_patch_module(module, NULL);
#endif
    return module;
}

/* pyfrozenset_new */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it) {
    if (it) {
        PyObject* result;
#if CYTHON_COMPILING_IN_PYPY
        PyObject* args;
        args = PyTuple_Pack(1, it);
        if (unlikely(!args))
            return NULL;
        result = PyObject_Call((PyObject*)&PyFrozenSet_Type, args, NULL);
        Py_DECREF(args);
        return result;
#else
        if (PyFrozenSet_CheckExact(it)) {
            Py_INCREF(it);
            return it;
        }
        result = PyFrozenSet_New(it);
        if (unlikely(!result))
            return NULL;
        if ((PY_VERSION_HEX >= 0x031000A1) || likely(PySet_GET_SIZE(result)))
            return result;
        Py_DECREF(result);
#endif
    }
#if CYTHON_USE_TYPE_SLOTS
    return PyFrozenSet_Type.tp_new(&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#else
    return PyObject_Call((PyObject*)&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#endif
}

/* PySetContains */
static int __Pyx_PySet_ContainsUnhashable(PyObject *set, PyObject *key) {
    int result = -1;
    if (PySet_Check(key) && PyErr_ExceptionMatches(PyExc_TypeError)) {
        PyObject *tmpkey;
        PyErr_Clear();
        tmpkey = __Pyx_PyFrozenSet_New(key);
        if (tmpkey != NULL) {
            result = PySet_Contains(set, tmpkey);
            Py_DECREF(tmpkey);
        }
    }
    return result;
}
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq) {
    int result = PySet_Contains(set, key);
    if (unlikely(result < 0)) {
        result = __Pyx_PySet_ContainsUnhashable(set, key);
    }
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* HasAttr */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* PyObjectCall2Args */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod1 */
#if !(CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2)
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_GetMethod;
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* SliceObject */
static CYTHON_INLINE int __Pyx_PyObject_SetSlice(PyObject* obj, PyObject* value,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_ass_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_ass_slice(obj, cstart, cstop, value);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_ass_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        int result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_ass_subscript(obj, py_slice, value);
#else
        result = value ? PyObject_SetItem(obj, py_slice, value) : PyObject_DelItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object does not support slice %.10s",
        obj_type_name, value ? "assignment" : "deletion");
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return -1;
}

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a == b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* IterNext */
static PyObject *__Pyx_PyIter_Next2Default(PyObject* defval) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (!defval || unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return NULL;
        __Pyx_PyErr_Clear();
        Py_INCREF(defval);
        return defval;
    }
    if (defval) {
        Py_INCREF(defval);
        return defval;
    }
    __Pyx_PyErr_SetNone(PyExc_StopIteration);
    return NULL;
}
static void __Pyx_PyIter_Next_ErrorNoIterator(PyObject *iterator) {
    __Pyx_TypeName iterator_type_name = __Pyx_PyType_GetName(Py_TYPE(iterator));
    PyErr_Format(PyExc_TypeError,
        __Pyx_FMT_TYPENAME " object is not an iterator", iterator_type_name);
    __Pyx_DECREF_TypeName(iterator_type_name);
}
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject* iterator, PyObject* defval) {
    PyObject* next;
    iternextfunc iternext = Py_TYPE(iterator)->tp_iternext;
    if (likely(iternext)) {
#if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
        next = iternext(iterator);
        if (likely(next))
            return next;
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
        if (unlikely(iternext == &_PyObject_NextNotImplemented))
            return NULL;
#endif
#else
        next = PyIter_Next(iterator);
        if (likely(next))
            return next;
#endif
    } else if (CYTHON_USE_TYPE_SLOTS || unlikely(!PyIter_Check(iterator))) {
        __Pyx_PyIter_Next_ErrorNoIterator(iterator);
        return NULL;
    }
#if !CYTHON_USE_TYPE_SLOTS
    else {
        next = PyIter_Next(iterator);
        if (likely(next))
            return next;
    }
#endif
    return __Pyx_PyIter_Next2Default(defval);
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        Py_ssize_t kwsize;
#if CYTHON_ASSUME_SAFE_MACROS
        kwsize = PyTuple_GET_SIZE(kw);
#else
        kwsize = PyTuple_Size(kw);
        if (kwsize < 0) return 0;
#endif
        if (unlikely(kwsize == 0))
            return 1;
        if (!kw_allowed) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, 0);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < kwsize; pos++) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, pos);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* SliceTupleAndList */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (length <= 0) {
        return PyList_New(0);
    }
    return __Pyx_PyList_FromArray(((PyListObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    return __Pyx_PyTuple_FromArray(((PyTupleObject*)src)->ob_item + start, length);
}
#endif

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (unlikely(!j)) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_ass_subscript) {
            int r;
            PyObject *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return -1;
            r = mm->mp_ass_subscript(o, key, v);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return sm->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* UnpackUnboundCMethod */
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    PyObject *result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
     METH_VARARGS | METH_KEYWORDS,
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #else
    if (likely(!__Pyx_CyOrPyCFunction_Check(method)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            target->method = unbound_method;
        }
    }
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if ((PY_VERSION_HEX >= 0x030600B1) && flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            #else
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            #endif
        } else if ((PY_VERSION_HEX >= 0x030700A0) && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    if (likely(cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
            return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, args, 2);
            #else
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
            #endif
        }
        #if PY_VERSION_HEX >= 0x030700A0
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
        #endif
    }
    return __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(3);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 1, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 2, arg2);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(3, self, arg1, arg2);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_LshiftObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        
            if (likely(b < (long) (sizeof(long)*8) && a == (a << b) >> b) || !a) {
                return PyInt_FromLong(a << b);
            }
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_lshift(op1, op2);
            }
        }
                x = a << b;
#ifdef HAVE_LONG_LONG
                if (unlikely(!(b < (long) (sizeof(long)*8) && a == x >> b)) && a) {
                    lla = a;
                    goto long_long;
                }
#else
                if (likely(b < (long) (sizeof(long)*8) && a == x >> b) || !a)
#endif
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla << llb;
                if (likely(lla == llx >> llb))
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    return (inplace ? PyNumber_InPlaceLshift : PyNumber_Lshift)(op1, op2);
}
#endif

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return with_error ? __Pyx_PyObject_GetAttrStr(obj, attr_name) : __Pyx_PyObject_GetAttrStrNoError(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* DelItemInt */
static int __Pyx_DelItem_Generic(PyObject *o, PyObject *j) {
    int r;
    if (unlikely(!j)) return -1;
    r = PyObject_DelItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_DelItemInt_Fast(PyObject *o, Py_ssize_t i,
                                               int is_list, CYTHON_NCP_UNUSED int wraparound) {
#if !CYTHON_USE_TYPE_SLOTS
    if (is_list || PySequence_Check(o)) {
        return PySequence_DelItem(o, i);
    }
#else
    PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
    PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
    if ((!is_list) && mm && mm->mp_ass_subscript) {
        PyObject *key = PyInt_FromSsize_t(i);
        return likely(key) ? mm->mp_ass_subscript(o, key, (PyObject *)NULL) : -1;
    }
    if (likely(sm && sm->sq_ass_item)) {
        if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
            Py_ssize_t l = sm->sq_length(o);
            if (likely(l >= 0)) {
                i += l;
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    return -1;
                PyErr_Clear();
            }
        }
        return sm->sq_ass_item(o, i, (PyObject *)NULL);
    }
#endif
    return __Pyx_DelItem_Generic(o, PyInt_FromSsize_t(i));
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            if (__Pyx_PyLong_IsZero(op1) == 1) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                Py_RETURN_FALSE;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 0;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a != b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) != 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 1;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 1;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal != 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a != (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* UnicodeAsUCS4 */
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject* x) {
   Py_ssize_t length;
   #if CYTHON_PEP393_ENABLED
   length = PyUnicode_GET_LENGTH(x);
   if (likely(length == 1)) {
       return PyUnicode_READ_CHAR(x, 0);
   }
   #else
   length = PyUnicode_GET_SIZE(x);
   if (likely(length == 1)) {
       return PyUnicode_AS_UNICODE(x)[0];
   }
   #if Py_UNICODE_SIZE == 2
   else if (PyUnicode_GET_SIZE(x) == 2) {
       Py_UCS4 high_val = PyUnicode_AS_UNICODE(x)[0];
       if (high_val >= 0xD800 && high_val <= 0xDBFF) {
           Py_UCS4 low_val = PyUnicode_AS_UNICODE(x)[1];
           if (low_val >= 0xDC00 && low_val <= 0xDFFF) {
               return 0x10000 + (((high_val & ((1<<10)-1)) << 10) | (low_val & ((1<<10)-1)));
           }
       }
   }
   #endif
   #endif
   PyErr_Format(PyExc_ValueError,
                "only single character unicode strings can be converted to Py_UCS4, "
                "got length %" CYTHON_FORMAT_SSIZE_T "d", length);
   return (Py_UCS4)-1;
}

/* object_ord */
static long __Pyx__PyObject_Ord(PyObject* c) {
    Py_ssize_t size;
    if (PyBytes_Check(c)) {
        size = PyBytes_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyBytes_AS_STRING(c)[0];
        }
#if PY_MAJOR_VERSION < 3
    } else if (PyUnicode_Check(c)) {
        return (long)__Pyx_PyUnicode_AsPy_UCS4(c);
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    } else if (PyByteArray_Check(c)) {
        size = PyByteArray_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyByteArray_AS_STRING(c)[0];
        }
#endif
    } else {
        __Pyx_TypeName c_type_name = __Pyx_PyType_GetName(Py_TYPE(c));
        PyErr_Format(PyExc_TypeError,
            "ord() expected string of length 1, but " __Pyx_FMT_TYPENAME " found",
            c_type_name);
        __Pyx_DECREF_TypeName(c_type_name);
        return (long)(Py_UCS4)-1;
    }
    PyErr_Format(PyExc_TypeError,
        "ord() expected a character, but string of length %zd found", size);
    return (long)(Py_UCS4)-1;
}

/* CallUnboundCMethod0 */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* py_dict_items */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_items, d);
    else
        return PyDict_Items(d);
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base, *meth, *new_base, *result, *new_bases = NULL;
    size_bases = PyTuple_GET_SIZE(bases);
    for (i = 0; i < size_bases; i++) {
        base  = PyTuple_GET_ITEM(bases, i);
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_n_s_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                base = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base);
                Py_INCREF(base);
            }
        }
        j = PyList_GET_SIZE(new_bases);
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
    return result;
error:
    Py_XDECREF(new_bases);
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_MACROS
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
#if PY_VERSION_HEX >= 0x03030000
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
#else
    CYTHON_MAYBE_UNUSED_VAR(qualname);
#endif
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
static int __Pyx_SetNamesPEP487(PyObject *type_obj) {
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *names_to_set, *key, *value, *set_name, *tmp;
    Py_ssize_t i = 0;
#if CYTHON_USE_TYPE_SLOTS
    names_to_set = PyDict_Copy(type->tp_dict);
#else
    {
        PyObject *d = PyObject_GetAttr(type_obj, __pyx_n_s_dict);
        names_to_set = NULL;
        if (likely(d)) {
            PyObject *names_to_set = PyDict_New();
            int ret = likely(names_to_set) ? PyDict_Update(names_to_set, d) : -1;
            Py_DECREF(d);
            if (unlikely(ret < 0))
                Py_CLEAR(names_to_set);
        }
    }
#endif
    if (unlikely(names_to_set == NULL))
        goto bad;
    while (PyDict_Next(names_to_set, &i, &key, &value)) {
        set_name = __Pyx_PyObject_LookupSpecialNoError(value, __pyx_n_s_set_name);
        if (unlikely(set_name != NULL)) {
            tmp = __Pyx_PyObject_Call2Args(set_name, type_obj, key);
            Py_DECREF(set_name);
            if (unlikely(tmp == NULL)) {
                __Pyx_TypeName value_type_name =
                    __Pyx_PyType_GetName(Py_TYPE(value));
                __Pyx_TypeName type_name = __Pyx_PyType_GetName(type);
                PyErr_Format(PyExc_RuntimeError,
#if PY_MAJOR_VERSION >= 3
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %R " "in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name, key, type_name);
#else
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %.100s in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name,
                    PyString_Check(key) ? PyString_AS_STRING(key) : "?",
                    type_name);
#endif
                goto bad;
            } else {
                Py_DECREF(tmp);
            }
        }
        else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
    Py_DECREF(names_to_set);
    return 0;
bad:
    Py_XDECREF(names_to_set);
    return -1;
}
static PyObject *__Pyx_InitSubclassPEP487(PyObject *type_obj, PyObject *mkw) {
#if CYTHON_USE_TYPE_SLOTS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *mro = type->tp_mro;
    Py_ssize_t i, nbases;
    if (unlikely(!mro)) goto done;
    (void) &__Pyx_GetBuiltinName;
    Py_INCREF(mro);
    nbases = PyTuple_GET_SIZE(mro);
    assert(PyTuple_GET_ITEM(mro, 0) == type_obj);
    for (i = 1; i < nbases-1; i++) {
        PyObject *base, *dict, *meth;
        base = PyTuple_GET_ITEM(mro, i);
        dict = ((PyTypeObject *)base)->tp_dict;
        meth = __Pyx_PyDict_GetItemStrWithError(dict, __pyx_n_s_init_subclass);
        if (unlikely(meth)) {
            descrgetfunc f = Py_TYPE(meth)->tp_descr_get;
            PyObject *res;
            Py_INCREF(meth);
            if (likely(f)) {
                res = f(meth, NULL, type_obj);
                Py_DECREF(meth);
                if (unlikely(!res)) goto bad;
                meth = res;
            }
            res = __Pyx_PyObject_FastCallDict(meth, NULL, 0, mkw);
            Py_DECREF(meth);
            if (unlikely(!res)) goto bad;
            Py_DECREF(res);
            goto done;
        } else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
done:
    Py_XDECREF(mro);
    return type_obj;
bad:
    Py_XDECREF(mro);
    Py_DECREF(type_obj);
    return NULL;
#else
    PyObject *super_type, *super, *func, *res;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    super_type = __Pyx_GetBuiltinName(__pyx_n_s_super);
#else
    super_type = (PyObject*) &PySuper_Type;
    (void) &__Pyx_GetBuiltinName;
#endif
    super = likely(super_type) ? __Pyx_PyObject_Call2Args(super_type, type_obj, type_obj) : NULL;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    Py_XDECREF(super_type);
#endif
    if (unlikely(!super)) {
        Py_CLEAR(type_obj);
        goto done;
    }
    func = __Pyx_PyObject_GetAttrStrNoError(super, __pyx_n_s_init_subclass);
    Py_DECREF(super);
    if (likely(!func)) {
        if (unlikely(PyErr_Occurred()))
            Py_CLEAR(type_obj);
        goto done;
    }
    res = __Pyx_PyObject_FastCallDict(func, NULL, 0, mkw);
    Py_DECREF(func);
    if (unlikely(!res))
        Py_CLEAR(type_obj);
    Py_XDECREF(res);
done:
    return type_obj;
#endif
}
#endif
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET,
#if PY_VERSION_HEX < 0x030600A4
        (metaclass == (PyObject*)&PyType_Type) ? NULL : mkw
#else
        mkw
#endif
    );
    Py_XDECREF(owned_metaclass);
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
    if (likely(result) && likely(PyType_Check(result))) {
        if (unlikely(__Pyx_SetNamesPEP487(result) < 0)) {
            Py_CLEAR(result);
        } else {
            result = __Pyx_InitSubclassPEP487(result, mkw);
        }
    }
#else
    (void) &__Pyx_GetBuiltinName;
#endif
    return result;
}

/* pop */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L) {
    if (__Pyx_IS_TYPE(L, &PySet_Type)) {
        return PySet_Pop(L);
    }
    return __Pyx_PyObject_CallMethod0(L, __pyx_n_s_pop);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L) {
    if (likely(PyList_GET_SIZE(L) > (((PyListObject*)L)->allocated >> 1))) {
        __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
        return PyList_GET_ITEM(L, PyList_GET_SIZE(L));
    }
    return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyList_Type_pop, L);
}
#endif

/* ValidateBasesTuple */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_MACROS
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (n < 0) return -1;
#endif
    for (i = 1; i < n; i++)
    {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#if !CYTHON_USE_TYPE_SLOTS
        if (dictoffset == 0) {
            PyErr_Format(PyExc_TypeError,
                "extension type '%s.200s': "
                "unable to validate whether bases have a __dict__ "
                "when CYTHON_USE_TYPE_SLOTS is off "
                "(likely because you are building in the limited API). "
                "Therefore, all extension types with multiple bases "
                "must add 'cdef dict __dict__' in this compilation mode",
                type_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#else
        if (dictoffset == 0 && b->tp_dictoffset)
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "extension type '%.200s' has no __dict__ slot, "
                "but base type '" __Pyx_FMT_TYPENAME "' has: "
                "either add 'cdef dict __dict__' to the extension type "
                "or add '__slots__ = [...]' to the base type",
                type_name, b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__117);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    #if PY_MAJOR_VERSION == 2
    static PyTypeObject *methoddescr_type = NULL;
    if (unlikely(methoddescr_type == NULL)) {
       PyObject *meth = PyObject_GetAttrString((PyObject*)&PyList_Type, "append");
       if (unlikely(!meth)) return NULL;
       methoddescr_type = Py_TYPE(meth);
       Py_DECREF(meth);
    }
    #else
    PyTypeObject *methoddescr_type = &PyMethodDescr_Type;
    #endif
    if (__Pyx_TypeCheck(method, methoddescr_type))
#endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        #if PY_VERSION_HEX < 0x03020000
        PyTypeObject *d_type = descr->d_type;
        #else
        PyTypeObject *d_type = descr->d_common.d_type;
        #endif
        return PyDescr_NewClassMethod(d_type, descr->d_method);
    }
#endif
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
}

/* SetNewInClass */
static int __Pyx_SetNewInClass(PyObject *ns, PyObject *name, PyObject *value) {
#ifdef __Pyx_CyFunction_USED
    int ret;
    if (__Pyx_CyFunction_Check(value)) {
        PyObject *staticnew = PyStaticMethod_New(value);
        if (unlikely(!staticnew)) return -1;
        ret = __Pyx_SetNameInClass(ns, name, staticnew);
        Py_DECREF(staticnew);
        return ret;
    }
#endif
    return __Pyx_SetNameInClass(ns, name, value);
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        
#ifdef HAVE_LONG_LONG
            if (sizeof(PY_LONG_LONG) > sizeof(long)) {
                PY_LONG_LONG result = (PY_LONG_LONG)a * (PY_LONG_LONG)b;
                return (result >= LONG_MIN && result <= LONG_MAX) ?
                    PyInt_FromLong((long)result) : PyLong_FromLongLong(result);
            }
#endif
#if CYTHON_USE_TYPE_SLOTS
            return PyInt_Type.tp_as_number->nb_multiply(op1, op2);
#else
            return PyNumber_Multiply(op1, op2);
#endif
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
            }
        }
                CYTHON_UNUSED_VAR(a);
                CYTHON_UNUSED_VAR(b);
                #ifdef HAVE_LONG_LONG
                lla = a;
                goto long_long;
                #else
                return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
                #endif
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla * llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("multiply", return NULL)
            result = ((double)a) * (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceMultiply : PyNumber_Multiply)(op1, op2);
}
#endif

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* BaseCaseSigned */
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
static CYTHON_INLINE int __Pyx_add_int_checking_overflow(int a, int b, int *overflow) {
    int result;
    *overflow |= __builtin_add_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE int __Pyx_sub_int_checking_overflow(int a, int b, int *overflow) {
    int result;
    *overflow |= __builtin_sub_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE int __Pyx_mul_int_checking_overflow(int a, int b, int *overflow) {
    int result;
    *overflow |= __builtin_mul_overflow(a, b, &result);
    return result;
}
#else
static CYTHON_INLINE int __Pyx_add_int_checking_overflow(int a, int b, int *overflow) {
    if ((sizeof(int) < sizeof(long))) {
        long big_r = ((long) a) + ((long) b);
        int r = (int) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if ((sizeof(int) < sizeof(PY_LONG_LONG))) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) + ((PY_LONG_LONG) b);
        int r = (int) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        unsigned int r = (unsigned int) a + (unsigned int) b;
        *overflow |= (((unsigned int)a ^ r) & ((unsigned int)b ^ r)) >> (8 * sizeof(int) - 1);
        return (int) r;
    }
}
static CYTHON_INLINE int __Pyx_sub_int_checking_overflow(int a, int b, int *overflow) {
    unsigned int r = (unsigned int) a - (unsigned int) b;
    *overflow |= (((unsigned int)a ^ (unsigned int)b) & ((unsigned int)a ^ r)) >> (8 * sizeof(int) - 1);
    return (int) r;
}
static CYTHON_INLINE int __Pyx_mul_int_checking_overflow(int a, int b, int *overflow) {
    if (__Pyx_is_constant(b)) {
        return __Pyx_mul_const_int_checking_overflow(a, b, overflow);
    } else if (__Pyx_is_constant(a)) {
        return __Pyx_mul_const_int_checking_overflow(b, a, overflow);
    } else if ((sizeof(int) < sizeof(long))) {
        long big_r = ((long) a) * ((long) b);
        int r = (int) big_r;
        *overflow |= big_r != r;
        return (int) r;
#ifdef HAVE_LONG_LONG
    } else if ((sizeof(int) < sizeof(PY_LONG_LONG))) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) * ((PY_LONG_LONG) b);
        int r = (int) big_r;
        *overflow |= big_r != r;
        return (int) r;
#endif
    } else {
        return __Pyx_mul_const_int_checking_overflow(a, b, overflow);
    }
}
static CYTHON_INLINE int __Pyx_mul_const_int_checking_overflow(int a, int b, int *overflow) {
    if (__Pyx_is_constant(a) && !__Pyx_is_constant(b)) {
        int temp = b;
        b = a;
        a = temp;
    }
    if (b > 1) {
        *overflow |= a > __PYX_MAX(int) / b;
        *overflow |= a < __PYX_MIN(int) / b;
    } else if (b == -1) {
        *overflow |= a == __PYX_MIN(int);
    } else if (b < -1) {
        *overflow |= a > __PYX_MIN(int) / b;
        *overflow |= a < __PYX_MAX(int) / b;
    }
    return (int) (((unsigned int)a) * ((unsigned int) b));
}
#endif  // defined(__PYX_HAVE_BUILTIN_OVERFLOW)
static CYTHON_INLINE int __Pyx_div_int_checking_overflow(int a, int b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    *overflow |= a == __PYX_MIN(int) && b == -1;
    return (int) ((unsigned int) a / (unsigned int) b);
}

/* BaseCaseSigned */
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
static CYTHON_INLINE long __Pyx_add_long_checking_overflow(long a, long b, int *overflow) {
    long result;
    *overflow |= __builtin_add_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE long __Pyx_sub_long_checking_overflow(long a, long b, int *overflow) {
    long result;
    *overflow |= __builtin_sub_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE long __Pyx_mul_long_checking_overflow(long a, long b, int *overflow) {
    long result;
    *overflow |= __builtin_mul_overflow(a, b, &result);
    return result;
}
#else
static CYTHON_INLINE long __Pyx_add_long_checking_overflow(long a, long b, int *overflow) {
    if ((sizeof(long) < sizeof(long))) {
        long big_r = ((long) a) + ((long) b);
        long r = (long) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if ((sizeof(long) < sizeof(PY_LONG_LONG))) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) + ((PY_LONG_LONG) b);
        long r = (long) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        unsigned long r = (unsigned long) a + (unsigned long) b;
        *overflow |= (((unsigned long)a ^ r) & ((unsigned long)b ^ r)) >> (8 * sizeof(long) - 1);
        return (long) r;
    }
}
static CYTHON_INLINE long __Pyx_sub_long_checking_overflow(long a, long b, int *overflow) {
    unsigned long r = (unsigned long) a - (unsigned long) b;
    *overflow |= (((unsigned long)a ^ (unsigned long)b) & ((unsigned long)a ^ r)) >> (8 * sizeof(long) - 1);
    return (long) r;
}
static CYTHON_INLINE long __Pyx_mul_long_checking_overflow(long a, long b, int *overflow) {
    if (__Pyx_is_constant(b)) {
        return __Pyx_mul_const_long_checking_overflow(a, b, overflow);
    } else if (__Pyx_is_constant(a)) {
        return __Pyx_mul_const_long_checking_overflow(b, a, overflow);
    } else if ((sizeof(long) < sizeof(long))) {
        long big_r = ((long) a) * ((long) b);
        long r = (long) big_r;
        *overflow |= big_r != r;
        return (long) r;
#ifdef HAVE_LONG_LONG
    } else if ((sizeof(long) < sizeof(PY_LONG_LONG))) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) * ((PY_LONG_LONG) b);
        long r = (long) big_r;
        *overflow |= big_r != r;
        return (long) r;
#endif
    } else {
        return __Pyx_mul_const_long_checking_overflow(a, b, overflow);
    }
}
static CYTHON_INLINE long __Pyx_mul_const_long_checking_overflow(long a, long b, int *overflow) {
    if (__Pyx_is_constant(a) && !__Pyx_is_constant(b)) {
        long temp = b;
        b = a;
        a = temp;
    }
    if (b > 1) {
        *overflow |= a > __PYX_MAX(long) / b;
        *overflow |= a < __PYX_MIN(long) / b;
    } else if (b == -1) {
        *overflow |= a == __PYX_MIN(long);
    } else if (b < -1) {
        *overflow |= a > __PYX_MIN(long) / b;
        *overflow |= a < __PYX_MAX(long) / b;
    }
    return (long) (((unsigned long)a) * ((unsigned long) b));
}
#endif  // defined(__PYX_HAVE_BUILTIN_OVERFLOW)
static CYTHON_INLINE long __Pyx_div_long_checking_overflow(long a, long b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    *overflow |= a == __PYX_MIN(long) && b == -1;
    return (long) ((unsigned long) a / (unsigned long) b);
}

/* BaseCaseSigned */
#ifdef HAVE_LONG_LONG
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
static CYTHON_INLINE long long __Pyx_add_long_long_checking_overflow(long long a, long long b, int *overflow) {
    long long result;
    *overflow |= __builtin_add_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE long long __Pyx_sub_long_long_checking_overflow(long long a, long long b, int *overflow) {
    long long result;
    *overflow |= __builtin_sub_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE long long __Pyx_mul_long_long_checking_overflow(long long a, long long b, int *overflow) {
    long long result;
    *overflow |= __builtin_mul_overflow(a, b, &result);
    return result;
}
#else
static CYTHON_INLINE long long __Pyx_add_long_long_checking_overflow(long long a, long long b, int *overflow) {
    if ((sizeof(long long) < sizeof(long))) {
        long big_r = ((long) a) + ((long) b);
        long long r = (long long) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if ((sizeof(long long) < sizeof(PY_LONG_LONG))) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) + ((PY_LONG_LONG) b);
        long long r = (long long) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        unsigned long long r = (unsigned long long) a + (unsigned long long) b;
        *overflow |= (((unsigned long long)a ^ r) & ((unsigned long long)b ^ r)) >> (8 * sizeof(long long) - 1);
        return (long long) r;
    }
}
static CYTHON_INLINE long long __Pyx_sub_long_long_checking_overflow(long long a, long long b, int *overflow) {
    unsigned long long r = (unsigned long long) a - (unsigned long long) b;
    *overflow |= (((unsigned long long)a ^ (unsigned long long)b) & ((unsigned long long)a ^ r)) >> (8 * sizeof(long long) - 1);
    return (long long) r;
}
static CYTHON_INLINE long long __Pyx_mul_long_long_checking_overflow(long long a, long long b, int *overflow) {
    if (__Pyx_is_constant(b)) {
        return __Pyx_mul_const_long_long_checking_overflow(a, b, overflow);
    } else if (__Pyx_is_constant(a)) {
        return __Pyx_mul_const_long_long_checking_overflow(b, a, overflow);
    } else if ((sizeof(long long) < sizeof(long))) {
        long big_r = ((long) a) * ((long) b);
        long long r = (long long) big_r;
        *overflow |= big_r != r;
        return (long long) r;
#ifdef HAVE_LONG_LONG
    } else if ((sizeof(long long) < sizeof(PY_LONG_LONG))) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) * ((PY_LONG_LONG) b);
        long long r = (long long) big_r;
        *overflow |= big_r != r;
        return (long long) r;
#endif
    } else {
        return __Pyx_mul_const_long_long_checking_overflow(a, b, overflow);
    }
}
static CYTHON_INLINE long long __Pyx_mul_const_long_long_checking_overflow(long long a, long long b, int *overflow) {
    if (__Pyx_is_constant(a) && !__Pyx_is_constant(b)) {
        long long temp = b;
        b = a;
        a = temp;
    }
    if (b > 1) {
        *overflow |= a > __PYX_MAX(long long) / b;
        *overflow |= a < __PYX_MIN(long long) / b;
    } else if (b == -1) {
        *overflow |= a == __PYX_MIN(long long);
    } else if (b < -1) {
        *overflow |= a > __PYX_MIN(long long) / b;
        *overflow |= a < __PYX_MAX(long long) / b;
    }
    return (long long) (((unsigned long long)a) * ((unsigned long long) b));
}
#endif  // defined(__PYX_HAVE_BUILTIN_OVERFLOW)
static CYTHON_INLINE long long __Pyx_div_long_long_checking_overflow(long long a, long long b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    *overflow |= a == __PYX_MIN(long long) && b == -1;
    return (long long) ((unsigned long long) a / (unsigned long long) b);
}
#endif

/* BaseCaseUnsigned */
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
static CYTHON_INLINE unsigned int __Pyx_add_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    unsigned int result;
    *overflow |= __builtin_add_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE unsigned int __Pyx_sub_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    unsigned int result;
    *overflow |= __builtin_sub_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE unsigned int __Pyx_mul_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    unsigned int result;
    *overflow |= __builtin_mul_overflow(a, b, &result);
    return result;
}
#else
static CYTHON_INLINE unsigned int __Pyx_add_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    unsigned int r = a + b;
    *overflow |= r < a;
    return r;
}
static CYTHON_INLINE unsigned int __Pyx_sub_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    unsigned int r = a - b;
    *overflow |= r > a;
    return r;
}
static CYTHON_INLINE unsigned int __Pyx_mul_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    if (__Pyx_is_constant(b)) {
        return __Pyx_mul_const_unsigned_int_checking_overflow(a, b, overflow);
    } else if (__Pyx_is_constant(a)) {
        return __Pyx_mul_const_unsigned_int_checking_overflow(b, a, overflow);
    } else if ((sizeof(unsigned int) < sizeof(unsigned long))) {
        unsigned long big_r = ((unsigned long) a) * ((unsigned long) b);
        unsigned int r = (unsigned int) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if ((sizeof(unsigned int) < sizeof(unsigned PY_LONG_LONG))) {
        unsigned PY_LONG_LONG big_r = ((unsigned PY_LONG_LONG) a) * ((unsigned PY_LONG_LONG) b);
        unsigned int r = (unsigned int) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        return __Pyx_mul_const_unsigned_int_checking_overflow(a, b, overflow);
    }
}
static CYTHON_INLINE unsigned int __Pyx_mul_const_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    unsigned int prod;
    if (__Pyx_is_constant(a) && !__Pyx_is_constant(b)) {
        unsigned int temp = b;
        b = a;
        a = temp;
    }
    prod = a * b;
    if (b != 0)
        *overflow |= a > (__PYX_MAX(unsigned int) / b);
    return prod;
}
#endif // __PYX_HAVE_BUILTIN_OVERFLOW
static CYTHON_INLINE unsigned int __Pyx_div_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    return a / b;
}

/* BaseCaseUnsigned */
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
static CYTHON_INLINE unsigned long __Pyx_add_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    unsigned long result;
    *overflow |= __builtin_add_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE unsigned long __Pyx_sub_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    unsigned long result;
    *overflow |= __builtin_sub_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE unsigned long __Pyx_mul_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    unsigned long result;
    *overflow |= __builtin_mul_overflow(a, b, &result);
    return result;
}
#else
static CYTHON_INLINE unsigned long __Pyx_add_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    unsigned long r = a + b;
    *overflow |= r < a;
    return r;
}
static CYTHON_INLINE unsigned long __Pyx_sub_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    unsigned long r = a - b;
    *overflow |= r > a;
    return r;
}
static CYTHON_INLINE unsigned long __Pyx_mul_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    if (__Pyx_is_constant(b)) {
        return __Pyx_mul_const_unsigned_long_checking_overflow(a, b, overflow);
    } else if (__Pyx_is_constant(a)) {
        return __Pyx_mul_const_unsigned_long_checking_overflow(b, a, overflow);
    } else if ((sizeof(unsigned long) < sizeof(unsigned long))) {
        unsigned long big_r = ((unsigned long) a) * ((unsigned long) b);
        unsigned long r = (unsigned long) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if ((sizeof(unsigned long) < sizeof(unsigned PY_LONG_LONG))) {
        unsigned PY_LONG_LONG big_r = ((unsigned PY_LONG_LONG) a) * ((unsigned PY_LONG_LONG) b);
        unsigned long r = (unsigned long) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        return __Pyx_mul_const_unsigned_long_checking_overflow(a, b, overflow);
    }
}
static CYTHON_INLINE unsigned long __Pyx_mul_const_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    unsigned long prod;
    if (__Pyx_is_constant(a) && !__Pyx_is_constant(b)) {
        unsigned long temp = b;
        b = a;
        a = temp;
    }
    prod = a * b;
    if (b != 0)
        *overflow |= a > (__PYX_MAX(unsigned long) / b);
    return prod;
}
#endif // __PYX_HAVE_BUILTIN_OVERFLOW
static CYTHON_INLINE unsigned long __Pyx_div_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    return a / b;
}

/* BaseCaseUnsigned */
#if defined(__PYX_HAVE_BUILTIN_OVERFLOW)
static CYTHON_INLINE unsigned long long __Pyx_add_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    unsigned long long result;
    *overflow |= __builtin_add_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE unsigned long long __Pyx_sub_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    unsigned long long result;
    *overflow |= __builtin_sub_overflow(a, b, &result);
    return result;
}
static CYTHON_INLINE unsigned long long __Pyx_mul_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    unsigned long long result;
    *overflow |= __builtin_mul_overflow(a, b, &result);
    return result;
}
#else
static CYTHON_INLINE unsigned long long __Pyx_add_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    unsigned long long r = a + b;
    *overflow |= r < a;
    return r;
}
static CYTHON_INLINE unsigned long long __Pyx_sub_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    unsigned long long r = a - b;
    *overflow |= r > a;
    return r;
}
static CYTHON_INLINE unsigned long long __Pyx_mul_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    if (__Pyx_is_constant(b)) {
        return __Pyx_mul_const_unsigned_long_long_checking_overflow(a, b, overflow);
    } else if (__Pyx_is_constant(a)) {
        return __Pyx_mul_const_unsigned_long_long_checking_overflow(b, a, overflow);
    } else if ((sizeof(unsigned long long) < sizeof(unsigned long))) {
        unsigned long big_r = ((unsigned long) a) * ((unsigned long) b);
        unsigned long long r = (unsigned long long) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if ((sizeof(unsigned long long) < sizeof(unsigned PY_LONG_LONG))) {
        unsigned PY_LONG_LONG big_r = ((unsigned PY_LONG_LONG) a) * ((unsigned PY_LONG_LONG) b);
        unsigned long long r = (unsigned long long) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        return __Pyx_mul_const_unsigned_long_long_checking_overflow(a, b, overflow);
    }
}
static CYTHON_INLINE unsigned long long __Pyx_mul_const_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    unsigned long long prod;
    if (__Pyx_is_constant(a) && !__Pyx_is_constant(b)) {
        unsigned long long temp = b;
        b = a;
        a = temp;
    }
    prod = a * b;
    if (b != 0)
        *overflow |= a > (__PYX_MAX(unsigned long long) / b);
    return prod;
}
#endif // __PYX_HAVE_BUILTIN_OVERFLOW
static CYTHON_INLINE unsigned long long __Pyx_div_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    return a / b;
}

/* Binop */
static CYTHON_INLINE Py_ssize_t __Pyx_sub_const_Py_ssize_t_checking_overflow(Py_ssize_t a, Py_ssize_t b, int *overflow) {
    if ((sizeof(Py_ssize_t) < sizeof(int))) {
        return __Pyx_sub_const_no_overflow(a, b, overflow);
    } else if (__PYX_IS_UNSIGNED(Py_ssize_t)) {
        if ((sizeof(Py_ssize_t) == sizeof(unsigned int))) {
            return (Py_ssize_t) __Pyx_sub_const_unsigned_int_checking_overflow(a, b, overflow);
        } else if ((sizeof(Py_ssize_t) == sizeof(unsigned long))) {
            return (Py_ssize_t) __Pyx_sub_const_unsigned_long_checking_overflow(a, b, overflow);
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(Py_ssize_t) == sizeof(unsigned PY_LONG_LONG))) {
            return (Py_ssize_t) __Pyx_sub_const_unsigned_long_long_checking_overflow(a, b, overflow);
#endif
        } else {
            abort(); return 0;
        }
    } else {
        if ((sizeof(Py_ssize_t) == sizeof(int))) {
            return (Py_ssize_t) __Pyx_sub_const_int_checking_overflow(a, b, overflow);
        } else if ((sizeof(Py_ssize_t) == sizeof(long))) {
            return (Py_ssize_t) __Pyx_sub_const_long_checking_overflow(a, b, overflow);
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(Py_ssize_t) == sizeof(PY_LONG_LONG))) {
            return (Py_ssize_t) __Pyx_sub_const_long_long_checking_overflow(a, b, overflow);
#endif
        } else {
            abort(); return 0;
        }
    }
}

/* Binop */
static CYTHON_INLINE Py_ssize_t __Pyx_sub_Py_ssize_t_checking_overflow(Py_ssize_t a, Py_ssize_t b, int *overflow) {
    if ((sizeof(Py_ssize_t) < sizeof(int))) {
        return __Pyx_sub_no_overflow(a, b, overflow);
    } else if (__PYX_IS_UNSIGNED(Py_ssize_t)) {
        if ((sizeof(Py_ssize_t) == sizeof(unsigned int))) {
            return (Py_ssize_t) __Pyx_sub_unsigned_int_checking_overflow(a, b, overflow);
        } else if ((sizeof(Py_ssize_t) == sizeof(unsigned long))) {
            return (Py_ssize_t) __Pyx_sub_unsigned_long_checking_overflow(a, b, overflow);
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(Py_ssize_t) == sizeof(unsigned PY_LONG_LONG))) {
            return (Py_ssize_t) __Pyx_sub_unsigned_long_long_checking_overflow(a, b, overflow);
#endif
        } else {
            abort(); return 0;
        }
    } else {
        if ((sizeof(Py_ssize_t) == sizeof(int))) {
            return (Py_ssize_t) __Pyx_sub_int_checking_overflow(a, b, overflow);
        } else if ((sizeof(Py_ssize_t) == sizeof(long))) {
            return (Py_ssize_t) __Pyx_sub_long_checking_overflow(a, b, overflow);
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(Py_ssize_t) == sizeof(PY_LONG_LONG))) {
            return (Py_ssize_t) __Pyx_sub_long_long_checking_overflow(a, b, overflow);
#endif
        } else {
            abort(); return 0;
        }
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_n_s__893);
    }
    return name;
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                                return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                                return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                                return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(long) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(long) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (long) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (long) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (long) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (long) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (long) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((long) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((long) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                                return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                                return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                                return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(int) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(int) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (int) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (int) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (int) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (int) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (int) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((int) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((int) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CoroutineBase */
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(PyObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body(self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(PyObject* gen, PyObject *retval) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
#if PY_VERSION_HEX < 0x030d00A1
            _PyGen_SetStopIterationValue(result);
#else
            if (!PyTuple_Check(result) && !PyExceptionInstance_Check(result)) {
                PyErr_SetObject(PyExc_StopIteration, result);
            } else {
                PyObject *exc = __Pyx_PyObject_CallOneArg(PyExc_StopIteration, result);
                if (likely(exc != NULL)) {
                    PyErr_SetObject(PyExc_StopIteration, exc);
                    Py_DECREF(exc);
                }
            }
#endif
        }
        Py_DECREF(result);
        result = NULL;
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval))
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    gen->is_running = 0;
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        Py_TYPE(gen)->tp_del(self);
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(Py_REFCNT(self) > 0);
    if (likely(--self->ob_refcnt == 0)) {
        return;
    }
    {
        Py_ssize_t refcnt = Py_REFCNT(self);
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(Py_TYPE(self)) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context)
{
    PyObject *frame = self->gi_frame;
    CYTHON_UNUSED_VAR(context);
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            __pyx_d,                 /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        if (unlikely(!frame))
            return NULL;
        self->gi_frame = frame;
    }
    Py_INCREF(frame);
    return frame;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (unlikely(!module)) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {(char *) "gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the generator"), 0},
    {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) __Pyx_PyObject_GenericGetAttrNoDict},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    __pyx_GeneratorType_slots
};
#else
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_Generator_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_GeneratorType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
#endif
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
